SECTION "bank0",HOME
SECTION "rst0",HOME[$0]
	di
	jp Start

SECTION "rst8",HOME[$8]
	jp $2d63

SECTION "rst10",HOME[$10] ; Bankswitch
	ld [$ff9d], a
	ld [$2000], a
	ret

SECTION "rst18",HOME[$18] ; Unused
	rst $38

SECTION "rst20",HOME[$20] ; Unused
	rst $38

SECTION "rst28",HOME[$28] ; Jump from pointer table
	push de
	ld e, a
	ld d, 00
	add hl, de
	add hl, de
	ld a, [hli]
	ld h, [hl]
	ld l, a
	pop de
	jp [hl] ; (actually jp hl)

; rst30 is midst rst28

SECTION "rst38",HOME[$38] ; Unused
	rst $38

SECTION "vblank",HOME[$40] ; vblank interrupt
	jp $0283

SECTION "lcd",HOME[$48] ; lcd interrupt
	jp $0552

SECTION "timer",HOME[$50] ; timer interrupt
	jp $3e93

SECTION "serial",HOME[$58] ; serial interrupt
	jp $06ef

SECTION "joypad",HOME[$60] ; joypad interrupt
	jp $092e

SECTION "romheader",HOME[$100]
Start:
	nop
	jp $016e

SECTION "start",HOME[$150]

INCBIN "baserom.gbc",$150,$45a - $150

DelayFrame: ; 0x45a
; delay for one frame
	ld a, $1
	ld [$cfb3], a ; was H_VBLANKOCCURRED

; wait for the next Vblank, halting to conserve battery
.halt\@
	db $76, $00 ; XXX this is a hack--rgbasm adds a nop after this instr even when ints are enabled
	ld a, [$cfb3]
	and a
	jr nz, .halt\@ ; 0x465 $f8
	ret
; 0x468

DelayFrames: ; 0x468
; wait n frames, where n is the value in c
	call DelayFrame
	dec c
	jr nz, DelayFrames
	ret
; 0x46f

RTC: ; 46f
; update time and time-sensitive palettes

; rtc enabled?
	ld a, [$c2ce]
	cp $0
	ret z
	
; update clock
	call UpdateTime
	
; obj update on?
	ld a, [VramState]
	bit 0, a ; obj update
	ret z
	
; update palettes
	callab TimeOfDayPals
	ret
; 485

INCBIN "baserom.gbc",$485,$52f - $485

IncGradGBPalTable_01: ; 52f
	db %11111111 ; bgp
	db %11111111 ; obp1
	db %11111111 ; obp2
	             ; and so on...
	db %11111110
	db %11111110
	db %11111000

	db %11111001
	db %11100100
	db %11100100
	
	db %11100100
	db %11010000
	db %11100000
	
	db %11100100
	db %11010000
	db %11100000
	
	db %10010000
	db %10000000
	db %10010000
	
	db %01000000
	db %01000000
	db %01000000
	
	db %00000000
	db %00000000
	db %00000000
; 547

INCBIN "baserom.gbc",$547,$568 - $547

DisableLCD: ; 568
; don't need to do anything if lcd is already off
	ld a, [$ff40] ; LCDC
	bit 7, a ; lcd enable
	ret z
	
; reset ints
	xor a
	ld [$ff0f], a ; IF
	
; save enabled ints
	ld a, [$ffff] ; IE
	ld b, a
	
; disable vblank
	res 0, a ; vblank
	ld [$ffff], a ; IE
	
.wait
; wait until vblank
	ld a, [$ff44] ; LY
	cp 145 ; >144 (ensure beginning of vblank)
	jr nz, .wait
	
; turn lcd off
	ld a, [$ff40] ; LCDC
	and %01111111 ; lcd enable off
	ld [$ff40], a ; LCDC
	
; reset ints
	xor a
	ld [$ff0f], a ; IF
	
; restore enabled ints
	ld a, b
	ld [$ffff], a ; IE
	ret
; 58a

EnableLCD: ; 58a
	ld a, [$ff40] ; LCDC
	set 7, a ; lcd enable
	ld [$ff40], a ; LCDC
	ret
; 591

AskTimer: ; 591
	INCBIN "baserom.gbc",$591,$59c - $591
; 59c

LatchClock: ; 59c
; latch clock counter data
	ld a, $0
	ld [$6000], a
	ld a, $1
	ld [$6000], a
	ret
; 5a7

UpdateTime: ; 5a7
; get rtc data
	call GetClock
; condense days to one byte, update rtc w/ new day count
	call FixDays
; add game time to rtc time
	call FixTime
; update time of day (0 = morn, 1 = day, 2 = nite)
	callba GetTimeOfDay
	ret
; 5b7

GetClock: ; 5b7
; store clock data in $ff8d-$ff91

; enable clock r/w
	ld a, $a
	ld [$0000], a
	
; get clock data
; stored 'backwards' in hram
	
	call LatchClock
	ld hl, $4000
	ld de, $a000
	
; seconds
	ld [hl], $8 ; S
	ld a, [de]
	and $3f
	ld [$ff91], a
; minutes
	ld [hl], $9 ; M
	ld a, [de]
	and $3f
	ld [$ff90], a
; hours
	ld [hl], $a ; H
	ld a, [de]
	and $1f
	ld [$ff8f], a
; day lo
	ld [hl], $b ; DL
	ld a, [de]
	ld [$ff8e], a
; day hi
	ld [hl], $c ; DH
	ld a, [de]
	ld [$ff8d], a
	
; cleanup
	call CloseSRAM ; unlatch clock, disable clock r/w
	ret
; 5e8


FixDays: ; 5e8
; fix day count
; mod by 140

; check if day count > 255 (bit 8 set)
	ld a, [$ff8d] ; DH
	bit 0, a
	jr z, .daylo
; reset dh (bit 8)
	res 0, a
	ld [$ff8d], a ; DH
	
; mod 140
; mod twice since bit 8 (DH) was set
	ld a, [$ff8e] ; DL
.modh
	sub 140
	jr nc, .modh
.modl
	sub 140
	jr nc, .modl
	add 140
	
; update dl
	ld [$ff8e], a ; DL

; unknown output
	ld a, $40 ; %1000000
	jr .set

.daylo
; quit if fewer than 140 days have passed
	ld a, [$ff8e] ; DL
	cp 140
	jr c, .quit
	
; mod 140
.mod
	sub 140
	jr nc, .mod
	add 140
	
; update dl
	ld [$ff8e], a ; DL
	
; unknown output
	ld a, $20 ; %100000
	
.set
; update clock with modded day value
	push af
	call SetClock
	pop af
	scf
	ret
	
.quit
	xor a
	ret
; 61d


FixTime: ; 61d
; add ingame time (set at newgame) to current time
;				  day     hr    min    sec
; store time in CurDay, $ff94, $ff96, $ff98

; second
	ld a, [$ff91] ; S
	ld c, a
	ld a, [StartSecond]
	add c
	sub 60
	jr nc, .updatesec
	add 60
.updatesec
	ld [$ff98], a
	
; minute
	ccf ; carry is set, so turn it off
	ld a, [$ff90] ; M
	ld c, a
	ld a, [StartMinute]
	adc c
	sub 60
	jr nc, .updatemin
	add 60
.updatemin
	ld [$ff96], a
	
; hour
	ccf ; carry is set, so turn it off
	ld a, [$ff8f] ; H
	ld c, a
	ld a, [StartHour]
	adc c
	sub 24
	jr nc, .updatehr
	add 24
.updatehr
	ld [$ff94], a
	
; day
	ccf ; carry is set, so turn it off
	ld a, [$ff8e] ; DL
	ld c, a
	ld a, [StartDay]
	adc c
	ld [CurDay], a
	ret
; 658


INCBIN "baserom.gbc",$658,$691 - $658


SetClock: ; 691
; set clock data from hram

; enable clock r/w
	ld a, $a
	ld [$0000], a
	
; set clock data
; stored 'backwards' in hram

	call LatchClock
	ld hl, $4000
	ld de, $a000
	
; seems to be a halt check that got partially commented out
; this block is totally pointless
	ld [hl], $c
	ld a, [de]
	bit 6, a ; halt
	ld [de], a
	
; seconds
	ld [hl], $8 ; S
	ld a, [$ff91]
	ld [de], a
; minutes
	ld [hl], $9 ; M
	ld a, [$ff90]
	ld [de], a
; hours
	ld [hl], $a ; H
	ld a, [$ff8f]
	ld [de], a
; day lo
	ld [hl], $b ; DL
	ld a, [$ff8e]
	ld [de], a
; day hi
	ld [hl], $c ; DH
	ld a, [$ff8d]
	res 6, a ; make sure timer is active
	ld [de], a
	
; cleanup
	call CloseSRAM ; unlatch clock, disable clock r/w
	ret
; 6c4

INCBIN "baserom.gbc",$6c4,$984 - $6c4

GetJoypadPublic: ; 984
; update mirror joypad input from $ffa4 (real input)

; $ffa6: released
; $ffa7: pressed
; $ffa8: input

; bit 0 A
;     1 B
;     2 SELECT
;     3 START
;     4 RIGHT
;     5 LEFT
;     6 UP
;     7 DOWN

	push af
	push hl
	push de
	push bc
	
; automated input?
	ld a, [InputType]
	cp a, $ff ; INPUT_AUTO
	jr z, .auto

; get input
	ld a, [$ffa4] ; real input
	ld b, a
	ld a, [$ffa8] ; last frame mirror
	ld e, a
	
; released
	xor b
	ld d, a
	and e
	ld [$ffa6], a
	
; pressed
	ld a, d
	and b
	ld [$ffa7], a
	
; leftover from pasted code
	ld c, a
	
;
	ld a, b
	ld [$ffa8], a ; frame input
.quit
	pop bc
	pop de
	pop hl
	pop af
	ret	

.auto
; use predetermined input feed (used in catch tutorial)
; struct: [input][duration]

; save bank
	ld a, [$ff9d]
	push af
;
	ld a, [AutoInputBank]
	rst $10
;
	ld hl, AutoInputAddress ; AutoInputAddress-9
	ld a, [hli]
	ld h, [hl]
	ld l, a
	
; update when frame count hits 0
	ld a, [AutoInputLength]
	and a
	jr z, .updateauto
	
; until then, do nothing
	dec a
	ld [AutoInputLength], a
; restore bank
	pop af
	rst $10
; we're done
	jr .quit
	
.updateauto
; get input
	ld a, [hli]
; stop?
	cp a, $ff
	jr z, .stopinput
	ld b, a
	
; duration
	ld a, [hli]
	ld [AutoInputLength], a
; duration $ff = end at input
	cp a, $ff
	jr nz, .next
	
; no input
	dec hl
	dec hl
	ld b, $00 ; no input
	jr .finishauto
	
.next
; output recorded
	ld a, l
	ld [AutoInputAddress], a
	ld a, h
	ld [AutoInputAddress+1], a
	jr .finishauto
	
.stopinput
	call StopAutoInput
	ld b, $00 ; no input
	
.finishauto
; restore bank
	pop af
	rst $10
; update mirrors
	ld a, b
	ld [$ffa7], a ; pressed
	ld [$ffa8], a ; input
	jr .quit
; 9ee

StartAutoInput: ; 9ee
; start auto input stream at a:hl
; bank
	ld [AutoInputBank], a
; address
	ld a, l
	ld [AutoInputAddress], a
	ld a, h
	ld [AutoInputAddress+1], a
; don't wait to update
	xor a
	ld [AutoInputLength], a
; clear input mirrors
	xor a
	ld [$ffa7], a ; pressed
	ld [$ffa6], a ; released
	ld [$ffa8], a ; input
; start reading input stream instead of player input
	ld a, $ff ; INPUT_AUTO
	ld [InputType], a
	ret
; a0a

StopAutoInput: ; a0a
; clear autoinput ram
	xor a
	ld [AutoInputBank], a
	ld [AutoInputAddress], a
	ld [AutoInputAddress+1], a
	ld [AutoInputLength], a
; normal input
	ld [InputType], a
	ret
; a1b

INCBIN "baserom.gbc",$a1b,$c9f - $a1b

DmgToCgbBGPals: ; c9f
; exists to forego reinserting cgb-converted image data

; input: a -> bgp
	ld [$ff47], a ; bgp
	push af
	
; check cgb
	ld a, [$ffe6]
	and a
	jr z, .end
	
	push hl
	push de
	push bc
; save wram bank
	ld a, [$ff70]
	push af
; wram bank 5
	ld a, 5
	ld [$ff70], a

; copy & reorder bg pal buffer
	ld hl, BGPals ; to
	ld de, Unkn1Pals ; from
; order
	ld a, [$ff47] ; bgp
	ld b, a
; # pals
	ld c, 8 ; all pals
	call CopyPals
; request pal update
	ld a, $1
	ld [$ffe5], a
; restore wram bank
	pop af
	ld [$ff70], a
	pop bc
	pop de
	pop hl
.end
	pop af
	ret
; ccb


DmgToCgbObjPals: ; ccb
; exists to forego reinserting cgb-converted image data

; input: d -> obp1
;		 e -> obp2
	ld a, e
	ld [$ff48], a ; obp0
	ld a, d
	ld [$ff49], a ; obp1
	
; check cgb
	ld a, [$ffe6]
	and a
	ret z
	
	push hl
	push de
	push bc
; save wram bank
	ld a, [$ff70]
	push af
; wram bank 5
	ld a, $5
	ld [$ff70], a
	
; copy & reorder obj pal buffer
	; to
	ld hl, OBPals
	; from
	ld de, Unkn2Pals
; order
	ld a, [$ff48] ; obp0
	ld b, a
; # pals
	ld c, 8 ; all pals
	call CopyPals
; request pal update
	ld a, $1
	ld [$ffe5], a
; restore wram bank
	pop af
	ld [$ff70], a
	pop bc
	pop de
	pop hl
	ret
; cf8

INCBIN "baserom.gbc",$cf8,$d50 - $cf8

CopyPals: ; d50
; copy c palettes in order b from de to hl

	push bc
	ld c, 4 ; NUM_PAL_COLORS
.loop
	push de
	push hl
	
; get pal color
	ld a, b
	and %11 ; color
; 2 bytes per color
	add a
	ld l, a
	ld h, $0
	add hl, de
	ld e, [hl]
	inc hl
	ld d, [hl]
	
; dest
	pop hl
; write color
	ld [hl], e
	inc hl
	ld [hl], d
	inc hl
; next pal color
	srl b
	srl b
; source
	pop de
; done pal?
	dec c
	jr nz, .loop
	
; de += 8 (next pal)
	ld a, 8 ; NUM_PAL_COLORS * 2 ; bytes per pal
	add e
	jr nc, .ok
	inc d
.ok
	ld e, a
	
; how many more pals?
	pop bc
	dec c
	jr nz, CopyPals
	ret
; d79

INCBIN "baserom.gbc",$d79,$e8d - $d79

; copy bc bytes from a:hl to de
FarCopyBytes: ; e8d
	ld [$ff8b], a
	ld a, [$ff9d] ; save old bank
	push af
	ld a, [$ff8b]
	rst $10
	call CopyBytes
	pop af
	rst $10
	ret
; 0xe9b

; copy bc*2 source bytes from a:hl to de, doubling each byte in process
FarCopyBytesDouble: ; e9b
	ld [$ff8b], a
	ld a, [$ff9d] ; save current bank
	push af
	ld a, [$ff8b]
	rst $10 ; bankswitch
	ld a, h ; switcheroo, de <> hl
	ld h, d
	ld d, a
	ld a, l
	ld l, e
	ld e, a
	inc b
	inc c
	jr .dec ; 0xeab $4
.loop
	ld a, [de]
	inc de
	ld [hli], a ; write twice
	ld [hli], a
.dec
	dec c
	jr nz, .loop
	dec b
	jr nz, .loop
	pop af
	rst $10
	ret
; 0xeba


INCBIN "baserom.gbc",$eba,$ff1 - $eba

TextBoxBorder: ; ff1
; draw a text box
; upper-left corner at coordinates hl
; height b
; width c

	; first row
	push hl
	ld a, "┌"
	ld [hli], a
	inc a    ; horizontal border ─
	call NPlaceChar
	inc a    ; upper-right border ┐
	ld [hl], a

	; middle rows
	pop hl
	ld de, 20
	add hl, de ; skip the top row

.PlaceRow\@
	push hl
	ld a, "│"
	ld [hli], a
	ld a, " "
	call NPlaceChar
	ld [hl], "│"

	pop hl
	ld de, 20
	add hl, de ; move to next row
	dec b
	jr nz, .PlaceRow\@

	; bottom row
	ld a, "└"
	ld [hli], a
	ld a, "─"
	call NPlaceChar
	ld [hl], "┘"
	ret
; 0x101e

NPlaceChar: ; 0x101e
; place a row of width c of identical characters
	ld d,c
.loop\@
	ld [hli],a
	dec d
	jr nz,.loop\@
	ret
; 0x1024

INCBIN "baserom.gbc",$1024,$1078 - $1024

PlaceString:
	push hl
PlaceNextChar:
	ld a, [de]
	cp "@"
	jr nz, CheckDict
	ld b, h
	ld c, l
	pop hl
	ret
	pop de

NextChar: ; 1083
	inc de
	jp PlaceNextChar

CheckDict:
	cp $15
	jp z, $117b
	cp $4f
	jp z, $12ea
	cp $4e
	jp z, $12a7
	cp $16
	jp z, $12b9
	and a
	jp z, $1383
	cp $4c
	jp z, $1337
	cp $4b
	jp z, $131f
	cp $51 ; Player name
	jp z, $12f2
	cp $49
	jp z, $1186
	cp $52 ; Mother name
	jp z, $118d
	cp $53
	jp z, $1194
	cp $35
	jp z, $11e8
	cp $36
	jp z, $11ef
	cp $37
	jp z, $11f6
	cp $38
	jp z, $119b
	cp $39
	jp z, $11a2
	cp $54
	jp z, $11c5
	cp $5b
	jp z, $11b7
	cp $5e
	jp z, $11be
	cp $5c
	jp z, $11b0
	cp $5d
	jp z, $11a9
	cp $23
	jp z, $11cc
	cp $22
	jp z, $12b0
	cp $55
	jp z, $1345
	cp $56
	jp z, $11d3
	cp $57
	jp z, $137c
	cp $58
	jp z, $135a
	cp $4a
	jp z, $11da
	cp $24
	jp z, $11e1
	cp $25
	jp z, NextChar
	cp $1f
	jr nz, .asm_1122
	ld a, $7f
.asm_1122
	cp $5f
	jp z, Char5F
	cp $59
	jp z, $11fd
	cp $5a
	jp z, $1203
	cp $3f
	jp z, $121b
	cp $14
	jp z, $1252
	cp $e4
	jr z, .asm_1174 ; 0x113d $35
	cp $e5
	jr z, .asm_1174 ; 0x1141 $31
	jr .asm_114c ; 0x1143 $7
	ld b, a
	call $13c6
	jp NextChar
.asm_114c
	cp $60
	jr nc, .asm_1174 ; 0x114e $24
	cp $40
	jr nc, .asm_1165 ; 0x1152 $11
	cp $20
	jr nc, .asm_115c ; 0x1156 $4
	add $80
	jr .asm_115e ; 0x115a $2
.asm_115c
	add $90
.asm_115e
	ld b, $e5
	call $13c6
	jr .asm_1174 ; 0x1163 $f
.asm_1165
	cp $44
	jr nc, .asm_116d ; 0x1167 $4
	add $59
	jr .asm_116f ; 0x116b $2
.asm_116d
	add $86
.asm_116f
	ld b, $e4
	call $13c6
.asm_1174
	ld [hli], a
	call PrintLetterDelay
	jp NextChar
; 0x117b

INCBIN "baserom.gbc",$117b,$1203 - $117b

Char5D:
	ld a, [$ffe4]
	push de
	and a
	jr nz, .asm_120e ; 0x1207 $5
	ld de, $c621
	jr .asm_126a ; 0x120c $5c
.asm_120e
	ld de, Char5AText ; Enemy
	call $1078
	ld h, b
	ld l, c
	ld de, $c616
	jr .asm_126a ; 0x1219 $4f
	push de
	ld a, [InLinkBattle]
	and a
	jr nz, .linkbattle
	ld a, [$d233]
	cp $9
	jr z, .asm_1248 ; 0x1227 $1f
	cp $2a
	jr z, .asm_1248 ; 0x122b $1b
	ld de, $c656
	call $1078
	ld h, b
	ld l, c
	ld de, $12a2
	call $1078
	push bc
	ld hl, $5939
	ld a, $e
	rst $8
	pop hl
	ld de, $d073
	jr .asm_126a ; 0x1246 $22
.asm_1248
	ld de, $d493
	jr .asm_126a ; 0x124b $1d
.linkbattle
	ld de, $c656
	jr .asm_126a ; 0x1250 $18
	push de
	ld de, PlayerName
	call $1078
	ld h, b
	ld l, c
	ld a, [$d472]
	bit 0, a
	ld de, $12a5
	jr z, .asm_126a ; 0x1263 $5
	ld de, $12a6
	jr .asm_126a ; 0x1268 $0
.asm_126a
	call $1078
	ld h, b
	ld l, c
	pop de
	jp $1083
; 0x1273


Char5CText: ; 0x1273
	db "TM@"
Char5DText: ; 0x1276
	db "TRAINER@"
Char5BText: ; 0x127e
	db "PC@"

INCBIN "baserom.gbc",$1281,$1293 - $1281

Char56Text: ; 0x1293
	db "…@"
Char5AText: ; 0x1295
	db "Enemy @"

INCBIN "baserom.gbc",$129c,$1356 - $129c

Char5F: ; 0x1356
; ends a Pokédex entry
	ld [hl],"."
	pop hl
	ret

INCBIN "baserom.gbc",$135a,$185d - $135a

GetTileType: ; 185d
; checks the properties of a tile
; input: a = tile id
	push de
	push hl
	ld hl, TileTypeTable
	ld e, a
	ld d, $00
	add hl, de
	ld a, [$ff9d] ; current bank
	push af
	ld a, BANK(TileTypeTable)
	rst $10
	ld e, [hl] ; get tile type
	pop af
	rst $10 ; return to current bank
	ld a, e
	and a, $0f ; lo nybble only
	pop hl
	pop de
	ret
; 1875

INCBIN "baserom.gbc",$1875,$261f - $1875

PushScriptPointer: ; 261f
; used to call a script from asm
; input:
;	a: bank
;	hl: address

; bank
	ld [$d439], a ; ScriptBank
	
; address
	ld a, l
	ld [$d43a], a ; ScriptAddressLo
	ld a, h
	ld [$d43b], a ; ScriptAddressHi
	
	ld a, $ff
	ld [$d438], a
	
	scf
	ret
; 2631

INCBIN "baserom.gbc",$2631,$26ef - $2631

ObjectEvent: ; 0x26ef
	jumptextfaceplayer ObjectEventText
; 0x26f2


ObjectEventText:
	TX_FAR _ObjectEventText
	db "@"

INCBIN "baserom.gbc",$26f7,$2bed-$26f7

GetMapHeaderPointer: ; 0x2bed
; Prior to calling this function, you must have switched banks so that
; MapHeaderPointers is visible.

; inputs:
; b = map group, c = map number
; XXX de = ???

; outputs:
; hl points to the map header
	push bc ; save map number for later

	; get pointer to map group
	dec b
	ld c, b
	ld b, $0
	ld hl, MapHeaderPointers
	add hl, bc
	add hl, bc

	ld a, [hli]
	ld h, [hl]
	ld l, a
	pop bc ; restore map number

	; find the cth map header
	dec c
	ld b, $0
	ld a, OlivineGym_MapHeader - MapHeader_0x94034
	call AddNTimes
	ret

GetMapHeaderMember: ; 0x2c04
; Extract data from the current map's header.

; inputs:
; de = offset of desired data within the mapheader

; outputs:
; bc = data from the current map's header
; (e.g., de = $0003 would return a pointer to the secondary map header)

	ld a, [MapGroup]
	ld b, a
	ld a, [MapNumber]
	ld c, a
	; fallthrough

GetAnyMapHeaderMember: ; 0x2c0c
	; bankswitch
	ld a, [$ff9d]
	push af
	ld a, BANK(MapHeaderPointers)
	rst $10

	call GetMapHeaderPointer
	add hl, de
	ld c, [hl]
	inc hl
	ld b, [hl]

	; bankswitch back
	pop af
	rst $10
	ret
; 0x2c1c

INCBIN "baserom.gbc",$2c1c,$2c7d-$2c1c

GetSecondaryMapHeaderPointer: ; 0x2c7d
; returns the current map's secondary map header pointer in hl.
	push bc
	push de
	ld de, $0003 ; secondary map header pointer (offset within header)
	call GetMapHeaderMember
	ld l, c
	ld h, b
	pop de
	pop bc
	ret

INCBIN "baserom.gbc",$2c8a,$2caf-$2c8a

GetWorldMapLocation: ; 0x2caf
; given a map group/id in bc, return its location on the Pokégear map.
	push hl
	push de
	push bc
	ld de, 5
	call GetAnyMapHeaderMember
	ld a, c
	pop bc
	pop de
	pop hl
	ret
; 0x2cbd

INCBIN "baserom.gbc",$2cbd,$2d83-$2cbd

Predef: ; 2d83
; call a function from given id a

; relies on $cfb4-8

; this function is somewhat unreadable at a glance
; the execution flow is as follows:
;	save bank
;	get function from id
;	call function
;	restore bank
; these are pushed to the stack in reverse

; most of the $cfbx trickery is just juggling hl (which is preserved)
; this allows hl, de and bc to be passed to the function

; input:
;	a: id
;	parameters bc, de, hl

; store id
	ld [$cfb4], a
	
; save bank
	ld a, [$ff9d] ; current bank
	push af
	
; get Predef function to call
; GetPredefFn also stores hl in $cfb5-6
	ld a, BANK(GetPredefFn)
	rst $10
	call GetPredefFn
; switch bank to Predef function
	rst $10
	
; clean up after Predef call
	ld hl, .cleanup
	push hl
	
; call Predef function from ret
	ld a, [$cfb7]
	ld h, a
	ld a, [$cfb8]
	ld l, a
	push hl
	
; get hl back
	ld a, [$cfb5]
	ld h, a
	ld a, [$cfb6]
	ld l, a
	ret

.cleanup
; store hl
	ld a, h
	ld [$cfb5], a
	ld a, l
	ld [$cfb6], a
	
; restore bank
	pop hl ; popping a pushed af. h = a (old bank)
	ld a, h
	rst $10
	
; get hl back
	ld a, [$cfb5]
	ld h, a
	ld a, [$cfb6]
	ld l, a
	ret
; 2dba

INCBIN "baserom.gbc",$2dba,$2e6f-$2dba

BitTable1Func: ; 0x2e6f
	ld hl, $da72
	call BitTableFunc
	ret

BitTableFunc: ; 0x2e76
; Perform a function on a bit in memory.

; inputs:
; b: function
;    0 clear bit
;    1 set bit
;    2 check bit
; de: bit number
; hl: index within bit table

	; get index within the byte
	ld a, e
	and $7

	; shift de right by three bits (get the index within memory)
	srl d
	rr e
	srl d
	rr e
	srl d
	rr e
	add hl, de

	; implement a decoder
	ld c, $1
	rrca
	jr nc, .one
	rlc c
.one
	rrca
	jr nc, .two
	rlc c
	rlc c
.two
	rrca
	jr nc, .three
	swap c
.three

	; check b's value: 0, 1, 2
	ld a, b
	cp 1
	jr c, .clearbit ; 0
	jr z, .setbit ; 1

	; check bit
	ld a, [hl]
	and c
	ld c, a
	ret

.setbit
	; set bit
	ld a, [hl]
	or c
	ld [hl], a
	ret

.clearbit
	; clear bit
	ld a, c
	cpl
	and [hl]
	ld [hl], a
	ret
; 0x2ead

INCBIN "baserom.gbc",$2ead,$2fb1-$2ead

Function2fb1: ; 2fb1
	push bc
	ld c, a
	xor a
	sub c
.asm_2fb5
	sub c
	jr nc, .asm_2fb5
	add c
	ld b, a
	push bc
.asm_2fbb
	call $2f8c
	ld a, [$ffe1]
	ld c, a
	add b
	jr c, .asm_2fbb
	ld a, c
	pop bc
	call $3110
	pop bc
	ret
; 2fcb

GetSRAMBank: ; 2fcb
; load sram bank a
; if invalid bank, sram is disabled
	cp NUM_SRAM_BANKS
	jr c, OpenSRAM
	jr CloseSRAM
; 2fd1

OpenSRAM: ; 2fd1
; switch to sram bank a
	push af
; latch clock data
	ld a, $1
	ld [$6000], a
; enable sram/clock write
	ld a, $a
	ld [$0000], a
; select sram bank
	pop af
	ld [$4000], a
	ret
; 2fe1

CloseSRAM: ; 2fe1
; preserve a
	push af
	ld a, $0
; reset clock latch for next time
	ld [$6000], a
; disable sram/clock write
	ld [$0000], a
	pop af
	ret
; 2fef

INCBIN "baserom.gbc",$2fec,$3026-$2fec

CopyBytes: ; 0x3026
; copy bc bytes from hl to de
	inc b  ; we bail the moment b hits 0, so include the last run
	inc c  ; same thing; include last byte
	jr .HandleLoop
.CopyByte
	ld a, [hli]
	ld [de], a
	inc de
.HandleLoop
	dec c
	jr nz, .CopyByte
	dec b
	jr nz, .CopyByte
	ret

SwapBytes: ; 0x3034
; swap bc bytes between hl and de
.Loop
	; stash [hl] away on the stack
	ld a, [hl]
	push af

	; copy a byte from [de] to [hl]
	ld a, [de]
	ld [hli], a

	; retrieve the previous value of [hl]; put it in [de]
	pop af
	ld [de], a

	; handle loop stuff
	inc de
	dec bc
	ld a, b
	or c
	jr nz, .Loop
	ret

ByteFill: ; 0x3041
; fill bc bytes with the value of a, starting at hl
	inc b  ; we bail the moment b hits 0, so include the last run
	inc c  ; same thing; include last byte
	jr .HandleLoop
.PutByte
	ld [hli], a
.HandleLoop
	dec c
	jr nz, .PutByte
	dec b
	jr nz, .PutByte
	ret

GetFarByte: ; 0x304d
; retrieve a single byte from a:hl, and return it in a.
	; bankswitch to new bank
	ld [$ff8b], a
	ld a, [$ff9d]
	push af
	ld a, [$ff8b]
	rst $10

	; get byte from new bank
	ld a, [hl]
	ld [$ff8b], a

	; bankswitch to previous bank
	pop af
	rst $10

	; return retrieved value in a
	ld a, [$ff8b]
	ret

GetFarHalfword: ; 0x305d
; retrieve a halfword from a:hl, and return it in hl.
	; bankswitch to new bank
	ld [$ff8b], a
	ld a, [$ff9d]
	push af
	ld a, [$ff8b]
	rst $10

	; get halfword from new bank, put it in hl
	ld a, [hli]
	ld h, [hl]
	ld l, a

	; bankswitch to previous bank and return
	pop af
	rst $10
	ret
; 0x306b

INCBIN "baserom.gbc",$306b,$30d6-$306b

CopyName1: ; 30d6
	ld hl, StringBuffer2
; 30d9
CopyName2: ; 30d9
.loop
	ld a, [de]
	inc de
	ld [hli], a
	cp "@"
	jr nz, .loop
	ret
; 30e1

IsInArray: ; 30e1
; searches an array at hl for the value in a.
; skips (de - 1) bytes between reads, so to check every byte, de should be 1.
; if found, returns count in b and sets carry.
	ld b,0
	ld c,a
.loop\@
	ld a,[hl]
	cp a,$FF
	jr z,.NotInArray\@
	cp c
	jr z,.InArray\@
	inc b
	add hl,de
	jr .loop\@
.NotInArray\@
	and a
	ret
.InArray\@
	scf
	ret
; 0x30f4

SkipNames: ; 0x30f4
; skips n names where n = a
	ld bc, $000b ; name length
	and a
	ret z
.loop
	add hl, bc
	dec a
	jr nz, .loop
	ret
; 0x30fe

AddNTimes: ; 0x30fe
; adds bc n times where n = a
	and a
	ret z
.loop
	add hl, bc
	dec a
	jr nz, .loop
	ret
; 0x3105

INCBIN "baserom.gbc",$3105,$3119-$3105

Multiply: ; 0x3119
; function to do multiplication
; all values are big endian
; INPUT
; ffb4-ffb6 =  multiplicand
; ffb7 = multiplier
; OUTPUT
; ffb3-ffb6 = product
	INCBIN "baserom.gbc",$3119,$3124 - $3119
; 0x3124

Divide: ; 0x3124
; function to do division
; all values are big endian
; INPUT
; ffb3-ffb6 = dividend
; ffb7 = divisor
; b = number of bytes in the dividend (starting from ffb3)
; OUTPUT
; ffb4-ffb6 = quotient
; ffb7 = remainder
	INCBIN "baserom.gbc",$3124,$3136 - $3124
; 0x3136

INCBIN "baserom.gbc",$3136,$313d - $3136

PrintLetterDelay: ; 313d
; wait some frames before printing the next letter
; the text speed setting in Options is actually a frame count
; 	fast: 1 frame
; 	mid:  3 frames
; 	slow: 5 frames
; $cfcf[!0] and A or B override text speed with a one-frame delay
; Options[4] and $cfcf[!1] disable the delay

; delay off?
	ld a, [Options]
	bit 4, a ; delay off
	ret nz
	
; non-scrolling text?
	ld a, [$cfcf]
	bit 1, a
	ret z
	
	push hl
	push de
	push bc
	
; save oam update status
	ld hl, $ffd8
	ld a, [hl]
	push af
; orginally turned oam update off, commented out
;	ld a, 1
	ld [hl], a
	
; force fast scroll?
	ld a, [$cfcf]
	bit 0, a
	jr z, .fast
	
; text speed
	ld a, [Options]
	and a, %111 ; # frames to delay
	jr .updatedelay
	
.fast
	ld a, 1
.updatedelay
	ld [TextDelayFrames], a
	
.checkjoypad
	call GetJoypadPublic
	
; input override
	ld a, [$c2d7]
	and a
	jr nz, .wait
	
; wait one frame if holding a
	ld a, [$ffa8] ; joypad
	bit 0, a ; A
	jr z, .checkb
	jr .delay
	
.checkb
; wait one frame if holding b
	bit 1, a ; B
	jr z, .wait
	
.delay
	call DelayFrame
	jr .end
	
.wait
; wait until frame counter hits 0 or the loop is broken
; this is a bad way to do this
	ld a, [TextDelayFrames]
	and a
	jr nz, .checkjoypad
	
.end
; restore oam update flag (not touched in this fn anymore)
	pop af
	ld [$ffd8], a
	pop bc
	pop de
	pop hl
	ret
; 318c

CopyDataUntil: ; 318c
; Copies [hl, bc) to [de, bc - hl).
; In other words, the source data is from hl up to but not including bc,
; and the destination is de.
	ld a, [hli]
	ld [de], a
	inc de
	ld a, h
	cp b
	jr nz, CopyDataUntil
	ld a, l
	cp c
	jr nz, CopyDataUntil
	ret
; 0x3198

INCBIN "baserom.gbc",$3198,$31db - $3198

StringCmp: ; 31db
; Compare strings, c bytes in length, at de and hl.
; Often used to compare big endian numbers in battle calculations.
	ld a, [de]
	cp [hl]
	ret nz
	inc de
	inc hl
	dec c
	jr nz, StringCmp
	ret
; 0x31e4

INCBIN "baserom.gbc",$31e4,$3340 - $31e4

GetSGBLayout: ; 3340
; load sgb packets unless gb

; check cgb
	ld a, [$ffe6]
	and a
	jr nz, .dosgb
	
; check sgb
	ld a, [$ffe7]
	and a
	ret z
	
.dosgb
	ld a, $31 ; LoadSGBLayout
	jp Predef
; 334e

INCBIN "baserom.gbc",$334e,$335f - $334e

CountSetBits: ; 0x335f
; function to count how many bits are set in a string of bytes
; INPUT:
; hl = address of string of bytes
; b = length of string of bytes
; OUTPUT:
; [$d265] = number of set bits
	ld c, $0
.loop\@
	ld a, [hli]
	ld e, a
	ld d, $8
.innerLoop\@ ; count how many bits are set in the current byte
	srl e
	ld a, $0
	adc c
	ld c, a
	dec d
	jr nz, .innerLoop\@
	dec b
	jr nz, .loop\@
	ld a, c
	ld [$d265], a
	ret
; 0x3376

INCBIN "baserom.gbc",$3376,$33ab - $3376

NamesPointerTable: ; 33ab
	dbw BANK(PokemonNames), PokemonNames
	dbw BANK(MoveNames), MoveNames
	dbw $00, $0000
	dbw BANK(ItemNames), ItemNames
	dbw $00, $ddff
	dbw $00, $d3a8
	dbw BANK(TrainerClassNames), TrainerClassNames
	dbw $04, $4b52

GetName: ; 33c3
	ld a, [$ff9d]
	push af
	push hl
	push bc
	push de
	ld a, [$cf61]
	cp $1
	jr nz, .asm_33e1 ; 0x33ce $11
	ld a, [$cf60]
	ld [$d265], a
	call $343b
	ld hl, $000b
	add hl, de
	ld e, l
	ld d, h
	jr .asm_3403 ; 0x33df $22
.asm_33e1
	ld a, [$cf61]
	dec a
	ld e, a
	ld d, $0
	ld hl, NamesPointerTable
	add hl, de
	add hl, de
	add hl, de
	ld a, [hli]
	rst $10 ; Bankswitch
	ld a, [hli]
	ld h, [hl]
	ld l, a
	ld a, [$cf60]
	dec a
	call GetNthString
	ld de, $d073
	ld bc, $000d
	call $3026
.asm_3403
	ld a, e
	ld [$d102], a
	ld a, d
	ld [$d103], a
	pop de
	pop bc
	pop hl
	pop af
	rst $10
	ret
; 0x3411

INCBIN "baserom.gbc",$3411,$3411 - $3411

GetNthString: ; 3411
; Starting at hl, this function returns the start address of the ath string.
	and a
	ret z
	push bc
	ld b, a
	ld c, "@"
.readChar
	ld a, [hli]
	cp c
	jr nz, .readChar ; 0x3419 $fc
	dec b
	jr nz, .readChar ; 0x341c $f9
	pop bc
	ret
; 0x3420

INCBIN "baserom.gbc",$3420,$3468 - $3420

GetItemName: ; 3468
	push hl
	push bc
	ld a, [$d265] ; Get the item
	cp $bf ; Is it a TM?
	jr nc, .tm ; 0x346f $d
	ld [$cf60], a
	ld a, $4 ; Item names
	ld [$cf61], a
	call GetName
	jr .copied ; 0x347c $3
.tm
	call $3487
.copied
	ld de, $d073
	pop bc
	pop hl
	ret
; 0x3487

INCBIN "baserom.gbc",$3487,$38a2 - $3487

GetNick: ; 38a2
; get the nickname of a partymon
; write nick to StringBuffer1

; input: a = which mon (0-5)

	push hl
	push bc
	; skip [a] nicks
	call SkipNames
	ld de, StringBuffer1
	; write nick
	push de
	ld bc, PKMN_NAME_LENGTH
	call CopyBytes
	; error-check
	pop de
	callab CheckNickErrors
	; we're done
	pop bc
	pop hl
	ret
; 38bb

PrintBCDNumber: ; 38bb
; function to print a BCD (Binary-coded decimal) number
; de = address of BCD number
; hl = destination address
; c = flags and length
; bit 7: if set, do not print leading zeroes
;        if unset, print leading zeroes
; bit 6: if set, left-align the string (do not pad empty digits with spaces)
;        if unset, right-align the string
; bit 5: if set, print currency symbol at the beginning of the string
;        if unset, do not print the currency symbol
; bits 0-4: length of BCD number in bytes
; Note that bits 5 and 7 are modified during execution. The above reflects
; their meaning at the beginning of the functions's execution.
	ld b, c ; save flags in b
	res 7, c
	res 6, c
	res 5, c ; c now holds the length
	bit 5, b
	jr z, .loop\@
	bit 7, b
	jr nz, .loop\@
	ld [hl], "¥"
	inc hl
.loop\@
	ld a, [de]
	swap a
	call PrintBCDDigit ; print upper digit
	ld a, [de]
	call PrintBCDDigit ; print lower digit
	inc de
	dec c
	jr nz, .loop\@
	bit 7, b ; were any non-zero digits printed?
	jr z, .done\@ ; if so, we are done
.numberEqualsZero\@ ; if every digit of the BCD number is zero
	bit 6, b ; left or right alignment?
	jr nz, .skipRightAlignmentAdjustment\@
	dec hl ; if the string is right-aligned, it needs to be moved back one space
.skipRightAlignmentAdjustment\@
	bit 5, b
	jr z, .skipCurrencySymbol\@
	ld [hl], "¥" ; currency symbol
	inc hl
.skipCurrencySymbol\@
	ld [hl], "0"
	call PrintLetterDelay
	inc hl
.done\@
	ret
; 0x38f2

PrintBCDDigit: ; 38f2
	and a, %00001111
	and a
	jr z, .zeroDigit\@
.nonzeroDigit\@
	bit 7, b ; have any non-space characters been printed?
	jr z, .outputDigit\@
; if bit 7 is set, then no numbers have been printed yet
	bit 5, b ; print the currency symbol?
	jr z, .skipCurrencySymbol\@
	ld [hl], "¥"
	inc hl
	res 5, b
.skipCurrencySymbol\@
	res 7, b ; unset 7 to indicate that a nonzero digit has been reached
.outputDigit\@
	add a, "0"
	ld [hli], a
	jp PrintLetterDelay
.zeroDigit\@
	bit 7, b ; either printing leading zeroes or already reached a nonzero digit?
	jr z, .outputDigit\@ ; if so, print a zero digit
	bit 6, b ; left or right alignment?
	ret nz
	ld a, " "
	ld [hli], a ; if right-aligned, "print" a space by advancing the pointer
	ret
; 0x3917

Function3917: ; 3917
	push bc
	ld hl, $dcdf
	ld c, a
	ld b, $00
	add hl, bc
	ld a, [$d109]
	call Function3927
	pop bc
	ret
; 3927

Function3927: ; 3927
; a is typically [$d109]
	ld bc, $0030
	jp AddNTimes
; 392d

INCBIN "baserom.gbc",$392d,$3b86 - $392d

LoadMusicByte: ; 3b86
; load music data into CurMusicByte
; input:
;   a: bank
;   de: address
	ld [$ff9d], a
	ld [$2000], a ; bankswitch
	ld a, [de]
	ld [CurMusicByte], a
	ld a, $3a ; manual bank restore
	ld [$ff9d], a
	ld [$2000], a ; bankswitch
	ret
; 3b97

StartMusic: ; 3b97
; input:
;   e = song number
	push hl
	push de
	push bc
	push af
	ld a, [$ff9d] ; save bank
	push af
	ld a, BANK(LoadMusic)
	ld [$ff9d], a
	ld [$2000], a ; bankswitch
	ld a, e ; song number
	and a
	jr z, .nomusic
	call LoadMusic
	jr .end
.nomusic
	call SoundRestart
.end
	pop af
	ld [$ff9d], a ; restore bank
	ld [$2000], a
	pop af
	pop bc
	pop de
	pop hl
	ret
; 3bbc

INCBIN "baserom.gbc",$3bbc,$3c23 - $3bbc

StartSFX: ; 3c23
; sfx id order is by priority (highest to lowest)
; to disable this, remove the check!
; input: de = sfx id
	push hl
	push de
	push bc
	push af
	; is something already playing?
	call CheckSFX
	jr nc, .asm_3c32
	; only play sfx if it has priority
	ld a, [CurSFX]
	cp e
	jr c, .quit
.asm_3c32
	ld a, [$ff9d] ; save bank
	push af
	ld a, $3a ; music bank
	ld [$ff9d], a
	ld [$2000], a ; bankswitch
	ld a, e
	ld [CurSFX], a
	call LoadSFX
	pop af
	ld [$ff9d], a ; restore bank
	ld [$2000], a ; bankswitch
.quit
	pop af
	pop bc
	pop de
	pop hl
	ret
; 3c4e

INCBIN "baserom.gbc",$3c4e,$3c55-$3c4e

WaitSFX: ; 3c55
; infinite loop until sfx is done playing
	push hl
	
.loop
	; ch5 on?
	ld hl, $c1cc ; Channel5Flags
	bit 0, [hl]
	jr nz, .loop
	; ch6 on?
	ld hl, $c1fe ; Channel6Flags
	bit 0, [hl]
	jr nz, .loop
	; ch7 on?
	ld hl, $c230 ; Channel7Flags
	bit 0, [hl]
	jr nz, .loop
	; ch8 on?
	ld hl, $c262 ; Channel8Flags
	bit 0, [hl]
	jr nz, .loop
	
	; we're done
	pop hl
	ret
; 3c74

INCBIN "baserom.gbc",$3c74,$3c97-$3c74

MaxVolume: ; 3c97
	ld a, $77 ; max
	ld [Volume], a
	ret
; 3c9d

LowVolume: ; 3c9d
	ld a, $33 ; 40%
	ld [Volume], a
	ret
; 3ca3

VolumeOff: ; 3ca3
	xor a
	ld [Volume], a
	ret
; 3ca8

INCBIN "baserom.gbc",$3ca8,$3dde - $3ca8

CheckSFX: ; 3dde
; returns carry if sfx channels are active
	ld a, [$c1cc] ; 1
	bit 0, a
	jr nz, .quit
	ld a, [$c1fe] ; 2
	bit 0, a
	jr nz, .quit
	ld a, [$c230] ; 3
	bit 0, a
	jr nz, .quit
	ld a, [$c262] ; 4
	bit 0, a
	jr nz, .quit
	and a
	ret
.quit
	scf
	ret
; 3dfe

INCBIN "baserom.gbc",$3dfe,$4000 - $3dfe

SECTION "bank1",DATA,BANK[$1]

INCBIN "baserom.gbc",$4000,$617c - $4000

IntroFadePalettes: ; 0x617c
	db %01010100
	db %10101000
	db %11111100
	db %11111000
	db %11110100
	db %11100100
; 6182

INCBIN "baserom.gbc",$6182,$669f - $6182

CheckNickErrors: ; 669f
; error-check monster nick before use
; must be a peace offering to gamesharkers

; input: de = nick location

	push bc
	push de
	ld b, PKMN_NAME_LENGTH

.checkchar
; end of nick?
	ld a, [de]
	cp "@" ; terminator
	jr z, .end

; check if this char is a text command
	ld hl, .textcommands
	dec hl
.loop
; next entry
	inc hl
; reached end of commands table?
	ld a, [hl]
	cp a, $ff
	jr z, .done

; is the current char between this value (inclusive)...
	ld a, [de]
	cp [hl]
	inc hl
	jr c, .loop
; ...and this one?
	cp [hl]
	jr nc, .loop

; replace it with a "?"
	ld a, "?"
	ld [de], a
	jr .loop

.done
; next char
	inc de
; reached end of nick without finding a terminator?
	dec b
	jr nz, .checkchar

; change nick to "?@"
	pop de
	push de
	ld a, "?"
	ld [de], a
	inc de
	ld a, "@"
	ld [de], a
.end
; if the nick has any errors at this point it's out of our hands
	pop de
	pop bc
	ret
; 66cf

.textcommands ; 66cf
; table definining which characters
; are actually text commands
; format:
;       >=   <
	db $00, $05
	db $14, $19
	db $1d, $26
	db $35, $3a
	db $3f, $40
	db $49, $5d
	db $5e, $7f
	db $ff ; end
; 66de

INCBIN "baserom.gbc",$66de,$8000 - $66de

SECTION "bank2",DATA,BANK[$2]

INCBIN "baserom.gbc",$8000,$854b - $8000

GetPredefFn: ; 854b
; input:
;	[$cfb4] id

; save hl for later
	ld a, h
	ld [$cfb5], a
	ld a, l
	ld [$cfb6], a
	
	push de
	
; get id
	ld a, [$cfb4]
	ld e, a
	ld d, $0
	ld hl, PredefPointers
; seek
	add hl, de
	add hl, de
	add hl, de
	
	pop de
	
; store address in [$cfb7-8]
; addr lo
	ld a, [hli]
	ld [$cfb8], a
; addr hi
	ld a, [hli]
	ld [$cfb7], a
; get bank
	ld a, [hl]
	ret
; 856b

PredefPointers: ; 856b
; $4b Predef pointers
; address, bank
	dwb $6508, $01
	dwb $747a, $01
	dwb $4658, $03
	dwb $57c1, $13
	dwb $4699, $03
	dwb $5a6d, $03
	dwb $588c, $03
	dwb $5a96, $03
	dwb $5b3f, $03
	dwb $5e6e, $03
	dwb $5f8c, $03
	dwb $46e0, $03
	dwb $6167, $03
	dwb $617b, $03
	dwb $5639, $04
	dwb $566a, $04
	dwb $4eef, $0a
	dwb $4b3e, $0b
	dwb $5f48, $0f
	dwb $6f6e, $0b
	dwb $5873, $0f
	dwb $6036, $0f
	dwb $74c1, $0f
	dwb $7390, $0f
	dwb $743d, $0f
	dwb $747c, $0f
	dwb $6487, $10
	dwb $64e1, $10
	dwb $61e6, $10
	dwb $4f63, $0a
	dwb $4f24, $0a
	dwb $484a, $14
	dwb $4d6f, $14
	dwb $4d2e, $14
	dwb $4cdb, $14
	dwb $4c50, $14
	dwb $4bdd, $14
	dwb $5c8a, $13
	dwb $4b0a, $14
	dwb $4b0e, $14
	dwb $4b7b, $14
	dwb $4964, $14
	dwb $493a, $14
	dwb $4953, $14
	dwb $490d, $14
	dwb $5040, $14
	dwb $7cdd, $32
	dwb $40d5, $33
	dwb $5853, $02
	dwb $464c, $02
	dwb $5d11, $24
	dwb $4a88, $02
	dwb $420f, $23
	dwb $4000, $23
	dwb $4000, $23
	dwb $40d6, $33
	dwb $40d5, $33
	dwb $40d5, $33
	dwb $51d0, $3f
	dwb $6a6c, $04
	dwb $5077, $14
	dwb $516c, $14
	dwb $508b, $14
	dwb $520d, $14
	dwb $525d, $14
	dwb $47d3, $0d
	dwb $7908, $3e
	dwb $7877, $3e
	dwb $4000, $34
	dwb $4d0a, $14
	dwb $40a3, $34
	dwb $408e, $34
	dwb $4669, $34
	dwb $466e, $34
	dwb $43ff, $2d
; 864c

INCBIN "baserom.gbc",$864c,$8a68 - $864c

CheckShininess: ; 0x8a68
; given a pointer to Attack/Defense DV in bc, determine if monster is shiny.
; if shiny, set carry.
	ld l,c
	ld h,b
	ld a,[hl]
	and a,%00100000 ; is attack DV xx1x?
	jr z,.NotShiny
	ld a,[hli]
	and a,%1111
	cp $A ; is defense DV 1010?
	jr nz,.NotShiny
	ld a,[hl]
	and a,%11110000
	cp $A0 ; is speed DV 1010?
	jr nz,.NotShiny
	ld a,[hl]
	and a,%1111
	cp $A ; is special DV 1010?
	jr nz,.NotShiny
	scf
	ret
.NotShiny
	and a ; clear carry flag
	ret

INCBIN "baserom.gbc",$8a88,$9a52-$8a88

CopyData: ; 0x9a52
; copy bc bytes of data from hl to de
	ld a, [hli]
	ld [de], a
	inc de
	dec bc
	ld a, c
	or b
	jr nz, CopyData
	ret
; 0x9a5b

INCBIN "baserom.gbc",$9a5b,$c000 - $9a5b

SECTION "bank3",DATA,BANK[$3]

INCBIN "baserom.gbc",$c000,$29

SpecialsPointers: ; 0xc029
	dbw $25,$7c28
	dbw $0a,$5ce8
	dbw $0a,$5d11
	dbw $0a,$5d92
	dbw $0a,$5e66
	dbw $0a,$5e82
	dbw $0a,$5efa
	dbw $0a,$5eee
	dbw $0a,$5c92
	dbw $0a,$5cf1
	dbw $0a,$5cfa
	dbw $0a,$5bfb
	dbw $0a,$5c7b
	dbw $0a,$5ec4
	dbw $0a,$5ed9
	dbw $0a,$5eaf
	dbw $0a,$5f47
	dbw $03,$42f6
	dbw $03,$4309
	dbw $41,$50b9
	dbw $03,$434a
	dbw $13,$59e5
	dbw $04,$7a12
	dbw $04,$7a31
	dbw $04,$75db
	dbw $3e,$7b32
	dbw $3e,$7cd2
	dbw $03,$4658
	dbw $05,$559a
	dbw $03,$42e7
	dbw $05,$66d6
	dbw $05,$672a
	dbw $05,$6936
	dbw $0b,$4547
	dbw $05,$6218
	dbw $23,$4c04
	dbw $03,$429d
	dbw $24,$4913
	dbw $03,$42c0
	dbw $03,$42cd
	dbw $03,$4355
	dbw $03,$4360
	dbw $03,$4373
	dbw $03,$4380
	dbw $03,$438d
	dbw $03,$43db
	dbw $23,$4084
	dbw $23,$4092
	dbw $23,$40b6
	dbw $23,$4079
	dbw $23,$40ab
	dbw $00,$0d91
	dbw $00,$31f3
	dbw $00,$0485
	dbw $00,$0fc8
	dbw $00,$1ad2
	dbw $00,$0e4a
	dbw $03,$4230
	dbw $03,$4252
	dbw BANK(WaitSFX),WaitSFX
	dbw $00,$3cdf
	dbw $00,$3d47
	dbw $04,$6324
	dbw $02,$4379
	dbw $03,$425a
	dbw $03,$4268
	dbw $03,$4276
	dbw $03,$4284
	dbw $03,$43ef
	dbw $05,$7421
	dbw $05,$7440
	dbw $04,$79a8
	dbw $03,$43fc
	dbw $09,$6feb
	dbw $09,$7043
	dbw $01,$7305
	dbw $01,$737e
	dbw $01,$73f7
	dbw $03,$4419
	dbw $09,$4b25
	dbw $09,$4b4e
	dbw $09,$4ae8
	dbw $13,$587a
	dbw $03,$4434
	dbw $03,$4422
	dbw $13,$59d3
	dbw $22,$4018
	dbw $03,$42b9
	dbw $03,$42da
	dbw $01,$718d
	dbw $01,$71ac
	dbw $0a,$64ab
	dbw $0a,$651f
	dbw $0a,$6567
	dbw $05,$4209
	dbw $3e,$7841
	dbw BANK(SpecialSnorlaxAwake),SpecialSnorlaxAwake
	dbw $01,$7413
	dbw $01,$7418
	dbw $01,$741d
	dbw $03,$4472
	dbw $09,$65ee
	dbw BANK(SpecialGameboyCheck),SpecialGameboyCheck
	dbw BANK(SpecialTrainerHouse),SpecialTrainerHouse
	dbw $05,$6dc7
	dbw BANK(SpecialRoamMons), SpecialRoamMons
	dbw $03,$448f
	dbw $03,$449f
	dbw $03,$44ac
	dbw $46,$6c3e
	dbw $46,$7444
	dbw $46,$75e8
	dbw $46,$77e5
	dbw $46,$7879
	dbw $46,$7920
	dbw $46,$793b
	dbw $5c,$40b0
	dbw $5c,$40ba
	dbw $5c,$4114
	dbw $5c,$4215
	dbw $5c,$44e1
	dbw $5c,$421d
	dbw $5c,$4b44
	dbw $46,$7a38
	dbw $5c,$4bd3
	dbw $45,$7656
	dbw $00,$0150
	dbw $40,$51f1
	dbw $40,$5220
	dbw $40,$5225
	dbw $40,$5231
	dbw $12,$525b
	dbw $22,$6def
	dbw $47,$41ab
	dbw $5c,$4687
	dbw $22,$6e68
	dbw $5f,$5224
	dbw $5f,$52b6
	dbw $5f,$52ce
	dbw $5f,$753d
	dbw $40,$7612
	dbw BANK(SpecialHoOhChamber),SpecialHoOhChamber
	dbw $40,$6142
	dbw $12,$589a
	dbw $12,$5bf9
	dbw $13,$70bc
	dbw $22,$6f6b
	dbw $22,$6fd4
	dbw BANK(SpecialDratini),SpecialDratini
	dbw $04,$5485
	dbw BANK(SpecialBeastsCheck),SpecialBeastsCheck
	dbw BANK(SpecialMonCheck),SpecialMonCheck
	dbw $03,$4225
	dbw $5c,$4bd2
	dbw $40,$766e
	dbw $40,$77eb
	dbw $40,$783c
	dbw $41,$60a2
	dbw $05,$4168
	dbw $40,$77c2
	dbw $41,$630f
	dbw $40,$7780
	dbw $40,$787b
	dbw $12,$6e12
	dbw $41,$47eb
	dbw $12,$6927
	dbw $24,$4a54
	dbw $24,$4a88
	dbw $03,$4224

INCBIN "baserom.gbc",$c224,$c43d - $c224

SpecialSnorlaxAwake: ; 0xc43d
; Check if the Poké Flute channel is playing, and if the player is standing
; next to Snorlax.

; outputs:
; ScriptVar is 1 if the conditions are met, otherwise 0.

; check background music
	ld a, [$c2c0]
	cp $40 ; Poké Flute Channel
	jr nz, .nope

	ld a, [XCoord]
	ld b, a
	ld a, [YCoord]
	ld c, a

	ld hl, .ProximityCoords
.loop
	ld a, [hli]
	cp $ff
	jr z, .nope
	cp b
	jr nz, .nextcoord
	ld a, [hli]
	cp c
	jr nz, .loop

	ld a, $1
	jr .done

.nextcoord
	inc hl
	jr .loop

.nope
	xor a
.done
	ld [ScriptVar], a
	ret

.ProximityCoords
	db $21,$08
	db $22,$0a
	db $23,$0a
	db $24,$08
	db $24,$09
	db $ff

INCBIN "baserom.gbc",$c472,$c478 - $c472

SpecialGameboyCheck: ; c478
; check cgb
	ld a, [$ffe6]
	and a
	jr nz, .cgb
; check sgb
	ld a, [$ffe7]
	and a
	jr nz, .sgb
; gb
	xor a
	jr .done
	
.sgb
	ld a, 1
	jr .done

.cgb
	ld a, 2
	
.done
	ld [ScriptVar], a
	ret

INCBIN "baserom.gbc",$c48f,$c4b9 - $c48f

SpecialTrainerHouse: ; 0xc4b9
	ld a, 0
	call GetSRAMBank
	ld a, [$abfd] ; XXX what is this memory location?
	ld [ScriptVar], a
	jp CloseSRAM

INCBIN "baserom.gbc",$c4c7,$c5d2 - $c4c7

PrintNumber_PrintDigit: ; c5d2
INCBIN "baserom.gbc",$c5d2,$c644 - $c5d2

PrintNumber_PrintLeadingZero: ; c644
; prints a leading zero unless they are turned off in the flags
	bit 7, d ; print leading zeroes?
	ret z
	ld [hl], "0"
	ret

PrintNumber_AdvancePointer: ; c64a
; increments the pointer unless leading zeroes are not being printed,
; the number is left-aligned, and no nonzero digits have been printed yet
	bit 7, d ; print leading zeroes?
	jr nz, .incrementPointer\@
	bit 6, d ; left alignment or right alignment?
	jr z, .incrementPointer\@
	ld a, [$ffb3] ; was H_PASTLEADINGZEROES
	and a
	ret z
.incrementPointer\@
	inc hl
	ret
; 0xc658

INCBIN "baserom.gbc",$c658,$c706 - $c658

GetPartyNick: ; c706
; write CurPartyMon nickname to StringBuffer1-3
	ld hl, PartyMon1Nickname
	ld a, $02
	ld [$cf5f], a
	ld a, [CurPartyMon]
	call GetNick
	call CopyName1
; copy text from StringBuffer2 to StringBuffer3
	ld de, StringBuffer2
	ld hl, StringBuffer3
	call CopyName2
	ret
; c721

CheckFlag2: ; c721
; using bittable2
; check flag id in de
; return carry if flag is not set
	ld b, $02 ; check flag
	callba GetFlag2
	ld a, c
	and a
	jr nz, .isset
	scf
	ret
.isset
	xor a
	ret
; c731

CheckBadge: ; c731
; input: a = badge flag id ($1b-$2b)
	call CheckFlag2
	ret nc
	ld hl, BadgeRequiredText
	call $1d67 ; push text to queue
	scf
	ret
; c73d

BadgeRequiredText: ; c73d
	TX_FAR _BadgeRequiredText	; Sorry! A new BADGE
	db "@"						; is required.
; c742

CheckPartyMove: ; c742
; checks if a pokemon in your party has a move
; e = partymon being checked

; input: d = move id
	ld e, $00 ; mon #
	xor a
	ld [CurPartyMon], a
.checkmon
; check for valid species
	ld c, e
	ld b, $00
	ld hl, PartySpecies
	add hl, bc
	ld a, [hl]
	and a ; no id
	jr z, .quit
	cp a, $ff ; terminator
	jr z, .quit
	cp a, EGG
	jr z, .nextmon
; navigate to appropriate move table
	ld bc, PartyMon2 - PartyMon1
	ld hl, PartyMon1Moves
	ld a, e
	call AddNTimes
	ld b, $04 ; number of moves
.checkmove
	ld a, [hli]
	cp d ; move id
	jr z, .end
	dec b ; how many moves left?
	jr nz, .checkmove
.nextmon
	inc e ; mon #
	jr .checkmon
.end
	ld a, e
	ld [CurPartyMon], a ; which mon has the move
	xor a
	ret
.quit
	scf
	ret
; c779

INCBIN "baserom.gbc",$c779,$c986 - $c779

UsedSurfScript: ; c986
; print "[MON] used SURF!"
	2writetext UsedSurfText
	closetext
	loadmovesprites
; this does absolutely nothing
	3callasm BANK(Functionc9a2), Functionc9a2
; write surftype to PlayerState
	copybytetovar $d1eb ; Buffer2
	writevarcode VAR_MOVEMENT
; update sprite tiles
	special SPECIAL_UPDATESPRITETILES
; start surf music
	special SPECIAL_BIKESURFMUSIC
; step into the water
	special SPECIAL_LOADFACESTEP ; (slow_step_x, step_end)
	applymovement $00, $d007 ; PLAYER, MovementBuffer
	end
; c9a2

Functionc9a2: ; c9a2
	callba Function1060bb ; empty
	ret
; c9a9

UsedSurfText: ; c9a9
	TX_FAR _UsedSurfText ; [MONSTER] used
	db "@"	       ; SURF!
; c9ae

CantSurfText: ; c9ae
	TX_FAR _CantSurfText ; You can't SURF
	db "@"	       ; here.
; c9b3

AlreadySurfingText: ; c9b3
	TX_FAR _AlreadySurfingText ; You're already
	db "@"		     ; SURFING.
; c9b8

GetSurfType: ; c9b8
; get surfmon species
	ld a, [CurPartyMon]
	ld e, a
	ld d, $00
	ld hl, PartySpecies
	add hl, de
; is pikachu surfing?
	ld a, [hl]
	cp PIKACHU
	ld a, PLAYER_SURF_PIKA
	ret z
	ld a, PLAYER_SURF
	ret
; c9cb

CheckDirection: ; c9cb
; set carry if a tile permission prevents you
; from moving in the direction you are facing

; get player direction
	ld a, [PlayerDirection]
	and a, %00001100 ; bits 2 and 3 contain direction
	rrca
	rrca
	ld e, a
	ld d, $00
	ld hl, .DirectionTable
	add hl, de
; can you walk in this direction?
	ld a, [TilePermissions]
	and [hl]
	jr nz, .quit
	xor a
	ret
.quit
	scf
	ret
; c9e3

.DirectionTable ; c9e3
	db %00001000 ; down
	db %00000100 ; up
	db %00000010 ; left
	db %00000001 ; right
; c9e7

CheckSurfOW: ; c9e7
; called when checking a tile in the overworld
; check if you can surf
; return carry if conditions are met

; can we surf?
	ld a, [PlayerState]
	; are you already surfing (pikachu)?
	cp PLAYER_SURF_PIKA
	jr z, .quit
	; are you already surfing (normal)?
	cp PLAYER_SURF
	jr z, .quit
	; are you facing a surf tile?
	ld a, [$d03e] ; buffer for the tile you are facing (used for other things too)
	call GetTileType
	cp $01 ; surfable
	jr nz, .quit
	; does this contradict tile permissions?
	call CheckDirection
	jr c, .quit
	; do you have fog badge?
	ld de, $001e ; FLAG_FOG_BADGE
	call CheckFlag2
	jr c, .quit
	; do you have a monster with surf?
	ld d, SURF
	call CheckPartyMove
	jr c, .quit
	; can you get off the bike (cycling road)?
	ld hl, $dbf5 ; overworld flags
	bit 1, [hl] ; always on bike (can't surf)
	jr nz, .quit
	
; load surftype into MovementType
	call GetSurfType
	ld [$d1eb], a ; MovementType
	
; get surfmon nick
	call GetPartyNick
	
; run AskSurfScript
	ld a, BANK(AskSurfScript)
	ld hl, AskSurfScript
	call PushScriptPointer

; conditions were met
	scf
	ret
	
.quit
; conditions were not met
	xor a
	ret
; ca2c

AskSurfScript: ; ca2c
	loadfont
	2writetext AskSurfText
	yesorno
	iftrue UsedSurfScript
	loadmovesprites
	end

AskSurfText: ; ca36
	TX_FAR _AskSurfText	; The water is calm.
	db "@"				; Want to SURF?
; ca3b

INCBIN "baserom.gbc",$ca3b,$10000 - $ca3b

SECTION "bank4",DATA,BANK[$4]

INCBIN "baserom.gbc",$10000,$1167a - $10000

TechnicalMachines: ; 0x1167a
	db DYNAMICPUNCH
	db HEADBUTT
	db CURSE
	db ROLLOUT
	db ROAR
	db TOXIC
	db ZAP_CANNON
	db ROCK_SMASH
	db PSYCH_UP
	db HIDDEN_POWER
	db SUNNY_DAY
	db SWEET_SCENT
	db SNORE
	db BLIZZARD
	db HYPER_BEAM
	db ICY_WIND
	db PROTECT
	db RAIN_DANCE
	db GIGA_DRAIN
	db ENDURE
	db FRUSTRATION
	db SOLARBEAM
	db IRON_TAIL
	db DRAGONBREATH
	db THUNDER
	db EARTHQUAKE
	db RETURN
	db DIG
	db PSYCHIC_M
	db SHADOW_BALL
	db MUD_SLAP
	db DOUBLE_TEAM
	db ICE_PUNCH
	db SWAGGER
	db SLEEP_TALK
	db SLUDGE_BOMB
	db SANDSTORM
	db FIRE_BLAST
	db SWIFT
	db DEFENSE_CURL
	db THUNDERPUNCH
	db DREAM_EATER
	db DETECT
	db REST
	db ATTRACT
	db THIEF
	db STEEL_WING
	db FIRE_PUNCH
	db FURY_CUTTER
	db NIGHTMARE
	db CUT
	db FLY
	db SURF
	db STRENGTH
	db FLASH
	db WHIRLPOOL
	db WATERFALL

INCBIN "baserom.gbc",$116b3,$11ce7 - $116b3

NameInputLower:
	db "a b c d e f g h i"
	db "j k l m n o p q r"
	db "s t u v w x y z  "
	db "× ( ) : ; [ ] ", $e1, " ", $e2
	db "UPPER  DEL   END "
BoxNameInputLower:
	db "a b c d e f g h i"
	db "j k l m n o p q r"
	db "s t u v w x y z  "
	db "é 'd 'l 'm 'r 's 't 'v 0"
	db "1 2 3 4 5 6 7 8 9"
	db "UPPER  DEL   END "
NameInputUpper:
	db "A B C D E F G H I"
	db "J K L M N O P Q R"
	db "S T U V W X Y Z  "
	db "- ? ! / . ,      "
	db "lower  DEL   END "
BoxNameInputUpper:
	db "A B C D E F G H I"
	db "J K L M N O P Q R"
	db "S T U V W X Y Z  "
	db "× ( ) : ; [ ] ", $e1, " ", $e2
	db "- ? ! ♂ ♀ / . , &"
	db "lower  DEL   END "


INCBIN "baserom.gbc",$11e5d,$14000 - $11e5d

SECTION "bank5",DATA,BANK[$5]

INCBIN "baserom.gbc",$14000,$14032 - $14000

GetTimeOfDay: ; 14032
; get time of day based on the current hour
	ld a, [$ff94] ; hour
	ld hl, TimeOfDayTable
	
.check
; if we're within the given time period,
; get the corresponding time of day
	cp [hl]
	jr c, .match
; else, get the next entry
	inc hl
	inc hl
; try again
	jr .check
	
.match
; get time of day
	inc hl
	ld a, [hl]
	ld [TimeOfDay], a
	ret
; 14044

TimeOfDayTable: ; 14044
; boundaries for the time of day
; 04-09 morn | 10-17 day | 18-03 nite
;	   hr, time of day
	db 04, $02 ; NITE
	db 10, $00 ; MORN
	db 18, $01 ; DAY
	db 24, $02 ; NITE
; 1404c

INCBIN "baserom.gbc",$1404c,$18000 - $1404c


SECTION "bank6",DATA,BANK[$6]

Tileset03GFX: ; 18000
INCBIN "gfx/tilesets/lz/03.lz"
; 18605

INCBIN "baserom.gbc", $18605, $19006 - $18605

Tileset00GFX:
Tileset01GFX: ; 19006
INCBIN "gfx/tilesets/lz/01.lz"
; 19c0d

INCBIN "baserom.gbc", $19c0d, $1a60e - $19c0d

Tileset29GFX: ; 1a60e
INCBIN "gfx/tilesets/lz/29.lz"
; 1af38

INCBIN "baserom.gbc", $1af38, $1b43e - $1af38

Tileset20GFX: ; 1b43e
INCBIN "gfx/tilesets/lz/20.lz"
; 1b8f1

INCBIN "baserom.gbc", $1b8f1, $1c000 - $1b8f1


SECTION "bank7",DATA,BANK[$7]

INCBIN "baserom.gbc", $1c000, $1c30c - $1c000

Tileset07GFX: ; 1c30c
INCBIN "gfx/tilesets/lz/07.lz"
; 1c73b

INCBIN "baserom.gbc", $1c73b, $1cc3c - $1c73b

Tileset09GFX: ; 1cc3c
INCBIN "gfx/tilesets/lz/09.lz"
; 1d047

INCBIN "baserom.gbc", $1d047, $1d54c - $1d047

Tileset06GFX: ; 1d54c
INCBIN "gfx/tilesets/lz/06.lz"
; 1d924

INCBIN "baserom.gbc", $1d924, $1de2c - $1d924

Tileset13GFX: ; 1de2c
INCBIN "gfx/tilesets/lz/13.lz"
; 1e58c

INCBIN "baserom.gbc", $1e58c, $1ea8c - $1e58c

Tileset24GFX: ; 1ea8c
INCBIN "gfx/tilesets/lz/24.lz"
; 1ee0e

INCBIN "baserom.gbc", $1ee0e, $1f31c - $1ee0e

Music_Credits: ; 0x1f31c
INCLUDE "music/credits.asm"
; 0x1fa8d

Music_Clair: ; 0x1fa8d
INCLUDE "music/clair.asm"
; 0x1fc87

Music_MobileAdapter: ; 0x1fc87
INCLUDE "music/mobileadapter.asm"
; 0x1ff6c

INCBIN "baserom.gbc",$1ff6c, $20000 - $1ff6c


SECTION "bank8",DATA,BANK[$8]

INCBIN "baserom.gbc", $20000, $20181 - $20000

Tileset23GFX: ; 20181
INCBIN "gfx/tilesets/lz/23.lz"
; 206d2

INCBIN "baserom.gbc", $206d2, $20be1 - $206d2

Tileset10GFX: ; 20be1
INCBIN "gfx/tilesets/lz/10.lz"
; 213e0

INCBIN "baserom.gbc", $213e0, $218e1 - $213e0

Tileset12GFX: ; 218e1
INCBIN "gfx/tilesets/lz/12.lz"
; 22026

INCBIN "baserom.gbc", $22026, $22531 - $22026

Tileset14GFX: ; 22531
INCBIN "gfx/tilesets/lz/14.lz"
; 22ae2

INCBIN "baserom.gbc", $22ae2, $22ff1 - $22ae2

Tileset17GFX: ; 22ff1
INCBIN "gfx/tilesets/lz/17.lz"
; 23391

INCBIN "baserom.gbc",$23391,$23b11 - $23391

EggMovePointers: ; 0x23b11
	dw BulbasaurEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw CharmanderEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw SquirtleEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw PidgeyEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw RattataEggMoves
	dw NoEggMoves
	dw SpearowEggMoves
	dw NoEggMoves
	dw EkansEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw SandshrewEggMoves
	dw NoEggMoves
	dw NidoranFEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NidoranMEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw VulpixEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw ZubatEggMoves
	dw NoEggMoves
	dw OddishEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw ParasEggMoves
	dw NoEggMoves
	dw VenonatEggMoves
	dw NoEggMoves
	dw DiglettEggMoves
	dw NoEggMoves
	dw MeowthEggMoves
	dw NoEggMoves
	dw PsyduckEggMoves
	dw NoEggMoves
	dw MankeyEggMoves
	dw NoEggMoves
	dw GrowlitheEggMoves
	dw NoEggMoves
	dw PoliwagEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw AbraEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw MachopEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw BellsproutEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw TentacoolEggMoves
	dw NoEggMoves
	dw GeodudeEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw PonytaEggMoves
	dw NoEggMoves
	dw SlowpokeEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw FarfetchDEggMoves
	dw DoduoEggMoves
	dw NoEggMoves
	dw SeelEggMoves
	dw NoEggMoves
	dw GrimerEggMoves
	dw NoEggMoves
	dw ShellderEggMoves
	dw NoEggMoves
	dw GastlyEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw OnixEggMoves
	dw DrowzeeEggMoves
	dw NoEggMoves
	dw KrabbyEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw ExeggcuteEggMoves
	dw NoEggMoves
	dw CuboneEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw LickitungEggMoves
	dw KoffingEggMoves
	dw NoEggMoves
	dw RhyhornEggMoves
	dw NoEggMoves
	dw ChanseyEggMoves
	dw TangelaEggMoves
	dw KangaskhanEggMoves
	dw HorseaEggMoves
	dw NoEggMoves
	dw GoldeenEggMoves
	dw NoEggMoves
if _CRYSTAL
	dw NoEggMoves
else
	dw StaryuEggMoves
endc
	dw NoEggMoves
	dw MrMimeEggMoves
	dw ScytherEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw PinsirEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw LaprasEggMoves
	dw NoEggMoves
	dw EeveeEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw OmanyteEggMoves
	dw NoEggMoves
	dw KabutoEggMoves
	dw NoEggMoves
	dw AerodactylEggMoves
	dw SnorlaxEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw DratiniEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw ChikoritaEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw CyndaquilEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw TotodileEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw SentretEggMoves
	dw NoEggMoves
	dw HoothootEggMoves
	dw NoEggMoves
	dw LedybaEggMoves
	dw NoEggMoves
	dw SpinarakEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw ChinchouEggMoves
	dw NoEggMoves
	dw PichuEggMoves
	dw CleffaEggMoves
	dw IgglybuffEggMoves
	dw TogepiEggMoves
	dw NoEggMoves
	dw NatuEggMoves
	dw NoEggMoves
	dw MareepEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw MarillEggMoves
	dw NoEggMoves
	dw SudowoodoEggMoves
	dw NoEggMoves
	dw HoppipEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw AipomEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw YanmaEggMoves
	dw WooperEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw MurkrowEggMoves
	dw NoEggMoves
	dw MisdreavusEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw GirafarigEggMoves
	dw PinecoEggMoves
	dw NoEggMoves
	dw DunsparceEggMoves
	dw GligarEggMoves
	dw NoEggMoves
	dw SnubbullEggMoves
	dw NoEggMoves
	dw QwilfishEggMoves
	dw NoEggMoves
	dw ShuckleEggMoves
	dw HeracrossEggMoves
	dw SneaselEggMoves
	dw TeddiursaEggMoves
	dw NoEggMoves
	dw SlugmaEggMoves
	dw NoEggMoves
	dw SwinubEggMoves
	dw NoEggMoves
	dw CorsolaEggMoves
	dw RemoraidEggMoves
	dw NoEggMoves
	dw DelibirdEggMoves
	dw MantineEggMoves
	dw SkarmoryEggMoves
	dw HoundourEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw PhanpyEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw StantlerEggMoves
	dw NoEggMoves
	dw TyrogueEggMoves
	dw NoEggMoves
	dw SmoochumEggMoves
	dw ElekidEggMoves
	dw MagbyEggMoves
	dw MiltankEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw LarvitarEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves
	dw NoEggMoves

; All instances of Charm, Steel Wing, Sweet Scent, and Lovely Kiss were
; removed from egg move lists in Crystal, because they are also TMs.

; Staryu's egg moves were removed in Crystal, because Staryu is genderless
; and can only breed with Ditto.

BulbasaurEggMoves:
	db LIGHT_SCREEN
	db SKULL_BASH
	db SAFEGUARD
if !_CRYSTAL
	db CHARM
endc
	db RAZOR_WIND
	db PETAL_DANCE
	db $ff

CharmanderEggMoves:
	db BELLY_DRUM
	db ANCIENTPOWER
	db ROCK_SLIDE
	db BITE
	db OUTRAGE
	db BEAT_UP
	db $ff

SquirtleEggMoves:
	db MIRROR_COAT
	db HAZE
	db MIST
	db CONFUSION
	db FORESIGHT
	db FLAIL
	db $ff

PidgeyEggMoves:
	db PURSUIT
	db FAINT_ATTACK
	db FORESIGHT
if !_CRYSTAL
	db STEEL_WING
endc
	db $ff

RattataEggMoves:
	db SCREECH
	db FLAME_WHEEL
	db FURY_SWIPES
	db BITE
	db COUNTER
	db REVERSAL
	db $ff

SpearowEggMoves:
	db FAINT_ATTACK
	db FALSE_SWIPE
	db SCARY_FACE
	db QUICK_ATTACK
	db TRI_ATTACK
	db $ff

EkansEggMoves:
	db PURSUIT
	db SLAM
	db SPITE
	db BEAT_UP
if _CRYSTAL
	db CRUNCH
endc
	db $ff

SandshrewEggMoves:
	db FLAIL
	db SAFEGUARD
	db COUNTER
	db RAPID_SPIN
if _CRYSTAL
	db METAL_CLAW
endc
	db $ff

NidoranFEggMoves:
	db SUPERSONIC
	db DISABLE
	db TAKE_DOWN
	db FOCUS_ENERGY
	db CHARM
	db COUNTER
	db BEAT_UP
	db $ff

NidoranMEggMoves:
	db SUPERSONIC
	db DISABLE
	db TAKE_DOWN
	db CONFUSION
	db AMNESIA
	db COUNTER
	db BEAT_UP
	db $ff

VulpixEggMoves:
	db FAINT_ATTACK
	db HYPNOSIS
	db FLAIL
	db SPITE
	db DISABLE
	db $ff

ZubatEggMoves:
	db QUICK_ATTACK
	db PURSUIT
	db FAINT_ATTACK
	db GUST
	db WHIRLWIND
	db $ff

OddishEggMoves:
	db SWORDS_DANCE
	db RAZOR_LEAF
	db FLAIL
	db SYNTHESIS
if !_CRYSTAL
	db CHARM
endc
	db $ff

ParasEggMoves:
	db FALSE_SWIPE
	db SCREECH
	db COUNTER
	db PSYBEAM
	db FLAIL
if !_CRYSTAL
	db SWEET_SCENT
endc
	db LIGHT_SCREEN
	db PURSUIT
	db $ff

VenonatEggMoves:
	db BATON_PASS
	db SCREECH
	db GIGA_DRAIN
	db $ff

DiglettEggMoves:
	db FAINT_ATTACK
	db SCREECH
	db ANCIENTPOWER
	db PURSUIT
	db BEAT_UP
	db $ff

MeowthEggMoves:
	db SPITE
	db CHARM
	db HYPNOSIS
	db AMNESIA
	db $ff

PsyduckEggMoves:
	db ICE_BEAM
	db HYPNOSIS
	db PSYBEAM
	db FORESIGHT
	db LIGHT_SCREEN
	db FUTURE_SIGHT
	db PSYCHIC_M
if _CRYSTAL
	db CROSS_CHOP
endc
	db $ff

MankeyEggMoves:
	db ROCK_SLIDE
	db FORESIGHT
	db MEDITATE
	db COUNTER
	db REVERSAL
	db BEAT_UP
	db $ff

GrowlitheEggMoves:
	db BODY_SLAM
	db SAFEGUARD
	db CRUNCH
	db THRASH
	db FIRE_SPIN
	db $ff

PoliwagEggMoves:
	db MIST
	db SPLASH
	db BUBBLEBEAM
	db HAZE
	db MIND_READER
	db $ff

AbraEggMoves:
	db LIGHT_SCREEN
	db ENCORE
	db BARRIER
	db $ff

MachopEggMoves:
	db LIGHT_SCREEN
	db MEDITATE
	db ROLLING_KICK
	db ENCORE
	db $ff

BellsproutEggMoves:
	db SWORDS_DANCE
	db ENCORE
	db REFLECT
	db SYNTHESIS
	db LEECH_LIFE
	db $ff

TentacoolEggMoves:
	db AURORA_BEAM
	db MIRROR_COAT
	db RAPID_SPIN
	db HAZE
	db SAFEGUARD
	db $ff

GeodudeEggMoves:
	db MEGA_PUNCH
	db ROCK_SLIDE
	db $ff

PonytaEggMoves:
	db FLAME_WHEEL
	db THRASH
	db DOUBLE_KICK
	db HYPNOSIS
	db CHARM
	db QUICK_ATTACK
	db $ff

SlowpokeEggMoves:
	db SAFEGUARD
	db BELLY_DRUM
	db FUTURE_SIGHT
	db STOMP
	db $ff

FarfetchDEggMoves:
if !_CRYSTAL
	db STEEL_WING
endc
	db FORESIGHT
	db MIRROR_MOVE
	db GUST
	db QUICK_ATTACK
	db FLAIL
	db $ff

DoduoEggMoves:
	db QUICK_ATTACK
	db SUPERSONIC
	db HAZE
	db FAINT_ATTACK
	db FLAIL
	db $ff

SeelEggMoves:
	db LICK
	db PERISH_SONG
	db DISABLE
	db PECK
	db SLAM
	db ENCORE
	db $ff

GrimerEggMoves:
	db HAZE
	db MEAN_LOOK
	db LICK
	db $ff

ShellderEggMoves:
	db BUBBLEBEAM
	db TAKE_DOWN
	db BARRIER
	db RAPID_SPIN
	db SCREECH
	db $ff

GastlyEggMoves:
	db PSYWAVE
	db PERISH_SONG
	db HAZE
	db $ff

OnixEggMoves:
	db ROCK_SLIDE
	db FLAIL
	db $ff

DrowzeeEggMoves:
	db LIGHT_SCREEN
	db BARRIER
	db $ff

KrabbyEggMoves:
	db DIG
	db HAZE
	db AMNESIA
	db FLAIL
	db SLAM
	db $ff

ExeggcuteEggMoves:
	db SYNTHESIS
	db MOONLIGHT
	db REFLECT
	db MEGA_DRAIN
	db ANCIENTPOWER
	db $ff

CuboneEggMoves:
	db ROCK_SLIDE
	db ANCIENTPOWER
	db BELLY_DRUM
	db SCREECH
	db SKULL_BASH
	db PERISH_SONG
if _CRYSTAL
	db SWORDS_DANCE
endc
	db $ff

LickitungEggMoves:
	db BELLY_DRUM
	db MAGNITUDE
	db BODY_SLAM
	db $ff

KoffingEggMoves:
	db SCREECH
	db PSYWAVE
	db PSYBEAM
	db DESTINY_BOND
	db PAIN_SPLIT
	db $ff

RhyhornEggMoves:
	db CRUNCH
	db REVERSAL
	db ROCK_SLIDE
	db THRASH
	db PURSUIT
	db COUNTER
	db MAGNITUDE
	db $ff

ChanseyEggMoves:
	db PRESENT
	db METRONOME
	db HEAL_BELL
	db $ff

TangelaEggMoves:
	db FLAIL
	db CONFUSION
	db MEGA_DRAIN
	db REFLECT
	db AMNESIA
	db $ff

KangaskhanEggMoves:
	db STOMP
	db FORESIGHT
	db FOCUS_ENERGY
	db SAFEGUARD
	db DISABLE
	db $ff

HorseaEggMoves:
	db FLAIL
	db AURORA_BEAM
	db OCTAZOOKA
	db DISABLE
	db SPLASH
	db DRAGON_RAGE
	db $ff

GoldeenEggMoves:
	db PSYBEAM
	db HAZE
	db HYDRO_PUMP
	db $ff

if !_CRYSTAL
StaryuEggMoves:
	db AURORA_BEAM
	db BARRIER
	db SUPERSONIC
	db $ff
endc

MrMimeEggMoves:
	db FUTURE_SIGHT
	db HYPNOSIS
	db MIMIC
	db $ff

ScytherEggMoves:
	db COUNTER
	db SAFEGUARD
	db BATON_PASS
	db RAZOR_WIND
	db REVERSAL
	db LIGHT_SCREEN
	db $ff

PinsirEggMoves:
	db FURY_ATTACK
	db FLAIL
	db $ff

LaprasEggMoves:
	db AURORA_BEAM
	db FORESIGHT
	db $ff

EeveeEggMoves:
	db FLAIL
	db CHARM
	db $ff

OmanyteEggMoves:
	db BUBBLEBEAM
	db AURORA_BEAM
	db SLAM
	db SUPERSONIC
	db HAZE
	db $ff

KabutoEggMoves:
	db BUBBLEBEAM
	db AURORA_BEAM
	db RAPID_SPIN
	db DIG
	db FLAIL
	db $ff

AerodactylEggMoves:
	db WHIRLWIND
	db PURSUIT
	db FORESIGHT
if !_CRYSTAL
	db STEEL_WING
endc
	db $ff

SnorlaxEggMoves:
	db LICK
if !_CRYSTAL
	db CHARM
endc
	db $ff

DratiniEggMoves:
	db LIGHT_SCREEN
	db MIST
	db HAZE
	db SUPERSONIC
	db $ff

ChikoritaEggMoves:
	db VINE_WHIP
	db LEECH_SEED
	db COUNTER
	db ANCIENTPOWER
	db FLAIL
	db SWORDS_DANCE
	db $ff

CyndaquilEggMoves:
	db FURY_SWIPES
	db QUICK_ATTACK
	db REVERSAL
	db THRASH
	db FORESIGHT
if _CRYSTAL
	db SUBMISSION
endc
	db $ff

TotodileEggMoves:
	db CRUNCH
	db THRASH
	db HYDRO_PUMP
	db ANCIENTPOWER
	db RAZOR_WIND
	db ROCK_SLIDE
	db $ff

SentretEggMoves:
	db DOUBLE_EDGE
	db PURSUIT
	db SLASH
	db FOCUS_ENERGY
	db REVERSAL
	db $ff

HoothootEggMoves:
	db MIRROR_MOVE
	db SUPERSONIC
	db FAINT_ATTACK
	db WING_ATTACK
	db WHIRLWIND
if _CRYSTAL
	db SKY_ATTACK
endc
	db $ff

LedybaEggMoves:
	db PSYBEAM
	db BIDE
	db LIGHT_SCREEN
	db $ff

SpinarakEggMoves:
	db PSYBEAM
	db DISABLE
	db SONICBOOM
	db BATON_PASS
	db PURSUIT
	db $ff

ChinchouEggMoves:
	db FLAIL
	db SUPERSONIC
	db SCREECH
	db $ff

PichuEggMoves:
	db REVERSAL
	db BIDE
	db PRESENT
	db ENCORE
	db DOUBLESLAP
	db $ff

CleffaEggMoves:
	db PRESENT
	db METRONOME
	db AMNESIA
	db BELLY_DRUM
	db SPLASH
	db MIMIC
	db $ff

IgglybuffEggMoves:
	db PERISH_SONG
	db PRESENT
	db FAINT_ATTACK
	db $ff

TogepiEggMoves:
	db PRESENT
	db MIRROR_MOVE
	db PECK
	db FORESIGHT
	db FUTURE_SIGHT
	db $ff

NatuEggMoves:
	db HAZE
	db DRILL_PECK
	db QUICK_ATTACK
	db FAINT_ATTACK
	db STEEL_WING
	db $ff

MareepEggMoves:
	db THUNDERBOLT
	db TAKE_DOWN
	db BODY_SLAM
	db SAFEGUARD
	db SCREECH
	db REFLECT
	db $ff

MarillEggMoves:
	db LIGHT_SCREEN
	db PRESENT
	db AMNESIA
	db FUTURE_SIGHT
	db BELLY_DRUM
	db PERISH_SONG
	db SUPERSONIC
	db FORESIGHT
	db $ff

SudowoodoEggMoves:
	db SELFDESTRUCT
	db $ff

HoppipEggMoves:
	db CONFUSION
	db GROWL
	db ENCORE
	db DOUBLE_EDGE
	db REFLECT
	db AMNESIA
	db PAY_DAY
	db $ff

AipomEggMoves:
	db COUNTER
	db SCREECH
	db PURSUIT
	db AGILITY
	db SPITE
	db SLAM
	db DOUBLESLAP
	db BEAT_UP
	db $ff

YanmaEggMoves:
	db WHIRLWIND
	db REVERSAL
	db LEECH_LIFE
	db $ff

WooperEggMoves:
	db BODY_SLAM
	db ANCIENTPOWER
	db SAFEGUARD
	db $ff

MurkrowEggMoves:
	db WHIRLWIND
	db DRILL_PECK
	db QUICK_ATTACK
	db MIRROR_MOVE
	db WING_ATTACK
if _CRYSTAL
	db SKY_ATTACK
endc
	db $ff

MisdreavusEggMoves:
	db SCREECH
	db DESTINY_BOND
	db $ff

GirafarigEggMoves:
	db TAKE_DOWN
	db AMNESIA
	db FORESIGHT
	db FUTURE_SIGHT
	db BEAT_UP
	db $ff

PinecoEggMoves:
	db REFLECT
	db PIN_MISSILE
	db FLAIL
	db SWIFT
	db $ff

DunsparceEggMoves:
	db BIDE
	db ANCIENTPOWER
	db ROCK_SLIDE
	db BITE
	db RAGE
	db $ff

GligarEggMoves:
	db METAL_CLAW
	db WING_ATTACK
	db RAZOR_WIND
	db COUNTER
	db $ff

SnubbullEggMoves:
	db METRONOME
	db FAINT_ATTACK
	db REFLECT
	db PRESENT
	db CRUNCH
	db HEAL_BELL
	db LICK
	db LEER
	db $ff

QwilfishEggMoves:
	db FLAIL
	db HAZE
	db BUBBLEBEAM
	db SUPERSONIC
	db $ff

ShuckleEggMoves:
	db SWEET_SCENT
	db $ff

HeracrossEggMoves:
	db HARDEN
	db BIDE
	db FLAIL
	db $ff

SneaselEggMoves:
	db COUNTER
	db SPITE
	db FORESIGHT
	db REFLECT
	db BITE
	db $ff

TeddiursaEggMoves:
	db CRUNCH
	db TAKE_DOWN
	db SEISMIC_TOSS
	db FOCUS_ENERGY
	db COUNTER
if _CRYSTAL
	db METAL_CLAW
endc
	db $ff

SlugmaEggMoves:
	db ACID_ARMOR
	db $ff

SwinubEggMoves:
	db TAKE_DOWN
	db BITE
	db BODY_SLAM
	db ROCK_SLIDE
	db ANCIENTPOWER
	db $ff

CorsolaEggMoves:
	db ROCK_SLIDE
	db SAFEGUARD
	db SCREECH
	db MIST
	db AMNESIA
	db $ff

RemoraidEggMoves:
	db AURORA_BEAM
	db OCTAZOOKA
	db SUPERSONIC
	db HAZE
	db SCREECH
	db $ff

DelibirdEggMoves:
	db AURORA_BEAM
	db QUICK_ATTACK
	db FUTURE_SIGHT
	db SPLASH
	db RAPID_SPIN
	db $ff

MantineEggMoves:
	db TWISTER
	db HYDRO_PUMP
	db HAZE
	db SLAM
	db $ff

SkarmoryEggMoves:
	db DRILL_PECK
	db PURSUIT
	db WHIRLWIND
if _CRYSTAL
	db SKY_ATTACK
endc
	db $ff

HoundourEggMoves:
	db FIRE_SPIN
	db RAGE
	db PURSUIT
	db COUNTER
	db SPITE
	db REVERSAL
	db BEAT_UP
	db $ff

PhanpyEggMoves:
	db FOCUS_ENERGY
	db BODY_SLAM
	db ANCIENTPOWER
if _CRYSTAL
	db WATER_GUN
endc
	db $ff

StantlerEggMoves:
	db REFLECT
	db SPITE
	db DISABLE
	db LIGHT_SCREEN
	db BITE
	db $ff

TyrogueEggMoves:
	db RAPID_SPIN
	db HI_JUMP_KICK
	db MACH_PUNCH
	db MIND_READER
	db $ff

SmoochumEggMoves:
if !_CRYSTAL
	db LOVELY_KISS
endc
	db MEDITATE
	db $ff

ElekidEggMoves:
	db KARATE_CHOP
	db BARRIER
	db ROLLING_KICK
	db MEDITATE
if _CRYSTAL
	db CROSS_CHOP
endc
	db $ff

MagbyEggMoves:
	db KARATE_CHOP
	db MEGA_PUNCH
	db BARRIER
	db SCREECH
if _CRYSTAL
	db CROSS_CHOP
endc
	db $ff

MiltankEggMoves:
	db PRESENT
	db REVERSAL
	db SEISMIC_TOSS
	db $ff

LarvitarEggMoves:
	db PURSUIT
	db STOMP
	db OUTRAGE
	db FOCUS_ENERGY
	db ANCIENTPOWER
	db $ff

NoEggMoves:
	db $ff

SECTION "bank9",DATA,BANK[$9]

INCBIN "baserom.gbc",$24000,$270c4 - $24000

GetTrainerDVs: ; 270c4
; get dvs based on trainer class
; output: bc
	push hl
; dec trainer class so there's no filler entry for $00
	ld a, [OtherTrainerClass]
	dec a
	ld c, a
	ld b, $0
; seek table
	ld hl, TrainerClassDVs
	add hl, bc
	add hl, bc
; get dvs
	ld a, [hli]
	ld b, a
	ld c, [hl]
; we're done
	pop hl
	ret
; 270d6

TrainerClassDVs ; 270d6
;   AtkDef, SpdSpc
	db $9A, $77 ; falkner
	db $88, $88 ; bugsy
	db $98, $88 ; whitney
	db $98, $88 ; morty
	db $98, $88 ; pryce
	db $98, $88 ; jasmine
	db $98, $88 ; chuck
	db $7C, $DD ; clair
	db $DD, $DD ; rival1
	db $98, $88 ; pokemon prof
	db $DC, $DD ; will
	db $DC, $DD ; cal
	db $DC, $DD ; bruno
	db $7F, $DF ; karen
	db $DC, $DD ; koga
	db $DC, $DD ; champion
	db $98, $88 ; brock
	db $78, $88 ; misty
	db $98, $88 ; lt surge
	db $98, $88 ; scientist
	db $78, $88 ; erika
	db $98, $88 ; youngster
	db $98, $88 ; schoolboy
	db $98, $88 ; bird keeper
	db $58, $88 ; lass
	db $98, $88 ; janine
	db $D8, $C8 ; cooltrainerm
	db $7C, $C8 ; cooltrainerf
	db $69, $C8 ; beauty
	db $98, $88 ; pokemaniac
	db $D8, $A8 ; gruntm
	db $98, $88 ; gentleman
	db $98, $88 ; skier
	db $68, $88 ; teacher
	db $7D, $87 ; sabrina
	db $98, $88 ; bug catcher
	db $98, $88 ; fisher
	db $98, $88 ; swimmerm
	db $78, $88 ; swimmerf
	db $98, $88 ; sailor
	db $98, $88 ; super nerd
	db $98, $88 ; rival2
	db $98, $88 ; guitarist
	db $A8, $88 ; hiker
	db $98, $88 ; biker
	db $98, $88 ; blaine
	db $98, $88 ; burglar
	db $98, $88 ; firebreather
	db $98, $88 ; juggler
	db $98, $88 ; blackbelt
	db $D8, $A8 ; executivem
	db $98, $88 ; psychic
	db $6A, $A8 ; picnicker
	db $98, $88 ; camper
	db $7E, $A8 ; executivef
	db $98, $88 ; sage
	db $78, $88 ; medium
	db $98, $88 ; boarder
	db $98, $88 ; pokefanm
	db $68, $8A ; kimono girl
	db $68, $A8 ; twins
	db $6D, $88 ; pokefanf
	db $FD, $DE ; red
	db $9D, $DD ; blue
	db $98, $88 ; officer
	db $7E, $A8 ; gruntf
	db $98, $88 ; mysticalman
; 2715c

INCBIN "baserom.gbc",$2715c,$28000 - $2715c

SECTION "bankA",DATA,BANK[$A]

INCBIN "baserom.gbc",$28000,$2a2a0 - $28000

SpecialRoamMons: ; 2a2a0
; initialize RoamMon structs
; include commented-out parts from the gs function

; species
	ld a, RAIKOU
	ld [RoamMon1Species], a
	ld a, ENTEI
	ld [RoamMon2Species], a
;	ld a, SUICUNE
;	ld [RoamMon3Species], a

; level
	ld a, 40
	ld [RoamMon1Level], a
	ld [RoamMon2Level], a
;	ld [RoamMon3Level], a

; raikou starting map
	ld a, GROUP_ROUTE_42
	ld [RoamMon1MapGroup], a
	ld a, MAP_ROUTE_42
	ld [RoamMon1MapNumber], a

; entei starting map
	ld a, GROUP_ROUTE_37
	ld [RoamMon2MapGroup], a
	ld a, MAP_ROUTE_37
	ld [RoamMon2MapNumber], a

; suicune starting map
;	ld a, GROUP_ROUTE_38
;	ld [RoamMon3MapGroup], a
;	ld a, MAP_ROUTE_38
;	ld [RoamMon3MapNumber], a

; hp
	xor a ; generate new stats
	ld [RoamMon1CurHP], a
	ld [RoamMon2CurHP], a
;	ld [RoamMon3CurHP], a

	ret
; 2a2ce

INCBIN "baserom.gbc",$2a2ce,$2a5e9 - $2a2ce

WildMons1: ; 0x2a5e9
; Johto Pokémon in grass

	db GROUP_SPROUT_TOWER_2F, MAP_SPROUT_TOWER_2F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 3,RATTATA
	db 4,RATTATA
	db 5,RATTATA
	db 3,RATTATA
	db 6,RATTATA
	db 5,RATTATA
	db 5,RATTATA
	; day
	db 3,RATTATA
	db 4,RATTATA
	db 5,RATTATA
	db 3,RATTATA
	db 6,RATTATA
	db 5,RATTATA
	db 5,RATTATA
	; nite
	db 3,GASTLY
	db 4,GASTLY
	db 5,GASTLY
	db 3,RATTATA
	db 6,GASTLY
	db 5,RATTATA
	db 5,RATTATA

	db GROUP_SPROUT_TOWER_3F, MAP_SPROUT_TOWER_3F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 3,RATTATA
	db 4,RATTATA
	db 5,RATTATA
	db 3,RATTATA
	db 6,RATTATA
	db 5,RATTATA
	db 5,RATTATA
	; day
	db 3,RATTATA
	db 4,RATTATA
	db 5,RATTATA
	db 3,RATTATA
	db 6,RATTATA
	db 5,RATTATA
	db 5,RATTATA
	; nite
	db 3,GASTLY
	db 4,GASTLY
	db 5,GASTLY
	db 3,RATTATA
	db 6,GASTLY
	db 5,RATTATA
	db 5,RATTATA

	db GROUP_TIN_TOWER_2F, MAP_TIN_TOWER_2F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; day
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; nite
	db 20,GASTLY
	db 21,GASTLY
	db 22,GASTLY
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA

	db GROUP_TIN_TOWER_3F, MAP_TIN_TOWER_3F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; day
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; nite
	db 20,GASTLY
	db 21,GASTLY
	db 22,GASTLY
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA

	db GROUP_TIN_TOWER_4F, MAP_TIN_TOWER_4F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; day
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; nite
	db 20,GASTLY
	db 21,GASTLY
	db 22,GASTLY
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA

	db GROUP_TIN_TOWER_5F, MAP_TIN_TOWER_5F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; day
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; nite
	db 20,GASTLY
	db 21,GASTLY
	db 22,GASTLY
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA

	db GROUP_TIN_TOWER_6F, MAP_TIN_TOWER_6F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; day
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; nite
	db 20,GASTLY
	db 21,GASTLY
	db 22,GASTLY
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA

	db GROUP_TIN_TOWER_7F, MAP_TIN_TOWER_7F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; day
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; nite
	db 20,GASTLY
	db 21,GASTLY
	db 22,GASTLY
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA

	db GROUP_TIN_TOWER_8F, MAP_TIN_TOWER_8F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; day
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; nite
	db 20,GASTLY
	db 21,GASTLY
	db 22,GASTLY
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA

	db GROUP_TIN_TOWER_9F, MAP_TIN_TOWER_9F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; day
	db 20,RATTATA
	db 21,RATTATA
	db 22,RATTATA
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA
	; nite
	db 20,GASTLY
	db 21,GASTLY
	db 22,GASTLY
	db 22,RATTATA
	db 23,RATTATA
	db 24,RATTATA
	db 24,RATTATA

	db GROUP_BURNED_TOWER_1F, MAP_BURNED_TOWER_1F
	db $0a,$0a,$0a ; encounter rates: morn/day/nite
	; morn
	db 13,RATTATA
	db 14,KOFFING
	db 15,RATTATA
	db 14,ZUBAT
	db 15,RATTATA
	db 15,RATICATE
	db 15,RATICATE
	; day
	db 13,RATTATA
	db 14,KOFFING
	db 15,RATTATA
	db 14,ZUBAT
	db 15,RATTATA
	db 15,RATICATE
	db 15,RATICATE
	; nite
	db 13,RATTATA
	db 14,KOFFING
	db 15,RATTATA
	db 14,ZUBAT
	db 15,RATTATA
	db 15,RATICATE
	db 15,RATICATE

	db GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 14,RATTATA
	db 14,KOFFING
	db 16,KOFFING
	db 15,ZUBAT
	db 12,KOFFING
	db 16,KOFFING
	db 16,WEEZING
	; day
	db 14,RATTATA
	db 14,KOFFING
	db 16,KOFFING
	db 15,ZUBAT
	db 12,KOFFING
	db 16,KOFFING
	db 16,WEEZING
	; nite
	db 14,RATTATA
	db 14,KOFFING
	db 16,KOFFING
	db 15,ZUBAT
	db 12,KOFFING
	db 16,KOFFING
	db 16,WEEZING

	db GROUP_NATIONAL_PARK, MAP_NATIONAL_PARK
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 12,NIDORAN_M
	db 12,NIDORAN_F
	db 14,LEDYBA
	db 13,PIDGEY
	db 10,CATERPIE
	db 10,WEEDLE
	db 10,WEEDLE
	; day
	db 12,NIDORAN_F
	db 12,NIDORAN_M
	db 14,SUNKERN
	db 13,PIDGEY
	db 10,CATERPIE
	db 10,WEEDLE
	db 10,WEEDLE
	; nite
	db 12,PSYDUCK
	db 13,HOOTHOOT
	db 14,SPINARAK
	db 15,HOOTHOOT
	db 10,VENONAT
	db 12,VENONAT
	db 12,VENONAT

	db GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	db $0a,$0a,$0a ; encounter rates: morn/day/nite
	; morn
	db 20,NATU
	db 22,NATU
	db 18,NATU
	db 24,NATU
	db 20,SMEARGLE
	db 22,SMEARGLE
	db 22,SMEARGLE
	; day
	db 20,NATU
	db 22,NATU
	db 18,NATU
	db 24,NATU
	db 20,SMEARGLE
	db 22,SMEARGLE
	db 22,SMEARGLE
	; nite
	db 20,NATU
	db 22,NATU
	db 18,NATU
	db 24,NATU
	db 22,WOOPER
	db 22,QUAGSIRE
	db 22,QUAGSIRE

	db GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	; day
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	; nite
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN
	db 5,UNOWN

	db GROUP_UNION_CAVE_1F, MAP_UNION_CAVE_1F
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 6,GEODUDE
	db 6,SANDSHREW
	db 5,ZUBAT
	db 4,RATTATA
	db 7,ZUBAT
	db 6,ONIX
	db 6,ONIX
	; day
	db 6,GEODUDE
	db 6,SANDSHREW
	db 5,ZUBAT
	db 4,RATTATA
	db 7,ZUBAT
	db 6,ONIX
	db 6,ONIX
	; nite
	db 6,GEODUDE
	db 6,RATTATA
	db 5,WOOPER
	db 4,RATTATA
	db 7,ZUBAT
	db 6,ONIX
	db 6,ONIX

	db GROUP_UNION_CAVE_B1F, MAP_UNION_CAVE_B1F
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 8,GEODUDE
	db 6,ZUBAT
	db 8,ZUBAT
	db 8,ONIX
	db 6,RATTATA
	db 8,RATTATA
	db 8,RATTATA
	; day
	db 8,GEODUDE
	db 6,ZUBAT
	db 8,ZUBAT
	db 8,ONIX
	db 6,RATTATA
	db 8,RATTATA
	db 8,RATTATA
	; nite
	db 8,GEODUDE
	db 6,ZUBAT
	db 8,WOOPER
	db 8,ONIX
	db 6,RATTATA
	db 8,RATTATA
	db 8,RATTATA

	db GROUP_UNION_CAVE_B2F, MAP_UNION_CAVE_B2F
	db $0a,$0a,$0a ; encounter rates: morn/day/nite
	; morn
	db 22,ZUBAT
	db 22,GOLBAT
	db 22,ZUBAT
	db 21,RATICATE
	db 20,GEODUDE
	db 23,ONIX
	db 23,ONIX
	; day
	db 22,ZUBAT
	db 22,GOLBAT
	db 22,ZUBAT
	db 21,RATICATE
	db 20,GEODUDE
	db 23,ONIX
	db 23,ONIX
	; nite
	db 22,ZUBAT
	db 22,GOLBAT
	db 22,QUAGSIRE
	db 21,RATICATE
	db 20,GEODUDE
	db 23,ONIX
	db 23,ONIX

	db GROUP_SLOWPOKE_WELL_B1F, MAP_SLOWPOKE_WELL_B1F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 5,ZUBAT
	db 6,ZUBAT
	db 7,ZUBAT
	db 6,SLOWPOKE
	db 8,ZUBAT
	db 8,SLOWPOKE
	db 8,SLOWPOKE
	; day
	db 5,ZUBAT
	db 6,ZUBAT
	db 7,ZUBAT
	db 6,SLOWPOKE
	db 8,ZUBAT
	db 8,SLOWPOKE
	db 8,SLOWPOKE
	; nite
	db 5,ZUBAT
	db 6,ZUBAT
	db 7,ZUBAT
	db 6,SLOWPOKE
	db 8,ZUBAT
	db 8,SLOWPOKE
	db 8,SLOWPOKE

	db GROUP_SLOWPOKE_WELL_B2F, MAP_SLOWPOKE_WELL_B2F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 21,ZUBAT
	db 23,ZUBAT
	db 19,ZUBAT
	db 21,SLOWPOKE
	db 23,GOLBAT
	db 23,SLOWPOKE
	db 23,SLOWPOKE
	; day
	db 21,ZUBAT
	db 23,ZUBAT
	db 19,ZUBAT
	db 21,SLOWPOKE
	db 23,GOLBAT
	db 23,SLOWPOKE
	db 23,SLOWPOKE
	; nite
	db 21,ZUBAT
	db 23,ZUBAT
	db 19,ZUBAT
	db 21,SLOWPOKE
	db 23,GOLBAT
	db 23,SLOWPOKE
	db 23,SLOWPOKE

	db GROUP_ILEX_FOREST, MAP_ILEX_FOREST
	db $0a,$0a,$0a ; encounter rates: morn/day/nite
	; morn
	db 5,CATERPIE
	db 5,WEEDLE
	db 7,METAPOD
	db 7,KAKUNA
	db 7,PIDGEY
	db 6,PARAS
	db 6,PARAS
	; day
	db 5,CATERPIE
	db 5,WEEDLE
	db 7,METAPOD
	db 7,KAKUNA
	db 7,PIDGEY
	db 6,PARAS
	db 6,PARAS
	; nite
	db 5,ODDISH
	db 5,VENONAT
	db 7,ODDISH
	db 7,PSYDUCK
	db 7,HOOTHOOT
	db 6,PARAS
	db 6,PARAS

	db GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 14,RATTATA
	db 13,ZUBAT
	db 14,MACHOP
	db 13,GOLBAT
	db 14,GEODUDE
	db 16,RATICATE
	db 16,RATICATE
	; day
	db 14,RATTATA
	db 13,ZUBAT
	db 14,MACHOP
	db 13,GOLBAT
	db 14,GEODUDE
	db 16,RATICATE
	db 16,RATICATE
	; nite
	db 14,RATTATA
	db 13,ZUBAT
	db 14,MARILL
	db 13,GOLBAT
	db 14,GEODUDE
	db 16,RATICATE
	db 16,RATICATE

	db GROUP_MOUNT_MORTAR_1F_INSIDE, MAP_MOUNT_MORTAR_1F_INSIDE
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 13,GEODUDE
	db 14,RATTATA
	db 15,MACHOP
	db 14,RATICATE
	db 15,ZUBAT
	db 15,GOLBAT
	db 15,GOLBAT
	; day
	db 13,GEODUDE
	db 14,RATTATA
	db 15,MACHOP
	db 14,RATICATE
	db 15,ZUBAT
	db 15,GOLBAT
	db 15,GOLBAT
	; nite
	db 13,GEODUDE
	db 14,RATTATA
	db 15,RATICATE
	db 14,ZUBAT
	db 15,MARILL
	db 15,GOLBAT
	db 15,GOLBAT

	db GROUP_MOUNT_MORTAR_2F_INSIDE, MAP_MOUNT_MORTAR_2F_INSIDE
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 31,GRAVELER
	db 32,MACHOKE
	db 31,GEODUDE
	db 30,RATICATE
	db 28,MACHOP
	db 30,GOLBAT
	db 30,GOLBAT
	; day
	db 31,GRAVELER
	db 32,MACHOKE
	db 31,GEODUDE
	db 30,RATICATE
	db 28,MACHOP
	db 30,GOLBAT
	db 30,GOLBAT
	; nite
	db 31,GRAVELER
	db 31,GEODUDE
	db 30,RATICATE
	db 30,GOLBAT
	db 28,MARILL
	db 32,GOLBAT
	db 32,GOLBAT

	db GROUP_MOUNT_MORTAR_B1F, MAP_MOUNT_MORTAR_B1F
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 15,ZUBAT
	db 17,ZUBAT
	db 17,GOLBAT
	db 16,MACHOP
	db 16,GEODUDE
	db 18,RATICATE
	db 18,RATICATE
	; day
	db 15,ZUBAT
	db 17,ZUBAT
	db 17,GOLBAT
	db 16,MACHOP
	db 16,GEODUDE
	db 18,RATICATE
	db 18,RATICATE
	; nite
	db 15,ZUBAT
	db 17,ZUBAT
	db 17,GOLBAT
	db 16,MARILL
	db 16,GEODUDE
	db 18,RATICATE
	db 18,RATICATE

	db GROUP_ICE_PATH_1F, MAP_ICE_PATH_1F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 21,SWINUB
	db 22,ZUBAT
	db 22,GOLBAT
	db 23,SWINUB
	db 24,GOLBAT
	db 22,GOLBAT
	db 22,GOLBAT
	; day
	db 21,SWINUB
	db 22,ZUBAT
	db 22,GOLBAT
	db 23,SWINUB
	db 24,GOLBAT
	db 22,GOLBAT
	db 22,GOLBAT
	; nite
	db 21,DELIBIRD
	db 22,ZUBAT
	db 22,GOLBAT
	db 23,DELIBIRD
	db 24,GOLBAT
	db 22,GOLBAT
	db 22,GOLBAT

	db GROUP_ICE_PATH_B1F, MAP_ICE_PATH_B1F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 22,SWINUB
	db 23,ZUBAT
	db 23,GOLBAT
	db 24,SWINUB
	db 25,GOLBAT
	db 23,GOLBAT
	db 22,JYNX
	; day
	db 22,SWINUB
	db 23,ZUBAT
	db 23,GOLBAT
	db 24,SWINUB
	db 25,GOLBAT
	db 23,GOLBAT
	db 22,JYNX
	; nite
	db 22,DELIBIRD
	db 23,ZUBAT
	db 23,GOLBAT
	db 24,DELIBIRD
	db 25,GOLBAT
	db 23,GOLBAT
	db 22,SNEASEL

	db GROUP_ICE_PATH_B2F_MAHOGANY_SIDE, MAP_ICE_PATH_B2F_MAHOGANY_SIDE
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 23,SWINUB
	db 24,ZUBAT
	db 24,GOLBAT
	db 25,SWINUB
	db 26,GOLBAT
	db 22,JYNX
	db 24,JYNX
	; day
	db 23,SWINUB
	db 24,ZUBAT
	db 24,GOLBAT
	db 25,SWINUB
	db 26,GOLBAT
	db 22,JYNX
	db 24,JYNX
	; nite
	db 23,DELIBIRD
	db 24,ZUBAT
	db 24,GOLBAT
	db 25,DELIBIRD
	db 26,GOLBAT
	db 22,SNEASEL
	db 24,SNEASEL

	db GROUP_ICE_PATH_B2F_BLACKTHORN_SIDE, MAP_ICE_PATH_B2F_BLACKTHORN_SIDE
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 23,SWINUB
	db 24,ZUBAT
	db 24,GOLBAT
	db 25,SWINUB
	db 26,GOLBAT
	db 22,JYNX
	db 24,JYNX
	; day
	db 23,SWINUB
	db 24,ZUBAT
	db 24,GOLBAT
	db 25,SWINUB
	db 26,GOLBAT
	db 22,JYNX
	db 24,JYNX
	; nite
	db 23,DELIBIRD
	db 24,ZUBAT
	db 24,GOLBAT
	db 25,DELIBIRD
	db 26,GOLBAT
	db 22,SNEASEL
	db 24,SNEASEL

	db GROUP_ICE_PATH_B3F, MAP_ICE_PATH_B3F
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 24,SWINUB
	db 25,ZUBAT
	db 25,GOLBAT
	db 26,SWINUB
	db 22,JYNX
	db 24,JYNX
	db 26,JYNX
	; day
	db 24,SWINUB
	db 25,ZUBAT
	db 25,GOLBAT
	db 26,SWINUB
	db 22,JYNX
	db 24,JYNX
	db 26,JYNX
	; nite
	db 24,DELIBIRD
	db 25,ZUBAT
	db 25,GOLBAT
	db 26,DELIBIRD
	db 22,SNEASEL
	db 24,SNEASEL
	db 26,SNEASEL

	db GROUP_WHIRL_ISLAND_NW, MAP_WHIRL_ISLAND_NW
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; day
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; nite
	db 22,KRABBY
	db 23,ZUBAT
	db 22,KRABBY
	db 24,KRABBY
	db 25,GOLBAT
	db 24,GOLBAT
	db 24,GOLBAT

	db GROUP_WHIRL_ISLAND_NE, MAP_WHIRL_ISLAND_NE
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; day
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; nite
	db 22,KRABBY
	db 23,ZUBAT
	db 22,KRABBY
	db 24,KRABBY
	db 25,GOLBAT
	db 24,GOLBAT
	db 24,GOLBAT

	db GROUP_WHIRL_ISLAND_SW, MAP_WHIRL_ISLAND_SW
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; day
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; nite
	db 22,KRABBY
	db 23,ZUBAT
	db 22,KRABBY
	db 24,KRABBY
	db 25,GOLBAT
	db 24,GOLBAT
	db 24,GOLBAT

	db GROUP_WHIRL_ISLAND_CAVE, MAP_WHIRL_ISLAND_CAVE
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; day
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; nite
	db 22,KRABBY
	db 23,ZUBAT
	db 22,KRABBY
	db 24,KRABBY
	db 25,GOLBAT
	db 24,GOLBAT
	db 24,GOLBAT

	db GROUP_WHIRL_ISLAND_SE, MAP_WHIRL_ISLAND_SE
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; day
	db 22,KRABBY
	db 23,ZUBAT
	db 22,SEEL
	db 24,KRABBY
	db 25,GOLBAT
	db 24,SEEL
	db 24,SEEL
	; nite
	db 22,KRABBY
	db 23,ZUBAT
	db 22,KRABBY
	db 24,KRABBY
	db 25,GOLBAT
	db 24,GOLBAT
	db 24,GOLBAT

	db GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 23,KRABBY
	db 24,ZUBAT
	db 23,SEEL
	db 25,KRABBY
	db 26,GOLBAT
	db 25,SEEL
	db 25,SEEL
	; day
	db 23,KRABBY
	db 24,ZUBAT
	db 23,SEEL
	db 25,KRABBY
	db 26,GOLBAT
	db 25,SEEL
	db 25,SEEL
	; nite
	db 23,KRABBY
	db 24,ZUBAT
	db 23,KRABBY
	db 25,KRABBY
	db 26,GOLBAT
	db 25,GOLBAT
	db 25,GOLBAT

	db GROUP_WHIRL_ISLAND_B2F, MAP_WHIRL_ISLAND_B2F
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 24,KRABBY
	db 25,ZUBAT
	db 24,SEEL
	db 26,KRABBY
	db 27,GOLBAT
	db 26,SEEL
	db 26,SEEL
	; day
	db 24,KRABBY
	db 25,ZUBAT
	db 24,SEEL
	db 26,KRABBY
	db 27,GOLBAT
	db 26,SEEL
	db 26,SEEL
	; nite
	db 24,KRABBY
	db 25,ZUBAT
	db 24,KRABBY
	db 26,KRABBY
	db 27,GOLBAT
	db 26,GOLBAT
	db 26,GOLBAT

	db GROUP_WHIRL_ISLAND_LUGIA_CHAMBER, MAP_WHIRL_ISLAND_LUGIA_CHAMBER
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 25,KRABBY
	db 26,ZUBAT
	db 25,SEEL
	db 27,KRABBY
	db 28,GOLBAT
	db 27,SEEL
	db 27,SEEL
	; day
	db 25,KRABBY
	db 26,ZUBAT
	db 25,SEEL
	db 27,KRABBY
	db 28,GOLBAT
	db 27,SEEL
	db 27,SEEL
	; nite
	db 25,KRABBY
	db 26,ZUBAT
	db 25,KRABBY
	db 27,KRABBY
	db 28,GOLBAT
	db 27,GOLBAT
	db 27,GOLBAT

	db GROUP_SILVER_CAVE_ROOM_1, MAP_SILVER_CAVE_ROOM_1
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 43,GRAVELER
	db 44,URSARING
	db 42,ONIX
	db 45,MAGMAR
	db 45,GOLBAT
	db 20,LARVITAR
	db 15,LARVITAR
	; day
	db 43,GRAVELER
	db 44,URSARING
	db 42,ONIX
	db 45,MAGMAR
	db 45,GOLBAT
	db 20,LARVITAR
	db 15,LARVITAR
	; nite
	db 43,GRAVELER
	db 44,GOLBAT
	db 42,ONIX
	db 42,GOLBAT
	db 45,GOLDUCK
	db 46,GOLBAT
	db 46,GOLBAT

	db GROUP_SILVER_CAVE_ROOM_2, MAP_SILVER_CAVE_ROOM_2
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 48,GOLBAT
	db 48,MACHOKE
	db 47,URSARING
	db 46,PARASECT
	db 48,PARASECT
	db 15,LARVITAR
	db 20,LARVITAR
	; day
	db 48,GOLBAT
	db 48,MACHOKE
	db 47,URSARING
	db 46,PARASECT
	db 48,PARASECT
	db 15,LARVITAR
	db 20,LARVITAR
	; nite
	db 48,GOLBAT
	db 48,GOLDUCK
	db 46,GOLBAT
	db 46,PARASECT
	db 48,PARASECT
	db 45,MISDREAVUS
	db 45,MISDREAVUS

	db GROUP_SILVER_CAVE_ROOM_3, MAP_SILVER_CAVE_ROOM_3
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 51,GOLBAT
	db 48,ONIX
	db 48,GRAVELER
	db 50,URSARING
	db 20,LARVITAR
	db 15,LARVITAR
	db 20,PUPITAR
	; day
	db 51,GOLBAT
	db 48,ONIX
	db 48,GRAVELER
	db 50,URSARING
	db 20,LARVITAR
	db 15,LARVITAR
	db 20,PUPITAR
	; nite
	db 51,GOLBAT
	db 48,ONIX
	db 48,GRAVELER
	db 49,GOLBAT
	db 45,GOLDUCK
	db 53,GOLBAT
	db 53,GOLBAT

	db GROUP_SILVER_CAVE_ITEM_ROOMS, MAP_SILVER_CAVE_ITEM_ROOMS
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 48,GOLBAT
	db 46,GOLBAT
	db 50,GOLBAT
	db 46,PARASECT
	db 48,PARASECT
	db 50,PARASECT
	db 52,PARASECT
	; day
	db 48,GOLBAT
	db 46,GOLBAT
	db 50,GOLBAT
	db 46,PARASECT
	db 48,PARASECT
	db 50,PARASECT
	db 52,PARASECT
	; nite
	db 45,MISDREAVUS
	db 48,GOLBAT
	db 50,GOLBAT
	db 46,PARASECT
	db 48,PARASECT
	db 50,PARASECT
	db 52,PARASECT

	db GROUP_DARK_CAVE_VIOLET_ENTRANCE, MAP_DARK_CAVE_VIOLET_ENTRANCE
	db $0a,$0a,$0a ; encounter rates: morn/day/nite
	; morn
	db 3,GEODUDE
	db 2,ZUBAT
	db 2,GEODUDE
	db 4,GEODUDE
	db 2,TEDDIURSA
	db 4,ZUBAT
	db 4,DUNSPARCE
	; day
	db 3,GEODUDE
	db 2,ZUBAT
	db 2,GEODUDE
	db 4,GEODUDE
	db 2,ZUBAT
	db 4,ZUBAT
	db 4,DUNSPARCE
	; nite
	db 3,GEODUDE
	db 2,ZUBAT
	db 2,GEODUDE
	db 4,GEODUDE
	db 2,ZUBAT
	db 4,ZUBAT
	db 4,DUNSPARCE

	db GROUP_DARK_CAVE_BLACKTHORN_ENTRANCE, MAP_DARK_CAVE_BLACKTHORN_ENTRANCE
	db $0a,$0a,$0a ; encounter rates: morn/day/nite
	; morn
	db 23,GEODUDE
	db 23,ZUBAT
	db 25,GRAVELER
	db 25,URSARING
	db 20,TEDDIURSA
	db 23,GOLBAT
	db 23,GOLBAT
	; day
	db 23,GEODUDE
	db 23,ZUBAT
	db 25,GRAVELER
	db 25,URSARING
	db 30,URSARING
	db 23,GOLBAT
	db 23,GOLBAT
	; nite
	db 23,GEODUDE
	db 23,ZUBAT
	db 25,GRAVELER
	db 20,WOBBUFFET
	db 25,WOBBUFFET
	db 23,GOLBAT
	db 23,GOLBAT

	db GROUP_ROUTE_29, MAP_ROUTE_29
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 2,PIDGEY
	db 2,SENTRET
	db 3,PIDGEY
	db 3,SENTRET
	db 2,RATTATA
	db 3,HOPPIP
	db 3,HOPPIP
	; day
	db 2,PIDGEY
	db 2,SENTRET
	db 3,PIDGEY
	db 3,SENTRET
	db 2,RATTATA
	db 3,HOPPIP
	db 3,HOPPIP
	; nite
	db 2,HOOTHOOT
	db 2,RATTATA
	db 3,HOOTHOOT
	db 3,RATTATA
	db 2,RATTATA
	db 3,HOOTHOOT
	db 3,HOOTHOOT

	db GROUP_ROUTE_30, MAP_ROUTE_30
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 3,LEDYBA
	db 3,CATERPIE
	db 4,CATERPIE
	db 4,PIDGEY
	db 3,WEEDLE
	db 4,HOPPIP
	db 4,HOPPIP
	; day
	db 3,PIDGEY
	db 3,CATERPIE
	db 4,CATERPIE
	db 4,PIDGEY
	db 3,WEEDLE
	db 4,HOPPIP
	db 4,HOPPIP
	; nite
	db 3,SPINARAK
	db 3,HOOTHOOT
	db 4,POLIWAG
	db 4,HOOTHOOT
	db 3,ZUBAT
	db 4,HOOTHOOT
	db 4,HOOTHOOT

	db GROUP_ROUTE_31, MAP_ROUTE_31
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 4,LEDYBA
	db 4,CATERPIE
	db 5,BELLSPROUT
	db 5,PIDGEY
	db 4,WEEDLE
	db 5,HOPPIP
	db 5,HOPPIP
	; day
	db 4,PIDGEY
	db 4,CATERPIE
	db 5,BELLSPROUT
	db 5,PIDGEY
	db 4,WEEDLE
	db 5,HOPPIP
	db 5,HOPPIP
	; nite
	db 4,SPINARAK
	db 4,POLIWAG
	db 5,BELLSPROUT
	db 5,HOOTHOOT
	db 4,ZUBAT
	db 5,GASTLY
	db 5,GASTLY

	db GROUP_ROUTE_32, MAP_ROUTE_32
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 4,EKANS
	db 5,RATTATA
	db 7,BELLSPROUT
	db 6,HOPPIP
	db 7,PIDGEY
	db 7,HOPPIP
	db 7,HOPPIP
	; day
	db 4,EKANS
	db 5,RATTATA
	db 7,BELLSPROUT
	db 6,HOPPIP
	db 7,PIDGEY
	db 7,HOPPIP
	db 7,HOPPIP
	; nite
	db 4,WOOPER
	db 5,RATTATA
	db 7,BELLSPROUT
	db 6,ZUBAT
	db 7,HOOTHOOT
	db 7,GASTLY
	db 7,GASTLY

	db GROUP_ROUTE_33, MAP_ROUTE_33
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 6,RATTATA
	db 6,SPEAROW
	db 6,GEODUDE
	db 6,HOPPIP
	db 7,EKANS
	db 7,HOPPIP
	db 7,HOPPIP
	; day
	db 6,RATTATA
	db 6,SPEAROW
	db 6,GEODUDE
	db 6,HOPPIP
	db 7,EKANS
	db 7,HOPPIP
	db 7,HOPPIP
	; nite
	db 6,RATTATA
	db 6,ZUBAT
	db 6,GEODUDE
	db 6,ZUBAT
	db 7,RATTATA
	db 7,RATTATA
	db 7,RATTATA

	db GROUP_ROUTE_34, MAP_ROUTE_34
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 10,SNUBBULL
	db 11,RATTATA
	db 12,PIDGEY
	db 10,ABRA
	db 12,JIGGLYPUFF
	db 10,DITTO
	db 10,DITTO
	; day
	db 10,SNUBBULL
	db 11,RATTATA
	db 12,PIDGEY
	db 10,ABRA
	db 12,JIGGLYPUFF
	db 10,DITTO
	db 10,DITTO
	; nite
	db 12,DROWZEE
	db 11,RATTATA
	db 12,HOOTHOOT
	db 10,ABRA
	db 12,JIGGLYPUFF
	db 10,DITTO
	db 10,DITTO

	db GROUP_ROUTE_35, MAP_ROUTE_35
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 12,SNUBBULL
	db 14,PIDGEY
	db 13,GROWLITHE
	db 10,ABRA
	db 12,JIGGLYPUFF
	db 10,DITTO
	db 12,YANMA
	; day
	db 12,SNUBBULL
	db 14,PIDGEY
	db 13,GROWLITHE
	db 10,ABRA
	db 12,JIGGLYPUFF
	db 10,DITTO
	db 12,YANMA
	; nite
	db 12,DROWZEE
	db 14,HOOTHOOT
	db 13,PSYDUCK
	db 10,ABRA
	db 12,JIGGLYPUFF
	db 10,DITTO
	db 12,YANMA

	db GROUP_ROUTE_36, MAP_ROUTE_36
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 4,LEDYBA
	db 4,PIDGEY
	db 5,BELLSPROUT
	db 5,GROWLITHE
	db 5,PIDGEY
	db 6,PIDGEY
	db 6,PIDGEY
	; day
	db 4,PIDGEY
	db 4,PIDGEY
	db 5,BELLSPROUT
	db 5,GROWLITHE
	db 5,PIDGEY
	db 6,PIDGEY
	db 6,PIDGEY
	; nite
	db 4,SPINARAK
	db 4,HOOTHOOT
	db 5,BELLSPROUT
	db 5,HOOTHOOT
	db 5,HOOTHOOT
	db 5,GASTLY
	db 5,GASTLY

	db GROUP_ROUTE_37, MAP_ROUTE_37
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 13,LEDYBA
	db 14,GROWLITHE
	db 15,PIDGEY
	db 16,GROWLITHE
	db 15,PIDGEOTTO
	db 15,LEDIAN
	db 15,LEDIAN
	; day
	db 13,PIDGEY
	db 14,GROWLITHE
	db 15,PIDGEY
	db 16,GROWLITHE
	db 15,PIDGEOTTO
	db 15,PIDGEY
	db 15,PIDGEY
	; nite
	db 13,SPINARAK
	db 14,STANTLER
	db 15,HOOTHOOT
	db 16,STANTLER
	db 15,NOCTOWL
	db 15,ARIADOS
	db 15,ARIADOS

	db GROUP_ROUTE_38, MAP_ROUTE_38
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 16,RATTATA
	db 16,RATICATE
	db 16,MAGNEMITE
	db 16,PIDGEOTTO
	db 13,TAUROS
	db 13,MILTANK
	db 13,MILTANK
	; day
	db 16,RATTATA
	db 16,RATICATE
	db 16,MAGNEMITE
	db 16,PIDGEOTTO
	db 13,TAUROS
	db 13,MILTANK
	db 13,MILTANK
	; nite
	db 16,MEOWTH
	db 16,RATICATE
	db 16,MAGNEMITE
	db 16,NOCTOWL
	db 16,MEOWTH
	db 16,MEOWTH
	db 16,MEOWTH

	db GROUP_ROUTE_39, MAP_ROUTE_39
	db $05,$05,$05 ; encounter rates: morn/day/nite
	; morn
	db 16,RATTATA
	db 16,RATICATE
	db 16,MAGNEMITE
	db 16,PIDGEOTTO
	db 15,MILTANK
	db 15,TAUROS
	db 15,TAUROS
	; day
	db 16,RATTATA
	db 16,RATICATE
	db 16,MAGNEMITE
	db 16,PIDGEOTTO
	db 15,MILTANK
	db 15,TAUROS
	db 15,TAUROS
	; nite
	db 16,MEOWTH
	db 16,RATICATE
	db 16,MAGNEMITE
	db 16,NOCTOWL
	db 18,MEOWTH
	db 18,MEOWTH
	db 18,MEOWTH

	db GROUP_ROUTE_42, MAP_ROUTE_42
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 13,EKANS
	db 14,SPEAROW
	db 15,RATTATA
	db 16,RATICATE
	db 15,ARBOK
	db 16,FEAROW
	db 16,FEAROW
	; day
	db 13,EKANS
	db 14,SPEAROW
	db 15,RATTATA
	db 16,RATICATE
	db 15,ARBOK
	db 16,FEAROW
	db 16,FEAROW
	; nite
	db 13,RATTATA
	db 14,ZUBAT
	db 15,RATICATE
	db 16,GOLBAT
	db 15,MARILL
	db 16,GOLBAT
	db 16,GOLBAT

	db GROUP_ROUTE_43, MAP_ROUTE_43
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 15,SENTRET
	db 16,PIDGEOTTO
	db 16,FARFETCH_D
	db 15,FURRET
	db 17,RATICATE
	db 17,FURRET
	db 17,FURRET
	; day
	db 15,SENTRET
	db 16,PIDGEOTTO
	db 16,FARFETCH_D
	db 15,FURRET
	db 17,RATICATE
	db 17,FURRET
	db 17,FURRET
	; nite
	db 15,VENONAT
	db 16,NOCTOWL
	db 16,RATICATE
	db 17,VENONAT
	db 17,RATICATE
	db 17,VENOMOTH
	db 17,VENOMOTH

	db GROUP_ROUTE_44, MAP_ROUTE_44
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 23,TANGELA
	db 22,LICKITUNG
	db 22,BELLSPROUT
	db 24,WEEPINBELL
	db 24,LICKITUNG
	db 26,LICKITUNG
	db 26,LICKITUNG
	; day
	db 23,TANGELA
	db 22,LICKITUNG
	db 22,BELLSPROUT
	db 24,WEEPINBELL
	db 24,LICKITUNG
	db 26,LICKITUNG
	db 26,LICKITUNG
	; nite
	db 23,TANGELA
	db 22,POLIWAG
	db 22,BELLSPROUT
	db 24,WEEPINBELL
	db 24,POLIWHIRL
	db 26,POLIWHIRL
	db 26,POLIWHIRL

	db GROUP_ROUTE_45, MAP_ROUTE_45
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 23,GEODUDE
	db 23,GRAVELER
	db 24,GLIGAR
	db 25,DONPHAN
	db 20,PHANPY
	db 27,SKARMORY
	db 27,SKARMORY
	; day
	db 23,GEODUDE
	db 23,GRAVELER
	db 24,GLIGAR
	db 25,DONPHAN
	db 30,DONPHAN
	db 27,SKARMORY
	db 27,SKARMORY
	; nite
	db 23,GEODUDE
	db 23,GRAVELER
	db 24,GLIGAR
	db 25,GRAVELER
	db 27,GRAVELER
	db 27,GRAVELER
	db 27,GRAVELER

	db GROUP_ROUTE_46, MAP_ROUTE_46
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 2,GEODUDE
	db 2,SPEAROW
	db 3,GEODUDE
	db 3,RATTATA
	db 2,PHANPY
	db 2,RATTATA
	db 2,RATTATA
	; day
	db 2,GEODUDE
	db 2,SPEAROW
	db 3,GEODUDE
	db 3,RATTATA
	db 2,RATTATA
	db 2,RATTATA
	db 2,RATTATA
	; nite
	db 2,GEODUDE
	db 2,RATTATA
	db 3,GEODUDE
	db 3,RATTATA
	db 2,RATTATA
	db 2,RATTATA
	db 2,RATTATA

	db GROUP_SILVER_CAVE_OUTSIDE, MAP_SILVER_CAVE_OUTSIDE
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 41,TANGELA
	db 42,PONYTA
	db 42,ARBOK
	db 44,RAPIDASH
	db 41,DODUO
	db 43,DODRIO
	db 43,DODRIO
	; day
	db 41,TANGELA
	db 42,PONYTA
	db 42,ARBOK
	db 44,RAPIDASH
	db 41,DODUO
	db 43,DODRIO
	db 43,DODRIO
	; nite
	db 41,TANGELA
	db 42,POLIWHIRL
	db 42,GOLBAT
	db 44,POLIWHIRL
	db 40,GOLBAT
	db 44,GOLBAT
	db 44,GOLBAT

	db $FF

WildMons2: ; 0x2b11d
; Johto Pokémon in water

	db GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	db $05 ; encounter rate
	db 15,WOOPER
	db 20,QUAGSIRE
	db 15,QUAGSIRE

	db GROUP_UNION_CAVE_1F, MAP_UNION_CAVE_1F
	db $05 ; encounter rate
	db 15,WOOPER
	db 20,QUAGSIRE
	db 15,QUAGSIRE

	db GROUP_UNION_CAVE_B1F, MAP_UNION_CAVE_B1F
	db $05 ; encounter rate
	db 15,WOOPER
	db 20,QUAGSIRE
	db 15,QUAGSIRE

	db GROUP_UNION_CAVE_B2F, MAP_UNION_CAVE_B2F
	db $0a ; encounter rate
	db 15,TENTACOOL
	db 20,QUAGSIRE
	db 20,TENTACRUEL

	db GROUP_SLOWPOKE_WELL_B1F, MAP_SLOWPOKE_WELL_B1F
	db $05 ; encounter rate
	db 15,SLOWPOKE
	db 20,SLOWPOKE
	db 10,SLOWPOKE

	db GROUP_SLOWPOKE_WELL_B2F, MAP_SLOWPOKE_WELL_B2F
	db $05 ; encounter rate
	db 15,SLOWPOKE
	db 20,SLOWPOKE
	db 20,SLOWBRO

	db GROUP_ILEX_FOREST, MAP_ILEX_FOREST
	db $05 ; encounter rate
	db 15,PSYDUCK
	db 10,PSYDUCK
	db 15,GOLDUCK

	db GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE
	db $0a ; encounter rate
	db 15,GOLDEEN
	db 20,MARILL
	db 20,SEAKING

	db GROUP_MOUNT_MORTAR_2F_INSIDE, MAP_MOUNT_MORTAR_2F_INSIDE
	db $05 ; encounter rate
	db 20,GOLDEEN
	db 25,MARILL
	db 25,SEAKING

	db GROUP_MOUNT_MORTAR_B1F, MAP_MOUNT_MORTAR_B1F
	db $05 ; encounter rate
	db 15,GOLDEEN
	db 20,MARILL
	db 20,SEAKING

	db GROUP_WHIRL_ISLAND_SW, MAP_WHIRL_ISLAND_SW
	db $0a ; encounter rate
	db 20,TENTACOOL
	db 15,HORSEA
	db 20,TENTACRUEL

	db GROUP_WHIRL_ISLAND_B2F, MAP_WHIRL_ISLAND_B2F
	db $0a ; encounter rate
	db 15,HORSEA
	db 20,HORSEA
	db 20,TENTACRUEL

	db GROUP_WHIRL_ISLAND_LUGIA_CHAMBER, MAP_WHIRL_ISLAND_LUGIA_CHAMBER
	db $0a ; encounter rate
	db 20,HORSEA
	db 20,TENTACRUEL
	db 20,SEADRA

	db GROUP_SILVER_CAVE_ROOM_2, MAP_SILVER_CAVE_ROOM_2
	db $05 ; encounter rate
	db 35,SEAKING
	db 35,GOLDUCK
	db 35,GOLDEEN

	db GROUP_DARK_CAVE_VIOLET_ENTRANCE, MAP_DARK_CAVE_VIOLET_ENTRANCE
	db $05 ; encounter rate
	db 15,MAGIKARP
	db 10,MAGIKARP
	db 5,MAGIKARP

	db GROUP_DARK_CAVE_BLACKTHORN_ENTRANCE, MAP_DARK_CAVE_BLACKTHORN_ENTRANCE
	db $05 ; encounter rate
	db 15,MAGIKARP
	db 10,MAGIKARP
	db 5,MAGIKARP

	db GROUP_DRAGONS_DEN_B1F, MAP_DRAGONS_DEN_B1F
	db $0a ; encounter rate
	db 15,MAGIKARP
	db 10,MAGIKARP
	db 10,DRATINI

	db GROUP_OLIVINE_PORT, MAP_OLIVINE_PORT
	db $05 ; encounter rate
	db 20,TENTACOOL
	db 15,TENTACOOL
	db 20,TENTACRUEL

	db GROUP_ROUTE_30, MAP_ROUTE_30
	db $05 ; encounter rate
	db 20,POLIWAG
	db 15,POLIWAG
	db 20,POLIWHIRL

	db GROUP_ROUTE_31, MAP_ROUTE_31
	db $05 ; encounter rate
	db 20,POLIWAG
	db 15,POLIWAG
	db 20,POLIWHIRL

	db GROUP_ROUTE_32, MAP_ROUTE_32
	db $0f ; encounter rate
	db 15,TENTACOOL
	db 20,QUAGSIRE
	db 20,TENTACRUEL

	db GROUP_ROUTE_34, MAP_ROUTE_34
	db $0f ; encounter rate
	db 20,TENTACOOL
	db 15,TENTACOOL
	db 20,TENTACRUEL

	db GROUP_ROUTE_35, MAP_ROUTE_35
	db $0a ; encounter rate
	db 20,PSYDUCK
	db 15,PSYDUCK
	db 20,GOLDUCK

	db GROUP_ROUTE_40, MAP_ROUTE_40
	db $0f ; encounter rate
	db 20,TENTACOOL
	db 15,TENTACOOL
	db 20,TENTACRUEL

	db GROUP_ROUTE_41, MAP_ROUTE_41
	db $0f ; encounter rate
	db 20,TENTACOOL
	db 20,TENTACRUEL
	db 20,MANTINE

	db GROUP_ROUTE_42, MAP_ROUTE_42
	db $0a ; encounter rate
	db 20,GOLDEEN
	db 15,GOLDEEN
	db 20,SEAKING

	db GROUP_ROUTE_43, MAP_ROUTE_43
	db $05 ; encounter rate
	db 20,MAGIKARP
	db 15,MAGIKARP
	db 10,MAGIKARP

	db GROUP_ROUTE_44, MAP_ROUTE_44
	db $05 ; encounter rate
	db 25,POLIWAG
	db 20,POLIWAG
	db 25,POLIWHIRL

	db GROUP_ROUTE_45, MAP_ROUTE_45
	db $05 ; encounter rate
	db 20,MAGIKARP
	db 15,MAGIKARP
	db 5,MAGIKARP

	db GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN
	db $0f ; encounter rate
	db 20,TENTACOOL
	db 15,TENTACOOL
	db 20,TENTACRUEL

	db GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY
	db $0f ; encounter rate
	db 20,TENTACOOL
	db 15,TENTACOOL
	db 20,TENTACRUEL

	db GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	db $05 ; encounter rate
	db 20,POLIWAG
	db 15,POLIWAG
	db 20,POLIWHIRL

	db GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY
	db $0f ; encounter rate
	db 20,TENTACOOL
	db 15,TENTACOOL
	db 20,TENTACRUEL

	db GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	db $0f ; encounter rate
	db 20,TENTACOOL
	db 15,TENTACOOL
	db 20,TENTACRUEL

	db GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	db $05 ; encounter rate
	db 20,POLIWAG
	db 15,POLIWAG
	db 20,POLIWHIRL

	db GROUP_LAKE_OF_RAGE, MAP_LAKE_OF_RAGE
	db $0f ; encounter rate
	db 15,MAGIKARP
	db 10,MAGIKARP
	db 15,GYARADOS

	db GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	db $0a ; encounter rate
	db 15,MAGIKARP
	db 10,MAGIKARP
	db 5,MAGIKARP

	db GROUP_SILVER_CAVE_OUTSIDE, MAP_SILVER_CAVE_OUTSIDE
	db $05 ; encounter rate
	db 35,POLIWHIRL
	db 40,POLIWHIRL
	db 35,POLIWAG

	db $FF

WildMons3: ; 0x2b274
; Kanto Pokémon in grass

	db GROUP_DIGLETTS_CAVE, MAP_DIGLETTS_CAVE
	db $0a,$05,$14 ; encounter rates: morn/day/nite
	; morn
	db 3,DIGLETT
	db 6,DIGLETT
	db 12,DIGLETT
	db 24,DIGLETT
	db 24,DUGTRIO
	db 24,DUGTRIO
	db 24,DUGTRIO
	; day
	db 2,DIGLETT
	db 4,DIGLETT
	db 8,DIGLETT
	db 16,DIGLETT
	db 16,DUGTRIO
	db 16,DUGTRIO
	db 16,DUGTRIO
	; nite
	db 4,DIGLETT
	db 8,DIGLETT
	db 16,DIGLETT
	db 32,DIGLETT
	db 32,DUGTRIO
	db 32,DUGTRIO
	db 32,DUGTRIO

	db GROUP_MOUNT_MOON, MAP_MOUNT_MOON
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 6,ZUBAT
	db 8,GEODUDE
	db 8,SANDSHREW
	db 12,PARAS
	db 10,GEODUDE
	db 8,CLEFAIRY
	db 8,CLEFAIRY
	; day
	db 6,ZUBAT
	db 8,GEODUDE
	db 8,SANDSHREW
	db 12,PARAS
	db 10,GEODUDE
	db 8,CLEFAIRY
	db 8,CLEFAIRY
	; nite
	db 6,ZUBAT
	db 8,GEODUDE
	db 8,CLEFAIRY
	db 12,PARAS
	db 10,GEODUDE
	db 12,CLEFAIRY
	db 12,CLEFAIRY

	db GROUP_ROCK_TUNNEL_1F, MAP_ROCK_TUNNEL_1F
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 10,CUBONE
	db 11,GEODUDE
	db 12,MACHOP
	db 12,ZUBAT
	db 15,MACHOKE
	db 12,MAROWAK
	db 12,MAROWAK
	; day
	db 10,CUBONE
	db 11,GEODUDE
	db 12,MACHOP
	db 12,ZUBAT
	db 15,MACHOKE
	db 12,MAROWAK
	db 12,MAROWAK
	; nite
	db 12,ZUBAT
	db 11,GEODUDE
	db 12,GEODUDE
	db 17,HAUNTER
	db 15,ZUBAT
	db 15,ZUBAT
	db 15,ZUBAT

	db GROUP_ROCK_TUNNEL_B1F, MAP_ROCK_TUNNEL_B1F
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 12,CUBONE
	db 14,GEODUDE
	db 16,ONIX
	db 12,ZUBAT
	db 15,MAROWAK
	db 15,KANGASKHAN
	db 15,KANGASKHAN
	; day
	db 12,CUBONE
	db 14,GEODUDE
	db 16,ONIX
	db 12,ZUBAT
	db 15,MAROWAK
	db 15,KANGASKHAN
	db 15,KANGASKHAN
	; nite
	db 12,ZUBAT
	db 14,GEODUDE
	db 16,ONIX
	db 15,ZUBAT
	db 15,HAUNTER
	db 15,GOLBAT
	db 15,GOLBAT

	db GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 34,GRAVELER
	db 32,RHYHORN
	db 33,ONIX
	db 34,GOLBAT
	db 35,SANDSLASH
	db 35,RHYDON
	db 35,RHYDON
	; day
	db 34,GRAVELER
	db 32,RHYHORN
	db 33,ONIX
	db 34,GOLBAT
	db 35,SANDSLASH
	db 35,RHYDON
	db 35,RHYDON
	; nite
	db 34,GOLBAT
	db 34,GRAVELER
	db 32,ONIX
	db 36,GRAVELER
	db 38,GRAVELER
	db 40,GRAVELER
	db 40,GRAVELER

	db GROUP_TOHJO_FALLS, MAP_TOHJO_FALLS
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 22,ZUBAT
	db 22,RATICATE
	db 24,GOLBAT
	db 21,SLOWPOKE
	db 20,RATTATA
	db 23,SLOWPOKE
	db 23,SLOWPOKE
	; day
	db 22,ZUBAT
	db 22,RATICATE
	db 24,GOLBAT
	db 21,SLOWPOKE
	db 20,RATTATA
	db 23,SLOWPOKE
	db 23,SLOWPOKE
	; nite
	db 22,ZUBAT
	db 22,RATICATE
	db 24,GOLBAT
	db 21,SLOWPOKE
	db 20,RATTATA
	db 23,SLOWPOKE
	db 23,SLOWPOKE

	db GROUP_ROUTE_1, MAP_ROUTE_1
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 2,PIDGEY
	db 2,RATTATA
	db 3,SENTRET
	db 3,PIDGEY
	db 6,FURRET
	db 4,PIDGEY
	db 4,PIDGEY
	; day
	db 2,PIDGEY
	db 2,RATTATA
	db 3,SENTRET
	db 3,PIDGEY
	db 6,FURRET
	db 4,PIDGEY
	db 4,PIDGEY
	; nite
	db 2,HOOTHOOT
	db 2,RATTATA
	db 3,RATTATA
	db 3,HOOTHOOT
	db 6,RATICATE
	db 4,HOOTHOOT
	db 4,HOOTHOOT

	db GROUP_ROUTE_2, MAP_ROUTE_2
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 3,CATERPIE
	db 3,LEDYBA
	db 5,PIDGEY
	db 7,BUTTERFREE
	db 7,LEDIAN
	db 4,PIKACHU
	db 4,PIKACHU
	; day
	db 3,CATERPIE
	db 3,PIDGEY
	db 5,PIDGEY
	db 7,BUTTERFREE
	db 7,PIDGEOTTO
	db 4,PIKACHU
	db 4,PIKACHU
	; nite
	db 3,HOOTHOOT
	db 3,SPINARAK
	db 5,HOOTHOOT
	db 7,NOCTOWL
	db 7,ARIADOS
	db 4,NOCTOWL
	db 4,NOCTOWL

	db GROUP_ROUTE_3, MAP_ROUTE_3
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 5,SPEAROW
	db 5,RATTATA
	db 8,EKANS
	db 10,RATICATE
	db 10,ARBOK
	db 10,SANDSHREW
	db 10,SANDSHREW
	; day
	db 5,SPEAROW
	db 5,RATTATA
	db 8,EKANS
	db 10,RATICATE
	db 10,ARBOK
	db 10,SANDSHREW
	db 10,SANDSHREW
	; nite
	db 5,RATTATA
	db 10,RATTATA
	db 10,RATICATE
	db 6,ZUBAT
	db 5,RATTATA
	db 6,CLEFAIRY
	db 6,CLEFAIRY

	db GROUP_ROUTE_4, MAP_ROUTE_4
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 5,SPEAROW
	db 5,RATTATA
	db 8,EKANS
	db 10,RATICATE
	db 10,ARBOK
	db 10,SANDSHREW
	db 10,SANDSHREW
	; day
	db 5,SPEAROW
	db 5,RATTATA
	db 8,EKANS
	db 10,RATICATE
	db 10,ARBOK
	db 10,SANDSHREW
	db 10,SANDSHREW
	; nite
	db 5,RATTATA
	db 10,RATTATA
	db 10,RATICATE
	db 6,ZUBAT
	db 5,RATTATA
	db 6,CLEFAIRY
	db 6,CLEFAIRY

	db GROUP_ROUTE_5, MAP_ROUTE_5
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 13,PIDGEY
	db 13,SNUBBULL
	db 15,PIDGEOTTO
	db 12,ABRA
	db 14,JIGGLYPUFF
	db 14,ABRA
	db 14,ABRA
	; day
	db 13,PIDGEY
	db 13,SNUBBULL
	db 15,PIDGEOTTO
	db 12,ABRA
	db 14,JIGGLYPUFF
	db 14,ABRA
	db 14,ABRA
	; nite
	db 13,HOOTHOOT
	db 13,MEOWTH
	db 15,NOCTOWL
	db 12,ABRA
	db 14,JIGGLYPUFF
	db 14,ABRA
	db 14,ABRA

	db GROUP_ROUTE_6, MAP_ROUTE_6
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 13,RATTATA
	db 13,SNUBBULL
	db 14,MAGNEMITE
	db 15,RATICATE
	db 12,JIGGLYPUFF
	db 15,GRANBULL
	db 15,GRANBULL
	; day
	db 13,RATTATA
	db 13,SNUBBULL
	db 14,MAGNEMITE
	db 15,RATICATE
	db 12,JIGGLYPUFF
	db 15,GRANBULL
	db 15,GRANBULL
	; nite
	db 13,MEOWTH
	db 13,DROWZEE
	db 14,MAGNEMITE
	db 15,PSYDUCK
	db 12,JIGGLYPUFF
	db 15,RATICATE
	db 15,RATICATE

	db GROUP_ROUTE_7, MAP_ROUTE_7
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 17,RATTATA
	db 17,SPEAROW
	db 18,SNUBBULL
	db 18,RATICATE
	db 18,JIGGLYPUFF
	db 16,ABRA
	db 16,ABRA
	; day
	db 17,RATTATA
	db 17,SPEAROW
	db 18,SNUBBULL
	db 18,RATICATE
	db 18,JIGGLYPUFF
	db 16,ABRA
	db 16,ABRA
	; nite
	db 17,MEOWTH
	db 17,MURKROW
	db 18,HOUNDOUR
	db 18,PERSIAN
	db 18,JIGGLYPUFF
	db 16,ABRA
	db 16,ABRA

	db GROUP_ROUTE_8, MAP_ROUTE_8
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 17,SNUBBULL
	db 19,PIDGEOTTO
	db 16,ABRA
	db 17,GROWLITHE
	db 16,JIGGLYPUFF
	db 18,KADABRA
	db 18,KADABRA
	; day
	db 17,SNUBBULL
	db 19,PIDGEOTTO
	db 16,ABRA
	db 17,GROWLITHE
	db 16,JIGGLYPUFF
	db 18,KADABRA
	db 18,KADABRA
	; nite
	db 17,MEOWTH
	db 20,NOCTOWL
	db 16,ABRA
	db 17,HAUNTER
	db 16,JIGGLYPUFF
	db 18,KADABRA
	db 18,KADABRA

	db GROUP_ROUTE_9, MAP_ROUTE_9
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 15,RATTATA
	db 15,SPEAROW
	db 15,RATICATE
	db 15,FEAROW
	db 15,FEAROW
	db 18,MAROWAK
	db 18,MAROWAK
	; day
	db 15,RATTATA
	db 15,SPEAROW
	db 15,RATICATE
	db 15,FEAROW
	db 15,FEAROW
	db 18,MAROWAK
	db 18,MAROWAK
	; nite
	db 15,RATTATA
	db 15,VENONAT
	db 15,RATICATE
	db 15,VENOMOTH
	db 15,ZUBAT
	db 18,RATICATE
	db 18,RATICATE

	db GROUP_ROUTE_10_NORTH, MAP_ROUTE_10_NORTH
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 15,SPEAROW
	db 17,VOLTORB
	db 15,RATICATE
	db 15,FEAROW
	db 15,MAROWAK
	db 16,ELECTABUZZ
	db 16,ELECTABUZZ
	; day
	db 15,SPEAROW
	db 17,VOLTORB
	db 15,RATICATE
	db 15,FEAROW
	db 15,MAROWAK
	db 18,ELECTABUZZ
	db 18,ELECTABUZZ
	; nite
	db 15,VENONAT
	db 17,VOLTORB
	db 15,RATICATE
	db 15,VENOMOTH
	db 15,ZUBAT
	db 16,ELECTABUZZ
	db 16,ELECTABUZZ

	db GROUP_ROUTE_11, MAP_ROUTE_11
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 14,HOPPIP
	db 13,RATICATE
	db 15,MAGNEMITE
	db 16,PIDGEOTTO
	db 16,RATTATA
	db 16,HOPPIP
	db 16,HOPPIP
	; day
	db 14,HOPPIP
	db 13,RATICATE
	db 15,MAGNEMITE
	db 16,PIDGEOTTO
	db 16,RATTATA
	db 16,HOPPIP
	db 16,HOPPIP
	; nite
	db 14,DROWZEE
	db 13,MEOWTH
	db 15,MAGNEMITE
	db 16,NOCTOWL
	db 16,RATICATE
	db 16,HYPNO
	db 16,HYPNO

	db GROUP_ROUTE_13, MAP_ROUTE_13
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 23,NIDORINO
	db 23,NIDORINA
	db 25,PIDGEOTTO
	db 25,HOPPIP
	db 27,HOPPIP
	db 27,HOPPIP
	db 25,CHANSEY
	; day
	db 23,NIDORINO
	db 23,NIDORINA
	db 25,PIDGEOTTO
	db 25,HOPPIP
	db 27,HOPPIP
	db 27,HOPPIP
	db 25,CHANSEY
	; nite
	db 23,VENONAT
	db 23,QUAGSIRE
	db 25,NOCTOWL
	db 25,VENOMOTH
	db 25,QUAGSIRE
	db 25,QUAGSIRE
	db 25,CHANSEY

	db GROUP_ROUTE_14, MAP_ROUTE_14
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 26,NIDORINO
	db 26,NIDORINA
	db 28,PIDGEOTTO
	db 28,HOPPIP
	db 30,SKIPLOOM
	db 30,SKIPLOOM
	db 28,CHANSEY
	; day
	db 26,NIDORINO
	db 26,NIDORINA
	db 28,PIDGEOTTO
	db 28,HOPPIP
	db 30,SKIPLOOM
	db 30,SKIPLOOM
	db 28,CHANSEY
	; nite
	db 26,VENONAT
	db 26,QUAGSIRE
	db 28,NOCTOWL
	db 28,VENOMOTH
	db 28,QUAGSIRE
	db 28,QUAGSIRE
	db 28,CHANSEY

	db GROUP_ROUTE_15, MAP_ROUTE_15
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 23,NIDORINO
	db 23,NIDORINA
	db 25,PIDGEOTTO
	db 25,HOPPIP
	db 27,HOPPIP
	db 27,HOPPIP
	db 25,CHANSEY
	; day
	db 23,NIDORINO
	db 23,NIDORINA
	db 25,PIDGEOTTO
	db 25,HOPPIP
	db 27,HOPPIP
	db 27,HOPPIP
	db 25,CHANSEY
	; nite
	db 23,VENONAT
	db 23,QUAGSIRE
	db 25,NOCTOWL
	db 25,VENOMOTH
	db 25,QUAGSIRE
	db 25,QUAGSIRE
	db 25,CHANSEY

	db GROUP_ROUTE_16, MAP_ROUTE_16
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 26,GRIMER
	db 27,FEAROW
	db 28,GRIMER
	db 29,FEAROW
	db 29,FEAROW
	db 30,MUK
	db 30,MUK
	; day
	db 26,GRIMER
	db 27,FEAROW
	db 28,GRIMER
	db 29,FEAROW
	db 29,SLUGMA
	db 30,MUK
	db 30,MUK
	; nite
	db 26,GRIMER
	db 27,GRIMER
	db 28,GRIMER
	db 29,MURKROW
	db 29,MURKROW
	db 30,MUK
	db 30,MUK

	db GROUP_ROUTE_17, MAP_ROUTE_17
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 30,FEAROW
	db 29,GRIMER
	db 31,GRIMER
	db 32,FEAROW
	db 33,GRIMER
	db 33,MUK
	db 33,MUK
	; day
	db 30,FEAROW
	db 29,SLUGMA
	db 29,GRIMER
	db 32,FEAROW
	db 32,SLUGMA
	db 33,MUK
	db 33,MUK
	; nite
	db 30,GRIMER
	db 29,GRIMER
	db 31,GRIMER
	db 32,GRIMER
	db 33,GRIMER
	db 33,MUK
	db 33,MUK

	db GROUP_ROUTE_18, MAP_ROUTE_18
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 26,GRIMER
	db 27,FEAROW
	db 28,GRIMER
	db 29,FEAROW
	db 29,FEAROW
	db 30,MUK
	db 30,MUK
	; day
	db 26,GRIMER
	db 27,FEAROW
	db 28,GRIMER
	db 29,FEAROW
	db 29,SLUGMA
	db 30,MUK
	db 30,MUK
	; nite
	db 26,GRIMER
	db 27,GRIMER
	db 28,GRIMER
	db 29,GRIMER
	db 29,GRIMER
	db 30,MUK
	db 30,MUK

	db GROUP_ROUTE_21, MAP_ROUTE_21
	db $0f,$0f,$0f ; encounter rates: morn/day/nite
	; morn
	db 30,TANGELA
	db 25,RATTATA
	db 35,TANGELA
	db 20,RATICATE
	db 30,MR__MIME
	db 28,MR__MIME
	db 28,MR__MIME
	; day
	db 30,TANGELA
	db 25,RATTATA
	db 35,TANGELA
	db 20,RATICATE
	db 28,MR__MIME
	db 30,MR__MIME
	db 30,MR__MIME
	; nite
	db 30,TANGELA
	db 25,RATTATA
	db 35,TANGELA
	db 20,RATICATE
	db 30,TANGELA
	db 28,TANGELA
	db 28,TANGELA

	db GROUP_ROUTE_22, MAP_ROUTE_22
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 3,RATTATA
	db 3,SPEAROW
	db 5,SPEAROW
	db 4,DODUO
	db 6,PONYTA
	db 7,FEAROW
	db 7,FEAROW
	; day
	db 3,RATTATA
	db 3,SPEAROW
	db 5,SPEAROW
	db 4,DODUO
	db 6,PONYTA
	db 7,FEAROW
	db 7,FEAROW
	; nite
	db 3,RATTATA
	db 3,POLIWAG
	db 5,RATTATA
	db 4,POLIWAG
	db 6,RATTATA
	db 7,RATTATA
	db 7,RATTATA

	db GROUP_ROUTE_24, MAP_ROUTE_24
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 8,CATERPIE
	db 10,CATERPIE
	db 12,METAPOD
	db 12,ABRA
	db 10,BELLSPROUT
	db 14,BUTTERFREE
	db 14,BUTTERFREE
	; day
	db 8,CATERPIE
	db 12,SUNKERN
	db 10,CATERPIE
	db 12,ABRA
	db 10,BELLSPROUT
	db 14,BUTTERFREE
	db 14,BUTTERFREE
	; nite
	db 10,VENONAT
	db 10,ODDISH
	db 12,ODDISH
	db 12,ABRA
	db 10,BELLSPROUT
	db 14,GLOOM
	db 14,GLOOM

	db GROUP_ROUTE_25, MAP_ROUTE_25
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 10,CATERPIE
	db 10,PIDGEY
	db 12,PIDGEOTTO
	db 12,METAPOD
	db 10,BELLSPROUT
	db 14,BUTTERFREE
	db 14,BUTTERFREE
	; day
	db 10,CATERPIE
	db 10,PIDGEY
	db 12,PIDGEOTTO
	db 12,METAPOD
	db 10,BELLSPROUT
	db 14,BUTTERFREE
	db 14,BUTTERFREE
	; nite
	db 10,ODDISH
	db 10,HOOTHOOT
	db 10,VENONAT
	db 12,NOCTOWL
	db 10,BELLSPROUT
	db 14,NOCTOWL
	db 14,NOCTOWL

	db GROUP_ROUTE_26, MAP_ROUTE_26
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 28,DODUO
	db 28,SANDSLASH
	db 32,PONYTA
	db 30,RATICATE
	db 30,DODUO
	db 30,ARBOK
	db 30,ARBOK
	; day
	db 28,DODUO
	db 28,SANDSLASH
	db 32,PONYTA
	db 30,RATICATE
	db 30,DODUO
	db 30,ARBOK
	db 30,ARBOK
	; nite
	db 28,NOCTOWL
	db 28,RATICATE
	db 32,NOCTOWL
	db 30,RATICATE
	db 30,QUAGSIRE
	db 30,QUAGSIRE
	db 30,QUAGSIRE

	db GROUP_ROUTE_27, MAP_ROUTE_27
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 28,DODUO
	db 28,ARBOK
	db 30,RATICATE
	db 30,DODUO
	db 32,PONYTA
	db 30,DODRIO
	db 30,DODRIO
	; day
	db 28,DODUO
	db 28,ARBOK
	db 30,RATICATE
	db 30,DODUO
	db 32,PONYTA
	db 30,DODRIO
	db 30,DODRIO
	; nite
	db 28,QUAGSIRE
	db 28,NOCTOWL
	db 30,RATICATE
	db 30,QUAGSIRE
	db 32,NOCTOWL
	db 32,NOCTOWL
	db 32,NOCTOWL

	db GROUP_ROUTE_28, MAP_ROUTE_28
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 39,TANGELA
	db 40,PONYTA
	db 40,RAPIDASH
	db 42,ARBOK
	db 41,DODUO
	db 43,DODRIO
	db 43,DODRIO
	; day
	db 39,TANGELA
	db 40,PONYTA
	db 40,RAPIDASH
	db 42,ARBOK
	db 41,DODUO
	db 43,DODRIO
	db 43,DODRIO
	; nite
	db 39,TANGELA
	db 40,POLIWHIRL
	db 40,GOLBAT
	db 40,POLIWHIRL
	db 42,GOLBAT
	db 42,GOLBAT
	db 42,GOLBAT

	db $FF

WildMons4: ; 0x2b7f7
; Kanto Pokémon in water

	db GROUP_TOHJO_FALLS, MAP_TOHJO_FALLS
	db $0a ; encounter rate
	db 20,GOLDEEN
	db 20,SLOWPOKE
	db 20,SEAKING

	db GROUP_VERMILION_PORT, MAP_VERMILION_PORT
	db $05 ; encounter rate
	db 35,TENTACOOL
	db 30,TENTACOOL
	db 35,TENTACRUEL

	db GROUP_ROUTE_4, MAP_ROUTE_4
	db $0a ; encounter rate
	db 10,GOLDEEN
	db 5,GOLDEEN
	db 10,SEAKING

	db GROUP_ROUTE_6, MAP_ROUTE_6
	db $05 ; encounter rate
	db 10,PSYDUCK
	db 5,PSYDUCK
	db 10,GOLDUCK

	db GROUP_ROUTE_9, MAP_ROUTE_9
	db $0a ; encounter rate
	db 15,GOLDEEN
	db 10,GOLDEEN
	db 15,SEAKING

	db GROUP_ROUTE_10_NORTH, MAP_ROUTE_10_NORTH
	db $0a ; encounter rate
	db 15,GOLDEEN
	db 10,GOLDEEN
	db 15,SEAKING

	db GROUP_ROUTE_12, MAP_ROUTE_12
	db $0f ; encounter rate
	db 25,TENTACOOL
	db 25,QUAGSIRE
	db 25,TENTACRUEL

	db GROUP_ROUTE_13, MAP_ROUTE_13
	db $0f ; encounter rate
	db 25,TENTACOOL
	db 25,QUAGSIRE
	db 25,TENTACRUEL

	db GROUP_ROUTE_19, MAP_ROUTE_19
	db $0f ; encounter rate
	db 35,TENTACOOL
	db 30,TENTACOOL
	db 35,TENTACRUEL

	db GROUP_ROUTE_20, MAP_ROUTE_20
	db $0f ; encounter rate
	db 35,TENTACOOL
	db 30,TENTACOOL
	db 35,TENTACRUEL

	db GROUP_ROUTE_21, MAP_ROUTE_21
	db $0f ; encounter rate
	db 35,TENTACOOL
	db 30,TENTACOOL
	db 35,TENTACRUEL

	db GROUP_ROUTE_22, MAP_ROUTE_22
	db $05 ; encounter rate
	db 10,POLIWAG
	db 5,POLIWAG
	db 10,POLIWHIRL

	db GROUP_ROUTE_24, MAP_ROUTE_24
	db $0a ; encounter rate
	db 10,GOLDEEN
	db 5,GOLDEEN
	db 10,SEAKING

	db GROUP_ROUTE_25, MAP_ROUTE_25
	db $0a ; encounter rate
	db 10,GOLDEEN
	db 5,GOLDEEN
	db 10,SEAKING

	db GROUP_ROUTE_26, MAP_ROUTE_26
	db $0f ; encounter rate
	db 30,TENTACOOL
	db 25,TENTACOOL
	db 30,TENTACRUEL

	db GROUP_ROUTE_27, MAP_ROUTE_27
	db $0f ; encounter rate
	db 20,TENTACOOL
	db 15,TENTACOOL
	db 20,TENTACRUEL

	db GROUP_ROUTE_28, MAP_ROUTE_28
	db $05 ; encounter rate
	db 40,POLIWAG
	db 35,POLIWAG
	db 40,POLIWHIRL

	db GROUP_PALLET_TOWN, MAP_PALLET_TOWN
	db $0f ; encounter rate
	db 35,TENTACOOL
	db 30,TENTACOOL
	db 35,TENTACRUEL

	db GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY
	db $05 ; encounter rate
	db 10,POLIWAG
	db 5,POLIWAG
	db 10,POLIWHIRL

	db GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY
	db $0a ; encounter rate
	db 10,GOLDEEN
	db 5,GOLDEEN
	db 10,SEAKING

	db GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	db $0f ; encounter rate
	db 35,TENTACOOL
	db 30,TENTACOOL
	db 35,TENTACRUEL

	db GROUP_CELADON_CITY, MAP_CELADON_CITY
	db $05 ; encounter rate
	db 20,GRIMER
	db 15,GRIMER
	db 15,MUK

	db GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	db $05 ; encounter rate
	db 20,MAGIKARP
	db 15,MAGIKARP
	db 10,MAGIKARP

	db GROUP_CINNABAR_ISLAND, MAP_CINNABAR_ISLAND
	db $0f ; encounter rate
	db 35,TENTACOOL
	db 30,TENTACOOL
	db 35,TENTACRUEL

	db $FF

WildMons5: ; 0x2b8d0
; swarms in grass

; Dunsparce swarm
	db GROUP_DARK_CAVE_VIOLET_ENTRANCE, MAP_DARK_CAVE_VIOLET_ENTRANCE
	db $0a,$0a,$0a ; encounter rates: morn/day/nite
	; morn
	db 3,GEODUDE
	db 3,DUNSPARCE
	db 2,ZUBAT
	db 2,GEODUDE
	db 2,DUNSPARCE
	db 4,DUNSPARCE
	db 4,DUNSPARCE
	; day
	db 3,GEODUDE
	db 3,DUNSPARCE
	db 2,ZUBAT
	db 2,GEODUDE
	db 2,DUNSPARCE
	db 4,DUNSPARCE
	db 4,DUNSPARCE
	; nite
	db 3,GEODUDE
	db 3,DUNSPARCE
	db 2,ZUBAT
	db 2,GEODUDE
	db 2,DUNSPARCE
	db 4,DUNSPARCE
	db 4,DUNSPARCE

; Yanma swarm
	db GROUP_ROUTE_35, MAP_ROUTE_35
	db $19,$19,$19 ; encounter rates: morn/day/nite
	; morn
	db 12,NIDORAN_M
	db 12,NIDORAN_F
	db 12,YANMA
	db 14,YANMA
	db 14,PIDGEY
	db 10,DITTO
	db 10,DITTO
	; day
	db 12,NIDORAN_M
	db 12,NIDORAN_F
	db 12,YANMA
	db 14,YANMA
	db 14,PIDGEY
	db 10,DITTO
	db 10,DITTO
	; nite
	db 12,NIDORAN_M
	db 12,NIDORAN_F
	db 12,YANMA
	db 14,YANMA
	db 14,HOOTHOOT
	db 10,DITTO
	db 10,DITTO

	db $FF

WildMons6: ; 0x2b92f
; swarms in water

	; no swarms encountered while surfing in Crystal
	db $FF

INCBIN "baserom.gbc", $2b930, $2ba1a - $2b930

PlayerGFX: ; 2ba1a
INCBIN "gfx/misc/lz/player.lz"
; 2bba0

INCBIN "baserom.gbc", $2bba0, $2bbaa - $2bba0

DudeGFX: ; 2bbaa
INCBIN "gfx/misc/lz/dude.lz"
; 2bce0

INCBIN "baserom.gbc", $2bce0, $2c000 - $2bce0


SECTION "bankB",DATA,BANK[$B]

INCBIN "baserom.gbc",$2C000,$2c1ef - $2C000

TrainerClassNames: ; 2c1ef
	db "LEADER@"
	db "LEADER@"
	db "LEADER@"
	db "LEADER@"
	db "LEADER@"
	db "LEADER@"
	db "LEADER@"
	db "LEADER@"
	db "RIVAL@"
	db "#MON PROF.@"
	db "ELITE FOUR@"
	db $4a, " TRAINER@"
	db "ELITE FOUR@"
	db "ELITE FOUR@"
	db "ELITE FOUR@"
	db "CHAMPION@"
	db "LEADER@"
	db "LEADER@"
	db "LEADER@"
	db "SCIENTIST@"
	db "LEADER@"
	db "YOUNGSTER@"
	db "SCHOOLBOY@"
	db "BIRD KEEPER@"
	db "LASS@"
	db "LEADER@"
	db "COOLTRAINER@"
	db "COOLTRAINER@"
	db "BEAUTY@"
	db "#MANIAC@"
	db "ROCKET@"
	db "GENTLEMAN@"
	db "SKIER@"
	db "TEACHER@"
	db "LEADER@"
	db "BUG CATCHER@"
	db "FISHER@"
	db "SWIMMER♂@"
	db "SWIMMER♀@"
	db "SAILOR@"
	db "SUPER NERD@"
	db "RIVAL@"
	db "GUITARIST@"
	db "HIKER@"
	db "BIKER@"
	db "LEADER@"
	db "BURGLAR@"
	db "FIREBREATHER@"
	db "JUGGLER@"
	db "BLACKBELT@"
	db "ROCKET@"
	db "PSYCHIC@"
	db "PICNICKER@"
	db "CAMPER@"
	db "ROCKET@"
	db "SAGE@"
	db "MEDIUM@"
	db "BOARDER@"
	db "#FAN@"
	db "KIMONO GIRL@"
	db "TWINS@"
	db "#FAN@"
	db $4a, " TRAINER@"
	db "LEADER@"
	db "OFFICER@"
	db "ROCKET@"
	db "MYSTICALMAN@"

INCBIN "baserom.gbc",$2C41a,$2ee8f - $2C41a

; XXX this is not the start of the routine
; determine what music plays in battle
	ld a, [OtherTrainerClass] ; are we fighting a trainer?
	and a
	jr nz, .trainermusic
	ld a, BANK(RegionCheck)
	ld hl, RegionCheck
	rst $8
	ld a, e
	and a
	jr nz, .kantowild
	ld de, $0029 ; johto daytime wild battle music
	ld a, [TimeOfDay] ; check time of day
	cp $2 ; nighttime?
	jr nz, .done ; if no, then done
	ld de, $004a ; johto nighttime wild battle music
	jr .done
.kantowild
	ld de, $0008 ; kanto wild battle music
	jr .done

.trainermusic
	ld de, $002f ; lance battle music
	cp CHAMPION
	jr z, .done
	cp RED
	jr z, .done

	; really, they should have included admins and scientists here too...
	ld de, $0031 ; rocket battle music
	cp GRUNTM
	jr z, .done
	cp GRUNTF
	jr z, .done

	ld de, $0006 ; kanto gym leader battle music
	ld a, BANK(IsKantoGymLeader)
	ld hl, IsKantoGymLeader
	rst $8
	jr c, .done

	ld de, $002e ; johto gym leader battle music
	ld a, BANK(IsJohtoGymLeader)
	ld hl, IsJohtoGymLeader
	rst $8
	jr c, .done

	ld de, $0030 ; rival battle music
	ld a, [OtherTrainerClass]
	cp RIVAL1
	jr z, .done
	cp RIVAL2
	jr nz, .othertrainer
	ld a, [OtherTrainerID] ; which rival are we fighting?
	cp $4
	jr c, .done ; if it's not the fight inside Indigo Plateau, we're done
	ld de, $002f ; rival indigo plateau battle music
	jr .done

.othertrainer
	ld a, [InLinkBattle]
	and a
	jr nz, .linkbattle
	ld a, BANK(RegionCheck)
	ld hl, RegionCheck
	rst $8
	ld a, e
	and a
	jr nz, .kantotrainer
.linkbattle
	ld de, $002a ; johto trainer battle music
	jr .done
.kantotrainer
	ld de, $0007 ; kanto trainer battle music
.done
	call $3b97
	pop bc
	pop de
	pop hl
	ret

INCBIN "baserom.gbc",$2ef18,$30000 - $2ef18


SECTION "bankC",DATA,BANK[$C]

Tileset15GFX: ; 30000
INCBIN "gfx/tilesets/lz/15.lz"
; 304d7

INCBIN "baserom.gbc", $304d7, $309e0 - $304d7

Tileset25GFX: ; 309e0
INCBIN "gfx/tilesets/lz/25.lz"
; 30e78

INCBIN "baserom.gbc", $30e78, $31380 - $30e78

Tileset27GFX: ; 31380
INCBIN "gfx/tilesets/lz/27.lz"
; 318dc

INCBIN "baserom.gbc", $318dc, $31de0 - $318dc

Tileset28GFX: ; 31de0
INCBIN "gfx/tilesets/lz/28.lz"
; 321a6

INCBIN "baserom.gbc", $321a6, $326b0 - $321a6

Tileset30GFX: ; 326b0
INCBIN "gfx/tilesets/lz/30.lz"
; 329ed

INCBIN "baserom.gbc",$329ed,$34000 - $329ed


SECTION "bankD",DATA,BANK[$D]

INCBIN "baserom.gbc",$34000,$34bb1 - $34000

TypeEffects: ; 34bb1
; multiplier /= 10 (20 = 2.0 etc)

;	  attacker  defender	*=

	db NORMAL,	 ROCK,		05
	db NORMAL,	 STEEL,		05
	db FIRE,	 FIRE,		05
	db FIRE,	 WATER,		05
	db FIRE,	 GRASS,		20
	db FIRE,	 ICE,		20
	db FIRE,	 BUG,		20
	db FIRE,	 ROCK,		05
	db FIRE,	 DRAGON,	05
	db FIRE,	 STEEL,		20
	db WATER,	 FIRE,		20
	db WATER,	 WATER,		05
	db WATER,	 GRASS,		05
	db WATER,	 GROUND,	20
	db WATER,	 ROCK,		20
	db WATER,	 DRAGON,	05
	db ELECTRIC, WATER,		20
	db ELECTRIC, ELECTRIC,	05
	db ELECTRIC, GRASS,		05
	db ELECTRIC, GROUND,	00
	db ELECTRIC, FLYING,	20
	db ELECTRIC, DRAGON,	05
	db GRASS,	 FIRE,		05
	db GRASS,	 WATER,		20
	db GRASS,	 GRASS,		05
	db GRASS,	 POISON,	05
	db GRASS,	 GROUND,	20
	db GRASS,	 FLYING,	05
	db GRASS,	 BUG,		05
	db GRASS,	 ROCK,		20
	db GRASS,	 DRAGON,	05
	db GRASS,	 STEEL,		05
	db ICE,		 WATER,		05
	db ICE,		 GRASS,		20
	db ICE,		 ICE,		05
	db ICE,		 GROUND,	20
	db ICE,		 FLYING,	20
	db ICE,		 DRAGON,	20
	db ICE,		 STEEL,		05
	db ICE,		 FIRE,		05
	db FIGHTING, NORMAL,	20
	db FIGHTING, ICE,		20
	db FIGHTING, POISON,	05
	db FIGHTING, FLYING,	05
	db FIGHTING, PSYCHIC,	05
	db FIGHTING, BUG,		05
	db FIGHTING, ROCK,		20
	db FIGHTING, DARK,		20
	db FIGHTING, STEEL,		20
	db POISON,	 GRASS,		20
	db POISON,	 POISON,	05
	db POISON,	 GROUND,	05
	db POISON,	 ROCK,		05
	db POISON,	 GHOST,		05
	db POISON,	 STEEL,		00
	db GROUND,	 FIRE,		20
	db GROUND,	 ELECTRIC,	20
	db GROUND,	 GRASS,		05
	db GROUND,	 POISON,	20
	db GROUND,	 FLYING,	00
	db GROUND,	 BUG,		05
	db GROUND,	 ROCK,		20
	db GROUND,	 STEEL,		20
	db FLYING,	 ELECTRIC,	05
	db FLYING,	 GRASS,		20
	db FLYING,	 FIGHTING,	20
	db FLYING,	 BUG,		20
	db FLYING,	 ROCK,		05
	db FLYING,	 STEEL,		05
	db PSYCHIC,	 FIGHTING,	20
	db PSYCHIC,	 POISON,	20
	db PSYCHIC,	 PSYCHIC,	05
	db PSYCHIC,	 DARK,		00
	db PSYCHIC,	 STEEL,		05
	db BUG,		 FIRE,		05
	db BUG,		 GRASS,		20
	db BUG,		 FIGHTING,	05
	db BUG,		 POISON,	05
	db BUG,		 FLYING,	05
	db BUG,		 PSYCHIC,	20
	db BUG,		 GHOST,		05
	db BUG,		 DARK,		20
	db BUG,		 STEEL,		05
	db ROCK,	 FIRE,		20
	db ROCK,	 ICE,		20
	db ROCK,	 FIGHTING,	05
	db ROCK,	 GROUND,	05
	db ROCK,	 FLYING,	20
	db ROCK,	 BUG,		20
	db ROCK,	 STEEL,		05
	db GHOST,	 NORMAL,	00
	db GHOST,	 PSYCHIC,	20
	db GHOST,	 DARK,		05
	db GHOST,	 STEEL,		05
	db GHOST,	 GHOST,		20
	db DRAGON,	 DRAGON,	20
	db DRAGON,	 STEEL,		05
	db DARK,	 FIGHTING,	05
	db DARK,	 PSYCHIC,	20
	db DARK,	 GHOST,		20
	db DARK,	 DARK,		05
	db DARK,	 STEEL,		05
	db STEEL,	 FIRE,		05
	db STEEL,	 WATER,		05
	db STEEL,	 ELECTRIC,	05
	db STEEL,	 ICE,		20
	db STEEL,	 ROCK,		20
	db STEEL,	 STEEL,		05

	db $fe ; foresight
	db NORMAL,	 GHOST,		00
	db FIGHTING, GHOST,		00

	db $ff ; end
; 34cfd

INCBIN "baserom.gbc",$34cfd,$38000 - $34cfd

SECTION "bankE",DATA,BANK[$E]

INCBIN "baserom.gbc",$38000,$39999 - $38000

TrainerGroupPointerTable: ; 0x39999
	dw FalknerTrainerGroupHeader
	dw WhitneyTrainerGroupHeader
	dw BugsyTrainerGroupHeader
	dw MortyTrainerGroupHeader
	dw PryceTrainerGroupHeader
	dw JasmineTrainerGroupHeader
	dw ChuckTrainerGroupHeader
	dw ClairTrainerGroupHeader
	dw Rival1TrainerGroupHeader
	dw EliteFourWillTrainerGroupHeader
	dw EliteFourWillTrainerGroupHeader
	dw PKMNTrainerGroupHeader
	dw EliteFourBrunoTrainerGroupHeader
	dw EliteFourKarenTrainerGroupHeader
	dw EliteFourKogaTrainerGroupHeader
	dw ChampionTrainerGroupHeader
	dw BrockTrainerGroupHeader
	dw MistyTrainerGroupHeader
	dw LtSurgeTrainerGroupHeader
	dw ScientistTrainerGroupHeader
	dw ErikaTrainerGroupHeader
	dw YoungsterTrainerGroupHeader
	dw SchoolboyTrainerGroupHeader
	dw BirdKeeperTrainerGroupHeader
	dw LassTrainerGroupHeader
	dw JanineTrainerGroupHeader
	dw CooltrainerMTrainerGroupHeader
	dw CooltrainerFTrainerGroupHeader
	dw BeautyTrainerGroupHeader
	dw PokemaniacTrainerGroupHeader
	dw GruntMTrainerGroupHeader
	dw GentlemanTrainerGroupHeader
	dw SkierTrainerGroupHeader
	dw TeacherTrainerGroupHeader
	dw SabrinaTrainerGroupHeader
	dw BugCatcherTrainerGroupHeader
	dw FisherTrainerGroupHeader
	dw SwimmerMTrainerGroupHeader
	dw SwimmerFTrainerGroupHeader
	dw SailorTrainerGroupHeader
	dw SuperNerdTrainerGroupHeader
	dw Rival2TrainerGroupHeader
	dw GuitaristTrainerGroupHeader
	dw HikerTrainerGroupHeader
	dw BikerTrainerGroupHeader
	dw BlaineTrainerGroupHeader
	dw BurglarTrainerGroupHeader
	dw FirebreatherTrainerGroupHeader
	dw JugglerTrainerGroupHeader
	dw BlackbeltTrainerGroupHeader
	dw ExecutiveMTrainerGroupHeader
	dw PsychicTrainerGroupHeader
	dw PicnickerTrainerGroupHeader
	dw CamperTrainerGroupHeader
	dw ExecutiveFTrainerGroupHeader
	dw SageTrainerGroupHeader
	dw MediumTrainerGroupHeader
	dw BoarderTrainerGroupHeader
	dw PokefanMTrainerGroupHeader
	dw KimonoGirlTrainerGroupHeader
	dw TwinsTrainerGroupHeader
	dw PokefanFTrainerGroupHeader
	dw RedTrainerGroupHeader
	dw BlueTrainerGroupHeader
	dw OfficerTrainerGroupHeader
	dw GruntFTrainerGroupHeader
	dw MysticalmanTrainerGroupHeader
; 0x39a1f

FalknerTrainerGroupHeader: ; 0x39a1f
	; FALKNER (1) at 0x39a1f
	db "FALKNER@"
	db $01 ; data type
	db 7, PIDGEY, TACKLE, MUD_SLAP, 0, 0
	db 9, PIDGEOTTO, TACKLE, MUD_SLAP, GUST, 0
	db $ff ; end trainer party mons
	; last_address=0x39a35 size=22
; 0x39a35

WhitneyTrainerGroupHeader: ; 0x39a35
	; WHITNEY (1) at 0x39a35
	db "WHITNEY@"
	db $01 ; data type
	db 18, CLEFAIRY, DOUBLESLAP, MIMIC, ENCORE, METRONOME
	db 20, MILTANK, ROLLOUT, ATTRACT, STOMP, MILK_DRINK
	db $ff ; end trainer party mons
	; last_address=0x39a4b size=22
; 0x39a4b

BugsyTrainerGroupHeader: ; 0x39a4b
	; BUGSY (1) at 0x39a4b
	db "BUGSY@"
	db $01 ; data type
	db 14, METAPOD, TACKLE, STRING_SHOT, HARDEN, 0
	db 14, KAKUNA, POISON_STING, STRING_SHOT, HARDEN, 0
	db 16, SCYTHER, QUICK_ATTACK, LEER, FURY_CUTTER, 0
	db $ff ; end trainer party mons
	; last_address=0x39a65 size=26
; 0x39a65

MortyTrainerGroupHeader: ; 0x39a65
	; MORTY (1) at 0x39a65
	db "MORTY@"
	db $01 ; data type
	db 21, GASTLY, LICK, SPITE, MEAN_LOOK, CURSE
	db 21, HAUNTER, HYPNOSIS, MIMIC, CURSE, NIGHT_SHADE
	db 25, GENGAR, HYPNOSIS, SHADOW_BALL, MEAN_LOOK, DREAM_EATER
	db 23, HAUNTER, SPITE, MEAN_LOOK, MIMIC, NIGHT_SHADE
	db $ff ; end trainer party mons
	; last_address=0x39a85 size=32
; 0x39a85

PryceTrainerGroupHeader: ; 0x39a85
	; PRYCE (1) at 0x39a85
	db "PRYCE@"
	db $01 ; data type
	db 27, SEEL, HEADBUTT, ICY_WIND, AURORA_BEAM, REST
	db 29, DEWGONG, HEADBUTT, ICY_WIND, AURORA_BEAM, REST
	db 31, PILOSWINE, ICY_WIND, FURY_ATTACK, MIST, BLIZZARD
	db $ff ; end trainer party mons
	; last_address=0x39a9f size=26
; 0x39a9f

JasmineTrainerGroupHeader: ; 0x39a9f
	; JASMINE (1) at 0x39a9f
	db "JASMINE@"
	db $01 ; data type
	db 30, MAGNEMITE, THUNDERBOLT, SUPERSONIC, SONICBOOM, THUNDER_WAVE
	db 30, MAGNEMITE, THUNDERBOLT, SUPERSONIC, SONICBOOM, THUNDER_WAVE
	db 35, STEELIX, SCREECH, SUNNY_DAY, ROCK_THROW, IRON_TAIL
	db $ff ; end trainer party mons
	; last_address=0x39abb size=28
; 0x39abb

ChuckTrainerGroupHeader: ; 0x39abb
	; CHUCK (1) at 0x39abb
	db "CHUCK@"
	db $01 ; data type
	db 27, PRIMEAPE, LEER, RAGE, KARATE_CHOP, FURY_SWIPES
	db 30, POLIWRATH, HYPNOSIS, MIND_READER, SURF, DYNAMICPUNCH
	db $ff ; end trainer party mons
	; last_address=0x39acf size=20
; 0x39acf

ClairTrainerGroupHeader: ; 0x39acf
	; CLAIR (1) at 0x39acf
	db "CLAIR@"
	db $01 ; data type
	db 37, DRAGONAIR, THUNDER_WAVE, SURF, SLAM, DRAGONBREATH
	db 37, DRAGONAIR, THUNDER_WAVE, THUNDERBOLT, SLAM, DRAGONBREATH
	db 37, DRAGONAIR, THUNDER_WAVE, ICE_BEAM, SLAM, DRAGONBREATH
	db 40, KINGDRA, SMOKESCREEN, SURF, HYPER_BEAM, DRAGONBREATH
	db $ff ; end trainer party mons
	; last_address=0x39aef size=32
; 0x39aef

Rival1TrainerGroupHeader: ; 0x39aef
	; RIVAL1_1 (1) at 0x39aef
	db "?@"
	db $00 ; data type
	db 5, CHIKORITA
	db $ff ; end trainer party mons
	; last_address=0x39af5 size=6

	; RIVAL1_2 (2) at 0x39af5
	db "?@"
	db $00 ; data type
	db 5, CYNDAQUIL
	db $ff ; end trainer party mons
	; last_address=0x39afb size=6

	; RIVAL1_3 (3) at 0x39afb
	db "?@"
	db $00 ; data type
	db 5, TOTODILE
	db $ff ; end trainer party mons
	; last_address=0x39b01 size=6

	; RIVAL1_4 (4) at 0x39b01
	db "?@"
	db $00 ; data type
	db 12, GASTLY
	db 14, ZUBAT
	db 16, BAYLEEF
	db $ff ; end trainer party mons
	; last_address=0x39b0b size=10

	; RIVAL1_5 (5) at 0x39b0b
	db "?@"
	db $00 ; data type
	db 12, GASTLY
	db 14, ZUBAT
	db 16, QUILAVA
	db $ff ; end trainer party mons
	; last_address=0x39b15 size=10

	; RIVAL1_6 (6) at 0x39b15
	db "?@"
	db $00 ; data type
	db 12, GASTLY
	db 14, ZUBAT
	db 16, CROCONAW
	db $ff ; end trainer party mons
	; last_address=0x39b1f size=10

	; RIVAL1_7 (7) at 0x39b1f
	db "?@"
	db $01 ; data type
	db 20, HAUNTER, LICK, SPITE, MEAN_LOOK, CURSE
	db 18, MAGNEMITE, TACKLE, THUNDERSHOCK, SUPERSONIC, SONICBOOM
	db 20, ZUBAT, LEECH_LIFE, SUPERSONIC, BITE, CONFUSE_RAY
	db 22, BAYLEEF, GROWL, REFLECT, RAZOR_LEAF, POISONPOWDER
	db $ff ; end trainer party mons
	; last_address=0x39b3b size=28

	; RIVAL1_8 (8) at 0x39b3b
	db "?@"
	db $01 ; data type
	db 20, HAUNTER, LICK, SPITE, MEAN_LOOK, CURSE
	db 18, MAGNEMITE, TACKLE, THUNDERSHOCK, SUPERSONIC, SONICBOOM
	db 20, ZUBAT, LEECH_LIFE, SUPERSONIC, BITE, CONFUSE_RAY
	db 22, QUILAVA, LEER, SMOKESCREEN, EMBER, QUICK_ATTACK
	db $ff ; end trainer party mons
	; last_address=0x39b57 size=28

	; RIVAL1_9 (9) at 0x39b57
	db "?@"
	db $01 ; data type
	db 20, HAUNTER, LICK, SPITE, MEAN_LOOK, CURSE
	db 18, MAGNEMITE, TACKLE, THUNDERSHOCK, SUPERSONIC, SONICBOOM
	db 20, ZUBAT, LEECH_LIFE, SUPERSONIC, BITE, CONFUSE_RAY
	db 22, CROCONAW, LEER, RAGE, WATER_GUN, BITE
	db $ff ; end trainer party mons
	; last_address=0x39b73 size=28

	; RIVAL1_10 (10) at 0x39b73
	db "?@"
	db $01 ; data type
	db 30, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db 28, MAGNEMITE, TACKLE, THUNDERSHOCK, SONICBOOM, THUNDER_WAVE
	db 30, HAUNTER, LICK, MEAN_LOOK, CURSE, SHADOW_BALL
	db 32, SNEASEL, LEER, QUICK_ATTACK, SCREECH, FAINT_ATTACK
	db 32, MEGANIUM, REFLECT, RAZOR_LEAF, POISONPOWDER, BODY_SLAM
	db $ff ; end trainer party mons
	; last_address=0x39b95 size=34

	; RIVAL1_11 (11) at 0x39b95
	db "?@"
	db $01 ; data type
	db 30, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db 28, MAGNEMITE, TACKLE, THUNDERSHOCK, SONICBOOM, THUNDER_WAVE
	db 30, HAUNTER, LICK, MEAN_LOOK, CURSE, SHADOW_BALL
	db 32, SNEASEL, LEER, QUICK_ATTACK, SCREECH, FAINT_ATTACK
	db 32, QUILAVA, SMOKESCREEN, EMBER, QUICK_ATTACK, FLAME_WHEEL
	db $ff ; end trainer party mons
	; last_address=0x39bb7 size=34

	; RIVAL1_12 (12) at 0x39bb7
	db "?@"
	db $01 ; data type
	db 30, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db 28, MAGNEMITE, TACKLE, THUNDERSHOCK, SONICBOOM, THUNDER_WAVE
	db 30, HAUNTER, LICK, MEAN_LOOK, CURSE, SHADOW_BALL
	db 32, SNEASEL, LEER, QUICK_ATTACK, SCREECH, FAINT_ATTACK
	db 32, FERALIGATR, RAGE, WATER_GUN, BITE, SCARY_FACE
	db $ff ; end trainer party mons
	; last_address=0x39bd9 size=34

	; RIVAL1_13 (13) at 0x39bd9
	db "?@"
	db $01 ; data type
	db 34, SNEASEL, QUICK_ATTACK, SCREECH, FAINT_ATTACK, FURY_CUTTER
	db 36, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db 35, MAGNETON, THUNDERSHOCK, SONICBOOM, THUNDER_WAVE, SWIFT
	db 35, HAUNTER, MEAN_LOOK, CURSE, SHADOW_BALL, CONFUSE_RAY
	db 35, KADABRA, DISABLE, PSYBEAM, RECOVER, FUTURE_SIGHT
	db 38, MEGANIUM, REFLECT, RAZOR_LEAF, POISONPOWDER, BODY_SLAM
	db $ff ; end trainer party mons
	; last_address=0x39c01 size=40

	; RIVAL1_14 (14) at 0x39c01
	db "?@"
	db $01 ; data type
	db 34, SNEASEL, QUICK_ATTACK, SCREECH, FAINT_ATTACK, FURY_CUTTER
	db 36, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db 35, MAGNETON, THUNDERSHOCK, SONICBOOM, THUNDER_WAVE, SWIFT
	db 35, HAUNTER, MEAN_LOOK, CURSE, SHADOW_BALL, CONFUSE_RAY
	db 35, KADABRA, DISABLE, PSYBEAM, RECOVER, FUTURE_SIGHT
	db 38, TYPHLOSION, SMOKESCREEN, EMBER, QUICK_ATTACK, FLAME_WHEEL
	db $ff ; end trainer party mons
	; last_address=0x39c29 size=40

	; RIVAL1_15 (15) at 0x39c29
	db "?@"
	db $01 ; data type
	db 34, SNEASEL, QUICK_ATTACK, SCREECH, FAINT_ATTACK, FURY_CUTTER
	db 36, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db 34, MAGNETON, THUNDERSHOCK, SONICBOOM, THUNDER_WAVE, SWIFT
	db 35, HAUNTER, MEAN_LOOK, CURSE, SHADOW_BALL, CONFUSE_RAY
	db 35, KADABRA, DISABLE, PSYBEAM, RECOVER, FUTURE_SIGHT
	db 38, FERALIGATR, RAGE, WATER_GUN, SCARY_FACE, SLASH
	db $ff ; end trainer party mons
	; last_address=0x39c51 size=40
; 0x39c51

PokemonProfTrainerGroupHeader: ; 0x39c51
	
; 0x39c51

EliteFourWillTrainerGroupHeader: ; 0x39c51
	; WILL (1) at 0x39c51
	db "WILL@"
	db $01 ; data type
	db 40, XATU, QUICK_ATTACK, FUTURE_SIGHT, CONFUSE_RAY, PSYCHIC_M
	db 41, JYNX, DOUBLESLAP, LOVELY_KISS, ICE_PUNCH, PSYCHIC_M
	db 41, EXEGGUTOR, REFLECT, LEECH_SEED, EGG_BOMB, PSYCHIC_M
	db 41, SLOWBRO, CURSE, AMNESIA, BODY_SLAM, PSYCHIC_M
	db 42, XATU, QUICK_ATTACK, FUTURE_SIGHT, CONFUSE_RAY, PSYCHIC_M
	db $ff ; end trainer party mons
	; last_address=0x39c76 size=37
; 0x39c76

PKMNTrainerGroupHeader: ; 0x39c76
	; CAL1 (2) at 0x39c76
	db "CAL@"
	db $00 ; data type
	db 10, CHIKORITA
	db 10, CYNDAQUIL
	db 10, TOTODILE
	db $ff ; end trainer party mons
	; last_address=0x39c82 size=12

	; CAL2 (3) at 0x39c82
	db "CAL@"
	db $00 ; data type
	db 30, BAYLEEF
	db 30, QUILAVA
	db 30, CROCONAW
	db $ff ; end trainer party mons
	; last_address=0x39c8e size=12

	; CAL3 (4) at 0x39c8e
	db "CAL@"
	db $00 ; data type
	db 50, MEGANIUM
	db 50, TYPHLOSION
	db 50, FERALIGATR
	db $ff ; end trainer party mons
	; last_address=0x39c9a size=12
; 0x39c9a

EliteFourBrunoTrainerGroupHeader: ; 0x39c9a
	; BRUNO (1) at 0x39c9a
	db "BRUNO@"
	db $01 ; data type
	db 42, HITMONTOP, PURSUIT, QUICK_ATTACK, DIG, DETECT
	db 42, HITMONLEE, SWAGGER, DOUBLE_KICK, HI_JUMP_KICK, FORESIGHT
	db 42, HITMONCHAN, THUNDERPUNCH, ICE_PUNCH, FIRE_PUNCH, MACH_PUNCH
	db 43, ONIX, BIND, EARTHQUAKE, SANDSTORM, ROCK_SLIDE
	db 46, MACHAMP, ROCK_SLIDE, FORESIGHT, VITAL_THROW, CROSS_CHOP
	db $ff ; end trainer party mons
	; last_address=0x39cc0 size=38
; 0x39cc0

EliteFourKarenTrainerGroupHeader: ; 0x39cc0
	; KAREN (1) at 0x39cc0
	db "KAREN@"
	db $01 ; data type
	db 42, UMBREON, SAND_ATTACK, CONFUSE_RAY, FAINT_ATTACK, MEAN_LOOK
	db 42, VILEPLUME, STUN_SPORE, ACID, MOONLIGHT, PETAL_DANCE
	db 45, GENGAR, LICK, SPITE, CURSE, DESTINY_BOND
	db 44, MURKROW, QUICK_ATTACK, WHIRLWIND, PURSUIT, FAINT_ATTACK
	db 47, HOUNDOOM, ROAR, PURSUIT, FLAMETHROWER, CRUNCH
	db $ff ; end trainer party mons
	; last_address=0x39ce6 size=38
; 0x39ce6

EliteFourKogaTrainerGroupHeader: ; 0x39ce6
	; KOGA (1) at 0x39ce6
	db "KOGA@"
	db $01 ; data type
	db 40, ARIADOS, DOUBLE_TEAM, SPIDER_WEB, BATON_PASS, GIGA_DRAIN
	db 41, VENOMOTH, SUPERSONIC, GUST, PSYCHIC_M, TOXIC
	db 43, FORRETRESS, PROTECT, SWIFT, EXPLOSION, SPIKES
	db 42, MUK, MINIMIZE, ACID_ARMOR, SLUDGE_BOMB, TOXIC
	db 44, CROBAT, DOUBLE_TEAM, QUICK_ATTACK, WING_ATTACK, TOXIC
	db $ff ; end trainer party mons
	; last_address=0x39d0b size=37
; 0x39d0b

ChampionTrainerGroupHeader: ; 0x39d0b
	; LANCE (1) at 0x39d0b
	db "LANCE@"
	db $01 ; data type
	db 44, GYARADOS, FLAIL, RAIN_DANCE, SURF, HYPER_BEAM
	db 47, DRAGONITE, THUNDER_WAVE, TWISTER, THUNDER, HYPER_BEAM
	db 47, DRAGONITE, THUNDER_WAVE, TWISTER, BLIZZARD, HYPER_BEAM
	db 46, AERODACTYL, WING_ATTACK, ANCIENTPOWER, ROCK_SLIDE, HYPER_BEAM
	db 46, CHARIZARD, FLAMETHROWER, WING_ATTACK, SLASH, HYPER_BEAM
	db 50, DRAGONITE, FIRE_BLAST, SAFEGUARD, OUTRAGE, HYPER_BEAM
	db $ff ; end trainer party mons
	; last_address=0x39d37 size=44
; 0x39d37

BrockTrainerGroupHeader: ; 0x39d37
	; BROCK (1) at 0x39d37
	db "BROCK@"
	db $01 ; data type
	db 41, GRAVELER, DEFENSE_CURL, ROCK_SLIDE, ROLLOUT, EARTHQUAKE
	db 41, RHYHORN, FURY_ATTACK, SCARY_FACE, EARTHQUAKE, HORN_DRILL
	db 42, OMASTAR, BITE, SURF, PROTECT, SPIKE_CANNON
	db 44, ONIX, BIND, ROCK_SLIDE, BIDE, SANDSTORM
	db 42, KABUTOPS, SLASH, SURF, ENDURE, GIGA_DRAIN
	db $ff ; end trainer party mons
	; last_address=0x39d5d size=38
; 0x39d5d

MistyTrainerGroupHeader: ; 0x39d5d
	; MISTY (1) at 0x39d5d
	db "MISTY@"
	db $01 ; data type
	db 42, GOLDUCK, SURF, DISABLE, PSYCH_UP, PSYCHIC_M
	db 42, QUAGSIRE, SURF, AMNESIA, EARTHQUAKE, RAIN_DANCE
	db 44, LAPRAS, SURF, PERISH_SONG, BLIZZARD, RAIN_DANCE
	db 47, STARMIE, SURF, CONFUSE_RAY, RECOVER, ICE_BEAM
	db $ff ; end trainer party mons
	; last_address=0x39d7d size=32
; 0x39d7d

LtSurgeTrainerGroupHeader: ; 0x39d7d
	; LT_SURGE (1) at 0x39d7d
	db "LT.SURGE@"
	db $01 ; data type
	db 44, RAICHU, THUNDER_WAVE, QUICK_ATTACK, THUNDERBOLT, THUNDER
	db 40, ELECTRODE, SCREECH, DOUBLE_TEAM, SWIFT, EXPLOSION
	db 40, MAGNETON, LOCK_ON, DOUBLE_TEAM, SWIFT, ZAP_CANNON
	db 40, ELECTRODE, SCREECH, DOUBLE_TEAM, SWIFT, EXPLOSION
	db 46, ELECTABUZZ, QUICK_ATTACK, THUNDERPUNCH, LIGHT_SCREEN, THUNDER
	db $ff ; end trainer party mons
	; last_address=0x39da6 size=41
; 0x39da6

ScientistTrainerGroupHeader: ; 0x39da6
	; ROSS (1) at 0x39da6
	db "ROSS@"
	db $00 ; data type
	db 22, KOFFING
	db 22, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x39db1 size=11

	; MITCH (2) at 0x39db1
	db "MITCH@"
	db $00 ; data type
	db 24, DITTO
	db $ff ; end trainer party mons
	; last_address=0x39dbb size=10

	; JED (3) at 0x39dbb
	db "JED@"
	db $00 ; data type
	db 20, MAGNEMITE
	db 20, MAGNEMITE
	db 20, MAGNEMITE
	db $ff ; end trainer party mons
	; last_address=0x39dc7 size=12

	; MARC (4) at 0x39dc7
	db "MARC@"
	db $00 ; data type
	db 27, MAGNEMITE
	db 27, MAGNEMITE
	db 27, MAGNEMITE
	db $ff ; end trainer party mons
	; last_address=0x39dd4 size=13

	; RICH (5) at 0x39dd4
	db "RICH@"
	db $01 ; data type
	db 30, PORYGON, CONVERSION, CONVERSION2, RECOVER, TRI_ATTACK
	db $ff ; end trainer party mons
	; last_address=0x39de1 size=13
; 0x39de1

ErikaTrainerGroupHeader: ; 0x39de1
	; ERIKA (1) at 0x39de1
	db "ERIKA@"
	db $01 ; data type
	db 42, TANGELA, VINE_WHIP, BIND, GIGA_DRAIN, SLEEP_POWDER
	db 41, JUMPLUFF, MEGA_DRAIN, LEECH_SEED, COTTON_SPORE, GIGA_DRAIN
	db 46, VICTREEBEL, SUNNY_DAY, SYNTHESIS, ACID, RAZOR_LEAF
	db 46, BELLOSSOM, SUNNY_DAY, SYNTHESIS, PETAL_DANCE, SOLARBEAM
	db $ff ; end trainer party mons
	; last_address=0x39e01 size=32
; 0x39e01

YoungsterTrainerGroupHeader: ; 0x39e01
	; JOEY1 (1) at 0x39e01
	db "JOEY@"
	db $00 ; data type
	db 4, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x39e0a size=9

	; MIKEY (2) at 0x39e0a
	db "MIKEY@"
	db $00 ; data type
	db 2, PIDGEY
	db 4, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x39e16 size=12

	; ALBERT (3) at 0x39e16
	db "ALBERT@"
	db $00 ; data type
	db 6, RATTATA
	db 8, ZUBAT
	db $ff ; end trainer party mons
	; last_address=0x39e23 size=13

	; GORDON (4) at 0x39e23
	db "GORDON@"
	db $00 ; data type
	db 10, WOOPER
	db $ff ; end trainer party mons
	; last_address=0x39e2e size=11

	; SAMUEL (5) at 0x39e2e
	db "SAMUEL@"
	db $00 ; data type
	db 7, RATTATA
	db 10, SANDSHREW
	db 8, SPEAROW
	db 8, SPEAROW
	db $ff ; end trainer party mons
	; last_address=0x39e3f size=17

	; IAN (6) at 0x39e3f
	db "IAN@"
	db $00 ; data type
	db 10, MANKEY
	db 12, DIGLETT
	db $ff ; end trainer party mons
	; last_address=0x39e49 size=10

	; JOEY2 (7) at 0x39e49
	db "JOEY@"
	db $00 ; data type
	db 15, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x39e52 size=9

	; JOEY3 (8) at 0x39e52
	db "JOEY@"
	db $01 ; data type
	db 21, RATICATE, TAIL_WHIP, QUICK_ATTACK, HYPER_FANG, SCARY_FACE
	db $ff ; end trainer party mons
	; last_address=0x39e5f size=13

	; WARREN (9) at 0x39e5f
	db "WARREN@"
	db $00 ; data type
	db 35, FEAROW
	db $ff ; end trainer party mons
	; last_address=0x39e6a size=11

	; JIMMY (10) at 0x39e6a
	db "JIMMY@"
	db $00 ; data type
	db 33, RATICATE
	db 33, ARBOK
	db $ff ; end trainer party mons
	; last_address=0x39e76 size=12

	; OWEN (11) at 0x39e76
	db "OWEN@"
	db $00 ; data type
	db 35, GROWLITHE
	db $ff ; end trainer party mons
	; last_address=0x39e7f size=9

	; JASON (12) at 0x39e7f
	db "JASON@"
	db $00 ; data type
	db 33, SANDSLASH
	db 33, CROBAT
	db $ff ; end trainer party mons
	; last_address=0x39e8b size=12

	; JOEY4 (13) at 0x39e8b
	db "JOEY@"
	db $01 ; data type
	db 30, RATICATE, TAIL_WHIP, QUICK_ATTACK, HYPER_FANG, PURSUIT
	db $ff ; end trainer party mons
	; last_address=0x39e98 size=13

	; JOEY5 (14) at 0x39e98
	db "JOEY@"
	db $01 ; data type
	db 37, RATICATE, HYPER_BEAM, QUICK_ATTACK, HYPER_FANG, PURSUIT
	db $ff ; end trainer party mons
	; last_address=0x39ea5 size=13
; 0x39ea5

SchoolboyTrainerGroupHeader: ; 0x39ea5
	; JACK1 (1) at 0x39ea5
	db "JACK@"
	db $00 ; data type
	db 12, ODDISH
	db 15, VOLTORB
	db $ff ; end trainer party mons
	; last_address=0x39eb0 size=11

	; KIPP (2) at 0x39eb0
	db "KIPP@"
	db $00 ; data type
	db 27, VOLTORB
	db 27, MAGNEMITE
	db 31, VOLTORB
	db 31, MAGNETON
	db $ff ; end trainer party mons
	; last_address=0x39ebf size=15

	; ALAN1 (3) at 0x39ebf
	db "ALAN@"
	db $00 ; data type
	db 16, TANGELA
	db $ff ; end trainer party mons
	; last_address=0x39ec8 size=9

	; JOHNNY (4) at 0x39ec8
	db "JOHNNY@"
	db $00 ; data type
	db 29, BELLSPROUT
	db 31, WEEPINBELL
	db 33, VICTREEBEL
	db $ff ; end trainer party mons
	; last_address=0x39ed7 size=15

	; DANNY (5) at 0x39ed7
	db "DANNY@"
	db $00 ; data type
	db 31, JYNX
	db 31, ELECTABUZZ
	db 31, MAGMAR
	db $ff ; end trainer party mons
	; last_address=0x39ee5 size=14

	; TOMMY (6) at 0x39ee5
	db "TOMMY@"
	db $00 ; data type
	db 32, XATU
	db 34, ALAKAZAM
	db $ff ; end trainer party mons
	; last_address=0x39ef1 size=12

	; DUDLEY (7) at 0x39ef1
	db "DUDLEY@"
	db $00 ; data type
	db 35, ODDISH
	db $ff ; end trainer party mons
	; last_address=0x39efc size=11

	; JOE (8) at 0x39efc
	db "JOE@"
	db $00 ; data type
	db 33, TANGELA
	db 33, VAPOREON
	db $ff ; end trainer party mons
	; last_address=0x39f06 size=10

	; BILLY (9) at 0x39f06
	db "BILLY@"
	db $00 ; data type
	db 27, PARAS
	db 27, PARAS
	db 27, POLIWHIRL
	db 35, DITTO
	db $ff ; end trainer party mons
	; last_address=0x39f16 size=16

	; CHAD1 (10) at 0x39f16
	db "CHAD@"
	db $00 ; data type
	db 19, MR__MIME
	db $ff ; end trainer party mons
	; last_address=0x39f1f size=9

	; NATE (11) at 0x39f1f
	db "NATE@"
	db $00 ; data type
	db 32, LEDIAN
	db 32, EXEGGUTOR
	db $ff ; end trainer party mons
	; last_address=0x39f2a size=11

	; RICKY (12) at 0x39f2a
	db "RICKY@"
	db $00 ; data type
	db 32, AIPOM
	db 32, DITTO
	db $ff ; end trainer party mons
	; last_address=0x39f36 size=12

	; JACK2 (13) at 0x39f36
	db "JACK@"
	db $00 ; data type
	db 14, ODDISH
	db 17, VOLTORB
	db $ff ; end trainer party mons
	; last_address=0x39f41 size=11

	; JACK3 (14) at 0x39f41
	db "JACK@"
	db $00 ; data type
	db 28, GLOOM
	db 31, ELECTRODE
	db $ff ; end trainer party mons
	; last_address=0x39f4c size=11

	; ALAN2 (15) at 0x39f4c
	db "ALAN@"
	db $00 ; data type
	db 17, TANGELA
	db 17, YANMA
	db $ff ; end trainer party mons
	; last_address=0x39f57 size=11

	; ALAN3 (16) at 0x39f57
	db "ALAN@"
	db $00 ; data type
	db 20, NATU
	db 22, TANGELA
	db 20, QUAGSIRE
	db 25, YANMA
	db $ff ; end trainer party mons
	; last_address=0x39f66 size=15

	; CHAD2 (17) at 0x39f66
	db "CHAD@"
	db $00 ; data type
	db 19, MR__MIME
	db 19, MAGNEMITE
	db $ff ; end trainer party mons
	; last_address=0x39f71 size=11

	; CHAD3 (18) at 0x39f71
	db "CHAD@"
	db $00 ; data type
	db 27, MR__MIME
	db 31, MAGNETON
	db $ff ; end trainer party mons
	; last_address=0x39f7c size=11

	; JACK4 (19) at 0x39f7c
	db "JACK@"
	db $00 ; data type
	db 30, GLOOM
	db 33, GROWLITHE
	db 33, ELECTRODE
	db $ff ; end trainer party mons
	; last_address=0x39f89 size=13

	; JACK5 (20) at 0x39f89
	db "JACK@"
	db $01 ; data type
	db 35, ELECTRODE, SCREECH, SONICBOOM, ROLLOUT, LIGHT_SCREEN
	db 35, GROWLITHE, SUNNY_DAY, LEER, TAKE_DOWN, FLAME_WHEEL
	db 37, VILEPLUME, SOLARBEAM, SLEEP_POWDER, ACID, MOONLIGHT
	db $ff ; end trainer party mons
	; last_address=0x39fa2 size=25

	; ALAN4 (21) at 0x39fa2
	db "ALAN@"
	db $00 ; data type
	db 27, NATU
	db 27, TANGELA
	db 30, QUAGSIRE
	db 30, YANMA
	db $ff ; end trainer party mons
	; last_address=0x39fb1 size=15

	; ALAN5 (22) at 0x39fb1
	db "ALAN@"
	db $01 ; data type
	db 35, XATU, PECK, NIGHT_SHADE, SWIFT, FUTURE_SIGHT
	db 32, TANGELA, POISONPOWDER, VINE_WHIP, BIND, MEGA_DRAIN
	db 32, YANMA, QUICK_ATTACK, DOUBLE_TEAM, SONICBOOM, SUPERSONIC
	db 35, QUAGSIRE, TAIL_WHIP, SLAM, AMNESIA, EARTHQUAKE
	db $ff ; end trainer party mons
	; last_address=0x39fd0 size=31

	; CHAD4 (23) at 0x39fd0
	db "CHAD@"
	db $00 ; data type
	db 30, MR__MIME
	db 34, MAGNETON
	db $ff ; end trainer party mons
	; last_address=0x39fdb size=11

	; CHAD5 (24) at 0x39fdb
	db "CHAD@"
	db $01 ; data type
	db 34, MR__MIME, PSYCHIC_M, LIGHT_SCREEN, REFLECT, ENCORE
	db 38, MAGNETON, ZAP_CANNON, THUNDER_WAVE, LOCK_ON, SWIFT
	db $ff ; end trainer party mons
	; last_address=0x39fee size=19
; 0x39fee

BirdKeeperTrainerGroupHeader: ; 0x39fee
	; ROD (1) at 0x39fee
	db "ROD@"
	db $00 ; data type
	db 7, PIDGEY
	db 7, PIDGEY
	db $ff ; end trainer party mons
	; last_address=0x39ff8 size=10

	; ABE (2) at 0x39ff8
	db "ABE@"
	db $00 ; data type
	db 9, SPEAROW
	db $ff ; end trainer party mons
	; last_address=0x3a000 size=8

	; BRYAN (3) at 0x3a000
	db "BRYAN@"
	db $00 ; data type
	db 12, PIDGEY
	db 14, PIDGEOTTO
	db $ff ; end trainer party mons
	; last_address=0x3a00c size=12

	; THEO (4) at 0x3a00c
	db "THEO@"
	db $00 ; data type
	db 17, PIDGEY
	db 15, PIDGEY
	db 19, PIDGEY
	db 15, PIDGEY
	db 15, PIDGEY
	db $ff ; end trainer party mons
	; last_address=0x3a01d size=17

	; TOBY (5) at 0x3a01d
	db "TOBY@"
	db $00 ; data type
	db 15, DODUO
	db 16, DODUO
	db 17, DODUO
	db $ff ; end trainer party mons
	; last_address=0x3a02a size=13

	; DENIS (6) at 0x3a02a
	db "DENIS@"
	db $00 ; data type
	db 18, SPEAROW
	db 20, FEAROW
	db 18, SPEAROW
	db $ff ; end trainer party mons
	; last_address=0x3a038 size=14

	; VANCE1 (7) at 0x3a038
	db "VANCE@"
	db $00 ; data type
	db 25, PIDGEOTTO
	db 25, PIDGEOTTO
	db $ff ; end trainer party mons
	; last_address=0x3a044 size=12

	; HANK (8) at 0x3a044
	db "HANK@"
	db $00 ; data type
	db 12, PIDGEY
	db 34, PIDGEOT
	db $ff ; end trainer party mons
	; last_address=0x3a04f size=11

	; ROY (9) at 0x3a04f
	db "ROY@"
	db $00 ; data type
	db 29, FEAROW
	db 35, FEAROW
	db $ff ; end trainer party mons
	; last_address=0x3a059 size=10

	; BORIS (10) at 0x3a059
	db "BORIS@"
	db $00 ; data type
	db 30, DODUO
	db 28, DODUO
	db 32, DODRIO
	db $ff ; end trainer party mons
	; last_address=0x3a067 size=14

	; BOB (11) at 0x3a067
	db "BOB@"
	db $00 ; data type
	db 34, NOCTOWL
	db $ff ; end trainer party mons
	; last_address=0x3a06f size=8

	; JOSE1 (12) at 0x3a06f
	db "JOSE@"
	db $00 ; data type
	db 36, FARFETCH_D
	db $ff ; end trainer party mons
	; last_address=0x3a078 size=9

	; PETER (13) at 0x3a078
	db "PETER@"
	db $00 ; data type
	db 6, PIDGEY
	db 6, PIDGEY
	db 8, SPEAROW
	db $ff ; end trainer party mons
	; last_address=0x3a086 size=14

	; JOSE2 (14) at 0x3a086
	db "JOSE@"
	db $00 ; data type
	db 34, FARFETCH_D
	db $ff ; end trainer party mons
	; last_address=0x3a08f size=9

	; PERRY (15) at 0x3a08f
	db "PERRY@"
	db $00 ; data type
	db 34, FARFETCH_D
	db $ff ; end trainer party mons
	; last_address=0x3a099 size=10

	; BRET (16) at 0x3a099
	db "BRET@"
	db $00 ; data type
	db 32, PIDGEOTTO
	db 32, FEAROW
	db $ff ; end trainer party mons
	; last_address=0x3a0a4 size=11

	; JOSE3 (17) at 0x3a0a4
	db "JOSE@"
	db $01 ; data type
	db 40, FARFETCH_D, FURY_ATTACK, DETECT, FLY, SLASH
	db $ff ; end trainer party mons
	; last_address=0x3a0b1 size=13

	; VANCE2 (18) at 0x3a0b1
	db "VANCE@"
	db $00 ; data type
	db 32, PIDGEOTTO
	db 32, PIDGEOTTO
	db $ff ; end trainer party mons
	; last_address=0x3a0bd size=12

	; VANCE3 (19) at 0x3a0bd
	db "VANCE@"
	db $01 ; data type
	db 38, PIDGEOT, TOXIC, QUICK_ATTACK, WHIRLWIND, FLY
	db 38, PIDGEOT, SWIFT, DETECT, STEEL_WING, FLY
	db $ff ; end trainer party mons
	; last_address=0x3a0d1 size=20
; 0x3a0d1

LassTrainerGroupHeader: ; 0x3a0d1
	; CARRIE (1) at 0x3a0d1
	db "CARRIE@"
	db $01 ; data type
	db 18, SNUBBULL, SCARY_FACE, CHARM, BITE, LICK
	db $ff ; end trainer party mons
	; last_address=0x3a0e0 size=15

	; BRIDGET (2) at 0x3a0e0
	db "BRIDGET@"
	db $00 ; data type
	db 15, JIGGLYPUFF
	db 15, JIGGLYPUFF
	db 15, JIGGLYPUFF
	db $ff ; end trainer party mons
	; last_address=0x3a0f0 size=16

	; ALICE (3) at 0x3a0f0
	db "ALICE@"
	db $00 ; data type
	db 30, GLOOM
	db 34, ARBOK
	db 30, GLOOM
	db $ff ; end trainer party mons
	; last_address=0x3a0fe size=14

	; KRISE (4) at 0x3a0fe
	db "KRISE@"
	db $00 ; data type
	db 12, ODDISH
	db 15, CUBONE
	db $ff ; end trainer party mons
	; last_address=0x3a10a size=12

	; CONNIE1 (5) at 0x3a10a
	db "CONNIE@"
	db $00 ; data type
	db 21, MARILL
	db $ff ; end trainer party mons
	; last_address=0x3a115 size=11

	; LINDA (6) at 0x3a115
	db "LINDA@"
	db $00 ; data type
	db 30, BULBASAUR
	db 32, IVYSAUR
	db 34, VENUSAUR
	db $ff ; end trainer party mons
	; last_address=0x3a123 size=14

	; LAURA (7) at 0x3a123
	db "LAURA@"
	db $00 ; data type
	db 28, GLOOM
	db 31, PIDGEOTTO
	db 31, BELLOSSOM
	db $ff ; end trainer party mons
	; last_address=0x3a131 size=14

	; SHANNON (8) at 0x3a131
	db "SHANNON@"
	db $00 ; data type
	db 29, PARAS
	db 29, PARAS
	db 32, PARASECT
	db $ff ; end trainer party mons
	; last_address=0x3a141 size=16

	; MICHELLE (9) at 0x3a141
	db "MICHELLE@"
	db $00 ; data type
	db 32, SKIPLOOM
	db 33, HOPPIP
	db 34, JUMPLUFF
	db $ff ; end trainer party mons
	; last_address=0x3a152 size=17

	; DANA1 (10) at 0x3a152
	db "DANA@"
	db $01 ; data type
	db 18, FLAAFFY, TACKLE, GROWL, THUNDERSHOCK, THUNDER_WAVE
	db 18, PSYDUCK, SCRATCH, TAIL_WHIP, DISABLE, CONFUSION
	db $ff ; end trainer party mons
	; last_address=0x3a165 size=19

	; ELLEN (11) at 0x3a165
	db "ELLEN@"
	db $00 ; data type
	db 30, WIGGLYTUFF
	db 34, GRANBULL
	db $ff ; end trainer party mons
	; last_address=0x3a171 size=12

	; CONNIE2 (12) at 0x3a171
	db "CONNIE@"
	db $00 ; data type
	db 21, MARILL
	db $ff ; end trainer party mons
	; last_address=0x3a17c size=11

	; CONNIE3 (13) at 0x3a17c
	db "CONNIE@"
	db $00 ; data type
	db 21, MARILL
	db $ff ; end trainer party mons
	; last_address=0x3a187 size=11

	; DANA2 (14) at 0x3a187
	db "DANA@"
	db $01 ; data type
	db 21, FLAAFFY, TACKLE, GROWL, THUNDERSHOCK, THUNDER_WAVE
	db 21, PSYDUCK, SCRATCH, TAIL_WHIP, DISABLE, CONFUSION
	db $ff ; end trainer party mons
	; last_address=0x3a19a size=19

	; DANA3 (15) at 0x3a19a
	db "DANA@"
	db $01 ; data type
	db 29, PSYDUCK, SCRATCH, DISABLE, CONFUSION, SCREECH
	db 29, AMPHAROS, TACKLE, THUNDERSHOCK, THUNDER_WAVE, COTTON_SPORE
	db $ff ; end trainer party mons
	; last_address=0x3a1ad size=19

	; DANA4 (16) at 0x3a1ad
	db "DANA@"
	db $01 ; data type
	db 32, PSYDUCK, SCRATCH, DISABLE, CONFUSION, SCREECH
	db 32, AMPHAROS, TACKLE, THUNDERPUNCH, THUNDER_WAVE, COTTON_SPORE
	db $ff ; end trainer party mons
	; last_address=0x3a1c0 size=19

	; DANA5 (17) at 0x3a1c0
	db "DANA@"
	db $01 ; data type
	db 36, AMPHAROS, SWIFT, THUNDERPUNCH, THUNDER_WAVE, COTTON_SPORE
	db 36, GOLDUCK, DISABLE, SURF, PSYCHIC_M, SCREECH
	db $ff ; end trainer party mons
	; last_address=0x3a1d3 size=19
; 0x3a1d3

JanineTrainerGroupHeader: ; 0x3a1d3
	; JANINE (1) at 0x3a1d3
	db "JANINE@"
	db $01 ; data type
	db 36, CROBAT, SCREECH, SUPERSONIC, CONFUSE_RAY, WING_ATTACK
	db 36, WEEZING, SMOG, SLUDGE_BOMB, TOXIC, EXPLOSION
	db 36, WEEZING, SMOG, SLUDGE_BOMB, TOXIC, EXPLOSION
	db 33, ARIADOS, SCARY_FACE, GIGA_DRAIN, STRING_SHOT, NIGHT_SHADE
	db 39, VENOMOTH, FORESIGHT, DOUBLE_TEAM, GUST, PSYCHIC_M
	db $ff ; end trainer party mons
	; last_address=0x3a1fa size=39
; 0x3a1fa

CooltrainerMTrainerGroupHeader: ; 0x3a1fa
	; NICK (1) at 0x3a1fa
	db "NICK@"
	db $01 ; data type
	db 26, CHARMANDER, EMBER, SMOKESCREEN, RAGE, SCARY_FACE
	db 26, SQUIRTLE, WITHDRAW, WATER_GUN, BITE, CURSE
	db 26, BULBASAUR, LEECH_SEED, POISONPOWDER, SLEEP_POWDER, RAZOR_LEAF
	db $ff ; end trainer party mons
	; last_address=0x3a213 size=25

	; AARON (2) at 0x3a213
	db "AARON@"
	db $00 ; data type
	db 24, IVYSAUR
	db 24, CHARMELEON
	db 24, WARTORTLE
	db $ff ; end trainer party mons
	; last_address=0x3a221 size=14

	; PAUL (3) at 0x3a221
	db "PAUL@"
	db $00 ; data type
	db 34, DRATINI
	db 34, DRATINI
	db 34, DRATINI
	db $ff ; end trainer party mons
	; last_address=0x3a22e size=13

	; CODY (4) at 0x3a22e
	db "CODY@"
	db $00 ; data type
	db 34, HORSEA
	db 36, SEADRA
	db $ff ; end trainer party mons
	; last_address=0x3a239 size=11

	; MIKE (5) at 0x3a239
	db "MIKE@"
	db $00 ; data type
	db 37, DRAGONAIR
	db $ff ; end trainer party mons
	; last_address=0x3a242 size=9

	; GAVEN1 (6) at 0x3a242
	db "GAVEN@"
	db $01 ; data type
	db 35, VICTREEBEL, WRAP, TOXIC, ACID, RAZOR_LEAF
	db 35, KINGLER, BUBBLEBEAM, STOMP, GUILLOTINE, PROTECT
	db 35, FLAREON, SAND_ATTACK, QUICK_ATTACK, BITE, FIRE_SPIN
	db $ff ; end trainer party mons
	; last_address=0x3a25c size=26

	; GAVEN2 (7) at 0x3a25c
	db "GAVEN@"
	db $03 ; data type
	db 39, VICTREEBEL, $0, GIGA_DRAIN, TOXIC, SLUDGE_BOMB, RAZOR_LEAF
	db 39, KINGLER, KINGS_ROCK, SURF, STOMP, GUILLOTINE, BLIZZARD
	db 39, FLAREON, $0, FLAMETHROWER, QUICK_ATTACK, BITE, FIRE_SPIN
	db $ff ; end trainer party mons
	; last_address=0x3a279 size=29

	; RYAN (8) at 0x3a279
	db "RYAN@"
	db $01 ; data type
	db 25, PIDGEOT, SAND_ATTACK, QUICK_ATTACK, WHIRLWIND, WING_ATTACK
	db 27, ELECTABUZZ, THUNDERPUNCH, LIGHT_SCREEN, SWIFT, SCREECH
	db $ff ; end trainer party mons
	; last_address=0x3a28c size=19

	; JAKE (9) at 0x3a28c
	db "JAKE@"
	db $01 ; data type
	db 33, PARASECT, LEECH_LIFE, SPORE, SLASH, SWORDS_DANCE
	db 35, GOLDUCK, CONFUSION, SCREECH, PSYCH_UP, FURY_SWIPES
	db $ff ; end trainer party mons
	; last_address=0x3a29f size=19

	; GAVEN3 (10) at 0x3a29f
	db "GAVEN@"
	db $01 ; data type
	db 32, VICTREEBEL, WRAP, TOXIC, ACID, RAZOR_LEAF
	db 32, KINGLER, BUBBLEBEAM, STOMP, GUILLOTINE, PROTECT
	db 32, FLAREON, SAND_ATTACK, QUICK_ATTACK, BITE, FIRE_SPIN
	db $ff ; end trainer party mons
	; last_address=0x3a2b9 size=26

	; BLAKE (11) at 0x3a2b9
	db "BLAKE@"
	db $01 ; data type
	db 33, MAGNETON, THUNDERBOLT, SUPERSONIC, SWIFT, SCREECH
	db 31, QUAGSIRE, WATER_GUN, SLAM, AMNESIA, EARTHQUAKE
	db 31, EXEGGCUTE, LEECH_SEED, CONFUSION, SLEEP_POWDER, SOLARBEAM
	db $ff ; end trainer party mons
	; last_address=0x3a2d3 size=26

	; BRIAN (12) at 0x3a2d3
	db "BRIAN@"
	db $01 ; data type
	db 35, SANDSLASH, SAND_ATTACK, POISON_STING, SLASH, SWIFT
	db $ff ; end trainer party mons
	; last_address=0x3a2e1 size=14

	; ERICK (13) at 0x3a2e1
	db "ERICK@"
	db $00 ; data type
	db 10, BULBASAUR
	db 10, CHARMANDER
	db 10, SQUIRTLE
	db $ff ; end trainer party mons
	; last_address=0x3a2ef size=14

	; ANDY (14) at 0x3a2ef
	db "ANDY@"
	db $00 ; data type
	db 10, BULBASAUR
	db 10, CHARMANDER
	db 10, SQUIRTLE
	db $ff ; end trainer party mons
	; last_address=0x3a2fc size=13

	; TYLER (15) at 0x3a2fc
	db "TYLER@"
	db $00 ; data type
	db 10, BULBASAUR
	db 10, CHARMANDER
	db 10, SQUIRTLE
	db $ff ; end trainer party mons
	; last_address=0x3a30a size=14

	; SEAN (16) at 0x3a30a
	db "SEAN@"
	db $00 ; data type
	db 35, FLAREON
	db 35, TANGELA
	db 35, TAUROS
	db $ff ; end trainer party mons
	; last_address=0x3a317 size=13

	; KEVIN (17) at 0x3a317
	db "KEVIN@"
	db $00 ; data type
	db 38, RHYHORN
	db 35, CHARMELEON
	db 35, WARTORTLE
	db $ff ; end trainer party mons
	; last_address=0x3a325 size=14

	; STEVE (18) at 0x3a325
	db "STEVE@"
	db $00 ; data type
	db 14, BULBASAUR
	db 14, CHARMANDER
	db 14, SQUIRTLE
	db $ff ; end trainer party mons
	; last_address=0x3a333 size=14

	; ALLEN (19) at 0x3a333
	db "ALLEN@"
	db $01 ; data type
	db 27, CHARMELEON, EMBER, SMOKESCREEN, RAGE, SCARY_FACE
	db $ff ; end trainer party mons
	; last_address=0x3a341 size=14

	; DARIN (20) at 0x3a341
	db "DARIN@"
	db $01 ; data type
	db 37, DRAGONAIR, WRAP, SURF, DRAGON_RAGE, SLAM
	db $ff ; end trainer party mons
	; last_address=0x3a34f size=14
; 0x3a34f

CooltrainerFTrainerGroupHeader: ; 0x3a34f
	; GWEN (1) at 0x3a34f
	db "GWEN@"
	db $00 ; data type
	db 26, EEVEE
	db 22, FLAREON
	db 22, VAPOREON
	db 22, JOLTEON
	db $ff ; end trainer party mons
	; last_address=0x3a35e size=15

	; LOIS (2) at 0x3a35e
	db "LOIS@"
	db $01 ; data type
	db 25, SKIPLOOM, SYNTHESIS, POISONPOWDER, MEGA_DRAIN, LEECH_SEED
	db 25, NINETALES, EMBER, QUICK_ATTACK, CONFUSE_RAY, SAFEGUARD
	db $ff ; end trainer party mons
	; last_address=0x3a371 size=19

	; FRAN (3) at 0x3a371
	db "FRAN@"
	db $00 ; data type
	db 37, SEADRA
	db $ff ; end trainer party mons
	; last_address=0x3a37a size=9

	; LOLA (4) at 0x3a37a
	db "LOLA@"
	db $00 ; data type
	db 34, DRATINI
	db 36, DRAGONAIR
	db $ff ; end trainer party mons
	; last_address=0x3a385 size=11

	; KATE (5) at 0x3a385
	db "KATE@"
	db $00 ; data type
	db 26, SHELLDER
	db 28, CLOYSTER
	db $ff ; end trainer party mons
	; last_address=0x3a390 size=11

	; IRENE (6) at 0x3a390
	db "IRENE@"
	db $00 ; data type
	db 22, GOLDEEN
	db 24, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3a39c size=12

	; KELLY (7) at 0x3a39c
	db "KELLY@"
	db $00 ; data type
	db 27, MARILL
	db 24, WARTORTLE
	db 24, WARTORTLE
	db $ff ; end trainer party mons
	; last_address=0x3a3aa size=14

	; JOYCE (8) at 0x3a3aa
	db "JOYCE@"
	db $01 ; data type
	db 36, PIKACHU, QUICK_ATTACK, DOUBLE_TEAM, THUNDERBOLT, THUNDER
	db 32, BLASTOISE, BITE, CURSE, SURF, RAIN_DANCE
	db $ff ; end trainer party mons
	; last_address=0x3a3be size=20

	; BETH1 (9) at 0x3a3be
	db "BETH@"
	db $01 ; data type
	db 36, RAPIDASH, STOMP, FIRE_SPIN, FURY_ATTACK, AGILITY
	db $ff ; end trainer party mons
	; last_address=0x3a3cb size=13

	; REENA1 (10) at 0x3a3cb
	db "REENA@"
	db $00 ; data type
	db 31, STARMIE
	db 33, NIDOQUEEN
	db 31, STARMIE
	db $ff ; end trainer party mons
	; last_address=0x3a3d9 size=14

	; MEGAN (11) at 0x3a3d9
	db "MEGAN@"
	db $01 ; data type
	db 32, BULBASAUR, GROWL, LEECH_SEED, POISONPOWDER, RAZOR_LEAF
	db 32, IVYSAUR, GROWL, LEECH_SEED, POISONPOWDER, RAZOR_LEAF
	db 32, VENUSAUR, BODY_SLAM, SLEEP_POWDER, RAZOR_LEAF, SWEET_SCENT
	db $ff ; end trainer party mons
	; last_address=0x3a3f3 size=26

	; BETH2 (12) at 0x3a3f3
	db "BETH@"
	db $01 ; data type
	db 39, RAPIDASH, STOMP, FIRE_SPIN, FURY_ATTACK, AGILITY
	db $ff ; end trainer party mons
	; last_address=0x3a400 size=13

	; CAROL (13) at 0x3a400
	db "CAROL@"
	db $00 ; data type
	db 35, ELECTRODE
	db 35, STARMIE
	db 35, NINETALES
	db $ff ; end trainer party mons
	; last_address=0x3a40e size=14

	; QUINN (14) at 0x3a40e
	db "QUINN@"
	db $00 ; data type
	db 38, IVYSAUR
	db 38, STARMIE
	db $ff ; end trainer party mons
	; last_address=0x3a41a size=12

	; EMMA (15) at 0x3a41a
	db "EMMA@"
	db $00 ; data type
	db 28, POLIWHIRL
	db $ff ; end trainer party mons
	; last_address=0x3a423 size=9

	; CYBIL (16) at 0x3a423
	db "CYBIL@"
	db $01 ; data type
	db 25, BUTTERFREE, CONFUSION, SLEEP_POWDER, WHIRLWIND, GUST
	db 25, BELLOSSOM, ABSORB, STUN_SPORE, ACID, SOLARBEAM
	db $ff ; end trainer party mons
	; last_address=0x3a437 size=20

	; JENN (17) at 0x3a437
	db "JENN@"
	db $00 ; data type
	db 24, STARYU
	db 26, STARMIE
	db $ff ; end trainer party mons
	; last_address=0x3a442 size=11

	; BETH3 (18) at 0x3a442
	db "BETH@"
	db $03 ; data type
	db 43, RAPIDASH, FOCUS_BAND, STOMP, FIRE_SPIN, FURY_ATTACK, FIRE_BLAST
	db $ff ; end trainer party mons
	; last_address=0x3a450 size=14

	; REENA2 (19) at 0x3a450
	db "REENA@"
	db $00 ; data type
	db 34, STARMIE
	db 36, NIDOQUEEN
	db 34, STARMIE
	db $ff ; end trainer party mons
	; last_address=0x3a45e size=14

	; REENA3 (20) at 0x3a45e
	db "REENA@"
	db $03 ; data type
	db 38, STARMIE, $0, DOUBLE_TEAM, PSYCHIC_M, WATERFALL, CONFUSE_RAY
	db 40, NIDOQUEEN, PINK_BOW, EARTHQUAKE, DOUBLE_KICK, TOXIC, BODY_SLAM
	db 38, STARMIE, $0, BLIZZARD, PSYCHIC_M, WATERFALL, RECOVER
	db $ff ; end trainer party mons
	; last_address=0x3a47b size=29

	; CARA (21) at 0x3a47b
	db "CARA@"
	db $01 ; data type
	db 33, HORSEA, SMOKESCREEN, LEER, WHIRLPOOL, TWISTER
	db 33, HORSEA, SMOKESCREEN, LEER, WHIRLPOOL, TWISTER
	db 35, SEADRA, SWIFT, LEER, WATERFALL, TWISTER
	db $ff ; end trainer party mons
	; last_address=0x3a494 size=25
; 0x3a494

BeautyTrainerGroupHeader: ; 0x3a494
	; VICTORIA (1) at 0x3a494
	db "VICTORIA@"
	db $00 ; data type
	db 9, SENTRET
	db 13, SENTRET
	db 17, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a4a5 size=17

	; SAMANTHA (2) at 0x3a4a5
	db "SAMANTHA@"
	db $01 ; data type
	db 16, MEOWTH, SCRATCH, GROWL, BITE, PAY_DAY
	db 16, MEOWTH, SCRATCH, GROWL, BITE, SLASH
	db $ff ; end trainer party mons
	; last_address=0x3a4bc size=23

	; JULIE (3) at 0x3a4bc
	db "JULIE@"
	db $00 ; data type
	db 15, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a4c6 size=10

	; JACLYN (4) at 0x3a4c6
	db "JACLYN@"
	db $00 ; data type
	db 15, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a4d1 size=11

	; BRENDA (5) at 0x3a4d1
	db "BRENDA@"
	db $00 ; data type
	db 16, FURRET
	db $ff ; end trainer party mons
	; last_address=0x3a4dc size=11

	; CASSIE (6) at 0x3a4dc
	db "CASSIE@"
	db $00 ; data type
	db 28, VILEPLUME
	db 34, BUTTERFREE
	db $ff ; end trainer party mons
	; last_address=0x3a4e9 size=13

	; CAROLINE (7) at 0x3a4e9
	db "CAROLINE@"
	db $00 ; data type
	db 30, MARILL
	db 32, SEEL
	db 30, MARILL
	db $ff ; end trainer party mons
	; last_address=0x3a4fa size=17

	; CARLENE (8) at 0x3a4fa
	db "CARLENE@"
	db $00 ; data type
	db 15, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a506 size=12

	; JESSICA (9) at 0x3a506
	db "JESSICA@"
	db $00 ; data type
	db 15, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a512 size=12

	; RACHAEL (10) at 0x3a512
	db "RACHAEL@"
	db $00 ; data type
	db 15, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a51e size=12

	; ANGELICA (11) at 0x3a51e
	db "ANGELICA@"
	db $00 ; data type
	db 15, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a52b size=13

	; KENDRA (12) at 0x3a52b
	db "KENDRA@"
	db $00 ; data type
	db 15, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a536 size=11

	; VERONICA (13) at 0x3a536
	db "VERONICA@"
	db $00 ; data type
	db 15, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a543 size=13

	; JULIA (14) at 0x3a543
	db "JULIA@"
	db $00 ; data type
	db 32, PARAS
	db 32, EXEGGCUTE
	db 35, PARASECT
	db $ff ; end trainer party mons
	; last_address=0x3a551 size=14

	; THERESA (15) at 0x3a551
	db "THERESA@"
	db $00 ; data type
	db 15, SENTRET
	db $ff ; end trainer party mons
	; last_address=0x3a55d size=12

	; VALERIE (16) at 0x3a55d
	db "VALERIE@"
	db $01 ; data type
	db 17, HOPPIP, SYNTHESIS, TAIL_WHIP, TACKLE, POISONPOWDER
	db 17, SKIPLOOM, SYNTHESIS, TAIL_WHIP, TACKLE, STUN_SPORE
	db $ff ; end trainer party mons
	; last_address=0x3a573 size=22

	; OLIVIA (17) at 0x3a573
	db "OLIVIA@"
	db $00 ; data type
	db 19, CORSOLA
	db $ff ; end trainer party mons
	; last_address=0x3a57e size=11
; 0x3a57e

PokemaniacTrainerGroupHeader: ; 0x3a57e
	; LARRY (1) at 0x3a57e
	db "LARRY@"
	db $00 ; data type
	db 10, SLOWPOKE
	db $ff ; end trainer party mons
	; last_address=0x3a588 size=10

	; ANDREW (2) at 0x3a588
	db "ANDREW@"
	db $00 ; data type
	db 24, MAROWAK
	db 24, MAROWAK
	db $ff ; end trainer party mons
	; last_address=0x3a595 size=13

	; CALVIN (3) at 0x3a595
	db "CALVIN@"
	db $00 ; data type
	db 26, KANGASKHAN
	db $ff ; end trainer party mons
	; last_address=0x3a5a0 size=11

	; SHANE (4) at 0x3a5a0
	db "SHANE@"
	db $00 ; data type
	db 16, NIDORINA
	db 16, NIDORINO
	db $ff ; end trainer party mons
	; last_address=0x3a5ac size=12

	; BEN (5) at 0x3a5ac
	db "BEN@"
	db $00 ; data type
	db 19, SLOWBRO
	db $ff ; end trainer party mons
	; last_address=0x3a5b4 size=8

	; BRENT1 (6) at 0x3a5b4
	db "BRENT@"
	db $00 ; data type
	db 19, LICKITUNG
	db $ff ; end trainer party mons
	; last_address=0x3a5be size=10

	; RON (7) at 0x3a5be
	db "RON@"
	db $00 ; data type
	db 19, NIDOKING
	db $ff ; end trainer party mons
	; last_address=0x3a5c6 size=8

	; ETHAN (8) at 0x3a5c6
	db "ETHAN@"
	db $00 ; data type
	db 31, RHYHORN
	db 31, RHYDON
	db $ff ; end trainer party mons
	; last_address=0x3a5d2 size=12

	; BRENT2 (9) at 0x3a5d2
	db "BRENT@"
	db $00 ; data type
	db 25, KANGASKHAN
	db $ff ; end trainer party mons
	; last_address=0x3a5dc size=10

	; BRENT3 (10) at 0x3a5dc
	db "BRENT@"
	db $01 ; data type
	db 36, PORYGON, RECOVER, PSYCHIC_M, CONVERSION2, TRI_ATTACK
	db $ff ; end trainer party mons
	; last_address=0x3a5ea size=14

	; ISSAC (11) at 0x3a5ea
	db "ISSAC@"
	db $01 ; data type
	db 12, LICKITUNG, LICK, SUPERSONIC, CUT, 0
	db $ff ; end trainer party mons
	; last_address=0x3a5f8 size=14

	; DONALD (12) at 0x3a5f8
	db "DONALD@"
	db $00 ; data type
	db 10, SLOWPOKE
	db 10, SLOWPOKE
	db $ff ; end trainer party mons
	; last_address=0x3a605 size=13

	; ZACH (13) at 0x3a605
	db "ZACH@"
	db $00 ; data type
	db 27, RHYHORN
	db $ff ; end trainer party mons
	; last_address=0x3a60e size=9

	; BRENT4 (14) at 0x3a60e
	db "BRENT@"
	db $01 ; data type
	db 41, CHANSEY, ROLLOUT, ATTRACT, EGG_BOMB, SOFTBOILED
	db $ff ; end trainer party mons
	; last_address=0x3a61c size=14

	; MILLER (15) at 0x3a61c
	db "MILLER@"
	db $00 ; data type
	db 17, NIDOKING
	db 17, NIDOQUEEN
	db $ff ; end trainer party mons
	; last_address=0x3a629 size=13
; 0x3a629

GruntMTrainerGroupHeader: ; 0x3a629
	; GRUNT1 (1) at 0x3a629
	db "GRUNT@"
	db $00 ; data type
	db 14, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3a633 size=10

	; GRUNT2 (2) at 0x3a633
	db "GRUNT@"
	db $00 ; data type
	db 7, RATTATA
	db 9, ZUBAT
	db 9, ZUBAT
	db $ff ; end trainer party mons
	; last_address=0x3a641 size=14

	; GRUNT3 (3) at 0x3a641
	db "GRUNT@"
	db $00 ; data type
	db 24, RATICATE
	db 24, RATICATE
	db $ff ; end trainer party mons
	; last_address=0x3a64d size=12

	; GRUNT4 (4) at 0x3a64d
	db "GRUNT@"
	db $00 ; data type
	db 23, GRIMER
	db 23, GRIMER
	db 25, MUK
	db $ff ; end trainer party mons
	; last_address=0x3a65b size=14

	; GRUNT5 (5) at 0x3a65b
	db "GRUNT@"
	db $00 ; data type
	db 21, RATTATA
	db 21, RATTATA
	db 23, RATTATA
	db 23, RATTATA
	db 23, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x3a66d size=18

	; GRUNT6 (6) at 0x3a66d
	db "GRUNT@"
	db $00 ; data type
	db 26, ZUBAT
	db 26, ZUBAT
	db $ff ; end trainer party mons
	; last_address=0x3a679 size=12

	; GRUNT7 (7) at 0x3a679
	db "GRUNT@"
	db $00 ; data type
	db 23, KOFFING
	db 23, GRIMER
	db 23, ZUBAT
	db 23, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x3a689 size=16

	; GRUNT8 (8) at 0x3a689
	db "GRUNT@"
	db $00 ; data type
	db 26, WEEZING
	db $ff ; end trainer party mons
	; last_address=0x3a693 size=10

	; GRUNT9 (9) at 0x3a693
	db "GRUNT@"
	db $00 ; data type
	db 24, RATICATE
	db 26, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3a69f size=12

	; GRUNT10 (10) at 0x3a69f
	db "GRUNT@"
	db $00 ; data type
	db 22, ZUBAT
	db 24, GOLBAT
	db 22, GRIMER
	db $ff ; end trainer party mons
	; last_address=0x3a6ad size=14

	; GRUNT11 (11) at 0x3a6ad
	db "GRUNT@"
	db $00 ; data type
	db 23, MUK
	db 23, KOFFING
	db 25, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x3a6bb size=14

	; GRUNT_EXECUTIVE1 (12) at 0x3a6bb
	db "EXECUTIVE@"
	db $00 ; data type
	db 33, HOUNDOUR
	db $ff ; end trainer party mons
	; last_address=0x3a6c9 size=14

	; GRUNT12 (13) at 0x3a6c9
	db "GRUNT@"
	db $00 ; data type
	db 27, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x3a6d3 size=10

	; GRUNT13 (14) at 0x3a6d3
	db "GRUNT@"
	db $00 ; data type
	db 24, RATICATE
	db 24, GOLBAT
	db $ff ; end trainer party mons
	; last_address=0x3a6df size=12

	; GRUNT14 (15) at 0x3a6df
	db "GRUNT@"
	db $00 ; data type
	db 26, GRIMER
	db 23, WEEZING
	db $ff ; end trainer party mons
	; last_address=0x3a6eb size=12

	; GRUNT15 (16) at 0x3a6eb
	db "GRUNT@"
	db $00 ; data type
	db 16, RATTATA
	db 16, RATTATA
	db 16, RATTATA
	db 16, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x3a6fb size=16

	; GRUNT16 (17) at 0x3a6fb
	db "GRUNT@"
	db $00 ; data type
	db 18, GOLBAT
	db $ff ; end trainer party mons
	; last_address=0x3a705 size=10

	; GRUNT17 (18) at 0x3a705
	db "GRUNT@"
	db $00 ; data type
	db 17, RATTATA
	db 17, ZUBAT
	db 17, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x3a713 size=14

	; GRUNT18 (19) at 0x3a713
	db "GRUNT@"
	db $00 ; data type
	db 18, VENONAT
	db 18, VENONAT
	db $ff ; end trainer party mons
	; last_address=0x3a71f size=12

	; GRUNT19 (20) at 0x3a71f
	db "GRUNT@"
	db $00 ; data type
	db 17, DROWZEE
	db 19, ZUBAT
	db $ff ; end trainer party mons
	; last_address=0x3a72b size=12

	; GRUNT20 (21) at 0x3a72b
	db "GRUNT@"
	db $00 ; data type
	db 16, ZUBAT
	db 17, GRIMER
	db 18, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x3a739 size=14

	; GRUNT_EXECUTIVE2 (22) at 0x3a739
	db "EXECUTIVE@"
	db $00 ; data type
	db 36, GOLBAT
	db $ff ; end trainer party mons
	; last_address=0x3a747 size=14

	; GRUNT_EXECUTIVE3 (23) at 0x3a747
	db "EXECUTIVE@"
	db $00 ; data type
	db 30, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3a755 size=14

	; GRUNT21 (24) at 0x3a755
	db "GRUNT@"
	db $00 ; data type
	db 25, KOFFING
	db 25, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3a761 size=12

	; GRUNT22 (25) at 0x3a761
	db "GRUNT@"
	db $00 ; data type
	db 24, KOFFING
	db 24, MUK
	db $ff ; end trainer party mons
	; last_address=0x3a76d size=12

	; GRUNT23 (26) at 0x3a76d
	db "GRUNT@"
	db $00 ; data type
	db 15, RATTATA
	db 15, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x3a779 size=12

	; GRUNT_EXECUTIVE4 (27) at 0x3a779
	db "EXECUTIVE@"
	db $00 ; data type
	db 22, ZUBAT
	db $ff ; end trainer party mons
	; last_address=0x3a787 size=14

	; GRUNT24 (28) at 0x3a787
	db "GRUNT@"
	db $00 ; data type
	db 19, RATICATE
	db $ff ; end trainer party mons
	; last_address=0x3a791 size=10

	; GRUNT25 (29) at 0x3a791
	db "GRUNT@"
	db $00 ; data type
	db 9, RATTATA
	db 9, RATTATA
	db $ff ; end trainer party mons
	; last_address=0x3a79d size=12

	; GRUNT26 (30) at 0x3a79d
	db "GRUNT@"
	db $00 ; data type
	db 25, GOLBAT
	db 25, GOLBAT
	db 30, ARBOK
	db $ff ; end trainer party mons
	; last_address=0x3a7ab size=14

	; GRUNT27 (31) at 0x3a7ab
	db "GRUNT@"
	db $00 ; data type
	db 30, GOLBAT
	db $ff ; end trainer party mons
	; last_address=0x3a7b5 size=10
; 0x3a7b5

GentlemanTrainerGroupHeader: ; 0x3a7b5
	; PRESTON (1) at 0x3a7b5
	db "PRESTON@"
	db $00 ; data type
	db 18, GROWLITHE
	db 18, GROWLITHE
	db $ff ; end trainer party mons
	; last_address=0x3a7c3 size=14

	; EDWARD (2) at 0x3a7c3
	db "EDWARD@"
	db $00 ; data type
	db 33, PERSIAN
	db $ff ; end trainer party mons
	; last_address=0x3a7ce size=11

	; GREGORY (3) at 0x3a7ce
	db "GREGORY@"
	db $00 ; data type
	db 37, PIKACHU
	db 33, FLAAFFY
	db $ff ; end trainer party mons
	; last_address=0x3a7dc size=14

	; VIRGIL (4) at 0x3a7dc
	db "VIRGIL@"
	db $00 ; data type
	db 20, PONYTA
	db $ff ; end trainer party mons
	; last_address=0x3a7e7 size=11

	; ALFRED (5) at 0x3a7e7
	db "ALFRED@"
	db $00 ; data type
	db 20, NOCTOWL
	db $ff ; end trainer party mons
	; last_address=0x3a7f2 size=11
; 0x3a7f2

SkierTrainerGroupHeader: ; 0x3a7f2
	; ROXANNE (1) at 0x3a7f2
	db "ROXANNE@"
	db $00 ; data type
	db 28, JYNX
	db $ff ; end trainer party mons
	; last_address=0x3a7fe size=12

	; CLARISSA (2) at 0x3a7fe
	db "CLARISSA@"
	db $00 ; data type
	db 28, DEWGONG
	db $ff ; end trainer party mons
	; last_address=0x3a80b size=13
; 0x3a80b

TeacherTrainerGroupHeader: ; 0x3a80b
	; COLETTE (1) at 0x3a80b
	db "COLETTE@"
	db $00 ; data type
	db 36, CLEFAIRY
	db $ff ; end trainer party mons
	; last_address=0x3a817 size=12

	; HILLARY (2) at 0x3a817
	db "HILLARY@"
	db $00 ; data type
	db 32, AIPOM
	db 36, CUBONE
	db $ff ; end trainer party mons
	; last_address=0x3a825 size=14

	; SHIRLEY (3) at 0x3a825
	db "SHIRLEY@"
	db $00 ; data type
	db 35, JIGGLYPUFF
	db $ff ; end trainer party mons
	; last_address=0x3a831 size=12
; 0x3a831

SabrinaTrainerGroupHeader: ; 0x3a831
	; SABRINA (1) at 0x3a831
	db "SABRINA@"
	db $01 ; data type
	db 46, ESPEON, SAND_ATTACK, QUICK_ATTACK, SWIFT, PSYCHIC_M
	db 46, MR__MIME, BARRIER, REFLECT, BATON_PASS, PSYCHIC_M
	db 48, ALAKAZAM, RECOVER, FUTURE_SIGHT, PSYCHIC_M, REFLECT
	db $ff ; end trainer party mons
	; last_address=0x3a84d size=28
; 0x3a84d

BugCatcherTrainerGroupHeader: ; 0x3a84d
	; DON (1) at 0x3a84d
	db "DON@"
	db $00 ; data type
	db 3, CATERPIE
	db 3, CATERPIE
	db $ff ; end trainer party mons
	; last_address=0x3a857 size=10

	; ROB (2) at 0x3a857
	db "ROB@"
	db $00 ; data type
	db 32, BEEDRILL
	db 32, BUTTERFREE
	db $ff ; end trainer party mons
	; last_address=0x3a861 size=10

	; ED (3) at 0x3a861
	db "ED@"
	db $00 ; data type
	db 30, BEEDRILL
	db 30, BEEDRILL
	db 30, BEEDRILL
	db $ff ; end trainer party mons
	; last_address=0x3a86c size=11

	; WADE1 (4) at 0x3a86c
	db "WADE@"
	db $00 ; data type
	db 2, CATERPIE
	db 2, CATERPIE
	db 3, WEEDLE
	db 2, CATERPIE
	db $ff ; end trainer party mons
	; last_address=0x3a87b size=15

	; BUG_CATCHER_BENNY (5) at 0x3a87b
	db "BENNY@"
	db $00 ; data type
	db 7, WEEDLE
	db 9, KAKUNA
	db 12, BEEDRILL
	db $ff ; end trainer party mons
	; last_address=0x3a889 size=14

	; AL (6) at 0x3a889
	db "AL@"
	db $00 ; data type
	db 12, CATERPIE
	db 12, WEEDLE
	db $ff ; end trainer party mons
	; last_address=0x3a892 size=9

	; JOSH (7) at 0x3a892
	db "JOSH@"
	db $00 ; data type
	db 13, PARAS
	db $ff ; end trainer party mons
	; last_address=0x3a89b size=9

	; ARNIE1 (8) at 0x3a89b
	db "ARNIE@"
	db $00 ; data type
	db 15, VENONAT
	db $ff ; end trainer party mons
	; last_address=0x3a8a5 size=10

	; KEN (9) at 0x3a8a5
	db "KEN@"
	db $00 ; data type
	db 30, ARIADOS
	db 32, PINSIR
	db $ff ; end trainer party mons
	; last_address=0x3a8af size=10

	; WADE2 (10) at 0x3a8af
	db "WADE@"
	db $00 ; data type
	db 9, METAPOD
	db 9, METAPOD
	db 10, KAKUNA
	db 9, METAPOD
	db $ff ; end trainer party mons
	; last_address=0x3a8be size=15

	; WADE3 (11) at 0x3a8be
	db "WADE@"
	db $00 ; data type
	db 14, BUTTERFREE
	db 14, BUTTERFREE
	db 15, BEEDRILL
	db 14, BUTTERFREE
	db $ff ; end trainer party mons
	; last_address=0x3a8cd size=15

	; DOUG (12) at 0x3a8cd
	db "DOUG@"
	db $00 ; data type
	db 34, ARIADOS
	db $ff ; end trainer party mons
	; last_address=0x3a8d6 size=9

	; ARNIE2 (13) at 0x3a8d6
	db "ARNIE@"
	db $00 ; data type
	db 19, VENONAT
	db $ff ; end trainer party mons
	; last_address=0x3a8e0 size=10

	; ARNIE3 (14) at 0x3a8e0
	db "ARNIE@"
	db $01 ; data type
	db 28, VENOMOTH, DISABLE, SUPERSONIC, CONFUSION, LEECH_LIFE
	db $ff ; end trainer party mons
	; last_address=0x3a8ee size=14

	; WADE4 (15) at 0x3a8ee
	db "WADE@"
	db $01 ; data type
	db 24, BUTTERFREE, CONFUSION, POISONPOWDER, SUPERSONIC, WHIRLWIND
	db 24, BUTTERFREE, CONFUSION, STUN_SPORE, SUPERSONIC, WHIRLWIND
	db 25, BEEDRILL, FURY_ATTACK, FOCUS_ENERGY, TWINEEDLE, RAGE
	db 24, BUTTERFREE, CONFUSION, SLEEP_POWDER, SUPERSONIC, WHIRLWIND
	db $ff ; end trainer party mons
	; last_address=0x3a90d size=31

	; WADE5 (16) at 0x3a90d
	db "WADE@"
	db $01 ; data type
	db 30, BUTTERFREE, CONFUSION, POISONPOWDER, SUPERSONIC, GUST
	db 30, BUTTERFREE, CONFUSION, STUN_SPORE, SUPERSONIC, GUST
	db 32, BEEDRILL, FURY_ATTACK, PURSUIT, TWINEEDLE, DOUBLE_TEAM
	db 34, BUTTERFREE, PSYBEAM, SLEEP_POWDER, GUST, WHIRLWIND
	db $ff ; end trainer party mons
	; last_address=0x3a92c size=31

	; ARNIE4 (17) at 0x3a92c
	db "ARNIE@"
	db $01 ; data type
	db 36, VENOMOTH, GUST, SUPERSONIC, PSYBEAM, LEECH_LIFE
	db $ff ; end trainer party mons
	; last_address=0x3a93a size=14

	; ARNIE5 (18) at 0x3a93a
	db "ARNIE@"
	db $01 ; data type
	db 40, VENOMOTH, GUST, SUPERSONIC, PSYCHIC_M, TOXIC
	db $ff ; end trainer party mons
	; last_address=0x3a948 size=14

	; WAYNE (19) at 0x3a948
	db "WAYNE@"
	db $00 ; data type
	db 8, LEDYBA
	db 10, PARAS
	db $ff ; end trainer party mons
	; last_address=0x3a954 size=12
; 0x3a954

FisherTrainerGroupHeader: ; 0x3a954
	; JUSTIN (1) at 0x3a954
	db "JUSTIN@"
	db $00 ; data type
	db 5, MAGIKARP
	db 5, MAGIKARP
	db 15, MAGIKARP
	db 5, MAGIKARP
	db $ff ; end trainer party mons
	; last_address=0x3a965 size=17

	; RALPH1 (2) at 0x3a965
	db "RALPH@"
	db $00 ; data type
	db 10, GOLDEEN
	db $ff ; end trainer party mons
	; last_address=0x3a96f size=10

	; ARNOLD (3) at 0x3a96f
	db "ARNOLD@"
	db $00 ; data type
	db 34, TENTACRUEL
	db $ff ; end trainer party mons
	; last_address=0x3a97a size=11

	; KYLE (4) at 0x3a97a
	db "KYLE@"
	db $00 ; data type
	db 28, SEAKING
	db 31, POLIWHIRL
	db 31, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3a987 size=13

	; HENRY (5) at 0x3a987
	db "HENRY@"
	db $00 ; data type
	db 8, POLIWAG
	db 8, POLIWAG
	db $ff ; end trainer party mons
	; last_address=0x3a993 size=12

	; MARVIN (6) at 0x3a993
	db "MARVIN@"
	db $00 ; data type
	db 10, MAGIKARP
	db 10, GYARADOS
	db 15, MAGIKARP
	db 15, GYARADOS
	db $ff ; end trainer party mons
	; last_address=0x3a9a4 size=17

	; TULLY1 (7) at 0x3a9a4
	db "TULLY@"
	db $00 ; data type
	db 18, QWILFISH
	db $ff ; end trainer party mons
	; last_address=0x3a9ae size=10

	; ANDRE (8) at 0x3a9ae
	db "ANDRE@"
	db $00 ; data type
	db 27, GYARADOS
	db $ff ; end trainer party mons
	; last_address=0x3a9b8 size=10

	; RAYMOND (9) at 0x3a9b8
	db "RAYMOND@"
	db $00 ; data type
	db 22, MAGIKARP
	db 22, MAGIKARP
	db 22, MAGIKARP
	db 22, MAGIKARP
	db $ff ; end trainer party mons
	; last_address=0x3a9ca size=18

	; WILTON1 (10) at 0x3a9ca
	db "WILTON@"
	db $00 ; data type
	db 23, GOLDEEN
	db 23, GOLDEEN
	db 25, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3a9d9 size=15

	; EDGAR (11) at 0x3a9d9
	db "EDGAR@"
	db $01 ; data type
	db 25, REMORAID, LOCK_ON, PSYBEAM, AURORA_BEAM, BUBBLEBEAM
	db 25, REMORAID, LOCK_ON, PSYBEAM, AURORA_BEAM, BUBBLEBEAM
	db $ff ; end trainer party mons
	; last_address=0x3a9ed size=20

	; JONAH (12) at 0x3a9ed
	db "JONAH@"
	db $00 ; data type
	db 25, SHELLDER
	db 29, OCTILLERY
	db 25, REMORAID
	db 29, CLOYSTER
	db $ff ; end trainer party mons
	; last_address=0x3a9fd size=16

	; MARTIN (13) at 0x3a9fd
	db "MARTIN@"
	db $00 ; data type
	db 32, REMORAID
	db 32, REMORAID
	db $ff ; end trainer party mons
	; last_address=0x3aa0a size=13

	; STEPHEN (14) at 0x3aa0a
	db "STEPHEN@"
	db $00 ; data type
	db 25, MAGIKARP
	db 25, MAGIKARP
	db 31, QWILFISH
	db 31, TENTACRUEL
	db $ff ; end trainer party mons
	; last_address=0x3aa1c size=18

	; BARNEY (15) at 0x3aa1c
	db "BARNEY@"
	db $00 ; data type
	db 30, GYARADOS
	db 30, GYARADOS
	db 30, GYARADOS
	db $ff ; end trainer party mons
	; last_address=0x3aa2b size=15

	; RALPH2 (16) at 0x3aa2b
	db "RALPH@"
	db $00 ; data type
	db 17, GOLDEEN
	db $ff ; end trainer party mons
	; last_address=0x3aa35 size=10

	; RALPH3 (17) at 0x3aa35
	db "RALPH@"
	db $00 ; data type
	db 17, QWILFISH
	db 19, GOLDEEN
	db $ff ; end trainer party mons
	; last_address=0x3aa41 size=12

	; TULLY2 (18) at 0x3aa41
	db "TULLY@"
	db $00 ; data type
	db 23, QWILFISH
	db $ff ; end trainer party mons
	; last_address=0x3aa4b size=10

	; TULLY3 (19) at 0x3aa4b
	db "TULLY@"
	db $00 ; data type
	db 32, GOLDEEN
	db 32, GOLDEEN
	db 32, QWILFISH
	db $ff ; end trainer party mons
	; last_address=0x3aa59 size=14

	; WILTON2 (20) at 0x3aa59
	db "WILTON@"
	db $00 ; data type
	db 29, GOLDEEN
	db 29, GOLDEEN
	db 32, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3aa68 size=15

	; SCOTT (21) at 0x3aa68
	db "SCOTT@"
	db $00 ; data type
	db 30, QWILFISH
	db 30, QWILFISH
	db 34, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3aa76 size=14

	; WILTON3 (22) at 0x3aa76
	db "WILTON@"
	db $01 ; data type
	db 34, SEAKING, SUPERSONIC, WATERFALL, FLAIL, FURY_ATTACK
	db 34, SEAKING, SUPERSONIC, WATERFALL, FLAIL, FURY_ATTACK
	db 38, REMORAID, PSYBEAM, AURORA_BEAM, BUBBLEBEAM, HYPER_BEAM
	db $ff ; end trainer party mons
	; last_address=0x3aa91 size=27

	; RALPH4 (23) at 0x3aa91
	db "RALPH@"
	db $00 ; data type
	db 30, QWILFISH
	db 32, GOLDEEN
	db $ff ; end trainer party mons
	; last_address=0x3aa9d size=12

	; RALPH5 (24) at 0x3aa9d
	db "RALPH@"
	db $01 ; data type
	db 35, QWILFISH, TOXIC, MINIMIZE, SURF, PIN_MISSILE
	db 39, SEAKING, ENDURE, FLAIL, FURY_ATTACK, WATERFALL
	db $ff ; end trainer party mons
	; last_address=0x3aab1 size=20

	; TULLY4 (25) at 0x3aab1
	db "TULLY@"
	db $01 ; data type
	db 34, SEAKING, SUPERSONIC, RAIN_DANCE, WATERFALL, FURY_ATTACK
	db 34, SEAKING, SUPERSONIC, RAIN_DANCE, WATERFALL, FURY_ATTACK
	db 37, QWILFISH, ROLLOUT, SURF, PIN_MISSILE, TAKE_DOWN
	db $ff ; end trainer party mons
	; last_address=0x3aacb size=26
; 0x3aacb

SwimmerMTrainerGroupHeader: ; 0x3aacb
	; HAROLD (1) at 0x3aacb
	db "HAROLD@"
	db $00 ; data type
	db 32, REMORAID
	db 30, SEADRA
	db $ff ; end trainer party mons
	; last_address=0x3aad8 size=13

	; SIMON (2) at 0x3aad8
	db "SIMON@"
	db $00 ; data type
	db 20, TENTACOOL
	db 20, TENTACOOL
	db $ff ; end trainer party mons
	; last_address=0x3aae4 size=12

	; RANDALL (3) at 0x3aae4
	db "RANDALL@"
	db $00 ; data type
	db 18, SHELLDER
	db 20, WARTORTLE
	db 18, SHELLDER
	db $ff ; end trainer party mons
	; last_address=0x3aaf4 size=16

	; CHARLIE (4) at 0x3aaf4
	db "CHARLIE@"
	db $00 ; data type
	db 21, SHELLDER
	db 19, TENTACOOL
	db 19, TENTACRUEL
	db $ff ; end trainer party mons
	; last_address=0x3ab04 size=16

	; GEORGE (5) at 0x3ab04
	db "GEORGE@"
	db $00 ; data type
	db 16, TENTACOOL
	db 17, TENTACOOL
	db 16, TENTACOOL
	db 19, STARYU
	db 17, TENTACOOL
	db 19, REMORAID
	db $ff ; end trainer party mons
	; last_address=0x3ab19 size=21

	; BERKE (6) at 0x3ab19
	db "BERKE@"
	db $00 ; data type
	db 23, QWILFISH
	db $ff ; end trainer party mons
	; last_address=0x3ab23 size=10

	; KIRK (7) at 0x3ab23
	db "KIRK@"
	db $00 ; data type
	db 20, GYARADOS
	db 20, GYARADOS
	db $ff ; end trainer party mons
	; last_address=0x3ab2e size=11

	; MATHEW (8) at 0x3ab2e
	db "MATHEW@"
	db $00 ; data type
	db 23, KRABBY
	db $ff ; end trainer party mons
	; last_address=0x3ab39 size=11

	; HAL (9) at 0x3ab39
	db "HAL@"
	db $00 ; data type
	db 24, SEEL
	db 25, DEWGONG
	db 24, SEEL
	db $ff ; end trainer party mons
	; last_address=0x3ab45 size=12

	; PATON (10) at 0x3ab45
	db "PATON@"
	db $00 ; data type
	db 26, PILOSWINE
	db 26, PILOSWINE
	db $ff ; end trainer party mons
	; last_address=0x3ab51 size=12

	; DARYL (11) at 0x3ab51
	db "DARYL@"
	db $00 ; data type
	db 24, SHELLDER
	db 25, CLOYSTER
	db 24, SHELLDER
	db $ff ; end trainer party mons
	; last_address=0x3ab5f size=14

	; WALTER (12) at 0x3ab5f
	db "WALTER@"
	db $00 ; data type
	db 15, HORSEA
	db 15, HORSEA
	db 20, SEADRA
	db $ff ; end trainer party mons
	; last_address=0x3ab6e size=15

	; TONY (13) at 0x3ab6e
	db "TONY@"
	db $00 ; data type
	db 13, STARYU
	db 18, STARMIE
	db 16, HORSEA
	db $ff ; end trainer party mons
	; last_address=0x3ab7b size=13

	; JEROME (14) at 0x3ab7b
	db "JEROME@"
	db $00 ; data type
	db 26, SEADRA
	db 28, TENTACOOL
	db 30, TENTACRUEL
	db 28, GOLDEEN
	db $ff ; end trainer party mons
	; last_address=0x3ab8c size=17

	; TUCKER (15) at 0x3ab8c
	db "TUCKER@"
	db $00 ; data type
	db 30, SHELLDER
	db 34, CLOYSTER
	db $ff ; end trainer party mons
	; last_address=0x3ab99 size=13

	; RICK (16) at 0x3ab99
	db "RICK@"
	db $00 ; data type
	db 13, STARYU
	db 18, STARMIE
	db 16, HORSEA
	db $ff ; end trainer party mons
	; last_address=0x3aba6 size=13

	; CAMERON (17) at 0x3aba6
	db "CAMERON@"
	db $00 ; data type
	db 34, MARILL
	db $ff ; end trainer party mons
	; last_address=0x3abb2 size=12

	; SETH (18) at 0x3abb2
	db "SETH@"
	db $00 ; data type
	db 29, QUAGSIRE
	db 29, OCTILLERY
	db 32, QUAGSIRE
	db $ff ; end trainer party mons
	; last_address=0x3abbf size=13

	; JAMES (19) at 0x3abbf
	db "JAMES@"
	db $00 ; data type
	db 13, STARYU
	db 18, STARMIE
	db 16, HORSEA
	db $ff ; end trainer party mons
	; last_address=0x3abcd size=14

	; LEWIS (20) at 0x3abcd
	db "LEWIS@"
	db $00 ; data type
	db 13, STARYU
	db 18, STARMIE
	db 16, HORSEA
	db $ff ; end trainer party mons
	; last_address=0x3abdb size=14

	; PARKER (21) at 0x3abdb
	db "PARKER@"
	db $00 ; data type
	db 32, HORSEA
	db 32, HORSEA
	db 35, SEADRA
	db $ff ; end trainer party mons
	; last_address=0x3abea size=15
; 0x3abea

SwimmerFTrainerGroupHeader: ; 0x3abea
	; ELAINE (1) at 0x3abea
	db "ELAINE@"
	db $00 ; data type
	db 21, STARYU
	db $ff ; end trainer party mons
	; last_address=0x3abf5 size=11

	; PAULA (2) at 0x3abf5
	db "PAULA@"
	db $00 ; data type
	db 19, STARYU
	db 19, SHELLDER
	db $ff ; end trainer party mons
	; last_address=0x3ac01 size=12

	; KAYLEE (3) at 0x3ac01
	db "KAYLEE@"
	db $00 ; data type
	db 18, GOLDEEN
	db 20, GOLDEEN
	db 20, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3ac10 size=15

	; SUSIE (4) at 0x3ac10
	db "SUSIE@"
	db $01 ; data type
	db 20, PSYDUCK, SCRATCH, TAIL_WHIP, DISABLE, CONFUSION
	db 22, GOLDEEN, PECK, TAIL_WHIP, SUPERSONIC, HORN_ATTACK
	db $ff ; end trainer party mons
	; last_address=0x3ac24 size=20

	; DENISE (5) at 0x3ac24
	db "DENISE@"
	db $00 ; data type
	db 22, SEEL
	db $ff ; end trainer party mons
	; last_address=0x3ac2f size=11

	; KARA (6) at 0x3ac2f
	db "KARA@"
	db $00 ; data type
	db 20, STARYU
	db 20, STARMIE
	db $ff ; end trainer party mons
	; last_address=0x3ac3a size=11

	; WENDY (7) at 0x3ac3a
	db "WENDY@"
	db $01 ; data type
	db 21, HORSEA, BUBBLE, SMOKESCREEN, LEER, WATER_GUN
	db 21, HORSEA, DRAGON_RAGE, SMOKESCREEN, LEER, WATER_GUN
	db $ff ; end trainer party mons
	; last_address=0x3ac4e size=20

	; LISA (8) at 0x3ac4e
	db "LISA@"
	db $00 ; data type
	db 28, JYNX
	db $ff ; end trainer party mons
	; last_address=0x3ac57 size=9

	; JILL (9) at 0x3ac57
	db "JILL@"
	db $00 ; data type
	db 28, DEWGONG
	db $ff ; end trainer party mons
	; last_address=0x3ac60 size=9

	; MARY (10) at 0x3ac60
	db "MARY@"
	db $00 ; data type
	db 20, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3ac69 size=9

	; KATIE (11) at 0x3ac69
	db "KATIE@"
	db $00 ; data type
	db 33, DEWGONG
	db $ff ; end trainer party mons
	; last_address=0x3ac73 size=10

	; DAWN (12) at 0x3ac73
	db "DAWN@"
	db $00 ; data type
	db 34, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3ac7c size=9

	; TARA (13) at 0x3ac7c
	db "TARA@"
	db $00 ; data type
	db 20, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3ac85 size=9

	; NICOLE (14) at 0x3ac85
	db "NICOLE@"
	db $00 ; data type
	db 29, MARILL
	db 29, MARILL
	db 32, LAPRAS
	db $ff ; end trainer party mons
	; last_address=0x3ac94 size=15

	; LORI (15) at 0x3ac94
	db "LORI@"
	db $00 ; data type
	db 32, STARMIE
	db 32, STARMIE
	db $ff ; end trainer party mons
	; last_address=0x3ac9f size=11

	; JODY (16) at 0x3ac9f
	db "JODY@"
	db $00 ; data type
	db 20, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3aca8 size=9

	; NIKKI (17) at 0x3aca8
	db "NIKKI@"
	db $00 ; data type
	db 28, SEEL
	db 28, SEEL
	db 28, SEEL
	db 28, DEWGONG
	db $ff ; end trainer party mons
	; last_address=0x3acb8 size=16

	; DIANA (18) at 0x3acb8
	db "DIANA@"
	db $00 ; data type
	db 37, GOLDUCK
	db $ff ; end trainer party mons
	; last_address=0x3acc2 size=10

	; BRIANA (19) at 0x3acc2
	db "BRIANA@"
	db $00 ; data type
	db 35, SEAKING
	db 35, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3accf size=13
; 0x3accf

SailorTrainerGroupHeader: ; 0x3accf
	; EUGENE (1) at 0x3accf
	db "EUGENE@"
	db $00 ; data type
	db 17, POLIWHIRL
	db 17, RATICATE
	db 19, KRABBY
	db $ff ; end trainer party mons
	; last_address=0x3acde size=15

	; HUEY1 (2) at 0x3acde
	db "HUEY@"
	db $00 ; data type
	db 18, POLIWAG
	db 18, POLIWHIRL
	db $ff ; end trainer party mons
	; last_address=0x3ace9 size=11

	; TERRELL (3) at 0x3ace9
	db "TERRELL@"
	db $00 ; data type
	db 20, POLIWHIRL
	db $ff ; end trainer party mons
	; last_address=0x3acf5 size=12

	; KENT (4) at 0x3acf5
	db "KENT@"
	db $01 ; data type
	db 18, KRABBY, BUBBLE, LEER, VICEGRIP, HARDEN
	db 20, KRABBY, BUBBLEBEAM, LEER, VICEGRIP, HARDEN
	db $ff ; end trainer party mons
	; last_address=0x3ad08 size=19

	; ERNEST (5) at 0x3ad08
	db "ERNEST@"
	db $00 ; data type
	db 18, MACHOP
	db 18, MACHOP
	db 18, POLIWHIRL
	db $ff ; end trainer party mons
	; last_address=0x3ad17 size=15

	; JEFF (6) at 0x3ad17
	db "JEFF@"
	db $00 ; data type
	db 32, RATICATE
	db 32, RATICATE
	db $ff ; end trainer party mons
	; last_address=0x3ad22 size=11

	; GARRETT (7) at 0x3ad22
	db "GARRETT@"
	db $00 ; data type
	db 34, KINGLER
	db $ff ; end trainer party mons
	; last_address=0x3ad2e size=12

	; KENNETH (8) at 0x3ad2e
	db "KENNETH@"
	db $00 ; data type
	db 28, MACHOP
	db 28, MACHOP
	db 28, POLIWRATH
	db 28, MACHOP
	db $ff ; end trainer party mons
	; last_address=0x3ad40 size=18

	; STANLY (9) at 0x3ad40
	db "STANLY@"
	db $00 ; data type
	db 31, MACHOP
	db 33, MACHOKE
	db 26, PSYDUCK
	db $ff ; end trainer party mons
	; last_address=0x3ad4f size=15

	; HARRY (10) at 0x3ad4f
	db "HARRY@"
	db $00 ; data type
	db 19, WOOPER
	db $ff ; end trainer party mons
	; last_address=0x3ad59 size=10

	; HUEY2 (11) at 0x3ad59
	db "HUEY@"
	db $00 ; data type
	db 28, POLIWHIRL
	db 28, POLIWHIRL
	db $ff ; end trainer party mons
	; last_address=0x3ad64 size=11

	; HUEY3 (12) at 0x3ad64
	db "HUEY@"
	db $00 ; data type
	db 34, POLIWHIRL
	db 34, POLIWRATH
	db $ff ; end trainer party mons
	; last_address=0x3ad6f size=11

	; HUEY4 (13) at 0x3ad6f
	db "HUEY@"
	db $01 ; data type
	db 38, POLITOED, WHIRLPOOL, RAIN_DANCE, BODY_SLAM, PERISH_SONG
	db 38, POLIWRATH, SURF, STRENGTH, ICE_PUNCH, SUBMISSION
	db $ff ; end trainer party mons
	; last_address=0x3ad82 size=19
; 0x3ad82

SuperNerdTrainerGroupHeader: ; 0x3ad82
	; STAN (2) at 0x3ad82
	db "STAN@"
	db $00 ; data type
	db 20, GRIMER
	db $ff ; end trainer party mons
	; last_address=0x3ad8b size=9

	; ERIC (3) at 0x3ad8b
	db "ERIC@"
	db $00 ; data type
	db 11, GRIMER
	db 11, GRIMER
	db $ff ; end trainer party mons
	; last_address=0x3ad96 size=11

	; GREGG (4) at 0x3ad96
	db "GREGG@"
	db $00 ; data type
	db 20, MAGNEMITE
	db 20, MAGNEMITE
	db 20, MAGNEMITE
	db $ff ; end trainer party mons
	; last_address=0x3ada4 size=14

	; JAY (5) at 0x3ada4
	db "JAY@"
	db $00 ; data type
	db 22, KOFFING
	db 22, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3adae size=10

	; DAVE (6) at 0x3adae
	db "DAVE@"
	db $00 ; data type
	db 24, DITTO
	db $ff ; end trainer party mons
	; last_address=0x3adb7 size=9

	; SAM (7) at 0x3adb7
	db "SAM@"
	db $00 ; data type
	db 34, GRIMER
	db 34, MUK
	db $ff ; end trainer party mons
	; last_address=0x3adc1 size=10

	; TOM (8) at 0x3adc1
	db "TOM@"
	db $00 ; data type
	db 32, MAGNEMITE
	db 32, MAGNEMITE
	db 32, MAGNEMITE
	db $ff ; end trainer party mons
	; last_address=0x3adcd size=12

	; PAT (9) at 0x3adcd
	db "PAT@"
	db $00 ; data type
	db 36, PORYGON
	db $ff ; end trainer party mons
	; last_address=0x3add5 size=8

	; SHAWN (10) at 0x3add5
	db "SHAWN@"
	db $00 ; data type
	db 31, MAGNEMITE
	db 33, MUK
	db 31, MAGNEMITE
	db $ff ; end trainer party mons
	; last_address=0x3ade3 size=14

	; TERU (11) at 0x3ade3
	db "TERU@"
	db $00 ; data type
	db 7, MAGNEMITE
	db 11, VOLTORB
	db 7, MAGNEMITE
	db 9, MAGNEMITE
	db $ff ; end trainer party mons
	; last_address=0x3adf2 size=15

	; RUSS (12) at 0x3adf2
	db "RUSS@"
	db $00 ; data type
	db 27, MAGNEMITE
	db 27, MAGNEMITE
	db 27, MAGNEMITE
	db $ff ; end trainer party mons
	; last_address=0x3adff size=13

	; NORTON (13) at 0x3adff
	db "NORTON@"
	db $01 ; data type
	db 30, PORYGON, CONVERSION, CONVERSION2, RECOVER, TRI_ATTACK
	db $ff ; end trainer party mons
	; last_address=0x3ae0e size=15

	; HUGH (14) at 0x3ae0e
	db "HUGH@"
	db $01 ; data type
	db 39, SEADRA, SMOKESCREEN, TWISTER, SURF, WATERFALL
	db $ff ; end trainer party mons
	; last_address=0x3ae1b size=13

	; MARKUS (15) at 0x3ae1b
	db "MARKUS@"
	db $01 ; data type
	db 19, SLOWPOKE, CURSE, WATER_GUN, GROWL, STRENGTH
	db $ff ; end trainer party mons
	; last_address=0x3ae2a size=15
; 0x3ae2a

Rival2TrainerGroupHeader: ; 0x3ae2a
	; RIVAL2_1 (1) at 0x3ae2a
	db "?@"
	db $01 ; data type
	db 41, SNEASEL, QUICK_ATTACK, SCREECH, FAINT_ATTACK, FURY_CUTTER
	db 42, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db 41, MAGNETON, THUNDERSHOCK, SONICBOOM, THUNDER_WAVE, SWIFT
	db 43, GENGAR, MEAN_LOOK, CURSE, SHADOW_BALL, CONFUSE_RAY
	db 43, ALAKAZAM, DISABLE, RECOVER, FUTURE_SIGHT, PSYCHIC_M
	db 45, MEGANIUM, RAZOR_LEAF, POISONPOWDER, BODY_SLAM, LIGHT_SCREEN
	db $ff ; end trainer party mons
	; last_address=0x3ae52 size=40

	; RIVAL2_2 (2) at 0x3ae52
	db "?@"
	db $01 ; data type
	db 41, SNEASEL, QUICK_ATTACK, SCREECH, FAINT_ATTACK, FURY_CUTTER
	db 42, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db 41, MAGNETON, THUNDERSHOCK, SONICBOOM, THUNDER_WAVE, SWIFT
	db 43, GENGAR, MEAN_LOOK, CURSE, SHADOW_BALL, CONFUSE_RAY
	db 43, ALAKAZAM, DISABLE, RECOVER, FUTURE_SIGHT, PSYCHIC_M
	db 45, TYPHLOSION, SMOKESCREEN, QUICK_ATTACK, FLAME_WHEEL, SWIFT
	db $ff ; end trainer party mons
	; last_address=0x3ae7a size=40

	; RIVAL2_3 (3) at 0x3ae7a
	db "?@"
	db $01 ; data type
	db 41, SNEASEL, QUICK_ATTACK, SCREECH, FAINT_ATTACK, FURY_CUTTER
	db 42, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db 41, MAGNETON, THUNDERSHOCK, SONICBOOM, THUNDER_WAVE, SWIFT
	db 43, GENGAR, MEAN_LOOK, CURSE, SHADOW_BALL, CONFUSE_RAY
	db 43, ALAKAZAM, DISABLE, RECOVER, FUTURE_SIGHT, PSYCHIC_M
	db 45, FERALIGATR, RAGE, WATER_GUN, SCARY_FACE, SLASH
	db $ff ; end trainer party mons
	; last_address=0x3aea2 size=40

	; RIVAL2_4 (4) at 0x3aea2
	db "?@"
	db $01 ; data type
	db 45, SNEASEL, QUICK_ATTACK, SCREECH, FAINT_ATTACK, FURY_CUTTER
	db 48, CROBAT, TOXIC, BITE, CONFUSE_RAY, WING_ATTACK
	db 45, MAGNETON, THUNDER, SONICBOOM, THUNDER_WAVE, SWIFT
	db 46, GENGAR, MEAN_LOOK, CURSE, SHADOW_BALL, CONFUSE_RAY
	db 46, ALAKAZAM, RECOVER, FUTURE_SIGHT, PSYCHIC_M, REFLECT
	db 50, MEGANIUM, GIGA_DRAIN, BODY_SLAM, LIGHT_SCREEN, SAFEGUARD
	db $ff ; end trainer party mons
	; last_address=0x3aeca size=40

	; RIVAL2_5 (5) at 0x3aeca
	db "?@"
	db $01 ; data type
	db 45, SNEASEL, QUICK_ATTACK, SCREECH, FAINT_ATTACK, FURY_CUTTER
	db 48, CROBAT, TOXIC, BITE, CONFUSE_RAY, WING_ATTACK
	db 45, MAGNETON, THUNDER, SONICBOOM, THUNDER_WAVE, SWIFT
	db 46, GENGAR, MEAN_LOOK, CURSE, SHADOW_BALL, CONFUSE_RAY
	db 46, ALAKAZAM, RECOVER, FUTURE_SIGHT, PSYCHIC_M, REFLECT
	db 50, TYPHLOSION, SMOKESCREEN, QUICK_ATTACK, FIRE_BLAST, SWIFT
	db $ff ; end trainer party mons
	; last_address=0x3aef2 size=40

	; RIVAL2_6 (6) at 0x3aef2
	db "?@"
	db $01 ; data type
	db 45, SNEASEL, QUICK_ATTACK, SCREECH, FAINT_ATTACK, FURY_CUTTER
	db 48, CROBAT, TOXIC, BITE, CONFUSE_RAY, WING_ATTACK
	db 45, MAGNETON, THUNDER, SONICBOOM, THUNDER_WAVE, SWIFT
	db 46, GENGAR, MEAN_LOOK, CURSE, SHADOW_BALL, CONFUSE_RAY
	db 46, ALAKAZAM, RECOVER, FUTURE_SIGHT, PSYCHIC_M, REFLECT
	db 50, FERALIGATR, SURF, RAIN_DANCE, SLASH, SCREECH
	db $ff ; end trainer party mons
	; last_address=0x3af1a size=40
; 0x3af1a

GuitaristTrainerGroupHeader: ; 0x3af1a
	; CLYDE (1) at 0x3af1a
	db "CLYDE@"
	db $00 ; data type
	db 34, ELECTABUZZ
	db $ff ; end trainer party mons
	; last_address=0x3af24 size=10

	; VINCENT (2) at 0x3af24
	db "VINCENT@"
	db $00 ; data type
	db 27, MAGNEMITE
	db 33, VOLTORB
	db 32, MAGNEMITE
	db 32, MAGNEMITE
	db $ff ; end trainer party mons
	; last_address=0x3af36 size=18
; 0x3af36

HikerTrainerGroupHeader: ; 0x3af36
	; ANTHONY1 (1) at 0x3af36
	db "ANTHONY@"
	db $00 ; data type
	db 16, GEODUDE
	db 18, MACHAMP
	db $ff ; end trainer party mons
	; last_address=0x3af44 size=14

	; RUSSELL (2) at 0x3af44
	db "RUSSELL@"
	db $00 ; data type
	db 4, GEODUDE
	db 6, GEODUDE
	db 8, GEODUDE
	db $ff ; end trainer party mons
	; last_address=0x3af54 size=16

	; PHILLIP (3) at 0x3af54
	db "PHILLIP@"
	db $00 ; data type
	db 23, GEODUDE
	db 23, GEODUDE
	db 23, GRAVELER
	db $ff ; end trainer party mons
	; last_address=0x3af64 size=16

	; LEONARD (4) at 0x3af64
	db "LEONARD@"
	db $00 ; data type
	db 23, GEODUDE
	db 25, MACHOP
	db $ff ; end trainer party mons
	; last_address=0x3af72 size=14

	; ANTHONY2 (5) at 0x3af72
	db "ANTHONY@"
	db $00 ; data type
	db 11, GEODUDE
	db 11, MACHOP
	db $ff ; end trainer party mons
	; last_address=0x3af80 size=14

	; BENJAMIN (6) at 0x3af80
	db "BENJAMIN@"
	db $00 ; data type
	db 14, DIGLETT
	db 14, GEODUDE
	db 16, DUGTRIO
	db $ff ; end trainer party mons
	; last_address=0x3af91 size=17

	; ERIK (7) at 0x3af91
	db "ERIK@"
	db $00 ; data type
	db 24, MACHOP
	db 27, GRAVELER
	db 27, MACHOP
	db $ff ; end trainer party mons
	; last_address=0x3af9e size=13

	; MICHAEL (8) at 0x3af9e
	db "MICHAEL@"
	db $00 ; data type
	db 25, GEODUDE
	db 25, GRAVELER
	db 25, GOLEM
	db $ff ; end trainer party mons
	; last_address=0x3afae size=16

	; PARRY1 (9) at 0x3afae
	db "PARRY@"
	db $00 ; data type
	db 35, ONIX
	db 33, SWINUB
	db $ff ; end trainer party mons
	; last_address=0x3afba size=12

	; TIMOTHY (10) at 0x3afba
	db "TIMOTHY@"
	db $01 ; data type
	db 27, DIGLETT, MAGNITUDE, DIG, SAND_ATTACK, SLASH
	db 27, DUGTRIO, MAGNITUDE, DIG, SAND_ATTACK, SLASH
	db $ff ; end trainer party mons
	; last_address=0x3afd0 size=22

	; BAILEY (11) at 0x3afd0
	db "BAILEY@"
	db $00 ; data type
	db 13, GEODUDE
	db 13, GEODUDE
	db 13, GEODUDE
	db 13, GEODUDE
	db 13, GEODUDE
	db $ff ; end trainer party mons
	; last_address=0x3afe3 size=19

	; ANTHONY3 (12) at 0x3afe3
	db "ANTHONY@"
	db $00 ; data type
	db 25, GRAVELER
	db 27, GRAVELER
	db 29, MACHOKE
	db $ff ; end trainer party mons
	; last_address=0x3aff3 size=16

	; TIM (13) at 0x3aff3
	db "TIM@"
	db $00 ; data type
	db 31, GRAVELER
	db 31, GRAVELER
	db 31, GRAVELER
	db $ff ; end trainer party mons
	; last_address=0x3afff size=12

	; NOLAND (14) at 0x3afff
	db "NOLAND@"
	db $00 ; data type
	db 31, SANDSLASH
	db 33, GOLEM
	db $ff ; end trainer party mons
	; last_address=0x3b00c size=13

	; SIDNEY (15) at 0x3b00c
	db "SIDNEY@"
	db $00 ; data type
	db 34, DUGTRIO
	db 32, ONIX
	db $ff ; end trainer party mons
	; last_address=0x3b019 size=13

	; KENNY (16) at 0x3b019
	db "KENNY@"
	db $00 ; data type
	db 27, SANDSLASH
	db 29, GRAVELER
	db 31, GOLEM
	db 29, GRAVELER
	db $ff ; end trainer party mons
	; last_address=0x3b029 size=16

	; JIM (17) at 0x3b029
	db "JIM@"
	db $00 ; data type
	db 35, MACHAMP
	db $ff ; end trainer party mons
	; last_address=0x3b031 size=8

	; DANIEL (18) at 0x3b031
	db "DANIEL@"
	db $00 ; data type
	db 11, ONIX
	db $ff ; end trainer party mons
	; last_address=0x3b03c size=11

	; PARRY2 (19) at 0x3b03c
	db "PARRY@"
	db $01 ; data type
	db 35, PILOSWINE, EARTHQUAKE, BLIZZARD, REST, TAKE_DOWN
	db 35, DUGTRIO, MAGNITUDE, DIG, MUD_SLAP, SLASH
	db 38, STEELIX, DIG, IRON_TAIL, SANDSTORM, SLAM
	db $ff ; end trainer party mons
	; last_address=0x3b056 size=26

	; PARRY3 (20) at 0x3b056
	db "PARRY@"
	db $00 ; data type
	db 29, ONIX
	db $ff ; end trainer party mons
	; last_address=0x3b060 size=10

	; ANTHONY4 (21) at 0x3b060
	db "ANTHONY@"
	db $00 ; data type
	db 30, GRAVELER
	db 30, GRAVELER
	db 32, MACHOKE
	db $ff ; end trainer party mons
	; last_address=0x3b070 size=16

	; ANTHONY5 (22) at 0x3b070
	db "ANTHONY@"
	db $01 ; data type
	db 34, GRAVELER, MAGNITUDE, SELFDESTRUCT, DEFENSE_CURL, ROLLOUT
	db 36, GOLEM, MAGNITUDE, SELFDESTRUCT, DEFENSE_CURL, ROLLOUT
	db 34, MACHOKE, KARATE_CHOP, VITAL_THROW, HEADBUTT, DIG
	db $ff ; end trainer party mons
	; last_address=0x3b08c size=28
; 0x3b08c

BikerTrainerGroupHeader: ; 0x3b08c
	; BIKER_BENNY (3) at 0x3b08c
	db "BENNY@"
	db $00 ; data type
	db 20, KOFFING
	db 20, KOFFING
	db 20, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b09a size=14

	; KAZU (4) at 0x3b09a
	db "KAZU@"
	db $00 ; data type
	db 20, KOFFING
	db 20, KOFFING
	db 20, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b0a7 size=13

	; DWAYNE (5) at 0x3b0a7
	db "DWAYNE@"
	db $00 ; data type
	db 27, KOFFING
	db 28, KOFFING
	db 29, KOFFING
	db 30, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b0b8 size=17

	; HARRIS (6) at 0x3b0b8
	db "HARRIS@"
	db $00 ; data type
	db 34, FLAREON
	db $ff ; end trainer party mons
	; last_address=0x3b0c3 size=11

	; ZEKE (7) at 0x3b0c3
	db "ZEKE@"
	db $00 ; data type
	db 32, KOFFING
	db 32, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b0ce size=11

	; CHARLES (8) at 0x3b0ce
	db "CHARLES@"
	db $00 ; data type
	db 30, KOFFING
	db 30, CHARMELEON
	db 30, WEEZING
	db $ff ; end trainer party mons
	; last_address=0x3b0de size=16

	; RILEY (9) at 0x3b0de
	db "RILEY@"
	db $00 ; data type
	db 34, WEEZING
	db $ff ; end trainer party mons
	; last_address=0x3b0e8 size=10

	; JOEL (10) at 0x3b0e8
	db "JOEL@"
	db $00 ; data type
	db 32, MAGMAR
	db 32, MAGMAR
	db $ff ; end trainer party mons
	; last_address=0x3b0f3 size=11

	; GLENN (11) at 0x3b0f3
	db "GLENN@"
	db $00 ; data type
	db 28, KOFFING
	db 30, MAGMAR
	db 32, WEEZING
	db $ff ; end trainer party mons
	; last_address=0x3b101 size=14
; 0x3b101

BlaineTrainerGroupHeader: ; 0x3b101
	; BLAINE (1) at 0x3b101
	db "BLAINE@"
	db $01 ; data type
	db 45, MAGCARGO, CURSE, SMOG, FLAMETHROWER, ROCK_SLIDE
	db 45, MAGMAR, THUNDERPUNCH, FIRE_PUNCH, SUNNY_DAY, CONFUSE_RAY
	db 50, RAPIDASH, QUICK_ATTACK, FIRE_SPIN, FURY_ATTACK, FIRE_BLAST
	db $ff ; end trainer party mons
	; last_address=0x3b11c size=27
; 0x3b11c

BurglarTrainerGroupHeader: ; 0x3b11c
	; DUNCAN (1) at 0x3b11c
	db "DUNCAN@"
	db $00 ; data type
	db 23, KOFFING
	db 25, MAGMAR
	db 23, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b12b size=15

	; EDDIE (2) at 0x3b12b
	db "EDDIE@"
	db $01 ; data type
	db 26, GROWLITHE, ROAR, EMBER, LEER, TAKE_DOWN
	db 24, KOFFING, TACKLE, SMOG, SLUDGE, SMOKESCREEN
	db $ff ; end trainer party mons
	; last_address=0x3b13f size=20

	; COREY (3) at 0x3b13f
	db "COREY@"
	db $00 ; data type
	db 25, KOFFING
	db 28, MAGMAR
	db 25, KOFFING
	db 30, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b14f size=16
; 0x3b14f

FirebreatherTrainerGroupHeader: ; 0x3b14f
	; OTIS (1) at 0x3b14f
	db "OTIS@"
	db $00 ; data type
	db 29, MAGMAR
	db 32, WEEZING
	db 29, MAGMAR
	db $ff ; end trainer party mons
	; last_address=0x3b15c size=13

	; DICK (2) at 0x3b15c
	db "DICK@"
	db $00 ; data type
	db 17, CHARMELEON
	db $ff ; end trainer party mons
	; last_address=0x3b165 size=9

	; NED (3) at 0x3b165
	db "NED@"
	db $00 ; data type
	db 15, KOFFING
	db 16, GROWLITHE
	db 15, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b171 size=12

	; BURT (4) at 0x3b171
	db "BURT@"
	db $00 ; data type
	db 32, KOFFING
	db 32, SLUGMA
	db $ff ; end trainer party mons
	; last_address=0x3b17c size=11

	; BILL (5) at 0x3b17c
	db "BILL@"
	db $00 ; data type
	db 6, KOFFING
	db 6, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b187 size=11

	; WALT (6) at 0x3b187
	db "WALT@"
	db $00 ; data type
	db 11, MAGMAR
	db 13, MAGMAR
	db $ff ; end trainer party mons
	; last_address=0x3b192 size=11

	; RAY (7) at 0x3b192
	db "RAY@"
	db $00 ; data type
	db 9, VULPIX
	db $ff ; end trainer party mons
	; last_address=0x3b19a size=8

	; LYLE (8) at 0x3b19a
	db "LYLE@"
	db $00 ; data type
	db 28, KOFFING
	db 31, FLAREON
	db 28, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b1a7 size=13
; 0x3b1a7

JugglerTrainerGroupHeader: ; 0x3b1a7
	; IRWIN1 (1) at 0x3b1a7
	db "IRWIN@"
	db $00 ; data type
	db 2, VOLTORB
	db 6, VOLTORB
	db 10, VOLTORB
	db 14, VOLTORB
	db $ff ; end trainer party mons
	; last_address=0x3b1b7 size=16

	; FRITZ (2) at 0x3b1b7
	db "FRITZ@"
	db $00 ; data type
	db 29, MR__MIME
	db 29, MAGMAR
	db 29, MACHOKE
	db $ff ; end trainer party mons
	; last_address=0x3b1c5 size=14

	; HORTON (3) at 0x3b1c5
	db "HORTON@"
	db $00 ; data type
	db 33, ELECTRODE
	db 33, ELECTRODE
	db 33, ELECTRODE
	db 33, ELECTRODE
	db $ff ; end trainer party mons
	; last_address=0x3b1d6 size=17

	; IRWIN2 (4) at 0x3b1d6
	db "IRWIN@"
	db $00 ; data type
	db 6, VOLTORB
	db 10, VOLTORB
	db 14, VOLTORB
	db 18, VOLTORB
	db $ff ; end trainer party mons
	; last_address=0x3b1e6 size=16

	; IRWIN3 (5) at 0x3b1e6
	db "IRWIN@"
	db $00 ; data type
	db 18, VOLTORB
	db 22, VOLTORB
	db 26, VOLTORB
	db 30, ELECTRODE
	db $ff ; end trainer party mons
	; last_address=0x3b1f6 size=16

	; IRWIN4 (6) at 0x3b1f6
	db "IRWIN@"
	db $00 ; data type
	db 18, VOLTORB
	db 22, VOLTORB
	db 26, VOLTORB
	db 30, ELECTRODE
	db $ff ; end trainer party mons
	; last_address=0x3b206 size=16
; 0x3b206

BlackbeltTrainerGroupHeader: ; 0x3b206
	; KENJI1 (2) at 0x3b206
	db "KENJI@"
	db $00 ; data type
	db 27, ONIX
	db 30, HITMONLEE
	db 27, ONIX
	db 32, MACHOKE
	db $ff ; end trainer party mons
	; last_address=0x3b216 size=16

	; YOSHI (3) at 0x3b216
	db "YOSHI@"
	db $01 ; data type
	db 27, HITMONLEE, DOUBLE_KICK, MEDITATE, JUMP_KICK, FOCUS_ENERGY
	db $ff ; end trainer party mons
	; last_address=0x3b224 size=14

	; KENJI2 (4) at 0x3b224
	db "KENJI@"
	db $01 ; data type
	db 33, ONIX, BIND, ROCK_THROW, TOXIC, DIG
	db 38, MACHAMP, HEADBUTT, SWAGGER, THUNDERPUNCH, VITAL_THROW
	db 33, STEELIX, EARTHQUAKE, ROCK_THROW, IRON_TAIL, SANDSTORM
	db 36, HITMONLEE, DOUBLE_TEAM, HI_JUMP_KICK, MUD_SLAP, SWIFT
	db $ff ; end trainer party mons
	; last_address=0x3b244 size=32

	; LAO (5) at 0x3b244
	db "LAO@"
	db $01 ; data type
	db 27, HITMONCHAN, COMET_PUNCH, THUNDERPUNCH, ICE_PUNCH, FIRE_PUNCH
	db $ff ; end trainer party mons
	; last_address=0x3b250 size=12

	; NOB (6) at 0x3b250
	db "NOB@"
	db $01 ; data type
	db 25, MACHOP, LEER, FOCUS_ENERGY, KARATE_CHOP, SEISMIC_TOSS
	db 25, MACHOKE, LEER, KARATE_CHOP, SEISMIC_TOSS, ROCK_SLIDE
	db $ff ; end trainer party mons
	; last_address=0x3b262 size=18

	; KIYO (7) at 0x3b262
	db "KIYO@"
	db $00 ; data type
	db 34, HITMONLEE
	db 34, HITMONCHAN
	db $ff ; end trainer party mons
	; last_address=0x3b26d size=11

	; LUNG (8) at 0x3b26d
	db "LUNG@"
	db $00 ; data type
	db 23, MANKEY
	db 23, MANKEY
	db 25, PRIMEAPE
	db $ff ; end trainer party mons
	; last_address=0x3b27a size=13

	; KENJI3 (9) at 0x3b27a
	db "KENJI@"
	db $00 ; data type
	db 28, MACHOKE
	db $ff ; end trainer party mons
	; last_address=0x3b284 size=10

	; WAI (10) at 0x3b284
	db "WAI@"
	db $00 ; data type
	db 30, MACHOKE
	db 32, MACHOKE
	db 34, MACHOKE
	db $ff ; end trainer party mons
	; last_address=0x3b290 size=12
; 0x3b290

ExecutiveMTrainerGroupHeader: ; 0x3b290
	; EXECUTIVE1 (1) at 0x3b290
	db "EXECUTIVE@"
	db $01 ; data type
	db 33, HOUNDOUR, EMBER, ROAR, BITE, FAINT_ATTACK
	db 33, KOFFING, TACKLE, SLUDGE, SMOKESCREEN, HAZE
	db 35, HOUNDOOM, EMBER, SMOG, BITE, FAINT_ATTACK
	db $ff ; end trainer party mons
	; last_address=0x3b2ae size=30

	; EXECUTIVE2 (2) at 0x3b2ae
	db "EXECUTIVE@"
	db $01 ; data type
	db 36, GOLBAT, LEECH_LIFE, BITE, CONFUSE_RAY, WING_ATTACK
	db $ff ; end trainer party mons
	; last_address=0x3b2c0 size=18

	; EXECUTIVE3 (3) at 0x3b2c0
	db "EXECUTIVE@"
	db $01 ; data type
	db 30, KOFFING, TACKLE, SELFDESTRUCT, SLUDGE, SMOKESCREEN
	db 30, KOFFING, TACKLE, SELFDESTRUCT, SLUDGE, SMOKESCREEN
	db 30, KOFFING, TACKLE, SELFDESTRUCT, SLUDGE, SMOKESCREEN
	db 32, WEEZING, TACKLE, EXPLOSION, SLUDGE, SMOKESCREEN
	db 30, KOFFING, TACKLE, SELFDESTRUCT, SLUDGE, SMOKESCREEN
	db 30, KOFFING, TACKLE, SMOG, SLUDGE, SMOKESCREEN
	db $ff ; end trainer party mons
	; last_address=0x3b2f0 size=48

	; EXECUTIVE4 (4) at 0x3b2f0
	db "EXECUTIVE@"
	db $00 ; data type
	db 22, ZUBAT
	db 24, RATICATE
	db 22, KOFFING
	db $ff ; end trainer party mons
	; last_address=0x3b302 size=18
; 0x3b302

PsychicTrainerGroupHeader: ; 0x3b302
	; NATHAN (1) at 0x3b302
	db "NATHAN@"
	db $00 ; data type
	db 26, GIRAFARIG
	db $ff ; end trainer party mons
	; last_address=0x3b30d size=11

	; FRANKLIN (2) at 0x3b30d
	db "FRANKLIN@"
	db $00 ; data type
	db 37, KADABRA
	db $ff ; end trainer party mons
	; last_address=0x3b31a size=13

	; HERMAN (3) at 0x3b31a
	db "HERMAN@"
	db $00 ; data type
	db 30, EXEGGCUTE
	db 30, EXEGGCUTE
	db 30, EXEGGUTOR
	db $ff ; end trainer party mons
	; last_address=0x3b329 size=15

	; FIDEL (4) at 0x3b329
	db "FIDEL@"
	db $00 ; data type
	db 34, XATU
	db $ff ; end trainer party mons
	; last_address=0x3b333 size=10

	; GREG (5) at 0x3b333
	db "GREG@"
	db $01 ; data type
	db 17, DROWZEE, HYPNOSIS, DISABLE, DREAM_EATER, 0
	db $ff ; end trainer party mons
	; last_address=0x3b340 size=13

	; NORMAN (6) at 0x3b340
	db "NORMAN@"
	db $01 ; data type
	db 17, SLOWPOKE, TACKLE, GROWL, WATER_GUN, 0
	db 20, SLOWPOKE, CURSE, BODY_SLAM, WATER_GUN, CONFUSION
	db $ff ; end trainer party mons
	; last_address=0x3b355 size=21

	; MARK (7) at 0x3b355
	db "MARK@"
	db $01 ; data type
	db 13, ABRA, TELEPORT, FLASH, 0, 0
	db 13, ABRA, TELEPORT, FLASH, 0, 0
	db 15, KADABRA, TELEPORT, KINESIS, CONFUSION, 0
	db $ff ; end trainer party mons
	; last_address=0x3b36e size=25

	; PHIL (8) at 0x3b36e
	db "PHIL@"
	db $01 ; data type
	db 24, NATU, LEER, NIGHT_SHADE, FUTURE_SIGHT, CONFUSE_RAY
	db 26, KADABRA, DISABLE, PSYBEAM, RECOVER, FUTURE_SIGHT
	db $ff ; end trainer party mons
	; last_address=0x3b381 size=19

	; RICHARD (9) at 0x3b381
	db "RICHARD@"
	db $00 ; data type
	db 36, ESPEON
	db $ff ; end trainer party mons
	; last_address=0x3b38d size=12

	; GILBERT (10) at 0x3b38d
	db "GILBERT@"
	db $00 ; data type
	db 30, STARMIE
	db 30, EXEGGCUTE
	db 34, GIRAFARIG
	db $ff ; end trainer party mons
	; last_address=0x3b39d size=16

	; JARED (11) at 0x3b39d
	db "JARED@"
	db $00 ; data type
	db 32, MR__MIME
	db 32, EXEGGCUTE
	db 35, EXEGGCUTE
	db $ff ; end trainer party mons
	; last_address=0x3b3ab size=14

	; RODNEY (12) at 0x3b3ab
	db "RODNEY@"
	db $00 ; data type
	db 29, DROWZEE
	db 33, HYPNO
	db $ff ; end trainer party mons
	; last_address=0x3b3b8 size=13
; 0x3b3b8

PicnickerTrainerGroupHeader: ; 0x3b3b8
	; LIZ1 (1) at 0x3b3b8
	db "LIZ@"
	db $00 ; data type
	db 9, NIDORAN_F
	db $ff ; end trainer party mons
	; last_address=0x3b3c0 size=8

	; GINA1 (2) at 0x3b3c0
	db "GINA@"
	db $00 ; data type
	db 9, HOPPIP
	db 9, HOPPIP
	db 12, BULBASAUR
	db $ff ; end trainer party mons
	; last_address=0x3b3cd size=13

	; BROOKE (3) at 0x3b3cd
	db "BROOKE@"
	db $01 ; data type
	db 16, PIKACHU, THUNDERSHOCK, GROWL, QUICK_ATTACK, DOUBLE_TEAM
	db $ff ; end trainer party mons
	; last_address=0x3b3dc size=15

	; KIM (4) at 0x3b3dc
	db "KIM@"
	db $00 ; data type
	db 15, VULPIX
	db $ff ; end trainer party mons
	; last_address=0x3b3e4 size=8

	; CINDY (5) at 0x3b3e4
	db "CINDY@"
	db $00 ; data type
	db 36, NIDOQUEEN
	db $ff ; end trainer party mons
	; last_address=0x3b3ee size=10

	; HOPE (6) at 0x3b3ee
	db "HOPE@"
	db $00 ; data type
	db 34, FLAAFFY
	db $ff ; end trainer party mons
	; last_address=0x3b3f7 size=9

	; SHARON (7) at 0x3b3f7
	db "SHARON@"
	db $00 ; data type
	db 31, FURRET
	db 33, RAPIDASH
	db $ff ; end trainer party mons
	; last_address=0x3b404 size=13

	; DEBRA (8) at 0x3b404
	db "DEBRA@"
	db $00 ; data type
	db 33, SEAKING
	db $ff ; end trainer party mons
	; last_address=0x3b40e size=10

	; GINA2 (9) at 0x3b40e
	db "GINA@"
	db $00 ; data type
	db 14, HOPPIP
	db 14, HOPPIP
	db 17, IVYSAUR
	db $ff ; end trainer party mons
	; last_address=0x3b41b size=13

	; ERIN1 (10) at 0x3b41b
	db "ERIN@"
	db $00 ; data type
	db 16, PONYTA
	db 16, PONYTA
	db $ff ; end trainer party mons
	; last_address=0x3b426 size=11

	; LIZ2 (11) at 0x3b426
	db "LIZ@"
	db $00 ; data type
	db 15, WEEPINBELL
	db 15, NIDORINA
	db $ff ; end trainer party mons
	; last_address=0x3b430 size=10

	; LIZ3 (12) at 0x3b430
	db "LIZ@"
	db $00 ; data type
	db 19, WEEPINBELL
	db 19, NIDORINO
	db 21, NIDOQUEEN
	db $ff ; end trainer party mons
	; last_address=0x3b43c size=12

	; HEIDI (13) at 0x3b43c
	db "HEIDI@"
	db $00 ; data type
	db 32, SKIPLOOM
	db 32, SKIPLOOM
	db $ff ; end trainer party mons
	; last_address=0x3b448 size=12

	; EDNA (14) at 0x3b448
	db "EDNA@"
	db $00 ; data type
	db 30, NIDORINA
	db 34, RAICHU
	db $ff ; end trainer party mons
	; last_address=0x3b453 size=11

	; GINA3 (15) at 0x3b453
	db "GINA@"
	db $00 ; data type
	db 26, SKIPLOOM
	db 26, SKIPLOOM
	db 29, IVYSAUR
	db $ff ; end trainer party mons
	; last_address=0x3b460 size=13

	; TIFFANY1 (16) at 0x3b460
	db "TIFFANY@"
	db $01 ; data type
	db 31, CLEFAIRY, ENCORE, SING, DOUBLESLAP, MINIMIZE
	db $ff ; end trainer party mons
	; last_address=0x3b470 size=16

	; TIFFANY2 (17) at 0x3b470
	db "TIFFANY@"
	db $01 ; data type
	db 37, CLEFAIRY, ENCORE, DOUBLESLAP, MINIMIZE, METRONOME
	db $ff ; end trainer party mons
	; last_address=0x3b480 size=16

	; ERIN2 (18) at 0x3b480
	db "ERIN@"
	db $00 ; data type
	db 32, PONYTA
	db 32, PONYTA
	db $ff ; end trainer party mons
	; last_address=0x3b48b size=11

	; TANYA (19) at 0x3b48b
	db "TANYA@"
	db $00 ; data type
	db 37, EXEGGUTOR
	db $ff ; end trainer party mons
	; last_address=0x3b495 size=10

	; TIFFANY3 (20) at 0x3b495
	db "TIFFANY@"
	db $01 ; data type
	db 20, CLEFAIRY, ENCORE, SING, DOUBLESLAP, MINIMIZE
	db $ff ; end trainer party mons
	; last_address=0x3b4a5 size=16

	; ERIN3 (21) at 0x3b4a5
	db "ERIN@"
	db $01 ; data type
	db 36, PONYTA, DOUBLE_TEAM, STOMP, FIRE_SPIN, SUNNY_DAY
	db 34, RAICHU, SWIFT, MUD_SLAP, QUICK_ATTACK, THUNDERBOLT
	db 36, PONYTA, DOUBLE_TEAM, STOMP, FIRE_SPIN, SUNNY_DAY
	db $ff ; end trainer party mons
	; last_address=0x3b4be size=25

	; LIZ4 (22) at 0x3b4be
	db "LIZ@"
	db $00 ; data type
	db 24, WEEPINBELL
	db 26, NIDORINO
	db 26, NIDOQUEEN
	db $ff ; end trainer party mons
	; last_address=0x3b4ca size=12

	; LIZ5 (23) at 0x3b4ca
	db "LIZ@"
	db $01 ; data type
	db 30, WEEPINBELL, SLEEP_POWDER, POISONPOWDER, STUN_SPORE, SLUDGE_BOMB
	db 32, NIDOKING, EARTHQUAKE, DOUBLE_KICK, POISON_STING, IRON_TAIL
	db 32, NIDOQUEEN, EARTHQUAKE, DOUBLE_KICK, TAIL_WHIP, BODY_SLAM
	db $ff ; end trainer party mons
	; last_address=0x3b4e2 size=24

	; GINA4 (24) at 0x3b4e2
	db "GINA@"
	db $00 ; data type
	db 30, SKIPLOOM
	db 30, SKIPLOOM
	db 32, IVYSAUR
	db $ff ; end trainer party mons
	; last_address=0x3b4ef size=13

	; GINA5 (25) at 0x3b4ef
	db "GINA@"
	db $01 ; data type
	db 33, JUMPLUFF, STUN_SPORE, SUNNY_DAY, LEECH_SEED, COTTON_SPORE
	db 33, JUMPLUFF, SUNNY_DAY, SLEEP_POWDER, LEECH_SEED, COTTON_SPORE
	db 38, VENUSAUR, SOLARBEAM, RAZOR_LEAF, HEADBUTT, MUD_SLAP
	db $ff ; end trainer party mons
	; last_address=0x3b508 size=25

	; TIFFANY4 (26) at 0x3b508
	db "TIFFANY@"
	db $01 ; data type
	db 43, CLEFAIRY, METRONOME, ENCORE, MOONLIGHT, MINIMIZE
	db $ff ; end trainer party mons
	; last_address=0x3b518 size=16
; 0x3b518

CamperTrainerGroupHeader: ; 0x3b518
	; ROLAND (1) at 0x3b518
	db "ROLAND@"
	db $00 ; data type
	db 9, NIDORAN_M
	db $ff ; end trainer party mons
	; last_address=0x3b523 size=11

	; TODD1 (2) at 0x3b523
	db "TODD@"
	db $00 ; data type
	db 14, PSYDUCK
	db $ff ; end trainer party mons
	; last_address=0x3b52c size=9

	; IVAN (3) at 0x3b52c
	db "IVAN@"
	db $00 ; data type
	db 10, DIGLETT
	db 10, ZUBAT
	db 14, DIGLETT
	db $ff ; end trainer party mons
	; last_address=0x3b539 size=13

	; ELLIOT (4) at 0x3b539
	db "ELLIOT@"
	db $00 ; data type
	db 13, SANDSHREW
	db 15, MARILL
	db $ff ; end trainer party mons
	; last_address=0x3b546 size=13

	; BARRY (5) at 0x3b546
	db "BARRY@"
	db $00 ; data type
	db 36, NIDOKING
	db $ff ; end trainer party mons
	; last_address=0x3b550 size=10

	; LLOYD (6) at 0x3b550
	db "LLOYD@"
	db $00 ; data type
	db 34, NIDOKING
	db $ff ; end trainer party mons
	; last_address=0x3b55a size=10

	; DEAN (7) at 0x3b55a
	db "DEAN@"
	db $00 ; data type
	db 33, GOLDUCK
	db 31, SANDSLASH
	db $ff ; end trainer party mons
	; last_address=0x3b565 size=11

	; SID (8) at 0x3b565
	db "SID@"
	db $00 ; data type
	db 32, DUGTRIO
	db 29, PRIMEAPE
	db 29, POLIWRATH
	db $ff ; end trainer party mons
	; last_address=0x3b571 size=12

	; HARVEY (9) at 0x3b571
	db "HARVEY@"
	db $00 ; data type
	db 15, NIDORINO
	db $ff ; end trainer party mons
	; last_address=0x3b57c size=11

	; DALE (10) at 0x3b57c
	db "DALE@"
	db $00 ; data type
	db 15, NIDORINO
	db $ff ; end trainer party mons
	; last_address=0x3b585 size=9

	; TED (11) at 0x3b585
	db "TED@"
	db $00 ; data type
	db 17, MANKEY
	db $ff ; end trainer party mons
	; last_address=0x3b58d size=8

	; TODD2 (12) at 0x3b58d
	db "TODD@"
	db $00 ; data type
	db 17, GEODUDE
	db 17, GEODUDE
	db 23, PSYDUCK
	db $ff ; end trainer party mons
	; last_address=0x3b59a size=13

	; TODD3 (13) at 0x3b59a
	db "TODD@"
	db $00 ; data type
	db 23, GEODUDE
	db 23, GEODUDE
	db 26, PSYDUCK
	db $ff ; end trainer party mons
	; last_address=0x3b5a7 size=13

	; THOMAS (14) at 0x3b5a7
	db "THOMAS@"
	db $00 ; data type
	db 33, GRAVELER
	db 36, GRAVELER
	db 40, GOLBAT
	db 42, GOLDUCK
	db $ff ; end trainer party mons
	; last_address=0x3b5b8 size=17

	; LEROY (15) at 0x3b5b8
	db "LEROY@"
	db $00 ; data type
	db 33, GRAVELER
	db 36, GRAVELER
	db 40, GOLBAT
	db 42, GOLDUCK
	db $ff ; end trainer party mons
	; last_address=0x3b5c8 size=16

	; DAVID (16) at 0x3b5c8
	db "DAVID@"
	db $00 ; data type
	db 33, GRAVELER
	db 36, GRAVELER
	db 40, GOLBAT
	db 42, GOLDUCK
	db $ff ; end trainer party mons
	; last_address=0x3b5d8 size=16

	; JOHN (17) at 0x3b5d8
	db "JOHN@"
	db $00 ; data type
	db 33, GRAVELER
	db 36, GRAVELER
	db 40, GOLBAT
	db 42, GOLDUCK
	db $ff ; end trainer party mons
	; last_address=0x3b5e7 size=15

	; JERRY (18) at 0x3b5e7
	db "JERRY@"
	db $00 ; data type
	db 37, SANDSLASH
	db $ff ; end trainer party mons
	; last_address=0x3b5f1 size=10

	; SPENCER (19) at 0x3b5f1
	db "SPENCER@"
	db $00 ; data type
	db 17, SANDSHREW
	db 17, SANDSLASH
	db 19, ZUBAT
	db $ff ; end trainer party mons
	; last_address=0x3b601 size=16

	; TODD4 (20) at 0x3b601
	db "TODD@"
	db $00 ; data type
	db 30, GRAVELER
	db 30, GRAVELER
	db 30, SLUGMA
	db 32, PSYDUCK
	db $ff ; end trainer party mons
	; last_address=0x3b610 size=15

	; TODD5 (21) at 0x3b610
	db "TODD@"
	db $01 ; data type
	db 33, GRAVELER, SELFDESTRUCT, ROCK_THROW, HARDEN, MAGNITUDE
	db 33, GRAVELER, SELFDESTRUCT, ROCK_THROW, HARDEN, MAGNITUDE
	db 36, MAGCARGO, ROCK_THROW, HARDEN, AMNESIA, FLAMETHROWER
	db 34, GOLDUCK, DISABLE, PSYCHIC_M, SURF, PSYCH_UP
	db $ff ; end trainer party mons
	; last_address=0x3b62f size=31

	; QUENTIN (22) at 0x3b62f
	db "QUENTIN@"
	db $00 ; data type
	db 30, FEAROW
	db 30, PRIMEAPE
	db 30, TAUROS
	db $ff ; end trainer party mons
	; last_address=0x3b63f size=16
; 0x3b63f

ExecutiveFTrainerGroupHeader: ; 0x3b63f
	; EXECUTIVE1 (1) at 0x3b63f
	db "EXECUTIVE@"
	db $01 ; data type
	db 32, ARBOK, WRAP, POISON_STING, BITE, GLARE
	db 32, VILEPLUME, ABSORB, SWEET_SCENT, SLEEP_POWDER, ACID
	db 32, MURKROW, PECK, PURSUIT, HAZE, NIGHT_SHADE
	db $ff ; end trainer party mons
	; last_address=0x3b65d size=30

	; EXECUTIVE2 (2) at 0x3b65d
	db "EXECUTIVE@"
	db $01 ; data type
	db 23, ARBOK, WRAP, LEER, POISON_STING, BITE
	db 23, GLOOM, ABSORB, SWEET_SCENT, SLEEP_POWDER, ACID
	db 25, MURKROW, PECK, PURSUIT, HAZE, 0
	db $ff ; end trainer party mons
	; last_address=0x3b67b size=30
; 0x3b67b

SageTrainerGroupHeader: ; 0x3b67b
	; CHOW (1) at 0x3b67b
	db "CHOW@"
	db $00 ; data type
	db 3, BELLSPROUT
	db 3, BELLSPROUT
	db 3, BELLSPROUT
	db $ff ; end trainer party mons
	; last_address=0x3b688 size=13

	; NICO (2) at 0x3b688
	db "NICO@"
	db $00 ; data type
	db 3, BELLSPROUT
	db 3, BELLSPROUT
	db 3, BELLSPROUT
	db $ff ; end trainer party mons
	; last_address=0x3b695 size=13

	; JIN (3) at 0x3b695
	db "JIN@"
	db $00 ; data type
	db 6, BELLSPROUT
	db $ff ; end trainer party mons
	; last_address=0x3b69d size=8

	; TROY (4) at 0x3b69d
	db "TROY@"
	db $00 ; data type
	db 7, BELLSPROUT
	db 7, HOOTHOOT
	db $ff ; end trainer party mons
	; last_address=0x3b6a8 size=11

	; JEFFREY (5) at 0x3b6a8
	db "JEFFREY@"
	db $00 ; data type
	db 22, HAUNTER
	db $ff ; end trainer party mons
	; last_address=0x3b6b4 size=12

	; PING (6) at 0x3b6b4
	db "PING@"
	db $00 ; data type
	db 16, GASTLY
	db 16, GASTLY
	db 16, GASTLY
	db 16, GASTLY
	db 16, GASTLY
	db $ff ; end trainer party mons
	; last_address=0x3b6c5 size=17

	; EDMOND (7) at 0x3b6c5
	db "EDMOND@"
	db $00 ; data type
	db 3, BELLSPROUT
	db 3, BELLSPROUT
	db 3, BELLSPROUT
	db $ff ; end trainer party mons
	; last_address=0x3b6d4 size=15

	; NEAL (8) at 0x3b6d4
	db "NEAL@"
	db $00 ; data type
	db 6, BELLSPROUT
	db $ff ; end trainer party mons
	; last_address=0x3b6dd size=9

	; LI (9) at 0x3b6dd
	db "LI@"
	db $00 ; data type
	db 7, BELLSPROUT
	db 7, BELLSPROUT
	db 10, HOOTHOOT
	db $ff ; end trainer party mons
	; last_address=0x3b6e8 size=11

	; GAKU (10) at 0x3b6e8
	db "GAKU@"
	db $00 ; data type
	db 32, NOCTOWL
	db 32, FLAREON
	db $ff ; end trainer party mons
	; last_address=0x3b6f3 size=11

	; MASA (11) at 0x3b6f3
	db "MASA@"
	db $00 ; data type
	db 32, NOCTOWL
	db 32, JOLTEON
	db $ff ; end trainer party mons
	; last_address=0x3b6fe size=11

	; KOJI (12) at 0x3b6fe
	db "KOJI@"
	db $00 ; data type
	db 32, NOCTOWL
	db 32, VAPOREON
	db $ff ; end trainer party mons
	; last_address=0x3b709 size=11
; 0x3b709

MediumTrainerGroupHeader: ; 0x3b709
	; MARTHA (1) at 0x3b709
	db "MARTHA@"
	db $00 ; data type
	db 18, GASTLY
	db 20, HAUNTER
	db 20, GASTLY
	db $ff ; end trainer party mons
	; last_address=0x3b718 size=15

	; GRACE (2) at 0x3b718
	db "GRACE@"
	db $00 ; data type
	db 20, HAUNTER
	db 20, HAUNTER
	db $ff ; end trainer party mons
	; last_address=0x3b724 size=12

	; BETHANY (3) at 0x3b724
	db "BETHANY@"
	db $00 ; data type
	db 25, HAUNTER
	db $ff ; end trainer party mons
	; last_address=0x3b730 size=12

	; MARGRET (4) at 0x3b730
	db "MARGRET@"
	db $00 ; data type
	db 25, HAUNTER
	db $ff ; end trainer party mons
	; last_address=0x3b73c size=12

	; ETHEL (5) at 0x3b73c
	db "ETHEL@"
	db $00 ; data type
	db 25, HAUNTER
	db $ff ; end trainer party mons
	; last_address=0x3b746 size=10

	; REBECCA (6) at 0x3b746
	db "REBECCA@"
	db $00 ; data type
	db 35, DROWZEE
	db 35, HYPNO
	db $ff ; end trainer party mons
	; last_address=0x3b754 size=14

	; DORIS (7) at 0x3b754
	db "DORIS@"
	db $00 ; data type
	db 34, SLOWPOKE
	db 36, SLOWBRO
	db $ff ; end trainer party mons
	; last_address=0x3b760 size=12
; 0x3b760

BoarderTrainerGroupHeader: ; 0x3b760
	; RONALD (1) at 0x3b760
	db "RONALD@"
	db $00 ; data type
	db 24, SEEL
	db 25, DEWGONG
	db 24, SEEL
	db $ff ; end trainer party mons
	; last_address=0x3b76f size=15

	; BRAD (2) at 0x3b76f
	db "BRAD@"
	db $00 ; data type
	db 26, SWINUB
	db 26, SWINUB
	db $ff ; end trainer party mons
	; last_address=0x3b77a size=11

	; DOUGLAS (3) at 0x3b77a
	db "DOUGLAS@"
	db $00 ; data type
	db 24, SHELLDER
	db 25, CLOYSTER
	db 24, SHELLDER
	db $ff ; end trainer party mons
	; last_address=0x3b78a size=16
; 0x3b78a

PokefanMTrainerGroupHeader: ; 0x3b78a
	; WILLIAM (1) at 0x3b78a
	db "WILLIAM@"
	db $02 ; data type
	db 14, RAICHU, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b797 size=13

	; DEREK1 (2) at 0x3b797
	db "DEREK@"
	db $02 ; data type
	db 17, PIKACHU, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b7a2 size=11

	; ROBERT (3) at 0x3b7a2
	db "ROBERT@"
	db $02 ; data type
	db 33, QUAGSIRE, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b7ae size=12

	; JOSHUA (4) at 0x3b7ae
	db "JOSHUA@"
	db $02 ; data type
	db 23, PIKACHU, BERRY
	db 23, PIKACHU, BERRY
	db 23, PIKACHU, BERRY
	db 23, PIKACHU, BERRY
	db 23, PIKACHU, BERRY
	db 23, PIKACHU, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b7c9 size=27

	; CARTER (5) at 0x3b7c9
	db "CARTER@"
	db $02 ; data type
	db 29, BULBASAUR, BERRY
	db 29, CHARMANDER, BERRY
	db 29, SQUIRTLE, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b7db size=18

	; TREVOR (6) at 0x3b7db
	db "TREVOR@"
	db $02 ; data type
	db 33, PSYDUCK, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b7e7 size=12

	; BRANDON (7) at 0x3b7e7
	db "BRANDON@"
	db $02 ; data type
	db 13, SNUBBULL, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b7f4 size=13

	; JEREMY (8) at 0x3b7f4
	db "JEREMY@"
	db $02 ; data type
	db 28, MEOWTH, BERRY
	db 28, MEOWTH, BERRY
	db 28, MEOWTH, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b806 size=18

	; COLIN (9) at 0x3b806
	db "COLIN@"
	db $02 ; data type
	db 32, DELIBIRD, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b811 size=11

	; DEREK2 (10) at 0x3b811
	db "DEREK@"
	db $02 ; data type
	db 19, PIKACHU, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b81c size=11

	; DEREK3 (11) at 0x3b81c
	db "DEREK@"
	db $02 ; data type
	db 36, PIKACHU, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b827 size=11

	; ALEX (12) at 0x3b827
	db "ALEX@"
	db $02 ; data type
	db 29, NIDOKING, BERRY
	db 29, SLOWKING, BERRY
	db 29, SEAKING, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b837 size=16

	; REX (13) at 0x3b837
	db "REX@"
	db $02 ; data type
	db 35, PHANPY, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b840 size=9

	; ALLAN (14) at 0x3b840
	db "ALLAN@"
	db $02 ; data type
	db 35, TEDDIURSA, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b84b size=11
; 0x3b84b

KimonoGirlTrainerGroupHeader: ; 0x3b84b
	; NAOKO1 (2) at 0x3b84b
	db "NAOKO@" ; unused
	db $00 ; data type
	db 20, SKIPLOOM
	db 20, VULPIX
	db 18, SKIPLOOM
	db $ff ; end trainer party mons
	; last_address=0x3b859 size=14

	; NAOKO2 (3) at 0x3b859
	db "NAOKO@"
	db $00 ; data type
	db 17, FLAREON
	db $ff ; end trainer party mons
	; last_address=0x3b863 size=10

	; SAYO (4) at 0x3b863
	db "SAYO@"
	db $00 ; data type
	db 17, ESPEON
	db $ff ; end trainer party mons
	; last_address=0x3b86c size=9

	; ZUKI (5) at 0x3b86c
	db "ZUKI@"
	db $00 ; data type
	db 17, UMBREON
	db $ff ; end trainer party mons
	; last_address=0x3b875 size=9

	; KUNI (6) at 0x3b875
	db "KUNI@"
	db $00 ; data type
	db 17, VAPOREON
	db $ff ; end trainer party mons
	; last_address=0x3b87e size=9

	; MIKI (7) at 0x3b87e
	db "MIKI@"
	db $00 ; data type
	db 17, JOLTEON
	db $ff ; end trainer party mons
	; last_address=0x3b887 size=9
; 0x3b887

TwinsTrainerGroupHeader: ; 0x3b887
	; AMYANDMAY1 (1) at 0x3b887
	db "AMY & MAY@"
	db $00 ; data type
	db 10, SPINARAK
	db 10, LEDYBA
	db $ff ; end trainer party mons
	; last_address=0x3b897 size=16

	; ANNANDANNE1 (2) at 0x3b897
	db "ANN & ANNE@"
	db $01 ; data type
	db 16, CLEFAIRY, GROWL, ENCORE, DOUBLESLAP, METRONOME
	db 16, JIGGLYPUFF, SING, DEFENSE_CURL, POUND, DISABLE
	db $ff ; end trainer party mons
	; last_address=0x3b8b0 size=25

	; ANNANDANNE2 (3) at 0x3b8b0
	db "ANN & ANNE@"
	db $01 ; data type
	db 16, JIGGLYPUFF, SING, DEFENSE_CURL, POUND, DISABLE
	db 16, CLEFAIRY, GROWL, ENCORE, DOUBLESLAP, METRONOME
	db $ff ; end trainer party mons
	; last_address=0x3b8c9 size=25

	; AMYANDMAY2 (4) at 0x3b8c9
	db "AMY & MAY@"
	db $00 ; data type
	db 10, LEDYBA
	db 10, SPINARAK
	db $ff ; end trainer party mons
	; last_address=0x3b8d9 size=16

	; JOANDZOE1 (5) at 0x3b8d9
	db "JO & ZOE@"
	db $00 ; data type
	db 35, VICTREEBEL
	db 35, VILEPLUME
	db $ff ; end trainer party mons
	; last_address=0x3b8e8 size=15

	; JOANDZOE2 (6) at 0x3b8e8
	db "JO & ZOE@"
	db $00 ; data type
	db 35, VILEPLUME
	db 35, VICTREEBEL
	db $ff ; end trainer party mons
	; last_address=0x3b8f7 size=15

	; MEGANDPEG1 (7) at 0x3b8f7
	db "MEG & PEG@"
	db $00 ; data type
	db 31, TEDDIURSA
	db 31, PHANPY
	db $ff ; end trainer party mons
	; last_address=0x3b907 size=16

	; MEGANDPEG2 (8) at 0x3b907
	db "MEG & PEG@"
	db $00 ; data type
	db 31, PHANPY
	db 31, TEDDIURSA
	db $ff ; end trainer party mons
	; last_address=0x3b917 size=16

	; LEAANDPIA1 (9) at 0x3b917
	db "LEA & PIA@"
	db $01 ; data type
	db 35, DRATINI, THUNDER_WAVE, TWISTER, FLAMETHROWER, HEADBUTT
	db 35, DRATINI, THUNDER_WAVE, TWISTER, ICE_BEAM, HEADBUTT
	db $ff ; end trainer party mons
	; last_address=0x3b92f size=24

	; LEAANDPIA2 (10) at 0x3b92f
	db "LEA & PIA@"
	db $01 ; data type
	db 38, DRATINI, THUNDER_WAVE, TWISTER, ICE_BEAM, HEADBUTT
	db 38, DRATINI, THUNDER_WAVE, TWISTER, FLAMETHROWER, HEADBUTT
	db $ff ; end trainer party mons
	; last_address=0x3b947 size=24
; 0x3b947

PokefanFTrainerGroupHeader: ; 0x3b947
	; BEVERLY1 (1) at 0x3b947
	db "BEVERLY@"
	db $02 ; data type
	db 14, SNUBBULL, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b954 size=13

	; RUTH (2) at 0x3b954
	db "RUTH@"
	db $02 ; data type
	db 17, PIKACHU, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b95e size=10

	; BEVERLY2 (3) at 0x3b95e
	db "BEVERLY@"
	db $02 ; data type
	db 18, SNUBBULL, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b96b size=13

	; BEVERLY3 (4) at 0x3b96b
	db "BEVERLY@"
	db $02 ; data type
	db 30, GRANBULL, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b978 size=13

	; GEORGIA (5) at 0x3b978
	db "GEORGIA@"
	db $02 ; data type
	db 23, SENTRET, BERRY
	db 23, SENTRET, BERRY
	db 23, SENTRET, BERRY
	db 28, FURRET, BERRY
	db 23, SENTRET, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b991 size=25

	; JAIME (6) at 0x3b991
	db "JAIME@"
	db $02 ; data type
	db 16, MEOWTH, BERRY
	db $ff ; end trainer party mons
	; last_address=0x3b99c size=11
; 0x3b99c

RedTrainerGroupHeader: ; 0x3b99c
	; RED (1) at 0x3b99c
	db "RED@"
	db $01 ; data type
	db 81, PIKACHU, CHARM, QUICK_ATTACK, THUNDERBOLT, THUNDER
	db 73, ESPEON, MUD_SLAP, REFLECT, SWIFT, PSYCHIC_M
	db 75, SNORLAX, AMNESIA, SNORE, REST, BODY_SLAM
	db 77, VENUSAUR, SUNNY_DAY, GIGA_DRAIN, SYNTHESIS, SOLARBEAM
	db 77, CHARIZARD, FLAMETHROWER, WING_ATTACK, SLASH, FIRE_SPIN
	db 77, BLASTOISE, RAIN_DANCE, SURF, BLIZZARD, WHIRLPOOL
	db $ff ; end trainer party mons
	; last_address=0x3b9c6 size=42
; 0x3b9c6

BlueTrainerGroupHeader: ; 0x3b9c6
	; BLUE (1) at 0x3b9c6
	db "BLUE@"
	db $01 ; data type
	db 56, PIDGEOT, QUICK_ATTACK, WHIRLWIND, WING_ATTACK, MIRROR_MOVE
	db 54, ALAKAZAM, DISABLE, RECOVER, PSYCHIC_M, REFLECT
	db 56, RHYDON, FURY_ATTACK, SANDSTORM, ROCK_SLIDE, EARTHQUAKE
	db 58, GYARADOS, TWISTER, HYDRO_PUMP, RAIN_DANCE, HYPER_BEAM
	db 58, EXEGGUTOR, SUNNY_DAY, LEECH_SEED, EGG_BOMB, SOLARBEAM
	db 58, ARCANINE, ROAR, SWIFT, FLAMETHROWER, EXTREMESPEED
	db $ff ; end trainer party mons
	; last_address=0x3b9f1 size=43
; 0x3b9f1

OfficerTrainerGroupHeader: ; 0x3b9f1
	; KEITH (1) at 0x3b9f1
	db "KEITH@"
	db $00 ; data type
	db 17, GROWLITHE
	db $ff ; end trainer party mons
	; last_address=0x3b9fb size=10

	; DIRK (2) at 0x3b9fb
	db "DIRK@"
	db $00 ; data type
	db 14, GROWLITHE
	db 14, GROWLITHE
	db $ff ; end trainer party mons
	; last_address=0x3ba06 size=11
; 0x3ba06

GruntFTrainerGroupHeader: ; 0x3ba06
	; GRUNT1 (1) at 0x3ba06
	db "GRUNT@"
	db $00 ; data type
	db 9, ZUBAT
	db 11, EKANS
	db $ff ; end trainer party mons
	; last_address=0x3ba12 size=12

	; GRUNT2 (2) at 0x3ba12
	db "GRUNT@"
	db $00 ; data type
	db 26, ARBOK
	db $ff ; end trainer party mons
	; last_address=0x3ba1c size=10

	; GRUNT3 (3) at 0x3ba1c
	db "GRUNT@"
	db $00 ; data type
	db 25, GLOOM
	db 25, GLOOM
	db $ff ; end trainer party mons
	; last_address=0x3ba28 size=12

	; GRUNT4 (4) at 0x3ba28
	db "GRUNT@"
	db $00 ; data type
	db 21, EKANS
	db 23, ODDISH
	db 21, EKANS
	db 24, GLOOM
	db $ff ; end trainer party mons
	; last_address=0x3ba38 size=16

	; GRUNT5 (5) at 0x3ba38
	db "GRUNT@"
	db $01 ; data type
	db 18, EKANS, WRAP, LEER, POISON_STING, BITE
	db 18, GLOOM, ABSORB, SWEET_SCENT, STUN_SPORE, SLEEP_POWDER
	db $ff ; end trainer party mons
	; last_address=0x3ba4c size=20
; 0x3ba4c

MysticalmanTrainerGroupHeader: ; 0x3ba4c
	; EUSINE (1) at 0x3ba4c
	db "EUSINE@"
	db $01 ; data type
	db 23, DROWZEE, DREAM_EATER, HYPNOSIS, DISABLE, CONFUSION
	db 23, HAUNTER, LICK, HYPNOSIS, MEAN_LOOK, CURSE
	db 25, ELECTRODE, SCREECH, SONICBOOM, THUNDER, ROLLOUT
	db $ff ; end trainer party mons
	; last_address=0x3ba67 size=27
; 0x3ba67

SECTION "bankF",DATA,BANK[$F]

INCBIN "baserom.gbc",$3C000,$3d123 - $3C000

; These functions check if the current opponent is a gym leader or one of a
; few other special trainers.

; Note: KantoGymLeaders is a subset of JohtoGymLeaders. If you wish to
; differentiate between the two, call IsKantoGymLeader first.

; The Lance and Red entries are unused for music checks; those trainers are
; accounted for elsewhere.

IsKantoGymLeader: ; 0x3d123
	ld hl, KantoGymLeaders
	jr IsGymLeaderCommon

IsJohtoGymLeader: ; 0x3d128
	ld hl, JohtoGymLeaders
IsGymLeaderCommon:
	push de
	ld a, [OtherTrainerClass]
	ld de, $0001
	call IsInArray
	pop de
	ret
; 0x3d137

JohtoGymLeaders:
	db FALKNER
	db WHITNEY
	db BUGSY
	db MORTY
	db PRYCE
	db JASMINE
	db CHUCK
	db CLAIR
	db WILL
	db BRUNO
	db KAREN
	db KOGA
; fallthrough
; these two entries are unused
	db CHAMPION
	db RED
; fallthrough
KantoGymLeaders:
	db BROCK
	db MISTY
	db LT_SURGE
	db ERIKA
	db JANINE
	db SABRINA
	db BLAINE
	db BLUE
	db $ff

INCBIN "baserom.gbc",$3d14e,$3ddc2 - $3d14e

	ld hl, RecoveredUsingText
	jp $3ad5
; 0x3ddc8

INCBIN "baserom.gbc",$3ddc8,$3e8eb - $3ddc8

Function3e8eb: ; 3e8eb
;part of battle init
	xor a
	ld hl, EnemyMonSpecies
	ld bc, $0027
	call ByteFill
	ld a, [InLinkBattle]
	and a
	jp nz, $5abd
	ld a, [$cfc0]
	bit 0, a
	jp nz, $5abd
	ld a, [TempEnemyMonSpecies]
	ld [EnemyMonSpecies], a
	ld [$cf60], a
	ld [$d108], a
	call $3856
	ld a, [$d22d]
	dec a
	jr z, .asm_3e925
	ld a, [$d109]
	ld hl, $d289
	call Function3927
	ld a, [hl]
	jr .asm_3e945
.asm_3e925
	ld a, [BattleType]
	cp a, $0a
	ld a, [$d241]
	jr z, .asm_3e945
	call $2f9f
	cp a, $c0
	ld a, $00
	jr c, .asm_3e945
	call $2f9f
	cp a, $14
	ld a, [$d241]
	jr nc, .asm_3e945
	ld a, [$d242]
.asm_3e945
	ld [EnemyMonItem], a
	ld a, [$d22d]
	and a
	jr z, .asm_3e963
	ld a, [$c671]
	bit 3, a
	jr z, .asm_3e963
	ld hl, $c6f2
	ld de, EnemyMonDVs
	ld a, [hli]
	ld [de], a
	inc de
	ld a, [hl]
	ld [de], a
	jp .asm_3ea1a
.asm_3e963
	ld a, $09
	ld hl, $70c4
	rst $08
	ld a, [$d22d]
	dec a
	jr nz, .asm_3e9a8
	ld a, [BattleType]
	cp a, $05
	jr nz, .asm_3e996
	call $7a01
	ld a, [hl]
	and a
	push af
	call $7a19
	inc hl
	ld a, [hld]
	ld c, a
	ld b, [hl]
	pop af
	jr nz, .asm_3e9a8
	call $7a19
	inc hl
	call $2f9f
	ld [hld], a
	ld c, a
	call $2f9f
	ld [hl], a
	ld b, a
	jr .asm_3e9a8	
.asm_3e996
	cp a, $07
	jr nz, .asm_3e9a0
	ld b, $ea
	ld c, $aa
	jr .asm_3e9a8
.asm_3e9a0
	call $2f9f
	ld b, a
	call $2f9f
	ld c, a
.asm_3e9a8
	ld hl, EnemyMonDVs
	ld a, b
	ld [hli], a
	ld [hl], c
	ld a, [$d22d]
	dec a
	jr nz, .asm_3ea1a
	ld a, [TempEnemyMonSpecies]
	cp a, UNOWN
	jr nz, .notunown
	ld hl, EnemyMonDVs
	ld a, $2d
	call $2d83
	call CheckUnownLetter
	jr c, .asm_3e9a0
.notunown
	ld a, [TempEnemyMonSpecies]
	cp a, MAGIKARP
	jr nz, .asm_3ea1a
	ld de, EnemyMonDVs
	ld bc, PlayerID
	ld hl, CalcMagikarpLength
	ld a, BANK(CalcMagikarpLength)
	rst $08
	ld a, [$d1ea] ; Magikarp's length
	cp a, $06
	jr nz, .asm_3e9fe
	call $2f8c
	cp a, $0c
	jr c, .asm_3e9fe
	ld a, [$d1eb]
	cp a, $50
	jr nc, .asm_3e9a0
	call $2f8c
	cp a, $32
	jr c, .asm_3e9fe
	ld a, [$d1eb]
	cp a, $40
	jr nc, .asm_3e9a0
.asm_3e9fe
	ld a, [$dcb5]
	cp a, $09
	jr z, .asm_3ea1a
	ld a, [$dcb6]
	cp a, $06
	jr z, .asm_3ea1a
	call $2f8c
	cp a, $64
	jr c, .asm_3ea1a
	ld a, [$d1ea]
	cp a, $04
	jr c, .asm_3e9a0
.asm_3ea1a
	ld a, $46
	ld [EnemyMonHappiness], a
	ld a, [$d143]
	ld [EnemyMonLevel], a
	ld de, EnemyMonMaxHP
	ld b, $00
	ld hl, $d201
	ld a, $0c
	call $2d83
	ld a, [$d22d]
	cp a, $02
	jr z, .asm_3ea74
	and a
	jr z, .asm_3ea44
	ld a, [$c671]
	bit 3, a
	jp nz, .asm_3ea90
.asm_3ea44
	call CheckSleepingTreeMon
	ld a, $07
	jr c, .asm_3ea4c
	xor a
.asm_3ea4c
	ld hl, EnemyMonStatus
	ld [hli], a
	xor a
	ld [hli], a
	ld a, [EnemyMonMaxHPHi]
	ld [hli], a
	ld a, [EnemyMonMaxHPLo]
	ld [hl], a
	ld a, [BattleType]
	cp a, $05
	jr nz, .asm_3ea90
	call $7a01
	ld a, [hl]
	and a
	jr z, .asm_3ea6e
	ld a, [hl]
	ld [EnemyMonHPLo], a
	jr .asm_3ea90
.asm_3ea6e
	ld a, [EnemyMonHPLo]
	ld [hl], a
	jr .asm_3ea90
.asm_3ea74
	ld hl, $d2ab
	ld a, [$d109]
	call Function3927
	ld a, [hld]
	ld [EnemyMonHPLo], a
	ld a, [hld]
	ld [EnemyMonHPHi], a
	ld a, [$d109]
	ld [$c663], a
	dec hl
	ld a, [hl]
	ld [EnemyMonStatus], a
.asm_3ea90
	ld hl, $d23d
	ld de, $d224
	ld a, [hli]
	ld [de], a
	inc de
	ld a, [hl]
	ld [de], a
	ld de, EnemyMonMoves
	ld a, [$d22d]
	cp a, $02
	jr nz, .asm_3eab6
	ld hl, OTPartyMon1Moves
	ld a, [$d109]
	call Function3927
	ld bc, $0004
	call CopyBytes
	jr .asm_3eac5
.asm_3eab6
	xor a
	ld h, d
	ld l, e
	ld [hli], a
	ld [hli], a
	ld [hli], a
	ld [hl], a
	ld [$d1ea], a
	ld a, $1b
	call $2d83
.asm_3eac5
	ld a, [$d22d]
	cp a, $02
	jr z, .asm_3ead9
	ld hl, EnemyMonMoves
	ld de, EnemyMonPP
	ld a, $05
	call $2d83
	jr .asm_3eaeb
.asm_3ead9
	ld hl, $d29f
	ld a, [$d109]
	call Function3927
	ld de, EnemyMonPP
	ld bc, $0004
	call CopyBytes
.asm_3eaeb
	ld hl, $d237
	ld de, $d226
	ld b, $05
.asm_3eaf3
	ld a, [hli]
	ld [de], a
	inc de
	dec b
	jr nz, .asm_3eaf3
	ld a, [$d23f]
	ld [de], a
	inc de
	ld a, [$d240]
	ld [de], a
	ld a, [TempEnemyMonSpecies]
	ld [$d265], a
	call $343b
	ld a, [$d22d]
	and a
	ret z
	ld hl, $d073
	ld de, $c616
	ld bc, $000b
	call CopyBytes
	ld a, [TempEnemyMonSpecies]
	dec a
	ld c, a
	ld b, $01
	ld hl, $deb9
	ld a, $03
	call $2d83
	ld hl, EnemyMonAtk
	ld de, $c6c1
	ld bc, $000a
	call CopyBytes
	ret
; 3eb38

CheckSleepingTreeMon: ; 3eb38
	ld a, [BattleType]
	cp a, $08 ; headbutt
	jr nz, .notsleeping
	ld hl, SleepingTreeMonMornTable
	ld a, [TimeOfDay]
	cp a, $01 ; day
	jr c, .check
	ld hl, SleepingTreeMonDayTable
	jr z, .check
	ld hl, SleepingTreeMonNiteTable
.check
	ld a, [TempEnemyMonSpecies]
	ld de, $0001
	call IsInArray
	ret c
.notsleeping
	and a
	ret
; 3eb5d

SleepingTreeMonNiteTable: ; 3eb5d
	db CATERPIE
	db METAPOD
	db BUTTERFREE
	db WEEDLE
	db KAKUNA
	db BEEDRILL
	db SPEAROW
	db EKANS
	db EXEGGCUTE
	db LEDYBA
	db AIPOM
	db $ff ; end
; 3eb69

SleepingTreeMonDayTable: ; 3eb69
	db VENONAT
	db HOOTHOOT
	db NOCTOWL
	db SPINARAK
	db HERACROSS
	db $ff ; end
; 3eb6f

SleepingTreeMonMornTable ; 3eb6f
	db VENONAT
	db HOOTHOOT
	db NOCTOWL
	db SPINARAK
	db HERACROSS
	db $ff ; end
; 3eb75

CheckUnownLetter: ; 3eb75
; returns carry if not a valid letter
	ld a, [$def3]
	ld c, a
	ld de, $0000
.asm_3eb7c
	srl c ; bit 0 off?
	jr nc, .asm_3eb96
	ld hl, UnownLetterPointerTable
	add hl, de
	ld a, [hli]
	ld h, [hl]
	ld l, a
	push de
	ld a, [$d234]
	ld de, $0001
	push bc
	call IsInArray
	pop bc
	pop de
	jr c, .end
.asm_3eb96
	inc e
	inc e
	ld a, e
	cp a, $08 ; has the end of the table been reached?
	jr c, .asm_3eb7c
	scf
	ret
.end
	and a
	ret
	
UnownLetterPointerTable: ; 3eba1
	dw UnownLetterTable
	dw UnownLetterTable2
	dw UnownLetterTable3
	dw UnownLetterTable4
; 3eba9
	
UnownLetterTable: ; 3eba9
	;   A    B    C    D    E    F    G    H    I    J    K
	db $01, $02, $03, $04, $05, $06, $07, $08, $09, $0a, $0b
	db $ff
; 3ebb5
	
UnownLetterTable2: ; 3ebb5
	;   L    M    N    O    P    Q    R
	db $0c, $0d, $0e, $0f, $10, $11, $12
	db $ff
; 3ebbd
	
UnownLetterTable3: ; 3ebbd
	;   S    T    U    V    W
	db $13, $14, $15, $16, $17
	db $ff
; 3ebc3
	
UnownLetterTable4: ; 3ebc3
	;   X    Y    Z
	db $18, $19, $1a
	db $ff
;3ebc7

INCBIN "baserom.gbc",$3ebc7,$3fc8b - $3ebc7

; I have no clue what most of this does

BattleStartMessage:
	ld a, [$d22d]
	dec a
	jr z, .asm_3fcaa ; 0x3fc8f $19
	ld de, $005e
	call $3c23
	call WaitSFX
	ld c, $14
	call $0468
	ld a, $e
	ld hl, $5939
	rst $8
	ld hl, $47a9
	jr .asm_3fd0e ; 0x3fca8 $64
.asm_3fcaa
	call $5a79
	jr nc, .asm_3fcc2 ; 0x3fcad $13
	xor a
	ld [$cfca], a
	ld a, $1
	ld [$ffe4], a
	ld a, $1
	ld [$c689], a
	ld de, $0101
	call $6e17
.asm_3fcc2
	ld a, $f
	ld hl, $6b38
	rst $8
	jr c, .messageSelection ; 0x3fcc8 $21
	ld a, $13
	ld hl, $6a44
	rst $8
	jr c, .asm_3fce0 ; 0x3fcd0 $e
	ld hl, $c4ac
	ld d, $0
	ld e, $1
	ld a, $47
	call $2d83
	jr .messageSelection ; 0x3fcde $b
.asm_3fce0
	ld a, $f
	ld [$c2bd], a
	ld a, [$d204]
	call $37b6
.messageSelection
	ld a, [$d230]
	cp $4
	jr nz, .asm_3fcfd ; 0x3fcf0 $b
	ld a, $41
	ld hl, $6086
	rst $8
	ld hl, HookedPokemonAttackedText
	jr .asm_3fd0e ; 0x3fcfb $11
.asm_3fcfd
	ld hl, PokemonFellFromTreeText
	cp $8
	jr z, .asm_3fd0e ; 0x3fd02 $a
	ld hl, WildPokemonAppearedText2
	cp $b
	jr z, .asm_3fd0e ; 0x3fd09 $3
	ld hl, WildPokemonAppearedText
.asm_3fd0e
	push hl
	ld a, $b
	ld hl, $4000
	rst $8
	pop hl
	call $3ad5
	call $7830
	ret nz
	ld c, $2
	ld a, $13
	ld hl, $6a0a
	rst $8
	ret
; 0x3fd26

INCBIN "baserom.gbc",$3fd26,$40000 - $3fd26

SECTION "bank10",DATA,BANK[$10]

INCBIN "baserom.gbc",$40000,$40c65-$40000

AlphabeticalPokedexOrder: ; 0x40c65
	db ABRA
	db AERODACTYL
	db AIPOM
	db ALAKAZAM
	db AMPHAROS
	db ARBOK
	db ARCANINE
	db ARIADOS
	db ARTICUNO
	db AZUMARILL
	db BAYLEEF
	db BEEDRILL
	db BELLOSSOM
	db BELLSPROUT
	db BLASTOISE
	db BLISSEY
	db BULBASAUR
	db BUTTERFREE
	db CATERPIE
	db CELEBI
	db CHANSEY
	db CHARIZARD
	db CHARMANDER
	db CHARMELEON
	db CHIKORITA
	db CHINCHOU
	db CLEFABLE
	db CLEFAIRY
	db CLEFFA
	db CLOYSTER
	db CORSOLA
	db CROBAT
	db CROCONAW
	db CUBONE
	db CYNDAQUIL
	db DELIBIRD
	db DEWGONG
	db DIGLETT
	db DITTO
	db DODRIO
	db DODUO
	db DONPHAN
	db DRAGONAIR
	db DRAGONITE
	db DRATINI
	db DROWZEE
	db DUGTRIO
	db DUNSPARCE
	db EEVEE
	db EKANS
	db ELECTABUZZ
	db ELECTRODE
	db ELEKID
	db ENTEI
	db ESPEON
	db EXEGGCUTE
	db EXEGGUTOR
	db FARFETCH_D
	db FEAROW
	db FERALIGATR
	db FLAAFFY
	db FLAREON
	db FORRETRESS
	db FURRET
	db GASTLY
	db GENGAR
	db GEODUDE
	db GIRAFARIG
	db GLIGAR
	db GLOOM
	db GOLBAT
	db GOLDEEN
	db GOLDUCK
	db GOLEM
	db GRANBULL
	db GRAVELER
	db GRIMER
	db GROWLITHE
	db GYARADOS
	db HAUNTER
	db HERACROSS
	db HITMONCHAN
	db HITMONLEE
	db HITMONTOP
	db HO_OH
	db HOOTHOOT
	db HOPPIP
	db HORSEA
	db HOUNDOOM
	db HOUNDOUR
	db HYPNO
	db IGGLYBUFF
	db IVYSAUR
	db JIGGLYPUFF
	db JOLTEON
	db JUMPLUFF
	db JYNX
	db KABUTO
	db KABUTOPS
	db KADABRA
	db KAKUNA
	db KANGASKHAN
	db KINGDRA
	db KINGLER
	db KOFFING
	db KRABBY
	db LANTURN
	db LAPRAS
	db LARVITAR
	db LEDIAN
	db LEDYBA
	db LICKITUNG
	db LUGIA
	db MACHAMP
	db MACHOKE
	db MACHOP
	db MAGBY
	db MAGCARGO
	db MAGIKARP
	db MAGMAR
	db MAGNEMITE
	db MAGNETON
	db MANKEY
	db MANTINE
	db MAREEP
	db MARILL
	db MAROWAK
	db MEGANIUM
	db MEOWTH
	db METAPOD
	db MEW
	db MEWTWO
	db MILTANK
	db MISDREAVUS
	db MOLTRES
	db MR__MIME
	db MUK
	db MURKROW
	db NATU
	db NIDOKING
	db NIDOQUEEN
	db NIDORAN_F
	db NIDORAN_M
	db NIDORINA
	db NIDORINO
	db NINETALES
	db NOCTOWL
	db OCTILLERY
	db ODDISH
	db OMANYTE
	db OMASTAR
	db ONIX
	db PARAS
	db PARASECT
	db PERSIAN
	db PHANPY
	db PICHU
	db PIDGEOT
	db PIDGEOTTO
	db PIDGEY
	db PIKACHU
	db PILOSWINE
	db PINECO
	db PINSIR
	db POLITOED
	db POLIWAG
	db POLIWHIRL
	db POLIWRATH
	db PONYTA
	db PORYGON
	db PORYGON2
	db PRIMEAPE
	db PSYDUCK
	db PUPITAR
	db QUAGSIRE
	db QUILAVA
	db QWILFISH
	db RAICHU
	db RAIKOU
	db RAPIDASH
	db RATICATE
	db RATTATA
	db REMORAID
	db RHYDON
	db RHYHORN
	db SANDSHREW
	db SANDSLASH
	db SCIZOR
	db SCYTHER
	db SEADRA
	db SEAKING
	db SEEL
	db SENTRET
	db SHELLDER
	db SHUCKLE
	db SKARMORY
	db SKIPLOOM
	db SLOWBRO
	db SLOWKING
	db SLOWPOKE
	db SLUGMA
	db SMEARGLE
	db SMOOCHUM
	db SNEASEL
	db SNORLAX
	db SNUBBULL
	db SPEAROW
	db SPINARAK
	db SQUIRTLE
	db STANTLER
	db STARMIE
	db STARYU
	db STEELIX
	db SUDOWOODO
	db SUICUNE
	db SUNFLORA
	db SUNKERN
	db SWINUB
	db TANGELA
	db TAUROS
	db TEDDIURSA
	db TENTACOOL
	db TENTACRUEL
	db TOGEPI
	db TOGETIC
	db TOTODILE
	db TYPHLOSION
	db TYRANITAR
	db TYROGUE
	db UMBREON
	db UNOWN
	db URSARING
	db VAPOREON
	db VENOMOTH
	db VENONAT
	db VENUSAUR
	db VICTREEBEL
	db VILEPLUME
	db VOLTORB
	db VULPIX
	db WARTORTLE
	db WEEDLE
	db WEEPINBELL
	db WEEZING
	db WIGGLYTUFF
	db WOBBUFFET
	db WOOPER
	db XATU
	db YANMA
	db ZAPDOS
	db ZUBAT

NewPokedexOrder: ; 0x40d60
	db CHIKORITA
	db BAYLEEF
	db MEGANIUM
	db CYNDAQUIL
	db QUILAVA
	db TYPHLOSION
	db TOTODILE
	db CROCONAW
	db FERALIGATR
	db PIDGEY
	db PIDGEOTTO
	db PIDGEOT
	db SPEAROW
	db FEAROW
	db HOOTHOOT
	db NOCTOWL
	db RATTATA
	db RATICATE
	db SENTRET
	db FURRET
	db PICHU
	db PIKACHU
	db RAICHU
	db CATERPIE
	db METAPOD
	db BUTTERFREE
	db WEEDLE
	db KAKUNA
	db BEEDRILL
	db LEDYBA
	db LEDIAN
	db SPINARAK
	db ARIADOS
	db GEODUDE
	db GRAVELER
	db GOLEM
	db ZUBAT
	db GOLBAT
	db CROBAT
	db CLEFFA
	db CLEFAIRY
	db CLEFABLE
	db IGGLYBUFF
	db JIGGLYPUFF
	db WIGGLYTUFF
	db TOGEPI
	db TOGETIC
	db SANDSHREW
	db SANDSLASH
	db EKANS
	db ARBOK
	db DUNSPARCE
	db MAREEP
	db FLAAFFY
	db AMPHAROS
	db WOOPER
	db QUAGSIRE
	db GASTLY
	db HAUNTER
	db GENGAR
	db UNOWN
	db ONIX
	db STEELIX
	db BELLSPROUT
	db WEEPINBELL
	db VICTREEBEL
	db HOPPIP
	db SKIPLOOM
	db JUMPLUFF
	db PARAS
	db PARASECT
	db POLIWAG
	db POLIWHIRL
	db POLIWRATH
	db POLITOED
	db MAGIKARP
	db GYARADOS
	db GOLDEEN
	db SEAKING
	db SLOWPOKE
	db SLOWBRO
	db SLOWKING
	db ODDISH
	db GLOOM
	db VILEPLUME
	db BELLOSSOM
	db DROWZEE
	db HYPNO
	db ABRA
	db KADABRA
	db ALAKAZAM
	db DITTO
	db PINECO
	db FORRETRESS
	db NIDORAN_F
	db NIDORINA
	db NIDOQUEEN
	db NIDORAN_M
	db NIDORINO
	db NIDOKING
	db YANMA
	db SUNKERN
	db SUNFLORA
	db EXEGGCUTE
	db EXEGGUTOR
	db SUDOWOODO
	db WOBBUFFET
	db VENONAT
	db VENOMOTH
	db SCYTHER
	db SCIZOR
	db PINSIR
	db HERACROSS
	db KOFFING
	db WEEZING
	db GRIMER
	db MUK
	db MAGNEMITE
	db MAGNETON
	db VOLTORB
	db ELECTRODE
	db AIPOM
	db SNUBBULL
	db GRANBULL
	db VULPIX
	db NINETALES
	db GROWLITHE
	db ARCANINE
	db STANTLER
	db MARILL
	db AZUMARILL
	db DIGLETT
	db DUGTRIO
	db MANKEY
	db PRIMEAPE
	db MEOWTH
	db PERSIAN
	db PSYDUCK
	db GOLDUCK
	db MACHOP
	db MACHOKE
	db MACHAMP
	db TYROGUE
	db HITMONLEE
	db HITMONCHAN
	db HITMONTOP
	db GIRAFARIG
	db TAUROS
	db MILTANK
	db MAGBY
	db MAGMAR
	db SMOOCHUM
	db JYNX
	db ELEKID
	db ELECTABUZZ
	db MR__MIME
	db SMEARGLE
	db FARFETCH_D
	db NATU
	db XATU
	db QWILFISH
	db TENTACOOL
	db TENTACRUEL
	db KRABBY
	db KINGLER
	db SHUCKLE
	db STARYU
	db STARMIE
	db SHELLDER
	db CLOYSTER
	db CORSOLA
	db REMORAID
	db OCTILLERY
	db CHINCHOU
	db LANTURN
	db SEEL
	db DEWGONG
	db LICKITUNG
	db TANGELA
	db EEVEE
	db VAPOREON
	db JOLTEON
	db FLAREON
	db ESPEON
	db UMBREON
	db HORSEA
	db SEADRA
	db KINGDRA
	db GLIGAR
	db DELIBIRD
	db SWINUB
	db PILOSWINE
	db TEDDIURSA
	db URSARING
	db PHANPY
	db DONPHAN
	db MANTINE
	db SKARMORY
	db DODUO
	db DODRIO
	db PONYTA
	db RAPIDASH
	db CUBONE
	db MAROWAK
	db KANGASKHAN
	db RHYHORN
	db RHYDON
	db MURKROW
	db HOUNDOUR
	db HOUNDOOM
	db SLUGMA
	db MAGCARGO
	db SNEASEL
	db MISDREAVUS
	db PORYGON
	db PORYGON2
	db CHANSEY
	db BLISSEY
	db LAPRAS
	db OMANYTE
	db OMASTAR
	db KABUTO
	db KABUTOPS
	db AERODACTYL
	db SNORLAX
	db BULBASAUR
	db IVYSAUR
	db VENUSAUR
	db CHARMANDER
	db CHARMELEON
	db CHARIZARD
	db SQUIRTLE
	db WARTORTLE
	db BLASTOISE
	db ARTICUNO
	db ZAPDOS
	db MOLTRES
	db RAIKOU
	db ENTEI
	db SUICUNE
	db DRATINI
	db DRAGONAIR
	db DRAGONITE
	db LARVITAR
	db PUPITAR
	db TYRANITAR
	db LUGIA
	db HO_OH
	db MEWTWO
	db MEW
	db CELEBI

INCBIN "baserom.gbc",$40e5b,$41afb-$40e5b

Moves: ; 0x41afb
; characteristics of each move
; animation, effect, power, type, accuracy, PP, effect chance
	db POUND,$00,40,NORMAL,$ff,35,$00
Move1:
	db KARATE_CHOP,$00,50,FIGHTING,$ff,25,$00
	db DOUBLESLAP,$1d,15,NORMAL,$d8,10,$00
	db COMET_PUNCH,$1d,18,NORMAL,$d8,15,$00
	db MEGA_PUNCH,$00,80,NORMAL,$d8,20,$00
	db PAY_DAY,$22,40,NORMAL,$ff,20,$00
	db FIRE_PUNCH,$04,75,FIRE,$ff,15,$19
	db ICE_PUNCH,$05,75,ICE,$ff,15,$19
	db THUNDERPUNCH,$06,75,ELECTRIC,$ff,15,$19
	db SCRATCH,$00,40,NORMAL,$ff,35,$00
	db VICEGRIP,$00,55,NORMAL,$ff,30,$00
	db GUILLOTINE,$26,0,NORMAL,$4c,5,$00
	db RAZOR_WIND,$27,80,NORMAL,$bf,10,$00
	db SWORDS_DANCE,$32,0,NORMAL,$ff,30,$00
	db CUT,$00,50,NORMAL,$f2,30,$00
	db GUST,$95,40,FLYING,$ff,35,$00
	db WING_ATTACK,$00,60,FLYING,$ff,35,$00
	db WHIRLWIND,$1c,0,NORMAL,$ff,20,$00
	db FLY,$9b,70,FLYING,$f2,15,$00
	db BIND,$2a,15,NORMAL,$bf,20,$00
	db SLAM,$00,80,NORMAL,$bf,20,$00
	db VINE_WHIP,$00,35,GRASS,$ff,10,$00
	db STOMP,$96,65,NORMAL,$ff,20,$4c
	db DOUBLE_KICK,$2c,30,FIGHTING,$ff,30,$00
	db MEGA_KICK,$00,120,NORMAL,$bf,5,$00
	db JUMP_KICK,$2d,70,FIGHTING,$f2,25,$00
	db ROLLING_KICK,$1f,60,FIGHTING,$d8,15,$4c
	db SAND_ATTACK,$17,0,GROUND,$ff,15,$00
	db HEADBUTT,$1f,70,NORMAL,$ff,15,$4c
	db HORN_ATTACK,$00,65,NORMAL,$ff,25,$00
	db FURY_ATTACK,$1d,15,NORMAL,$d8,20,$00
	db HORN_DRILL,$26,1,NORMAL,$4c,5,$00
	db TACKLE,$00,35,NORMAL,$f2,35,$00
	db BODY_SLAM,$06,85,NORMAL,$ff,15,$4c
	db WRAP,$2a,15,NORMAL,$d8,20,$00
	db TAKE_DOWN,$30,90,NORMAL,$d8,20,$00
	db THRASH,$1b,90,NORMAL,$ff,20,$00
	db DOUBLE_EDGE,$30,120,NORMAL,$ff,15,$00
	db TAIL_WHIP,$13,0,NORMAL,$ff,30,$00
	db POISON_STING,$02,15,POISON,$ff,35,$4c
	db TWINEEDLE,$4d,25,BUG,$ff,20,$33
	db PIN_MISSILE,$1d,14,BUG,$d8,20,$00
	db LEER,$13,0,NORMAL,$ff,30,$00
	db BITE,$1f,60,DARK,$ff,25,$4c
	db GROWL,$12,0,NORMAL,$ff,40,$00
	db ROAR,$1c,0,NORMAL,$ff,20,$00
	db SING,$01,0,NORMAL,$8c,15,$00
	db SUPERSONIC,$31,0,NORMAL,$8c,20,$00
	db SONICBOOM,$29,20,NORMAL,$e5,20,$00
	db DISABLE,$56,0,NORMAL,$8c,20,$00
	db ACID,$45,40,POISON,$ff,30,$19
	db EMBER,$04,40,FIRE,$ff,25,$19
	db FLAMETHROWER,$04,95,FIRE,$ff,15,$19
	db MIST,$2e,0,ICE,$ff,30,$00
	db WATER_GUN,$00,40,WATER,$ff,25,$00
	db HYDRO_PUMP,$00,120,WATER,$cc,5,$00
	db SURF,$00,95,WATER,$ff,15,$00
	db ICE_BEAM,$05,95,ICE,$ff,10,$19
	db BLIZZARD,$05,120,ICE,$b2,5,$19
	db PSYBEAM,$4c,65,PSYCHIC,$ff,20,$19
	db BUBBLEBEAM,$46,65,WATER,$ff,20,$19
	db AURORA_BEAM,$44,65,ICE,$ff,20,$19
	db HYPER_BEAM,$50,150,NORMAL,$e5,5,$00
	db PECK,$00,35,FLYING,$ff,35,$00
	db DRILL_PECK,$00,80,FLYING,$ff,20,$00
	db SUBMISSION,$30,80,FIGHTING,$cc,25,$00
	db LOW_KICK,$1f,50,FIGHTING,$e5,20,$4c
	db COUNTER,$59,1,FIGHTING,$ff,20,$00
	db SEISMIC_TOSS,$57,1,FIGHTING,$ff,20,$00
	db STRENGTH,$00,80,NORMAL,$ff,15,$00
	db ABSORB,$03,20,GRASS,$ff,20,$00
	db MEGA_DRAIN,$03,40,GRASS,$ff,10,$00
	db LEECH_SEED,$54,0,GRASS,$e5,10,$00
	db GROWTH,$0d,0,NORMAL,$ff,40,$00
	db RAZOR_LEAF,$00,55,GRASS,$f2,25,$00
	db SOLARBEAM,$97,120,GRASS,$ff,10,$00
	db POISONPOWDER,$42,0,POISON,$bf,35,$00
	db STUN_SPORE,$43,0,GRASS,$bf,30,$00
	db SLEEP_POWDER,$01,0,GRASS,$bf,15,$00
	db PETAL_DANCE,$1b,70,GRASS,$ff,20,$00
	db STRING_SHOT,$14,0,BUG,$f2,40,$00
	db DRAGON_RAGE,$29,40,DRAGON,$ff,10,$00
	db FIRE_SPIN,$2a,15,FIRE,$b2,15,$00
	db THUNDERSHOCK,$06,40,ELECTRIC,$ff,30,$19
	db THUNDERBOLT,$06,95,ELECTRIC,$ff,15,$19
	db THUNDER_WAVE,$43,0,ELECTRIC,$ff,20,$00
	db THUNDER,$98,120,ELECTRIC,$b2,10,$4c
	db ROCK_THROW,$00,50,ROCK,$e5,15,$00
	db EARTHQUAKE,$93,100,GROUND,$ff,10,$00
	db FISSURE,$26,1,GROUND,$4c,5,$00
	db DIG,$9b,60,GROUND,$ff,10,$00
	db TOXIC,$21,0,POISON,$d8,10,$00
	db CONFUSION,$4c,50,PSYCHIC,$ff,25,$19
	db PSYCHIC_M,$48,90,PSYCHIC,$ff,10,$19
	db HYPNOSIS,$01,0,PSYCHIC,$99,20,$00
	db MEDITATE,$0a,0,PSYCHIC,$ff,40,$00
	db AGILITY,$34,0,PSYCHIC,$ff,30,$00
	db QUICK_ATTACK,$67,40,NORMAL,$ff,30,$00
	db RAGE,$51,20,NORMAL,$ff,20,$00
	db TELEPORT,$99,0,PSYCHIC,$ff,20,$00
	db NIGHT_SHADE,$57,1,GHOST,$ff,15,$00
	db MIMIC,$52,0,NORMAL,$ff,10,$00
	db SCREECH,$3b,0,NORMAL,$d8,40,$00
	db DOUBLE_TEAM,$10,0,NORMAL,$ff,15,$00
	db RECOVER,$20,0,NORMAL,$ff,20,$00
	db HARDEN,$0b,0,NORMAL,$ff,30,$00
	db MINIMIZE,$10,0,NORMAL,$ff,20,$00
	db SMOKESCREEN,$17,0,NORMAL,$ff,20,$00
	db CONFUSE_RAY,$31,0,GHOST,$ff,10,$00
	db WITHDRAW,$0b,0,WATER,$ff,40,$00
	db DEFENSE_CURL,$9c,0,NORMAL,$ff,40,$00
	db BARRIER,$33,0,PSYCHIC,$ff,30,$00
	db LIGHT_SCREEN,$23,0,PSYCHIC,$ff,30,$00
	db HAZE,$19,0,ICE,$ff,30,$00
	db REFLECT,$41,0,PSYCHIC,$ff,20,$00
	db FOCUS_ENERGY,$2f,0,NORMAL,$ff,30,$00
	db BIDE,$1a,0,NORMAL,$ff,10,$00
	db METRONOME,$53,0,NORMAL,$ff,10,$00
	db MIRROR_MOVE,$09,0,FLYING,$ff,20,$00
	db SELFDESTRUCT,$07,200,NORMAL,$ff,5,$00
	db EGG_BOMB,$00,100,NORMAL,$bf,10,$00
	db LICK,$06,20,GHOST,$ff,30,$4c
	db SMOG,$02,20,POISON,$b2,20,$66
	db SLUDGE,$02,65,POISON,$ff,20,$4c
	db BONE_CLUB,$1f,65,GROUND,$d8,20,$19
	db FIRE_BLAST,$04,120,FIRE,$d8,5,$19
	db WATERFALL,$00,80,WATER,$ff,15,$00
	db CLAMP,$2a,35,WATER,$bf,10,$00
	db SWIFT,$11,60,NORMAL,$ff,20,$00
	db SKULL_BASH,$91,100,NORMAL,$ff,15,$00
	db SPIKE_CANNON,$1d,20,NORMAL,$ff,15,$00
	db CONSTRICT,$46,10,NORMAL,$ff,35,$19
	db AMNESIA,$36,0,PSYCHIC,$ff,20,$00
	db KINESIS,$17,0,PSYCHIC,$cc,15,$00
	db SOFTBOILED,$20,0,NORMAL,$ff,10,$00
	db HI_JUMP_KICK,$2d,85,FIGHTING,$e5,20,$00
	db GLARE,$43,0,NORMAL,$bf,30,$00
	db DREAM_EATER,$08,100,PSYCHIC,$ff,15,$00
	db POISON_GAS,$42,0,POISON,$8c,40,$00
	db BARRAGE,$1d,15,NORMAL,$d8,20,$00
	db LEECH_LIFE,$03,20,BUG,$ff,15,$00
	db LOVELY_KISS,$01,0,NORMAL,$bf,10,$00
	db SKY_ATTACK,$4b,140,FLYING,$e5,5,$00
	db TRANSFORM,$39,0,NORMAL,$ff,10,$00
	db BUBBLE,$46,20,WATER,$ff,30,$19
	db DIZZY_PUNCH,$4c,70,NORMAL,$ff,10,$33
	db SPORE,$01,0,GRASS,$ff,15,$00
	db FLASH,$17,0,NORMAL,$b2,20,$00
	db PSYWAVE,$58,1,PSYCHIC,$cc,15,$00
	db SPLASH,$55,0,NORMAL,$ff,40,$00
	db ACID_ARMOR,$33,0,POISON,$ff,40,$00
	db CRABHAMMER,$00,90,WATER,$d8,10,$00
	db EXPLOSION,$07,250,NORMAL,$ff,5,$00
	db FURY_SWIPES,$1d,18,NORMAL,$cc,15,$00
	db BONEMERANG,$2c,50,GROUND,$e5,10,$00
	db REST,$20,0,PSYCHIC,$ff,10,$00
	db ROCK_SLIDE,$1f,75,ROCK,$e5,10,$4c
	db HYPER_FANG,$1f,80,NORMAL,$e5,15,$19
	db SHARPEN,$0a,0,NORMAL,$ff,30,$00
	db CONVERSION,$1e,0,NORMAL,$ff,30,$00
	db TRI_ATTACK,$24,80,NORMAL,$ff,10,$33
	db SUPER_FANG,$28,1,NORMAL,$e5,10,$00
	db SLASH,$00,70,NORMAL,$ff,20,$00
	db SUBSTITUTE,$4f,0,NORMAL,$ff,10,$00
	db STRUGGLE,$30,50,NORMAL,$ff,1,$00
	db SKETCH,$5f,0,NORMAL,$ff,1,$00
	db TRIPLE_KICK,$68,10,FIGHTING,$e5,10,$00
	db THIEF,$69,40,DARK,$ff,10,$ff
	db SPIDER_WEB,$6a,0,BUG,$ff,10,$00
	db MIND_READER,$5e,0,NORMAL,$ff,5,$00
	db NIGHTMARE,$6b,0,GHOST,$ff,15,$00
	db FLAME_WHEEL,$6c,60,FIRE,$ff,25,$19
	db SNORE,$5c,40,NORMAL,$ff,15,$4c
	db CURSE,$6d,0,CURSE_T,$ff,10,$00
	db FLAIL,$63,1,NORMAL,$ff,15,$00
	db CONVERSION2,$5d,0,NORMAL,$ff,30,$00
	db AEROBLAST,$00,100,FLYING,$f2,5,$00
	db COTTON_SPORE,$3c,0,GRASS,$d8,40,$00
	db REVERSAL,$63,1,FIGHTING,$ff,15,$00
	db SPITE,$64,0,GHOST,$ff,10,$00
	db POWDER_SNOW,$05,40,ICE,$ff,25,$19
	db PROTECT,$6f,0,NORMAL,$ff,10,$00
	db MACH_PUNCH,$67,40,FIGHTING,$ff,30,$00
	db SCARY_FACE,$3c,0,NORMAL,$e5,10,$00
	db FAINT_ATTACK,$11,60,DARK,$ff,20,$00
	db SWEET_KISS,$31,0,NORMAL,$bf,10,$00
	db BELLY_DRUM,$8e,0,NORMAL,$ff,10,$00
	db SLUDGE_BOMB,$02,90,POISON,$ff,10,$4c
	db MUD_SLAP,$49,20,GROUND,$ff,10,$ff
	db OCTAZOOKA,$49,65,WATER,$d8,10,$7f
	db SPIKES,$70,0,GROUND,$ff,20,$00
	db ZAP_CANNON,$06,100,ELECTRIC,$7f,5,$ff
	db FORESIGHT,$71,0,NORMAL,$ff,40,$00
	db DESTINY_BOND,$62,0,GHOST,$ff,5,$00
	db PERISH_SONG,$72,0,NORMAL,$ff,5,$00
	db ICY_WIND,$46,55,ICE,$f2,15,$ff
	db DETECT,$6f,0,FIGHTING,$ff,5,$00
	db BONE_RUSH,$1d,25,GROUND,$cc,10,$00
	db LOCK_ON,$5e,0,NORMAL,$ff,5,$00
	db OUTRAGE,$1b,90,DRAGON,$ff,15,$00
	db SANDSTORM,$73,0,ROCK,$ff,10,$00
	db GIGA_DRAIN,$03,60,GRASS,$ff,5,$00
	db ENDURE,$74,0,NORMAL,$ff,10,$00
	db CHARM,$3a,0,NORMAL,$ff,20,$00
	db ROLLOUT,$75,30,ROCK,$e5,20,$00
	db FALSE_SWIPE,$65,40,NORMAL,$ff,40,$00
	db SWAGGER,$76,0,NORMAL,$e5,15,$ff
	db MILK_DRINK,$20,0,NORMAL,$ff,10,$00
	db SPARK,$06,65,ELECTRIC,$ff,20,$4c
	db FURY_CUTTER,$77,10,BUG,$f2,20,$00
	db STEEL_WING,$8a,70,STEEL,$e5,25,$19
	db MEAN_LOOK,$6a,0,NORMAL,$ff,5,$00
	db ATTRACT,$78,0,NORMAL,$ff,15,$00
	db SLEEP_TALK,$61,0,NORMAL,$ff,10,$00
	db HEAL_BELL,$66,0,NORMAL,$ff,5,$00
	db RETURN,$79,1,NORMAL,$ff,20,$00
	db PRESENT,$7a,1,NORMAL,$e5,15,$00
	db FRUSTRATION,$7b,1,NORMAL,$ff,20,$00
	db SAFEGUARD,$7c,0,NORMAL,$ff,25,$00
	db PAIN_SPLIT,$5b,0,NORMAL,$ff,20,$00
	db SACRED_FIRE,$7d,100,FIRE,$f2,5,$7f
	db MAGNITUDE,$7e,1,GROUND,$ff,30,$00
	db DYNAMICPUNCH,$4c,100,FIGHTING,$7f,5,$ff
	db MEGAHORN,$00,120,BUG,$d8,10,$00
	db DRAGONBREATH,$06,60,DRAGON,$ff,20,$4c
	db BATON_PASS,$7f,0,NORMAL,$ff,40,$00
	db ENCORE,$5a,0,NORMAL,$ff,5,$00
	db PURSUIT,$80,40,DARK,$ff,20,$00
	db RAPID_SPIN,$81,20,NORMAL,$ff,40,$00
	db SWEET_SCENT,$18,0,NORMAL,$ff,20,$00
	db IRON_TAIL,$45,100,STEEL,$bf,15,$4c
	db METAL_CLAW,$8b,50,STEEL,$f2,35,$19
	db VITAL_THROW,$11,70,FIGHTING,$ff,10,$00
	db MORNING_SUN,$84,0,NORMAL,$ff,5,$00
	db SYNTHESIS,$85,0,GRASS,$ff,5,$00
	db MOONLIGHT,$86,0,NORMAL,$ff,5,$00
	db HIDDEN_POWER,$87,1,NORMAL,$ff,15,$00
	db CROSS_CHOP,$00,100,FIGHTING,$cc,5,$00
	db TWISTER,$92,40,DRAGON,$ff,20,$33
	db RAIN_DANCE,$88,0,WATER,$e5,5,$00
	db SUNNY_DAY,$89,0,FIRE,$e5,5,$00
	db CRUNCH,$48,80,DARK,$ff,15,$33
	db MIRROR_COAT,$90,1,PSYCHIC,$ff,20,$00
	db PSYCH_UP,$8f,0,NORMAL,$ff,10,$00
	db EXTREMESPEED,$67,80,NORMAL,$ff,5,$00
	db ANCIENTPOWER,$8c,60,ROCK,$ff,5,$19
	db SHADOW_BALL,$48,80,GHOST,$ff,15,$33
	db FUTURE_SIGHT,$94,80,PSYCHIC,$e5,15,$00
	db ROCK_SMASH,$45,20,FIGHTING,$ff,15,$7f
	db WHIRLPOOL,$2a,15,WATER,$b2,15,$00
	db BEAT_UP,$9a,10,DARK,$ff,10,$00

INCBIN "baserom.gbc",$421d8,$425b1-$421d8

EvosAttacksPointers: ; 0x425b1
	dw BulbasaurEvosAttacks
	dw IvysaurEvosAttacks
	dw VenusaurEvosAttacks
	dw CharmanderEvosAttacks
	dw CharmeleonEvosAttacks
	dw CharizardEvosAttacks
	dw SquirtleEvosAttacks
	dw WartortleEvosAttacks
	dw BlastoiseEvosAttacks
	dw CaterpieEvosAttacks
	dw MetapodEvosAttacks
	dw ButterfreeEvosAttacks
	dw WeedleEvosAttacks
	dw KakunaEvosAttacks
	dw BeedrillEvosAttacks
	dw PidgeyEvosAttacks
	dw PidgeottoEvosAttacks
	dw PidgeotEvosAttacks
	dw RattataEvosAttacks
	dw RaticateEvosAttacks
	dw SpearowEvosAttacks
	dw FearowEvosAttacks
	dw EkansEvosAttacks
	dw ArbokEvosAttacks
	dw PikachuEvosAttacks
	dw RaichuEvosAttacks
	dw SandshrewEvosAttacks
	dw SandslashEvosAttacks
	dw NidoranFEvosAttacks
	dw NidorinaEvosAttacks
	dw NidoqueenEvosAttacks
	dw NidoranMEvosAttacks
	dw NidorinoEvosAttacks
	dw NidokingEvosAttacks
	dw ClefairyEvosAttacks
	dw ClefableEvosAttacks
	dw VulpixEvosAttacks
	dw NinetalesEvosAttacks
	dw JigglypuffEvosAttacks
	dw WigglytuffEvosAttacks
	dw ZubatEvosAttacks
	dw GolbatEvosAttacks
	dw OddishEvosAttacks
	dw GloomEvosAttacks
	dw VileplumeEvosAttacks
	dw ParasEvosAttacks
	dw ParasectEvosAttacks
	dw VenonatEvosAttacks
	dw VenomothEvosAttacks
	dw DiglettEvosAttacks
	dw DugtrioEvosAttacks
	dw MeowthEvosAttacks
	dw PersianEvosAttacks
	dw PsyduckEvosAttacks
	dw GolduckEvosAttacks
	dw MankeyEvosAttacks
	dw PrimeapeEvosAttacks
	dw GrowlitheEvosAttacks
	dw ArcanineEvosAttacks
	dw PoliwagEvosAttacks
	dw PoliwhirlEvosAttacks
	dw PoliwrathEvosAttacks
	dw AbraEvosAttacks
	dw KadabraEvosAttacks
	dw AlakazamEvosAttacks
	dw MachopEvosAttacks
	dw MachokeEvosAttacks
	dw MachampEvosAttacks
	dw BellsproutEvosAttacks
	dw WeepinbellEvosAttacks
	dw VictreebelEvosAttacks
	dw TentacoolEvosAttacks
	dw TentacruelEvosAttacks
	dw GeodudeEvosAttacks
	dw GravelerEvosAttacks
	dw GolemEvosAttacks
	dw PonytaEvosAttacks
	dw RapidashEvosAttacks
	dw SlowpokeEvosAttacks
	dw SlowbroEvosAttacks
	dw MagnemiteEvosAttacks
	dw MagnetonEvosAttacks
	dw FarfetchDEvosAttacks
	dw DoduoEvosAttacks
	dw DodrioEvosAttacks
	dw SeelEvosAttacks
	dw DewgongEvosAttacks
	dw GrimerEvosAttacks
	dw MukEvosAttacks
	dw ShellderEvosAttacks
	dw CloysterEvosAttacks
	dw GastlyEvosAttacks
	dw HaunterEvosAttacks
	dw GengarEvosAttacks
	dw OnixEvosAttacks
	dw DrowzeeEvosAttacks
	dw HypnoEvosAttacks
	dw KrabbyEvosAttacks
	dw KinglerEvosAttacks
	dw VoltorbEvosAttacks
	dw ElectrodeEvosAttacks
	dw ExeggcuteEvosAttacks
	dw ExeggutorEvosAttacks
	dw CuboneEvosAttacks
	dw MarowakEvosAttacks
	dw HitmonleeEvosAttacks
	dw HitmonchanEvosAttacks
	dw LickitungEvosAttacks
	dw KoffingEvosAttacks
	dw WeezingEvosAttacks
	dw RhyhornEvosAttacks
	dw RhydonEvosAttacks
	dw ChanseyEvosAttacks
	dw TangelaEvosAttacks
	dw KangaskhanEvosAttacks
	dw HorseaEvosAttacks
	dw SeadraEvosAttacks
	dw GoldeenEvosAttacks
	dw SeakingEvosAttacks
	dw StaryuEvosAttacks
	dw StarmieEvosAttacks
	dw MrMimeEvosAttacks
	dw ScytherEvosAttacks
	dw JynxEvosAttacks
	dw ElectabuzzEvosAttacks
	dw MagmarEvosAttacks
	dw PinsirEvosAttacks
	dw TaurosEvosAttacks
	dw MagikarpEvosAttacks
	dw GyaradosEvosAttacks
	dw LaprasEvosAttacks
	dw DittoEvosAttacks
	dw EeveeEvosAttacks
	dw VaporeonEvosAttacks
	dw JolteonEvosAttacks
	dw FlareonEvosAttacks
	dw PorygonEvosAttacks
	dw OmanyteEvosAttacks
	dw OmastarEvosAttacks
	dw KabutoEvosAttacks
	dw KabutopsEvosAttacks
	dw AerodactylEvosAttacks
	dw SnorlaxEvosAttacks
	dw ArticunoEvosAttacks
	dw ZapdosEvosAttacks
	dw MoltresEvosAttacks
	dw DratiniEvosAttacks
	dw DragonairEvosAttacks
	dw DragoniteEvosAttacks
	dw MewtwoEvosAttacks
	dw MewEvosAttacks
	dw ChikoritaEvosAttacks
	dw BayleefEvosAttacks
	dw MeganiumEvosAttacks
	dw CyndaquilEvosAttacks
	dw QuilavaEvosAttacks
	dw TyphlosionEvosAttacks
	dw TotodileEvosAttacks
	dw CroconawEvosAttacks
	dw FeraligatrEvosAttacks
	dw SentretEvosAttacks
	dw FurretEvosAttacks
	dw HoothootEvosAttacks
	dw NoctowlEvosAttacks
	dw LedybaEvosAttacks
	dw LedianEvosAttacks
	dw SpinarakEvosAttacks
	dw AriadosEvosAttacks
	dw CrobatEvosAttacks
	dw ChinchouEvosAttacks
	dw LanturnEvosAttacks
	dw PichuEvosAttacks
	dw CleffaEvosAttacks
	dw IgglybuffEvosAttacks
	dw TogepiEvosAttacks
	dw TogeticEvosAttacks
	dw NatuEvosAttacks
	dw XatuEvosAttacks
	dw MareepEvosAttacks
	dw FlaaffyEvosAttacks
	dw AmpharosEvosAttacks
	dw BellossomEvosAttacks
	dw MarillEvosAttacks
	dw AzumarillEvosAttacks
	dw SudowoodoEvosAttacks
	dw PolitoedEvosAttacks
	dw HoppipEvosAttacks
	dw SkiploomEvosAttacks
	dw JumpluffEvosAttacks
	dw AipomEvosAttacks
	dw SunkernEvosAttacks
	dw SunfloraEvosAttacks
	dw YanmaEvosAttacks
	dw WooperEvosAttacks
	dw QuagsireEvosAttacks
	dw EspeonEvosAttacks
	dw UmbreonEvosAttacks
	dw MurkrowEvosAttacks
	dw SlowkingEvosAttacks
	dw MisdreavusEvosAttacks
	dw UnownEvosAttacks
	dw WobbuffetEvosAttacks
	dw GirafarigEvosAttacks
	dw PinecoEvosAttacks
	dw ForretressEvosAttacks
	dw DunsparceEvosAttacks
	dw GligarEvosAttacks
	dw SteelixEvosAttacks
	dw SnubbullEvosAttacks
	dw GranbullEvosAttacks
	dw QwilfishEvosAttacks
	dw ScizorEvosAttacks
	dw ShuckleEvosAttacks
	dw HeracrossEvosAttacks
	dw SneaselEvosAttacks
	dw TeddiursaEvosAttacks
	dw UrsaringEvosAttacks
	dw SlugmaEvosAttacks
	dw MagcargoEvosAttacks
	dw SwinubEvosAttacks
	dw PiloswineEvosAttacks
	dw CorsolaEvosAttacks
	dw RemoraidEvosAttacks
	dw OctilleryEvosAttacks
	dw DelibirdEvosAttacks
	dw MantineEvosAttacks
	dw SkarmoryEvosAttacks
	dw HoundourEvosAttacks
	dw HoundoomEvosAttacks
	dw KingdraEvosAttacks
	dw PhanpyEvosAttacks
	dw DonphanEvosAttacks
	dw Porygon2EvosAttacks
	dw StantlerEvosAttacks
	dw SmeargleEvosAttacks
	dw TyrogueEvosAttacks
	dw HitmontopEvosAttacks
	dw SmoochumEvosAttacks
	dw ElekidEvosAttacks
	dw MagbyEvosAttacks
	dw MiltankEvosAttacks
	dw BlisseyEvosAttacks
	dw RaikouEvosAttacks
	dw EnteiEvosAttacks
	dw SuicuneEvosAttacks
	dw LarvitarEvosAttacks
	dw PupitarEvosAttacks
	dw TyranitarEvosAttacks
	dw LugiaEvosAttacks
	dw HoOhEvosAttacks
	dw CelebiEvosAttacks

BulbasaurEvosAttacks:
	db EVOLVE_LEVEL,16,IVYSAUR
	db 0 ; no more evolutions
	db 1,TACKLE
	db 4,GROWL
	db 7,LEECH_SEED
	db 10,VINE_WHIP
	db 15,POISONPOWDER
	db 15,SLEEP_POWDER
	db 20,RAZOR_LEAF
	db 25,SWEET_SCENT
	db 32,GROWTH
	db 39,SYNTHESIS
	db 46,SOLARBEAM
	db 0 ; no more level-up moves

IvysaurEvosAttacks:
	db EVOLVE_LEVEL,32,VENUSAUR
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 1,LEECH_SEED
	db 4,GROWL
	db 7,LEECH_SEED
	db 10,VINE_WHIP
	db 15,POISONPOWDER
	db 15,SLEEP_POWDER
	db 22,RAZOR_LEAF
	db 29,SWEET_SCENT
	db 38,GROWTH
	db 47,SYNTHESIS
	db 56,SOLARBEAM
	db 0 ; no more level-up moves

VenusaurEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 1,LEECH_SEED
	db 1,VINE_WHIP
	db 4,GROWL
	db 7,LEECH_SEED
	db 10,VINE_WHIP
	db 15,POISONPOWDER
	db 15,SLEEP_POWDER
	db 22,RAZOR_LEAF
	db 29,SWEET_SCENT
	db 41,GROWTH
	db 53,SYNTHESIS
	db 65,SOLARBEAM
	db 0 ; no more level-up moves

CharmanderEvosAttacks:
	db EVOLVE_LEVEL,16,CHARMELEON
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,GROWL
	db 7,EMBER
	db 13,SMOKESCREEN
	db 19,RAGE
	db 25,SCARY_FACE
	db 31,FLAMETHROWER
	db 37,SLASH
	db 43,DRAGON_RAGE
	db 49,FIRE_SPIN
	db 0 ; no more level-up moves

CharmeleonEvosAttacks:
	db EVOLVE_LEVEL,36,CHARIZARD
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,GROWL
	db 1,EMBER
	db 7,EMBER
	db 13,SMOKESCREEN
	db 20,RAGE
	db 27,SCARY_FACE
	db 34,FLAMETHROWER
	db 41,SLASH
	db 48,DRAGON_RAGE
	db 55,FIRE_SPIN
	db 0 ; no more level-up moves

CharizardEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,GROWL
	db 1,EMBER
	db 1,SMOKESCREEN
	db 7,EMBER
	db 13,SMOKESCREEN
	db 20,RAGE
	db 27,SCARY_FACE
	db 34,FLAMETHROWER
	db 36,WING_ATTACK
	db 44,SLASH
	db 54,DRAGON_RAGE
	db 64,FIRE_SPIN
	db 0 ; no more level-up moves

SquirtleEvosAttacks:
	db EVOLVE_LEVEL,16,WARTORTLE
	db 0 ; no more evolutions
	db 1,TACKLE
	db 4,TAIL_WHIP
	db 7,BUBBLE
	db 10,WITHDRAW
	db 13,WATER_GUN
	db 18,BITE
	db 23,RAPID_SPIN
	db 28,PROTECT
	db 33,RAIN_DANCE
	db 40,SKULL_BASH
	db 47,HYDRO_PUMP
	db 0 ; no more level-up moves

WartortleEvosAttacks:
	db EVOLVE_LEVEL,36,BLASTOISE
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 1,BUBBLE
	db 4,TAIL_WHIP
	db 7,BUBBLE
	db 10,WITHDRAW
	db 13,WATER_GUN
	db 19,BITE
	db 25,RAPID_SPIN
	db 31,PROTECT
	db 37,RAIN_DANCE
	db 45,SKULL_BASH
	db 53,HYDRO_PUMP
	db 0 ; no more level-up moves

BlastoiseEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 1,BUBBLE
	db 1,WITHDRAW
	db 4,TAIL_WHIP
	db 7,BUBBLE
	db 10,WITHDRAW
	db 13,WATER_GUN
	db 19,BITE
	db 25,RAPID_SPIN
	db 31,PROTECT
	db 42,RAIN_DANCE
	db 55,SKULL_BASH
	db 68,HYDRO_PUMP
	db 0 ; no more level-up moves

CaterpieEvosAttacks:
	db EVOLVE_LEVEL,7,METAPOD
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,STRING_SHOT
	db 0 ; no more level-up moves

MetapodEvosAttacks:
	db EVOLVE_LEVEL,10,BUTTERFREE
	db 0 ; no more evolutions
	db 1,HARDEN
	db 7,HARDEN
	db 0 ; no more level-up moves

ButterfreeEvosAttacks:
	db 0 ; no more evolutions
	db 1,CONFUSION
	db 10,CONFUSION
	db 13,POISONPOWDER
	db 14,STUN_SPORE
	db 15,SLEEP_POWDER
	db 18,SUPERSONIC
	db 23,WHIRLWIND
	db 28,GUST
	db 34,PSYBEAM
	db 40,SAFEGUARD
	db 0 ; no more level-up moves

WeedleEvosAttacks:
	db EVOLVE_LEVEL,7,KAKUNA
	db 0 ; no more evolutions
	db 1,POISON_STING
	db 1,STRING_SHOT
	db 0 ; no more level-up moves

KakunaEvosAttacks:
	db EVOLVE_LEVEL,10,BEEDRILL
	db 0 ; no more evolutions
	db 1,HARDEN
	db 7,HARDEN
	db 0 ; no more level-up moves

BeedrillEvosAttacks:
	db 0 ; no more evolutions
	db 1,FURY_ATTACK
	db 10,FURY_ATTACK
	db 15,FOCUS_ENERGY
	db 20,TWINEEDLE
	db 25,RAGE
	db 30,PURSUIT
	db 35,PIN_MISSILE
	db 40,AGILITY
	db 0 ; no more level-up moves

PidgeyEvosAttacks:
	db EVOLVE_LEVEL,18,PIDGEOTTO
	db 0 ; no more evolutions
	db 1,TACKLE
	db 5,SAND_ATTACK
	db 9,GUST
	db 15,QUICK_ATTACK
	db 21,WHIRLWIND
	db 29,WING_ATTACK
	db 37,AGILITY
	db 47,MIRROR_MOVE
	db 0 ; no more level-up moves

PidgeottoEvosAttacks:
	db EVOLVE_LEVEL,36,PIDGEOT
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,SAND_ATTACK
	db 1,GUST
	db 5,SAND_ATTACK
	db 9,GUST
	db 15,QUICK_ATTACK
	db 23,WHIRLWIND
	db 33,WING_ATTACK
	db 43,AGILITY
	db 55,MIRROR_MOVE
	db 0 ; no more level-up moves

PidgeotEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,SAND_ATTACK
	db 1,GUST
	db 1,QUICK_ATTACK
	db 5,SAND_ATTACK
	db 9,GUST
	db 15,QUICK_ATTACK
	db 23,WHIRLWIND
	db 33,WING_ATTACK
	db 46,AGILITY
	db 61,MIRROR_MOVE
	db 0 ; no more level-up moves

RattataEvosAttacks:
	db EVOLVE_LEVEL,20,RATICATE
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 7,QUICK_ATTACK
	db 13,HYPER_FANG
	db 20,FOCUS_ENERGY
	db 27,PURSUIT
	db 34,SUPER_FANG
	db 0 ; no more level-up moves

RaticateEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 1,QUICK_ATTACK
	db 7,QUICK_ATTACK
	db 13,HYPER_FANG
	db 20,SCARY_FACE
	db 30,PURSUIT
	db 40,SUPER_FANG
	db 0 ; no more level-up moves

SpearowEvosAttacks:
	db EVOLVE_LEVEL,20,FEAROW
	db 0 ; no more evolutions
	db 1,PECK
	db 1,GROWL
	db 7,LEER
	db 13,FURY_ATTACK
	db 25,PURSUIT
	db 31,MIRROR_MOVE
	db 37,DRILL_PECK
	db 43,AGILITY
	db 0 ; no more level-up moves

FearowEvosAttacks:
	db 0 ; no more evolutions
	db 1,PECK
	db 1,GROWL
	db 1,LEER
	db 1,FURY_ATTACK
	db 7,LEER
	db 13,FURY_ATTACK
	db 26,PURSUIT
	db 32,MIRROR_MOVE
	db 40,DRILL_PECK
	db 47,AGILITY
	db 0 ; no more level-up moves

EkansEvosAttacks:
	db EVOLVE_LEVEL,22,ARBOK
	db 0 ; no more evolutions
	db 1,WRAP
	db 1,LEER
	db 9,POISON_STING
	db 15,BITE
	db 23,GLARE
	db 29,SCREECH
	db 37,ACID
	db 43,HAZE
	db 0 ; no more level-up moves

ArbokEvosAttacks:
	db 0 ; no more evolutions
	db 1,WRAP
	db 1,LEER
	db 1,POISON_STING
	db 1,BITE
	db 9,POISON_STING
	db 15,BITE
	db 25,GLARE
	db 33,SCREECH
	db 43,ACID
	db 51,HAZE
	db 0 ; no more level-up moves

PikachuEvosAttacks:
	db EVOLVE_ITEM,THUNDERSTONE,RAICHU
	db 0 ; no more evolutions
	db 1,THUNDERSHOCK
	db 1,GROWL
	db 6,TAIL_WHIP
	db 8,THUNDER_WAVE
	db 11,QUICK_ATTACK
	db 15,DOUBLE_TEAM
	db 20,SLAM
	db 26,THUNDERBOLT
	db 33,AGILITY
	db 41,THUNDER
	db 50,LIGHT_SCREEN
	db 0 ; no more level-up moves

RaichuEvosAttacks:
	db 0 ; no more evolutions
	db 1,THUNDERSHOCK
	db 1,TAIL_WHIP
	db 1,QUICK_ATTACK
	db 1,THUNDERBOLT
	db 0 ; no more level-up moves

SandshrewEvosAttacks:
	db EVOLVE_LEVEL,22,SANDSLASH
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 6,DEFENSE_CURL
	db 11,SAND_ATTACK
	db 17,POISON_STING
	db 23,SLASH
	db 30,SWIFT
	db 37,FURY_SWIPES
	db 45,SANDSTORM
	db 0 ; no more level-up moves

SandslashEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,DEFENSE_CURL
	db 1,SAND_ATTACK
	db 6,DEFENSE_CURL
	db 11,SAND_ATTACK
	db 17,POISON_STING
	db 24,SLASH
	db 33,SWIFT
	db 42,FURY_SWIPES
	db 52,SANDSTORM
	db 0 ; no more level-up moves

NidoranFEvosAttacks:
	db EVOLVE_LEVEL,16,NIDORINA
	db 0 ; no more evolutions
	db 1,GROWL
	db 1,TACKLE
	db 8,SCRATCH
	db 12,DOUBLE_KICK
	db 17,POISON_STING
	db 23,TAIL_WHIP
	db 30,BITE
	db 38,FURY_SWIPES
	db 0 ; no more level-up moves

NidorinaEvosAttacks:
	db EVOLVE_ITEM,MOON_STONE,NIDOQUEEN
	db 0 ; no more evolutions
	db 1,GROWL
	db 1,TACKLE
	db 8,SCRATCH
	db 12,DOUBLE_KICK
	db 19,POISON_STING
	db 27,TAIL_WHIP
	db 36,BITE
	db 46,FURY_SWIPES
	db 0 ; no more level-up moves

NidoqueenEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,SCRATCH
	db 1,DOUBLE_KICK
	db 1,TAIL_WHIP
	db 23,BODY_SLAM
	db 0 ; no more level-up moves

NidoranMEvosAttacks:
	db EVOLVE_LEVEL,16,NIDORINO
	db 0 ; no more evolutions
	db 1,LEER
	db 1,TACKLE
	db 8,HORN_ATTACK
	db 12,DOUBLE_KICK
	db 17,POISON_STING
	db 23,FOCUS_ENERGY
	db 30,FURY_ATTACK
	db 38,HORN_DRILL
	db 0 ; no more level-up moves

NidorinoEvosAttacks:
	db EVOLVE_ITEM,MOON_STONE,NIDOKING
	db 0 ; no more evolutions
	db 1,LEER
	db 1,TACKLE
	db 8,HORN_ATTACK
	db 12,DOUBLE_KICK
	db 19,POISON_STING
	db 27,FOCUS_ENERGY
	db 36,FURY_ATTACK
	db 46,HORN_DRILL
	db 0 ; no more level-up moves

NidokingEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,HORN_ATTACK
	db 1,DOUBLE_KICK
	db 1,POISON_STING
	db 23,THRASH
	db 0 ; no more level-up moves

ClefairyEvosAttacks:
	db EVOLVE_ITEM,MOON_STONE,CLEFABLE
	db 0 ; no more evolutions
	db 1,POUND
	db 1,GROWL
	db 4,ENCORE
	db 8,SING
	db 13,DOUBLESLAP
	db 19,MINIMIZE
	db 26,DEFENSE_CURL
	db 34,METRONOME
	db 43,MOONLIGHT
	db 53,LIGHT_SCREEN
	db 0 ; no more level-up moves

ClefableEvosAttacks:
	db 0 ; no more evolutions
	db 1,SING
	db 1,DOUBLESLAP
	db 1,METRONOME
	db 1,MOONLIGHT
	db 0 ; no more level-up moves

VulpixEvosAttacks:
	db EVOLVE_ITEM,FIRE_STONE,NINETALES
	db 0 ; no more evolutions
	db 1,EMBER
	db 1,TAIL_WHIP
	db 7,QUICK_ATTACK
	db 13,ROAR
	db 19,CONFUSE_RAY
	db 25,SAFEGUARD
	db 31,FLAMETHROWER
	db 37,FIRE_SPIN
	db 0 ; no more level-up moves

NinetalesEvosAttacks:
	db 0 ; no more evolutions
	db 1,EMBER
	db 1,QUICK_ATTACK
	db 1,CONFUSE_RAY
	db 1,SAFEGUARD
	db 43,FIRE_SPIN
	db 0 ; no more level-up moves

JigglypuffEvosAttacks:
	db EVOLVE_ITEM,MOON_STONE,WIGGLYTUFF
	db 0 ; no more evolutions
	db 1,SING
	db 4,DEFENSE_CURL
	db 9,POUND
	db 14,DISABLE
	db 19,ROLLOUT
	db 24,DOUBLESLAP
	db 29,REST
	db 34,BODY_SLAM
	db 39,DOUBLE_EDGE
	db 0 ; no more level-up moves

WigglytuffEvosAttacks:
	db 0 ; no more evolutions
	db 1,SING
	db 1,DISABLE
	db 1,DEFENSE_CURL
	db 1,DOUBLESLAP
	db 0 ; no more level-up moves

ZubatEvosAttacks:
	db EVOLVE_LEVEL,22,GOLBAT
	db 0 ; no more evolutions
	db 1,LEECH_LIFE
	db 6,SUPERSONIC
	db 12,BITE
	db 19,CONFUSE_RAY
	db 27,WING_ATTACK
	db 36,MEAN_LOOK
	db 46,HAZE
	db 0 ; no more level-up moves

GolbatEvosAttacks:
	db EVOLVE_HAPPINESS,TR_ANYTIME,CROBAT
	db 0 ; no more evolutions
	db 1,SCREECH
	db 1,LEECH_LIFE
	db 1,SUPERSONIC
	db 6,SUPERSONIC
	db 12,BITE
	db 19,CONFUSE_RAY
	db 30,WING_ATTACK
	db 42,MEAN_LOOK
	db 55,HAZE
	db 0 ; no more level-up moves

OddishEvosAttacks:
	db EVOLVE_LEVEL,21,GLOOM
	db 0 ; no more evolutions
	db 1,ABSORB
	db 7,SWEET_SCENT
	db 14,POISONPOWDER
	db 16,STUN_SPORE
	db 18,SLEEP_POWDER
	db 23,ACID
	db 32,MOONLIGHT
	db 39,PETAL_DANCE
	db 0 ; no more level-up moves

GloomEvosAttacks:
	db EVOLVE_ITEM,LEAF_STONE,VILEPLUME
	db EVOLVE_ITEM,SUN_STONE,BELLOSSOM
	db 0 ; no more evolutions
	db 1,ABSORB
	db 1,SWEET_SCENT
	db 1,POISONPOWDER
	db 7,SWEET_SCENT
	db 14,POISONPOWDER
	db 16,STUN_SPORE
	db 18,SLEEP_POWDER
	db 24,ACID
	db 35,MOONLIGHT
	db 44,PETAL_DANCE
	db 0 ; no more level-up moves

VileplumeEvosAttacks:
	db 0 ; no more evolutions
	db 1,ABSORB
	db 1,SWEET_SCENT
	db 1,STUN_SPORE
	db 1,PETAL_DANCE
	db 0 ; no more level-up moves

ParasEvosAttacks:
	db EVOLVE_LEVEL,24,PARASECT
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 7,STUN_SPORE
	db 13,POISONPOWDER
	db 19,LEECH_LIFE
	db 25,SPORE
	db 31,SLASH
	db 37,GROWTH
	db 43,GIGA_DRAIN
	db 0 ; no more level-up moves

ParasectEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,STUN_SPORE
	db 1,POISONPOWDER
	db 7,STUN_SPORE
	db 13,POISONPOWDER
	db 19,LEECH_LIFE
	db 28,SPORE
	db 37,SLASH
	db 46,GROWTH
	db 55,GIGA_DRAIN
	db 0 ; no more level-up moves

VenonatEvosAttacks:
	db EVOLVE_LEVEL,31,VENOMOTH
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,DISABLE
	db 1,FORESIGHT
	db 9,SUPERSONIC
	db 17,CONFUSION
	db 20,POISONPOWDER
	db 25,LEECH_LIFE
	db 28,STUN_SPORE
	db 33,PSYBEAM
	db 36,SLEEP_POWDER
	db 41,PSYCHIC_M
	db 0 ; no more level-up moves

VenomothEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,DISABLE
	db 1,FORESIGHT
	db 1,SUPERSONIC
	db 9,SUPERSONIC
	db 17,CONFUSION
	db 20,POISONPOWDER
	db 25,LEECH_LIFE
	db 28,STUN_SPORE
	db 31,GUST
	db 36,PSYBEAM
	db 42,SLEEP_POWDER
	db 52,PSYCHIC_M
	db 0 ; no more level-up moves

DiglettEvosAttacks:
	db EVOLVE_LEVEL,26,DUGTRIO
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 5,GROWL
	db 9,MAGNITUDE
	db 17,DIG
	db 25,SAND_ATTACK
	db 33,SLASH
	db 41,EARTHQUAKE
	db 49,FISSURE
	db 0 ; no more level-up moves

DugtrioEvosAttacks:
	db 0 ; no more evolutions
if _CRYSTAL
	db 1,TRI_ATTACK
endc
	db 1,SCRATCH
	db 1,GROWL
	db 1,MAGNITUDE
	db 5,GROWL
	db 9,MAGNITUDE
	db 17,DIG
	db 25,SAND_ATTACK
	db 37,SLASH
	db 49,EARTHQUAKE
	db 61,FISSURE
	db 0 ; no more level-up moves

MeowthEvosAttacks:
	db EVOLVE_LEVEL,28,PERSIAN
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,GROWL
	db 11,BITE
	db 20,PAY_DAY
	db 28,FAINT_ATTACK
	db 35,SCREECH
	db 41,FURY_SWIPES
	db 46,SLASH
	db 0 ; no more level-up moves

PersianEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,GROWL
	db 1,BITE
	db 11,BITE
	db 20,PAY_DAY
	db 29,FAINT_ATTACK
	db 38,SCREECH
	db 46,FURY_SWIPES
	db 53,SLASH
	db 0 ; no more level-up moves

PsyduckEvosAttacks:
	db EVOLVE_LEVEL,33,GOLDUCK
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 5,TAIL_WHIP
	db 10,DISABLE
	db 16,CONFUSION
	db 23,SCREECH
	db 31,PSYCH_UP
	db 40,FURY_SWIPES
	db 50,HYDRO_PUMP
	db 0 ; no more level-up moves

GolduckEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,TAIL_WHIP
	db 1,DISABLE
	db 1,CONFUSION
	db 5,TAIL_WHIP
	db 10,DISABLE
	db 16,CONFUSION
	db 23,SCREECH
	db 31,PSYCH_UP
	db 44,FURY_SWIPES
	db 58,HYDRO_PUMP
	db 0 ; no more level-up moves

MankeyEvosAttacks:
	db EVOLVE_LEVEL,28,PRIMEAPE
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,LEER
	db 9,LOW_KICK
	db 15,KARATE_CHOP
	db 21,FURY_SWIPES
	db 27,FOCUS_ENERGY
	db 33,SEISMIC_TOSS
	db 39,CROSS_CHOP
	db 45,SCREECH
	db 51,THRASH
	db 0 ; no more level-up moves

PrimeapeEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,LEER
	db 1,LOW_KICK
	db 1,RAGE
	db 9,LOW_KICK
	db 15,KARATE_CHOP
	db 21,FURY_SWIPES
	db 27,FOCUS_ENERGY
	db 28,RAGE
	db 36,SEISMIC_TOSS
	db 45,CROSS_CHOP
	db 54,SCREECH
	db 63,THRASH
	db 0 ; no more level-up moves

GrowlitheEvosAttacks:
	db EVOLVE_ITEM,FIRE_STONE,ARCANINE
	db 0 ; no more evolutions
	db 1,BITE
	db 1,ROAR
	db 9,EMBER
	db 18,LEER
	db 26,TAKE_DOWN
	db 34,FLAME_WHEEL
	db 42,AGILITY
	db 50,FLAMETHROWER
	db 0 ; no more level-up moves

ArcanineEvosAttacks:
	db 0 ; no more evolutions
	db 1,ROAR
	db 1,LEER
	db 1,TAKE_DOWN
	db 1,FLAME_WHEEL
	db 50,EXTREMESPEED
	db 0 ; no more level-up moves

PoliwagEvosAttacks:
	db EVOLVE_LEVEL,25,POLIWHIRL
	db 0 ; no more evolutions
	db 1,BUBBLE
	db 7,HYPNOSIS
	db 13,WATER_GUN
	db 19,DOUBLESLAP
	db 25,RAIN_DANCE
	db 31,BODY_SLAM
	db 37,BELLY_DRUM
	db 43,HYDRO_PUMP
	db 0 ; no more level-up moves

PoliwhirlEvosAttacks:
	db EVOLVE_ITEM,WATER_STONE,POLIWRATH
	db EVOLVE_TRADE,KINGS_ROCK,POLITOED
	db 0 ; no more evolutions
	db 1,BUBBLE
	db 1,HYPNOSIS
	db 1,WATER_GUN
	db 7,HYPNOSIS
	db 13,WATER_GUN
	db 19,DOUBLESLAP
	db 27,RAIN_DANCE
	db 35,BODY_SLAM
	db 43,BELLY_DRUM
	db 51,HYDRO_PUMP
	db 0 ; no more level-up moves

PoliwrathEvosAttacks:
	db 0 ; no more evolutions
	db 1,WATER_GUN
	db 1,HYPNOSIS
	db 1,DOUBLESLAP
	db 1,SUBMISSION
	db 35,SUBMISSION
	db 51,MIND_READER
	db 0 ; no more level-up moves

AbraEvosAttacks:
	db EVOLVE_LEVEL,16,KADABRA
	db 0 ; no more evolutions
	db 1,TELEPORT
	db 0 ; no more level-up moves

KadabraEvosAttacks:
	db EVOLVE_TRADE,$ff,ALAKAZAM
	db 0 ; no more evolutions
	db 1,TELEPORT
	db 1,KINESIS
	db 1,CONFUSION
	db 16,CONFUSION
	db 18,DISABLE
	db 21,PSYBEAM
	db 26,RECOVER
	db 31,FUTURE_SIGHT
	db 38,PSYCHIC_M
	db 45,REFLECT
	db 0 ; no more level-up moves

AlakazamEvosAttacks:
	db 0 ; no more evolutions
	db 1,TELEPORT
	db 1,KINESIS
	db 1,CONFUSION
	db 16,CONFUSION
	db 18,DISABLE
	db 21,PSYBEAM
	db 26,RECOVER
	db 31,FUTURE_SIGHT
	db 38,PSYCHIC_M
	db 45,REFLECT
	db 0 ; no more level-up moves

MachopEvosAttacks:
	db EVOLVE_LEVEL,28,MACHOKE
	db 0 ; no more evolutions
	db 1,LOW_KICK
	db 1,LEER
	db 7,FOCUS_ENERGY
	db 13,KARATE_CHOP
	db 19,SEISMIC_TOSS
	db 25,FORESIGHT
	db 31,VITAL_THROW
	db 37,CROSS_CHOP
	db 43,SCARY_FACE
	db 49,SUBMISSION
	db 0 ; no more level-up moves

MachokeEvosAttacks:
	db EVOLVE_TRADE,$ff,MACHAMP
	db 0 ; no more evolutions
	db 1,LOW_KICK
	db 1,LEER
	db 1,FOCUS_ENERGY
	db 8,FOCUS_ENERGY
	db 15,KARATE_CHOP
	db 19,SEISMIC_TOSS
	db 25,FORESIGHT
	db 34,VITAL_THROW
	db 43,CROSS_CHOP
	db 52,SCARY_FACE
	db 61,SUBMISSION
	db 0 ; no more level-up moves

MachampEvosAttacks:
	db 0 ; no more evolutions
	db 1,LOW_KICK
	db 1,LEER
	db 1,FOCUS_ENERGY
	db 8,FOCUS_ENERGY
	db 15,KARATE_CHOP
	db 19,SEISMIC_TOSS
	db 25,FORESIGHT
	db 34,VITAL_THROW
	db 43,CROSS_CHOP
	db 52,SCARY_FACE
	db 61,SUBMISSION
	db 0 ; no more level-up moves

BellsproutEvosAttacks:
	db EVOLVE_LEVEL,21,WEEPINBELL
	db 0 ; no more evolutions
	db 1,VINE_WHIP
	db 6,GROWTH
	db 11,WRAP
	db 15,SLEEP_POWDER
	db 17,POISONPOWDER
	db 19,STUN_SPORE
	db 23,ACID
	db 30,SWEET_SCENT
	db 37,RAZOR_LEAF
	db 45,SLAM
	db 0 ; no more level-up moves

WeepinbellEvosAttacks:
	db EVOLVE_ITEM,LEAF_STONE,VICTREEBEL
	db 0 ; no more evolutions
	db 1,VINE_WHIP
	db 1,GROWTH
	db 1,WRAP
	db 6,GROWTH
	db 11,WRAP
	db 15,SLEEP_POWDER
	db 17,POISONPOWDER
	db 19,STUN_SPORE
	db 24,ACID
	db 33,SWEET_SCENT
	db 42,RAZOR_LEAF
	db 54,SLAM
	db 0 ; no more level-up moves

VictreebelEvosAttacks:
	db 0 ; no more evolutions
	db 1,VINE_WHIP
	db 1,SLEEP_POWDER
	db 1,SWEET_SCENT
	db 1,RAZOR_LEAF
	db 0 ; no more level-up moves

TentacoolEvosAttacks:
	db EVOLVE_LEVEL,30,TENTACRUEL
	db 0 ; no more evolutions
	db 1,POISON_STING
	db 6,SUPERSONIC
	db 12,CONSTRICT
	db 19,ACID
	db 25,BUBBLEBEAM
	db 30,WRAP
	db 36,BARRIER
	db 43,SCREECH
	db 49,HYDRO_PUMP
	db 0 ; no more level-up moves

TentacruelEvosAttacks:
	db 0 ; no more evolutions
	db 1,POISON_STING
	db 1,SUPERSONIC
	db 1,CONSTRICT
	db 6,SUPERSONIC
	db 12,CONSTRICT
	db 19,ACID
	db 25,BUBBLEBEAM
	db 30,WRAP
	db 38,BARRIER
	db 47,SCREECH
	db 55,HYDRO_PUMP
	db 0 ; no more level-up moves

GeodudeEvosAttacks:
	db EVOLVE_LEVEL,25,GRAVELER
	db 0 ; no more evolutions
	db 1,TACKLE
	db 6,DEFENSE_CURL
	db 11,ROCK_THROW
	db 16,MAGNITUDE
	db 21,SELFDESTRUCT
	db 26,HARDEN
	db 31,ROLLOUT
	db 36,EARTHQUAKE
	db 41,EXPLOSION
	db 0 ; no more level-up moves

GravelerEvosAttacks:
	db EVOLVE_TRADE,$ff,GOLEM
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,DEFENSE_CURL
	db 1,ROCK_THROW
	db 6,DEFENSE_CURL
	db 11,ROCK_THROW
	db 16,MAGNITUDE
	db 21,SELFDESTRUCT
	db 27,HARDEN
	db 34,ROLLOUT
	db 41,EARTHQUAKE
	db 48,EXPLOSION
	db 0 ; no more level-up moves

GolemEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,DEFENSE_CURL
	db 1,ROCK_THROW
	db 1,MAGNITUDE
	db 6,DEFENSE_CURL
	db 11,ROCK_THROW
	db 16,MAGNITUDE
	db 21,SELFDESTRUCT
	db 27,HARDEN
	db 34,ROLLOUT
	db 41,EARTHQUAKE
	db 48,EXPLOSION
	db 0 ; no more level-up moves

PonytaEvosAttacks:
	db EVOLVE_LEVEL,40,RAPIDASH
	db 0 ; no more evolutions
	db 1,TACKLE
	db 4,GROWL
	db 8,TAIL_WHIP
	db 13,EMBER
	db 19,STOMP
	db 26,FIRE_SPIN
	db 34,TAKE_DOWN
	db 43,AGILITY
	db 53,FIRE_BLAST
	db 0 ; no more level-up moves

RapidashEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 1,TAIL_WHIP
	db 1,EMBER
	db 4,GROWL
	db 8,TAIL_WHIP
	db 13,EMBER
	db 19,STOMP
	db 26,FIRE_SPIN
	db 34,TAKE_DOWN
	db 40,FURY_ATTACK
	db 47,AGILITY
	db 61,FIRE_BLAST
	db 0 ; no more level-up moves

SlowpokeEvosAttacks:
	db EVOLVE_LEVEL,37,SLOWBRO
	db EVOLVE_TRADE,KINGS_ROCK,SLOWKING
	db 0 ; no more evolutions
	db 1,CURSE
	db 1,TACKLE
	db 6,GROWL
	db 15,WATER_GUN
	db 20,CONFUSION
	db 29,DISABLE
	db 34,HEADBUTT
	db 43,AMNESIA
	db 48,PSYCHIC_M
	db 0 ; no more level-up moves

SlowbroEvosAttacks:
	db 0 ; no more evolutions
	db 1,CURSE
	db 1,TACKLE
	db 1,GROWL
	db 1,WATER_GUN
	db 6,GROWL
	db 15,WATER_GUN
	db 20,CONFUSION
	db 29,DISABLE
	db 34,HEADBUTT
	db 37,WITHDRAW
	db 46,AMNESIA
	db 54,PSYCHIC_M
	db 0 ; no more level-up moves

MagnemiteEvosAttacks:
	db EVOLVE_LEVEL,30,MAGNETON
	db 0 ; no more evolutions
	db 1,TACKLE
	db 6,THUNDERSHOCK
	db 11,SUPERSONIC
	db 16,SONICBOOM
	db 21,THUNDER_WAVE
	db 27,LOCK_ON
	db 33,SWIFT
	db 39,SCREECH
	db 45,ZAP_CANNON
	db 0 ; no more level-up moves

MagnetonEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,THUNDERSHOCK
	db 1,SUPERSONIC
	db 1,SONICBOOM
	db 6,THUNDERSHOCK
	db 11,SUPERSONIC
	db 16,SONICBOOM
	db 21,THUNDER_WAVE
	db 27,LOCK_ON
if _CRYSTAL
	db 35,TRI_ATTACK
else
	db 35,SWIFT
endc
	db 43,SCREECH
	db 53,ZAP_CANNON
	db 0 ; no more level-up moves

FarfetchDEvosAttacks:
	db 0 ; no more evolutions
	db 1,PECK
	db 7,SAND_ATTACK
	db 13,LEER
	db 19,FURY_ATTACK
	db 25,SWORDS_DANCE
	db 31,AGILITY
	db 37,SLASH
	db 44,FALSE_SWIPE
	db 0 ; no more level-up moves

DoduoEvosAttacks:
	db EVOLVE_LEVEL,31,DODRIO
	db 0 ; no more evolutions
	db 1,PECK
	db 1,GROWL
	db 9,PURSUIT
	db 13,FURY_ATTACK
	db 21,TRI_ATTACK
	db 25,RAGE
	db 33,DRILL_PECK
	db 37,AGILITY
	db 0 ; no more level-up moves

DodrioEvosAttacks:
	db 0 ; no more evolutions
	db 1,PECK
	db 1,GROWL
	db 1,PURSUIT
	db 1,FURY_ATTACK
	db 9,PURSUIT
	db 13,FURY_ATTACK
	db 21,TRI_ATTACK
	db 25,RAGE
	db 38,DRILL_PECK
	db 47,AGILITY
	db 0 ; no more level-up moves

SeelEvosAttacks:
	db EVOLVE_LEVEL,34,DEWGONG
	db 0 ; no more evolutions
	db 1,HEADBUTT
	db 5,GROWL
	db 16,AURORA_BEAM
	db 21,REST
	db 32,TAKE_DOWN
	db 37,ICE_BEAM
	db 48,SAFEGUARD
	db 0 ; no more level-up moves

DewgongEvosAttacks:
	db 0 ; no more evolutions
	db 1,HEADBUTT
	db 1,GROWL
	db 1,AURORA_BEAM
	db 5,GROWL
	db 16,AURORA_BEAM
	db 21,REST
	db 32,TAKE_DOWN
	db 43,ICE_BEAM
	db 60,SAFEGUARD
	db 0 ; no more level-up moves

GrimerEvosAttacks:
	db EVOLVE_LEVEL,38,MUK
	db 0 ; no more evolutions
	db 1,POISON_GAS
	db 1,POUND
	db 5,HARDEN
	db 10,DISABLE
	db 16,SLUDGE
	db 23,MINIMIZE
	db 31,SCREECH
	db 40,ACID_ARMOR
	db 50,SLUDGE_BOMB
	db 0 ; no more level-up moves

MukEvosAttacks:
	db 0 ; no more evolutions
	db 1,POISON_GAS
	db 1,POUND
	db 1,HARDEN
	db 33,HARDEN
	db 37,DISABLE
	db 45,SLUDGE
	db 23,MINIMIZE
	db 31,SCREECH
	db 45,ACID_ARMOR
	db 60,SLUDGE_BOMB
	db 0 ; no more level-up moves

ShellderEvosAttacks:
	db EVOLVE_ITEM,WATER_STONE,CLOYSTER
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,WITHDRAW
	db 9,SUPERSONIC
	db 17,AURORA_BEAM
	db 25,PROTECT
	db 33,LEER
	db 41,CLAMP
	db 49,ICE_BEAM
	db 0 ; no more level-up moves

CloysterEvosAttacks:
	db 0 ; no more evolutions
	db 1,WITHDRAW
	db 1,SUPERSONIC
	db 1,AURORA_BEAM
	db 1,PROTECT
if _CRYSTAL
	db 33,SPIKES
endc
	db 41,SPIKE_CANNON
	db 0 ; no more level-up moves

GastlyEvosAttacks:
	db EVOLVE_LEVEL,25,HAUNTER
	db 0 ; no more evolutions
	db 1,HYPNOSIS
	db 1,LICK
	db 8,SPITE
	db 13,MEAN_LOOK
	db 16,CURSE
	db 21,NIGHT_SHADE
	db 28,CONFUSE_RAY
	db 33,DREAM_EATER
	db 36,DESTINY_BOND
	db 0 ; no more level-up moves

HaunterEvosAttacks:
	db EVOLVE_TRADE,$ff,GENGAR
	db 0 ; no more evolutions
	db 1,HYPNOSIS
	db 1,LICK
	db 1,SPITE
	db 8,SPITE
	db 13,MEAN_LOOK
	db 16,CURSE
	db 21,NIGHT_SHADE
	db 31,CONFUSE_RAY
	db 39,DREAM_EATER
	db 48,DESTINY_BOND
	db 0 ; no more level-up moves

GengarEvosAttacks:
	db 0 ; no more evolutions
	db 1,HYPNOSIS
	db 1,LICK
	db 1,SPITE
	db 8,SPITE
	db 13,MEAN_LOOK
	db 16,CURSE
	db 21,NIGHT_SHADE
	db 31,CONFUSE_RAY
	db 39,DREAM_EATER
	db 48,DESTINY_BOND
	db 0 ; no more level-up moves

OnixEvosAttacks:
	db EVOLVE_TRADE,METAL_COAT,STEELIX
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,SCREECH
	db 10,BIND
	db 14,ROCK_THROW
	db 23,HARDEN
	db 27,RAGE
	db 36,SANDSTORM
	db 40,SLAM
	db 0 ; no more level-up moves

DrowzeeEvosAttacks:
	db EVOLVE_LEVEL,26,HYPNO
	db 0 ; no more evolutions
	db 1,POUND
	db 1,HYPNOSIS
	db 10,DISABLE
	db 18,CONFUSION
	db 25,HEADBUTT
	db 31,POISON_GAS
	db 36,MEDITATE
	db 40,PSYCHIC_M
	db 43,PSYCH_UP
	db 45,FUTURE_SIGHT
	db 0 ; no more level-up moves

HypnoEvosAttacks:
	db 0 ; no more evolutions
	db 1,POUND
	db 1,HYPNOSIS
	db 1,DISABLE
	db 1,CONFUSION
	db 10,DISABLE
	db 18,CONFUSION
	db 25,HEADBUTT
	db 33,POISON_GAS
	db 40,MEDITATE
	db 49,PSYCHIC_M
	db 55,PSYCH_UP
	db 60,FUTURE_SIGHT
	db 0 ; no more level-up moves

KrabbyEvosAttacks:
	db EVOLVE_LEVEL,28,KINGLER
	db 0 ; no more evolutions
	db 1,BUBBLE
	db 5,LEER
	db 12,VICEGRIP
	db 16,HARDEN
	db 23,STOMP
	db 27,GUILLOTINE
	db 34,PROTECT
	db 41,CRABHAMMER
	db 0 ; no more level-up moves

KinglerEvosAttacks:
	db 0 ; no more evolutions
	db 1,BUBBLE
	db 1,LEER
	db 1,VICEGRIP
	db 5,LEER
	db 12,VICEGRIP
	db 16,HARDEN
	db 23,STOMP
	db 27,GUILLOTINE
	db 38,PROTECT
	db 49,CRABHAMMER
	db 0 ; no more level-up moves

VoltorbEvosAttacks:
	db EVOLVE_LEVEL,30,ELECTRODE
	db 0 ; no more evolutions
	db 1,TACKLE
	db 9,SCREECH
	db 17,SONICBOOM
	db 23,SELFDESTRUCT
	db 29,ROLLOUT
	db 33,LIGHT_SCREEN
	db 37,SWIFT
	db 39,EXPLOSION
	db 41,MIRROR_COAT
	db 0 ; no more level-up moves

ElectrodeEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,SCREECH
	db 1,SONICBOOM
	db 1,SELFDESTRUCT
	db 9,SCREECH
	db 17,SONICBOOM
	db 23,SELFDESTRUCT
	db 29,ROLLOUT
	db 34,LIGHT_SCREEN
	db 40,SWIFT
	db 44,EXPLOSION
	db 48,MIRROR_COAT
	db 0 ; no more level-up moves

ExeggcuteEvosAttacks:
	db EVOLVE_ITEM,LEAF_STONE,EXEGGUTOR
	db 0 ; no more evolutions
	db 1,BARRAGE
	db 1,HYPNOSIS
	db 7,REFLECT
	db 13,LEECH_SEED
	db 19,CONFUSION
	db 25,STUN_SPORE
	db 31,POISONPOWDER
	db 37,SLEEP_POWDER
	db 43,SOLARBEAM
	db 0 ; no more level-up moves

ExeggutorEvosAttacks:
	db 0 ; no more evolutions
	db 1,BARRAGE
	db 1,HYPNOSIS
	db 1,CONFUSION
	db 19,STOMP
	db 31,EGG_BOMB
	db 0 ; no more level-up moves

CuboneEvosAttacks:
	db EVOLVE_LEVEL,28,MAROWAK
	db 0 ; no more evolutions
	db 1,GROWL
	db 5,TAIL_WHIP
	db 9,BONE_CLUB
	db 13,HEADBUTT
	db 17,LEER
	db 21,FOCUS_ENERGY
	db 25,BONEMERANG
	db 29,RAGE
	db 33,FALSE_SWIPE
	db 37,THRASH
	db 41,BONE_RUSH
	db 0 ; no more level-up moves

MarowakEvosAttacks:
	db 0 ; no more evolutions
	db 1,GROWL
	db 1,TAIL_WHIP
	db 1,BONE_CLUB
	db 1,HEADBUTT
	db 5,TAIL_WHIP
	db 9,BONE_CLUB
	db 13,HEADBUTT
	db 17,LEER
	db 21,FOCUS_ENERGY
	db 25,BONEMERANG
	db 32,RAGE
	db 39,FALSE_SWIPE
	db 46,THRASH
	db 53,BONE_RUSH
	db 0 ; no more level-up moves

HitmonleeEvosAttacks:
	db 0 ; no more evolutions
	db 1,DOUBLE_KICK
	db 6,MEDITATE
	db 11,ROLLING_KICK
	db 16,JUMP_KICK
	db 21,FOCUS_ENERGY
	db 26,HI_JUMP_KICK
	db 31,MIND_READER
	db 36,FORESIGHT
	db 41,ENDURE
	db 46,MEGA_KICK
	db 51,REVERSAL
	db 0 ; no more level-up moves

HitmonchanEvosAttacks:
	db 0 ; no more evolutions
	db 1,COMET_PUNCH
	db 7,AGILITY
	db 13,PURSUIT
	db 26,THUNDERPUNCH
	db 26,ICE_PUNCH
	db 26,FIRE_PUNCH
	db 32,MACH_PUNCH
	db 38,MEGA_PUNCH
	db 44,DETECT
	db 50,COUNTER
	db 0 ; no more level-up moves

LickitungEvosAttacks:
	db 0 ; no more evolutions
	db 1,LICK
	db 7,SUPERSONIC
	db 13,DEFENSE_CURL
	db 19,STOMP
	db 25,WRAP
	db 31,DISABLE
	db 37,SLAM
	db 43,SCREECH
	db 0 ; no more level-up moves

KoffingEvosAttacks:
	db EVOLVE_LEVEL,35,WEEZING
	db 0 ; no more evolutions
	db 1,POISON_GAS
	db 1,TACKLE
	db 9,SMOG
	db 17,SELFDESTRUCT
	db 21,SLUDGE
	db 25,SMOKESCREEN
	db 33,HAZE
	db 41,EXPLOSION
	db 45,DESTINY_BOND
	db 0 ; no more level-up moves

WeezingEvosAttacks:
	db 0 ; no more evolutions
	db 1,POISON_GAS
	db 1,TACKLE
	db 1,SMOG
	db 1,SELFDESTRUCT
	db 9,SMOG
	db 17,SELFDESTRUCT
	db 21,SLUDGE
	db 25,SMOKESCREEN
	db 33,HAZE
	db 44,EXPLOSION
	db 51,DESTINY_BOND
	db 0 ; no more level-up moves

RhyhornEvosAttacks:
	db EVOLVE_LEVEL,42,RHYDON
	db 0 ; no more evolutions
	db 1,HORN_ATTACK
	db 1,TAIL_WHIP
	db 13,STOMP
	db 19,FURY_ATTACK
	db 31,SCARY_FACE
	db 37,HORN_DRILL
	db 49,TAKE_DOWN
	db 55,EARTHQUAKE
	db 0 ; no more level-up moves

RhydonEvosAttacks:
	db 0 ; no more evolutions
	db 1,HORN_ATTACK
	db 1,TAIL_WHIP
	db 1,STOMP
	db 1,FURY_ATTACK
	db 13,STOMP
	db 19,FURY_ATTACK
	db 31,SCARY_FACE
	db 37,HORN_DRILL
	db 54,TAKE_DOWN
	db 65,EARTHQUAKE
	db 0 ; no more level-up moves

ChanseyEvosAttacks:
	db EVOLVE_HAPPINESS,TR_ANYTIME,BLISSEY
	db 0 ; no more evolutions
	db 1,POUND
	db 5,GROWL
	db 9,TAIL_WHIP
	db 13,SOFTBOILED
	db 17,DOUBLESLAP
	db 23,MINIMIZE
	db 29,SING
	db 35,EGG_BOMB
	db 41,DEFENSE_CURL
	db 49,LIGHT_SCREEN
	db 57,DOUBLE_EDGE
	db 0 ; no more level-up moves

TangelaEvosAttacks:
	db 0 ; no more evolutions
	db 1,CONSTRICT
	db 4,SLEEP_POWDER
	db 10,ABSORB
	db 13,POISONPOWDER
	db 19,VINE_WHIP
	db 25,BIND
	db 31,MEGA_DRAIN
	db 34,STUN_SPORE
	db 40,SLAM
	db 46,GROWTH
	db 0 ; no more level-up moves

KangaskhanEvosAttacks:
	db 0 ; no more evolutions
	db 1,COMET_PUNCH
	db 7,LEER
	db 13,BITE
	db 19,TAIL_WHIP
	db 25,MEGA_PUNCH
	db 31,RAGE
	db 37,ENDURE
	db 43,DIZZY_PUNCH
	db 49,REVERSAL
	db 0 ; no more level-up moves

HorseaEvosAttacks:
	db EVOLVE_LEVEL,32,SEADRA
	db 0 ; no more evolutions
	db 1,BUBBLE
	db 8,SMOKESCREEN
	db 15,LEER
	db 22,WATER_GUN
	db 29,TWISTER
	db 36,AGILITY
	db 43,HYDRO_PUMP
	db 0 ; no more level-up moves

SeadraEvosAttacks:
	db EVOLVE_TRADE,DRAGON_SCALE,KINGDRA
	db 0 ; no more evolutions
	db 1,BUBBLE
	db 1,SMOKESCREEN
	db 1,LEER
	db 1,WATER_GUN
	db 8,SMOKESCREEN
	db 15,LEER
	db 22,WATER_GUN
	db 29,TWISTER
	db 40,AGILITY
	db 51,HYDRO_PUMP
	db 0 ; no more level-up moves

GoldeenEvosAttacks:
	db EVOLVE_LEVEL,33,SEAKING
	db 0 ; no more evolutions
	db 1,PECK
	db 1,TAIL_WHIP
	db 10,SUPERSONIC
	db 15,HORN_ATTACK
	db 24,FLAIL
	db 29,FURY_ATTACK
	db 38,WATERFALL
	db 43,HORN_DRILL
	db 52,AGILITY
	db 0 ; no more level-up moves

SeakingEvosAttacks:
	db 0 ; no more evolutions
	db 1,PECK
	db 1,TAIL_WHIP
	db 1,TAIL_WHIP
	db 10,SUPERSONIC
	db 15,HORN_ATTACK
	db 24,FLAIL
	db 29,FURY_ATTACK
	db 41,WATERFALL
	db 49,HORN_DRILL
	db 61,AGILITY
	db 0 ; no more level-up moves

StaryuEvosAttacks:
	db EVOLVE_ITEM,WATER_STONE,STARMIE
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,HARDEN
	db 7,WATER_GUN
	db 13,RAPID_SPIN
	db 19,RECOVER
	db 25,SWIFT
	db 31,BUBBLEBEAM
	db 37,MINIMIZE
	db 43,LIGHT_SCREEN
	db 50,HYDRO_PUMP
	db 0 ; no more level-up moves

StarmieEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,RAPID_SPIN
	db 1,RECOVER
	db 1,BUBBLEBEAM
	db 37,CONFUSE_RAY
	db 0 ; no more level-up moves

MrMimeEvosAttacks:
	db 0 ; no more evolutions
	db 1,BARRIER
	db 6,CONFUSION
	db 11,SUBSTITUTE
	db 16,MEDITATE
	db 21,DOUBLESLAP
	db 26,LIGHT_SCREEN
	db 26,REFLECT
	db 31,ENCORE
	db 36,PSYBEAM
	db 41,BATON_PASS
	db 46,SAFEGUARD
	db 0 ; no more level-up moves

ScytherEvosAttacks:
	db EVOLVE_TRADE,METAL_COAT,SCIZOR
	db 0 ; no more evolutions
	db 1,QUICK_ATTACK
	db 1,LEER
	db 6,FOCUS_ENERGY
	db 12,PURSUIT
	db 18,FALSE_SWIPE
	db 24,AGILITY
	db 30,WING_ATTACK
	db 36,SLASH
	db 42,SWORDS_DANCE
	db 48,DOUBLE_TEAM
	db 0 ; no more level-up moves

JynxEvosAttacks:
	db 0 ; no more evolutions
	db 1,POUND
	db 1,LICK
	db 1,LOVELY_KISS
	db 1,POWDER_SNOW
	db 9,LOVELY_KISS
	db 13,POWDER_SNOW
	db 21,DOUBLESLAP
	db 25,ICE_PUNCH
	db 35,MEAN_LOOK
	db 41,BODY_SLAM
	db 51,PERISH_SONG
	db 57,BLIZZARD
	db 0 ; no more level-up moves

ElectabuzzEvosAttacks:
	db 0 ; no more evolutions
	db 1,QUICK_ATTACK
	db 1,LEER
	db 1,THUNDERPUNCH
	db 9,THUNDERPUNCH
	db 17,LIGHT_SCREEN
	db 25,SWIFT
	db 36,SCREECH
	db 47,THUNDERBOLT
	db 58,THUNDER
	db 0 ; no more level-up moves

MagmarEvosAttacks:
	db 0 ; no more evolutions
	db 1,EMBER
	db 1,LEER
	db 1,SMOG
	db 1,FIRE_PUNCH
	db 7,LEER
	db 13,SMOG
	db 19,FIRE_PUNCH
	db 25,SMOKESCREEN
	db 33,SUNNY_DAY
	db 41,FLAMETHROWER
	db 49,CONFUSE_RAY
	db 57,FIRE_BLAST
	db 0 ; no more level-up moves

PinsirEvosAttacks:
	db 0 ; no more evolutions
	db 1,VICEGRIP
	db 7,FOCUS_ENERGY
	db 13,BIND
	db 19,SEISMIC_TOSS
	db 25,HARDEN
	db 31,GUILLOTINE
	db 37,SUBMISSION
	db 43,SWORDS_DANCE
	db 0 ; no more level-up moves

TaurosEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 4,TAIL_WHIP
	db 8,RAGE
	db 13,HORN_ATTACK
	db 19,SCARY_FACE
	db 26,PURSUIT
	db 34,REST
	db 43,THRASH
	db 53,TAKE_DOWN
	db 0 ; no more level-up moves

MagikarpEvosAttacks:
	db EVOLVE_LEVEL,20,GYARADOS
	db 0 ; no more evolutions
	db 1,SPLASH
	db 15,TACKLE
	db 30,FLAIL
	db 0 ; no more level-up moves

GyaradosEvosAttacks:
	db 0 ; no more evolutions
	db 1,THRASH
	db 20,BITE
	db 25,DRAGON_RAGE
	db 30,LEER
	db 35,TWISTER
	db 40,HYDRO_PUMP
	db 45,RAIN_DANCE
	db 50,HYPER_BEAM
	db 0 ; no more level-up moves

LaprasEvosAttacks:
	db 0 ; no more evolutions
	db 1,WATER_GUN
	db 1,GROWL
	db 1,SING
	db 8,MIST
	db 15,BODY_SLAM
	db 22,CONFUSE_RAY
	db 29,PERISH_SONG
	db 36,ICE_BEAM
	db 43,RAIN_DANCE
	db 50,SAFEGUARD
	db 57,HYDRO_PUMP
	db 0 ; no more level-up moves

DittoEvosAttacks:
	db 0 ; no more evolutions
	db 1,TRANSFORM
	db 0 ; no more level-up moves

EeveeEvosAttacks:
	db EVOLVE_ITEM,THUNDERSTONE,JOLTEON
	db EVOLVE_ITEM,WATER_STONE,VAPOREON
	db EVOLVE_ITEM,FIRE_STONE,FLAREON
	db EVOLVE_HAPPINESS,TR_MORNDAY,ESPEON
	db EVOLVE_HAPPINESS,TR_NITE,UMBREON
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 8,SAND_ATTACK
	db 16,GROWL
	db 23,QUICK_ATTACK
	db 30,BITE
if _CRYSTAL
	db 36,BATON_PASS
else
	db 36,FOCUS_ENERGY
endc
	db 42,TAKE_DOWN
	db 0 ; no more level-up moves

VaporeonEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 8,SAND_ATTACK
	db 16,WATER_GUN
	db 23,QUICK_ATTACK
	db 30,BITE
	db 36,AURORA_BEAM
	db 42,HAZE
	db 47,ACID_ARMOR
	db 52,HYDRO_PUMP
	db 0 ; no more level-up moves

JolteonEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 8,SAND_ATTACK
	db 16,THUNDERSHOCK
	db 23,QUICK_ATTACK
	db 30,DOUBLE_KICK
	db 36,PIN_MISSILE
	db 42,THUNDER_WAVE
	db 47,AGILITY
	db 52,THUNDER
	db 0 ; no more level-up moves

FlareonEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 8,SAND_ATTACK
	db 16,EMBER
	db 23,QUICK_ATTACK
	db 30,BITE
	db 36,FIRE_SPIN
	db 42,SMOG
	db 47,LEER
	db 52,FLAMETHROWER
	db 0 ; no more level-up moves

PorygonEvosAttacks:
	db EVOLVE_TRADE,UP_GRADE,PORYGON2
	db 0 ; no more evolutions
	db 1,CONVERSION2
	db 1,TACKLE
	db 1,CONVERSION
	db 9,AGILITY
	db 12,PSYBEAM
	db 20,RECOVER
	db 24,SHARPEN
	db 32,LOCK_ON
	db 36,TRI_ATTACK
	db 44,ZAP_CANNON
	db 0 ; no more level-up moves

OmanyteEvosAttacks:
	db EVOLVE_LEVEL,40,OMASTAR
	db 0 ; no more evolutions
	db 1,CONSTRICT
	db 1,WITHDRAW
	db 13,BITE
	db 19,WATER_GUN
	db 31,LEER
	db 37,PROTECT
	db 49,ANCIENTPOWER
	db 55,HYDRO_PUMP
	db 0 ; no more level-up moves

OmastarEvosAttacks:
	db 0 ; no more evolutions
	db 1,CONSTRICT
	db 1,WITHDRAW
	db 1,BITE
	db 13,BITE
	db 19,WATER_GUN
	db 31,LEER
	db 37,PROTECT
	db 40,SPIKE_CANNON
	db 54,ANCIENTPOWER
	db 65,HYDRO_PUMP
	db 0 ; no more level-up moves

KabutoEvosAttacks:
	db EVOLVE_LEVEL,40,KABUTOPS
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,HARDEN
	db 10,ABSORB
	db 19,LEER
	db 28,SAND_ATTACK
	db 37,ENDURE
	db 46,MEGA_DRAIN
	db 55,ANCIENTPOWER
	db 0 ; no more level-up moves

KabutopsEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,HARDEN
	db 1,ABSORB
	db 10,ABSORB
	db 19,LEER
	db 28,SAND_ATTACK
	db 37,ENDURE
	db 40,SLASH
	db 51,MEGA_DRAIN
	db 65,ANCIENTPOWER
	db 0 ; no more level-up moves

AerodactylEvosAttacks:
	db 0 ; no more evolutions
	db 1,WING_ATTACK
	db 8,AGILITY
	db 15,BITE
	db 22,SUPERSONIC
	db 29,ANCIENTPOWER
	db 36,SCARY_FACE
	db 43,TAKE_DOWN
	db 50,HYPER_BEAM
	db 0 ; no more level-up moves

SnorlaxEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 8,AMNESIA
	db 15,DEFENSE_CURL
	db 22,BELLY_DRUM
	db 29,HEADBUTT
	db 36,SNORE
	db 36,REST
	db 43,BODY_SLAM
	db 50,ROLLOUT
	db 57,HYPER_BEAM
	db 0 ; no more level-up moves

ArticunoEvosAttacks:
	db 0 ; no more evolutions
	db 1,GUST
	db 1,POWDER_SNOW
	db 13,MIST
	db 25,AGILITY
	db 37,MIND_READER
	db 49,ICE_BEAM
	db 61,REFLECT
	db 73,BLIZZARD
	db 0 ; no more level-up moves

ZapdosEvosAttacks:
	db 0 ; no more evolutions
	db 1,PECK
	db 1,THUNDERSHOCK
	db 13,THUNDER_WAVE
	db 25,AGILITY
	db 37,DETECT
	db 49,DRILL_PECK
	db 61,LIGHT_SCREEN
	db 73,THUNDER
	db 0 ; no more level-up moves

MoltresEvosAttacks:
	db 0 ; no more evolutions
	db 1,WING_ATTACK
	db 1,EMBER
	db 13,FIRE_SPIN
	db 25,AGILITY
	db 37,ENDURE
	db 49,FLAMETHROWER
	db 61,SAFEGUARD
	db 73,SKY_ATTACK
	db 0 ; no more level-up moves

DratiniEvosAttacks:
	db EVOLVE_LEVEL,30,DRAGONAIR
	db 0 ; no more evolutions
	db 1,WRAP
	db 1,LEER
	db 8,THUNDER_WAVE
	db 15,TWISTER
	db 22,DRAGON_RAGE
	db 29,SLAM
	db 36,AGILITY
	db 43,SAFEGUARD
	db 50,OUTRAGE
	db 57,HYPER_BEAM
	db 0 ; no more level-up moves

DragonairEvosAttacks:
	db EVOLVE_LEVEL,55,DRAGONITE
	db 0 ; no more evolutions
	db 1,WRAP
	db 1,LEER
	db 1,THUNDER_WAVE
	db 1,TWISTER
	db 8,THUNDER_WAVE
	db 15,TWISTER
	db 22,DRAGON_RAGE
	db 29,SLAM
	db 38,AGILITY
	db 47,SAFEGUARD
	db 56,OUTRAGE
	db 65,HYPER_BEAM
	db 0 ; no more level-up moves

DragoniteEvosAttacks:
	db 0 ; no more evolutions
	db 1,WRAP
	db 1,LEER
	db 1,THUNDER_WAVE
	db 1,TWISTER
	db 8,THUNDER_WAVE
	db 15,TWISTER
	db 22,DRAGON_RAGE
	db 29,SLAM
	db 38,AGILITY
	db 47,SAFEGUARD
	db 55,WING_ATTACK
	db 61,OUTRAGE
	db 75,HYPER_BEAM
	db 0 ; no more level-up moves

MewtwoEvosAttacks:
	db 0 ; no more evolutions
	db 1,CONFUSION
	db 1,DISABLE
	db 11,BARRIER
	db 22,SWIFT
	db 33,PSYCH_UP
	db 44,FUTURE_SIGHT
	db 55,MIST
	db 66,PSYCHIC_M
	db 77,AMNESIA
	db 88,RECOVER
	db 99,SAFEGUARD
	db 0 ; no more level-up moves

MewEvosAttacks:
	db 0 ; no more evolutions
	db 1,POUND
	db 10,TRANSFORM
	db 20,MEGA_PUNCH
	db 30,METRONOME
	db 40,PSYCHIC_M
	db 50,ANCIENTPOWER
	db 0 ; no more level-up moves

ChikoritaEvosAttacks:
	db EVOLVE_LEVEL,16,BAYLEEF
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 8,RAZOR_LEAF
	db 12,REFLECT
	db 15,POISONPOWDER
	db 22,SYNTHESIS
	db 29,BODY_SLAM
	db 36,LIGHT_SCREEN
	db 43,SAFEGUARD
	db 50,SOLARBEAM
	db 0 ; no more level-up moves

BayleefEvosAttacks:
	db EVOLVE_LEVEL,32,MEGANIUM
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 1,RAZOR_LEAF
	db 1,REFLECT
	db 8,RAZOR_LEAF
	db 12,REFLECT
	db 15,POISONPOWDER
	db 23,SYNTHESIS
	db 31,BODY_SLAM
	db 39,LIGHT_SCREEN
	db 47,SAFEGUARD
	db 55,SOLARBEAM
	db 0 ; no more level-up moves

MeganiumEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 1,RAZOR_LEAF
	db 1,REFLECT
	db 8,RAZOR_LEAF
	db 12,REFLECT
	db 15,POISONPOWDER
	db 23,SYNTHESIS
	db 31,BODY_SLAM
	db 41,LIGHT_SCREEN
	db 51,SAFEGUARD
	db 61,SOLARBEAM
	db 0 ; no more level-up moves

CyndaquilEvosAttacks:
	db EVOLVE_LEVEL,14,QUILAVA
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,LEER
	db 6,SMOKESCREEN
	db 12,EMBER
	db 19,QUICK_ATTACK
	db 27,FLAME_WHEEL
	db 36,SWIFT
	db 46,FLAMETHROWER
	db 0 ; no more level-up moves

QuilavaEvosAttacks:
	db EVOLVE_LEVEL,36,TYPHLOSION
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,LEER
	db 1,SMOKESCREEN
	db 6,SMOKESCREEN
	db 12,EMBER
	db 21,QUICK_ATTACK
	db 31,FLAME_WHEEL
	db 42,SWIFT
	db 54,FLAMETHROWER
	db 0 ; no more level-up moves

TyphlosionEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,LEER
	db 1,SMOKESCREEN
	db 1,EMBER
	db 6,SMOKESCREEN
	db 12,EMBER
	db 21,QUICK_ATTACK
	db 31,FLAME_WHEEL
	db 45,SWIFT
	db 60,FLAMETHROWER
	db 0 ; no more level-up moves

TotodileEvosAttacks:
	db EVOLVE_LEVEL,18,CROCONAW
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,LEER
	db 7,RAGE
	db 13,WATER_GUN
	db 20,BITE
	db 27,SCARY_FACE
	db 35,SLASH
	db 43,SCREECH
	db 52,HYDRO_PUMP
	db 0 ; no more level-up moves

CroconawEvosAttacks:
	db EVOLVE_LEVEL,30,FERALIGATR
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,LEER
	db 1,RAGE
	db 7,RAGE
	db 13,WATER_GUN
	db 21,BITE
	db 28,SCARY_FACE
	db 37,SLASH
	db 45,SCREECH
	db 55,HYDRO_PUMP
	db 0 ; no more level-up moves

FeraligatrEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,LEER
	db 1,RAGE
	db 1,WATER_GUN
	db 7,RAGE
	db 13,WATER_GUN
	db 21,BITE
	db 28,SCARY_FACE
	db 38,SLASH
	db 47,SCREECH
	db 58,HYDRO_PUMP
	db 0 ; no more level-up moves

SentretEvosAttacks:
	db EVOLVE_LEVEL,15,FURRET
	db 0 ; no more evolutions
	db 1,TACKLE
	db 5,DEFENSE_CURL
	db 11,QUICK_ATTACK
	db 17,FURY_SWIPES
	db 25,SLAM
	db 33,REST
	db 41,AMNESIA
	db 0 ; no more level-up moves

FurretEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,DEFENSE_CURL
	db 1,QUICK_ATTACK
	db 5,DEFENSE_CURL
	db 11,QUICK_ATTACK
	db 18,FURY_SWIPES
	db 28,SLAM
	db 38,REST
	db 48,AMNESIA
	db 0 ; no more level-up moves

HoothootEvosAttacks:
	db EVOLVE_LEVEL,20,NOCTOWL
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 6,FORESIGHT
	db 11,PECK
	db 16,HYPNOSIS
	db 22,REFLECT
	db 28,TAKE_DOWN
	db 34,CONFUSION
	db 48,DREAM_EATER
	db 0 ; no more level-up moves

NoctowlEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 1,FORESIGHT
	db 1,PECK
	db 6,FORESIGHT
	db 11,PECK
	db 16,HYPNOSIS
	db 25,REFLECT
	db 33,TAKE_DOWN
	db 41,CONFUSION
	db 57,DREAM_EATER
	db 0 ; no more level-up moves

LedybaEvosAttacks:
	db EVOLVE_LEVEL,18,LEDIAN
	db 0 ; no more evolutions
	db 1,TACKLE
	db 8,SUPERSONIC
	db 15,COMET_PUNCH
	db 22,LIGHT_SCREEN
	db 22,REFLECT
	db 22,SAFEGUARD
	db 29,BATON_PASS
	db 36,SWIFT
	db 43,AGILITY
	db 50,DOUBLE_EDGE
	db 0 ; no more level-up moves

LedianEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,SUPERSONIC
	db 8,SUPERSONIC
	db 15,COMET_PUNCH
	db 24,LIGHT_SCREEN
	db 24,REFLECT
	db 24,SAFEGUARD
	db 33,BATON_PASS
	db 42,SWIFT
	db 51,AGILITY
	db 60,DOUBLE_EDGE
	db 0 ; no more level-up moves

SpinarakEvosAttacks:
	db EVOLVE_LEVEL,22,ARIADOS
	db 0 ; no more evolutions
	db 1,POISON_STING
	db 1,STRING_SHOT
	db 6,SCARY_FACE
	db 11,CONSTRICT
	db 17,NIGHT_SHADE
	db 23,LEECH_LIFE
	db 30,FURY_SWIPES
	db 37,SPIDER_WEB
if _CRYSTAL
	db 45,AGILITY
else
	db 45,SCREECH
endc
	db 53,PSYCHIC_M
	db 0 ; no more level-up moves

AriadosEvosAttacks:
	db 0 ; no more evolutions
	db 1,POISON_STING
	db 1,STRING_SHOT
	db 1,SCARY_FACE
	db 1,CONSTRICT
	db 6,SCARY_FACE
	db 11,CONSTRICT
	db 17,NIGHT_SHADE
	db 25,LEECH_LIFE
	db 34,FURY_SWIPES
	db 43,SPIDER_WEB
if _CRYSTAL
	db 53,AGILITY
else
	db 53,SCREECH
endc
	db 63,PSYCHIC_M
	db 0 ; no more level-up moves

CrobatEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCREECH
	db 1,LEECH_LIFE
	db 1,SUPERSONIC
	db 6,SUPERSONIC
	db 12,BITE
	db 19,CONFUSE_RAY
	db 30,WING_ATTACK
	db 42,MEAN_LOOK
	db 55,HAZE
	db 0 ; no more level-up moves

ChinchouEvosAttacks:
	db EVOLVE_LEVEL,27,LANTURN
	db 0 ; no more evolutions
	db 1,BUBBLE
	db 1,THUNDER_WAVE
	db 5,SUPERSONIC
	db 13,FLAIL
	db 17,WATER_GUN
	db 25,SPARK
	db 29,CONFUSE_RAY
	db 37,TAKE_DOWN
	db 41,HYDRO_PUMP
	db 0 ; no more level-up moves

LanturnEvosAttacks:
	db 0 ; no more evolutions
	db 1,BUBBLE
	db 1,THUNDER_WAVE
	db 1,SUPERSONIC
	db 5,SUPERSONIC
	db 13,FLAIL
	db 17,WATER_GUN
	db 25,SPARK
	db 33,CONFUSE_RAY
	db 45,TAKE_DOWN
	db 53,HYDRO_PUMP
	db 0 ; no more level-up moves

PichuEvosAttacks:
	db EVOLVE_HAPPINESS,TR_ANYTIME,PIKACHU
	db 0 ; no more evolutions
	db 1,THUNDERSHOCK
	db 1,CHARM
	db 6,TAIL_WHIP
	db 8,THUNDER_WAVE
	db 11,SWEET_KISS
	db 0 ; no more level-up moves

CleffaEvosAttacks:
	db EVOLVE_HAPPINESS,TR_ANYTIME,CLEFAIRY
	db 0 ; no more evolutions
	db 1,POUND
	db 1,CHARM
	db 4,ENCORE
	db 8,SING
	db 13,SWEET_KISS
	db 0 ; no more level-up moves

IgglybuffEvosAttacks:
	db EVOLVE_HAPPINESS,TR_ANYTIME,JIGGLYPUFF
	db 0 ; no more evolutions
	db 1,SING
	db 1,CHARM
	db 4,DEFENSE_CURL
	db 9,POUND
	db 14,SWEET_KISS
	db 0 ; no more level-up moves

TogepiEvosAttacks:
	db EVOLVE_HAPPINESS,TR_ANYTIME,TOGETIC
	db 0 ; no more evolutions
	db 1,GROWL
	db 1,CHARM
	db 7,METRONOME
	db 18,SWEET_KISS
	db 25,ENCORE
	db 31,SAFEGUARD
	db 38,DOUBLE_EDGE
	db 0 ; no more level-up moves

TogeticEvosAttacks:
	db 0 ; no more evolutions
	db 1,GROWL
	db 1,CHARM
	db 7,METRONOME
	db 18,SWEET_KISS
	db 25,ENCORE
	db 31,SAFEGUARD
	db 38,DOUBLE_EDGE
	db 0 ; no more level-up moves

NatuEvosAttacks:
	db EVOLVE_LEVEL,25,XATU
	db 0 ; no more evolutions
	db 1,PECK
	db 1,LEER
	db 10,NIGHT_SHADE
	db 20,TELEPORT
	db 30,FUTURE_SIGHT
	db 40,CONFUSE_RAY
	db 50,PSYCHIC_M
	db 0 ; no more level-up moves

XatuEvosAttacks:
	db 0 ; no more evolutions
	db 1,PECK
	db 1,LEER
	db 1,NIGHT_SHADE
	db 10,NIGHT_SHADE
	db 20,TELEPORT
	db 35,FUTURE_SIGHT
	db 50,CONFUSE_RAY
	db 65,PSYCHIC_M
	db 0 ; no more level-up moves

MareepEvosAttacks:
	db EVOLVE_LEVEL,15,FLAAFFY
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 9,THUNDERSHOCK
	db 16,THUNDER_WAVE
	db 23,COTTON_SPORE
	db 30,LIGHT_SCREEN
	db 37,THUNDER
	db 0 ; no more level-up moves

FlaaffyEvosAttacks:
	db EVOLVE_LEVEL,30,AMPHAROS
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 1,THUNDERSHOCK
	db 9,THUNDERSHOCK
	db 18,THUNDER_WAVE
	db 27,COTTON_SPORE
	db 36,LIGHT_SCREEN
	db 45,THUNDER
	db 0 ; no more level-up moves

AmpharosEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 1,THUNDERSHOCK
	db 1,THUNDER_WAVE
	db 9,THUNDERSHOCK
	db 18,THUNDER_WAVE
	db 27,COTTON_SPORE
	db 30,THUNDERPUNCH
	db 42,LIGHT_SCREEN
	db 57,THUNDER
	db 0 ; no more level-up moves

BellossomEvosAttacks:
	db 0 ; no more evolutions
	db 1,ABSORB
	db 1,SWEET_SCENT
	db 1,STUN_SPORE
	db 1,PETAL_DANCE
	db 55,SOLARBEAM
	db 0 ; no more level-up moves

MarillEvosAttacks:
	db EVOLVE_LEVEL,18,AZUMARILL
	db 0 ; no more evolutions
	db 1,TACKLE
	db 3,DEFENSE_CURL
	db 6,TAIL_WHIP
	db 10,WATER_GUN
	db 15,ROLLOUT
	db 21,BUBBLEBEAM
	db 28,DOUBLE_EDGE
	db 36,RAIN_DANCE
	db 0 ; no more level-up moves

AzumarillEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,DEFENSE_CURL
	db 1,TAIL_WHIP
	db 1,WATER_GUN
	db 3,DEFENSE_CURL
	db 6,TAIL_WHIP
	db 10,WATER_GUN
	db 15,ROLLOUT
	db 25,BUBBLEBEAM
	db 36,DOUBLE_EDGE
	db 48,RAIN_DANCE
	db 0 ; no more level-up moves

SudowoodoEvosAttacks:
	db 0 ; no more evolutions
	db 1,ROCK_THROW
	db 1,MIMIC
	db 10,FLAIL
	db 19,LOW_KICK
	db 28,ROCK_SLIDE
	db 37,FAINT_ATTACK
	db 46,SLAM
	db 0 ; no more level-up moves

PolitoedEvosAttacks:
	db 0 ; no more evolutions
	db 1,WATER_GUN
	db 1,HYPNOSIS
	db 1,DOUBLESLAP
	db 1,PERISH_SONG
	db 35,PERISH_SONG
	db 51,SWAGGER
	db 0 ; no more level-up moves

HoppipEvosAttacks:
	db EVOLVE_LEVEL,18,SKIPLOOM
	db 0 ; no more evolutions
	db 1,SPLASH
if _CRYSTAL
	db 5,SYNTHESIS
else
	db 1,SYNTHESIS
endc
	db 5,TAIL_WHIP
	db 10,TACKLE
	db 13,POISONPOWDER
	db 15,STUN_SPORE
	db 17,SLEEP_POWDER
	db 20,LEECH_SEED
	db 25,COTTON_SPORE
	db 30,MEGA_DRAIN
	db 0 ; no more level-up moves

SkiploomEvosAttacks:
	db EVOLVE_LEVEL,27,JUMPLUFF
	db 0 ; no more evolutions
	db 1,SPLASH
	db 1,SYNTHESIS
	db 1,TAIL_WHIP
	db 1,TACKLE
if _CRYSTAL
	db 5,SYNTHESIS
endc
	db 5,TAIL_WHIP
	db 10,TACKLE
	db 13,POISONPOWDER
	db 15,STUN_SPORE
	db 17,SLEEP_POWDER
	db 22,LEECH_SEED
	db 29,COTTON_SPORE
	db 36,MEGA_DRAIN
	db 0 ; no more level-up moves

JumpluffEvosAttacks:
	db 0 ; no more evolutions
	db 1,SPLASH
	db 1,SYNTHESIS
	db 1,TAIL_WHIP
	db 1,TACKLE
if _CRYSTAL
	db 5,SYNTHESIS
endc
	db 5,TAIL_WHIP
	db 10,TACKLE
	db 13,POISONPOWDER
	db 15,STUN_SPORE
	db 17,SLEEP_POWDER
	db 22,LEECH_SEED
	db 33,COTTON_SPORE
	db 44,MEGA_DRAIN
	db 0 ; no more level-up moves

AipomEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,TAIL_WHIP
	db 6,SAND_ATTACK
	db 12,BATON_PASS
	db 19,FURY_SWIPES
	db 27,SWIFT
	db 36,SCREECH
	db 46,AGILITY
	db 0 ; no more level-up moves

SunkernEvosAttacks:
	db EVOLVE_ITEM,SUN_STONE,SUNFLORA
	db 0 ; no more evolutions
	db 1,ABSORB
	db 4,GROWTH
	db 10,MEGA_DRAIN
	db 19,SUNNY_DAY
	db 31,SYNTHESIS
	db 46,GIGA_DRAIN
	db 0 ; no more level-up moves

SunfloraEvosAttacks:
	db 0 ; no more evolutions
	db 1,ABSORB
	db 1,POUND
	db 4,GROWTH
	db 10,RAZOR_LEAF
	db 19,SUNNY_DAY
	db 31,PETAL_DANCE
	db 46,SOLARBEAM
	db 0 ; no more level-up moves

YanmaEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,FORESIGHT
	db 7,QUICK_ATTACK
	db 13,DOUBLE_TEAM
	db 19,SONICBOOM
	db 25,DETECT
	db 31,SUPERSONIC
if _CRYSTAL
	db 37,WING_ATTACK
else
	db 37,SWIFT
endc
	db 43,SCREECH
	db 0 ; no more level-up moves

WooperEvosAttacks:
	db EVOLVE_LEVEL,20,QUAGSIRE
	db 0 ; no more evolutions
	db 1,WATER_GUN
	db 1,TAIL_WHIP
	db 11,SLAM
	db 21,AMNESIA
	db 31,EARTHQUAKE
	db 41,RAIN_DANCE
	db 51,MIST
	db 51,HAZE
	db 0 ; no more level-up moves

QuagsireEvosAttacks:
	db 0 ; no more evolutions
	db 1,WATER_GUN
	db 1,TAIL_WHIP
	db 11,SLAM
	db 23,AMNESIA
	db 35,EARTHQUAKE
	db 47,RAIN_DANCE
	db 59,MIST
	db 59,HAZE
	db 0 ; no more level-up moves

EspeonEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 8,SAND_ATTACK
	db 16,CONFUSION
	db 23,QUICK_ATTACK
	db 30,SWIFT
	db 36,PSYBEAM
	db 42,PSYCH_UP
	db 47,PSYCHIC_M
	db 52,MORNING_SUN
	db 0 ; no more level-up moves

UmbreonEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,TAIL_WHIP
	db 8,SAND_ATTACK
	db 16,PURSUIT
	db 23,QUICK_ATTACK
	db 30,CONFUSE_RAY
	db 36,FAINT_ATTACK
	db 42,MEAN_LOOK
	db 47,SCREECH
	db 52,MOONLIGHT
	db 0 ; no more level-up moves

MurkrowEvosAttacks:
	db 0 ; no more evolutions
	db 1,PECK
	db 11,PURSUIT
	db 16,HAZE
	db 26,NIGHT_SHADE
	db 31,FAINT_ATTACK
	db 41,MEAN_LOOK
	db 0 ; no more level-up moves

SlowkingEvosAttacks:
	db 0 ; no more evolutions
	db 1,CURSE
	db 1,TACKLE
	db 6,GROWL
	db 15,WATER_GUN
	db 20,CONFUSION
	db 29,DISABLE
	db 34,HEADBUTT
	db 43,SWAGGER
	db 48,PSYCHIC_M
	db 0 ; no more level-up moves

MisdreavusEvosAttacks:
	db 0 ; no more evolutions
	db 1,GROWL
	db 1,PSYWAVE
	db 6,SPITE
	db 12,CONFUSE_RAY
	db 19,MEAN_LOOK
	db 27,PSYBEAM
	db 36,PAIN_SPLIT
	db 46,PERISH_SONG
	db 0 ; no more level-up moves

UnownEvosAttacks:
	db 0 ; no more evolutions
	db 1,HIDDEN_POWER
	db 0 ; no more level-up moves

WobbuffetEvosAttacks:
	db 0 ; no more evolutions
	db 1,COUNTER
	db 1,MIRROR_COAT
	db 1,SAFEGUARD
	db 1,DESTINY_BOND
	db 0 ; no more level-up moves

GirafarigEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 1,CONFUSION
	db 1,STOMP
	db 7,CONFUSION
	db 13,STOMP
	db 20,AGILITY
	db 30,BATON_PASS
	db 41,PSYBEAM
	db 54,CRUNCH
	db 0 ; no more level-up moves

PinecoEvosAttacks:
	db EVOLVE_LEVEL,31,FORRETRESS
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,PROTECT
	db 8,SELFDESTRUCT
	db 15,TAKE_DOWN
	db 22,RAPID_SPIN
	db 29,BIDE
	db 36,EXPLOSION
	db 43,SPIKES
	db 50,DOUBLE_EDGE
	db 0 ; no more level-up moves

ForretressEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,PROTECT
	db 1,SELFDESTRUCT
	db 8,SELFDESTRUCT
	db 15,TAKE_DOWN
	db 22,RAPID_SPIN
	db 29,BIDE
	db 39,EXPLOSION
	db 49,SPIKES
	db 59,DOUBLE_EDGE
	db 0 ; no more level-up moves

DunsparceEvosAttacks:
	db 0 ; no more evolutions
	db 1,RAGE
	db 5,DEFENSE_CURL
	db 13,GLARE
	db 18,SPITE
	db 26,PURSUIT
	db 30,SCREECH
	db 38,TAKE_DOWN
	db 0 ; no more level-up moves

GligarEvosAttacks:
	db 0 ; no more evolutions
	db 1,POISON_STING
	db 6,SAND_ATTACK
	db 13,HARDEN
	db 20,QUICK_ATTACK
	db 28,FAINT_ATTACK
	db 36,SLASH
	db 44,SCREECH
	db 52,GUILLOTINE
	db 0 ; no more level-up moves

SteelixEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,SCREECH
	db 10,BIND
	db 14,ROCK_THROW
	db 23,HARDEN
	db 27,RAGE
	db 36,SANDSTORM
	db 40,SLAM
	db 49,CRUNCH
	db 0 ; no more level-up moves

SnubbullEvosAttacks:
	db EVOLVE_LEVEL,23,GRANBULL
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,SCARY_FACE
	db 4,TAIL_WHIP
	db 8,CHARM
	db 13,BITE
	db 19,LICK
	db 26,ROAR
	db 34,RAGE
	db 43,TAKE_DOWN
	db 0 ; no more level-up moves

GranbullEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,SCARY_FACE
	db 4,TAIL_WHIP
	db 8,CHARM
	db 13,BITE
	db 19,LICK
	db 28,ROAR
	db 38,RAGE
	db 51,TAKE_DOWN
	db 0 ; no more level-up moves

QwilfishEvosAttacks:
	db 0 ; no more evolutions
if _CRYSTAL
	db 1,SPIKES
endc
	db 1,TACKLE
	db 1,POISON_STING
	db 10,HARDEN
	db 10,MINIMIZE
	db 19,WATER_GUN
	db 28,PIN_MISSILE
	db 37,TAKE_DOWN
	db 46,HYDRO_PUMP
	db 0 ; no more level-up moves

ScizorEvosAttacks:
	db 0 ; no more evolutions
	db 1,QUICK_ATTACK
	db 1,LEER
	db 6,FOCUS_ENERGY
	db 12,PURSUIT
	db 18,FALSE_SWIPE
	db 24,AGILITY
	db 30,METAL_CLAW
	db 36,SLASH
	db 42,SWORDS_DANCE
	db 48,DOUBLE_TEAM
	db 0 ; no more level-up moves

ShuckleEvosAttacks:
	db 0 ; no more evolutions
	db 1,CONSTRICT
	db 1,WITHDRAW
	db 9,WRAP
	db 14,ENCORE
	db 23,SAFEGUARD
	db 28,BIDE
	db 37,REST
	db 0 ; no more level-up moves

HeracrossEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,LEER
	db 6,HORN_ATTACK
	db 12,ENDURE
	db 19,FURY_ATTACK
	db 27,COUNTER
	db 35,TAKE_DOWN
	db 44,REVERSAL
	db 54,MEGAHORN
	db 0 ; no more level-up moves

SneaselEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,LEER
	db 9,QUICK_ATTACK
	db 17,SCREECH
	db 25,FAINT_ATTACK
	db 33,FURY_SWIPES
	db 41,AGILITY
	db 49,SLASH
	db 57,BEAT_UP
if _CRYSTAL
	db 65,METAL_CLAW
endc
	db 0 ; no more level-up moves

TeddiursaEvosAttacks:
	db EVOLVE_LEVEL,30,URSARING
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,LEER
	db 8,LICK
	db 15,FURY_SWIPES
	db 22,FAINT_ATTACK
	db 29,REST
	db 36,SLASH
	db 43,SNORE
	db 50,THRASH
	db 0 ; no more level-up moves

UrsaringEvosAttacks:
	db 0 ; no more evolutions
	db 1,SCRATCH
	db 1,LEER
	db 1,LICK
	db 1,FURY_SWIPES
	db 8,LICK
	db 15,FURY_SWIPES
	db 22,FAINT_ATTACK
	db 29,REST
	db 39,SLASH
	db 49,SNORE
	db 59,THRASH
	db 0 ; no more level-up moves

SlugmaEvosAttacks:
	db EVOLVE_LEVEL,38,MAGCARGO
	db 0 ; no more evolutions
	db 1,SMOG
	db 8,EMBER
	db 15,ROCK_THROW
	db 22,HARDEN
	db 29,AMNESIA
	db 36,FLAMETHROWER
	db 43,ROCK_SLIDE
	db 50,BODY_SLAM
	db 0 ; no more level-up moves

MagcargoEvosAttacks:
	db 0 ; no more evolutions
	db 1,SMOG
	db 1,EMBER
	db 1,ROCK_THROW
	db 8,EMBER
	db 15,ROCK_THROW
	db 22,HARDEN
	db 29,AMNESIA
	db 36,FLAMETHROWER
	db 48,ROCK_SLIDE
	db 60,BODY_SLAM
	db 0 ; no more level-up moves

SwinubEvosAttacks:
	db EVOLVE_LEVEL,33,PILOSWINE
	db 0 ; no more evolutions
	db 1,TACKLE
	db 10,POWDER_SNOW
	db 19,ENDURE
	db 28,TAKE_DOWN
	db 37,MIST
	db 46,BLIZZARD
if _CRYSTAL
	db 55,AMNESIA
endc
	db 0 ; no more level-up moves

PiloswineEvosAttacks:
	db 0 ; no more evolutions
	db 1,HORN_ATTACK
	db 1,POWDER_SNOW
	db 1,ENDURE
	db 10,POWDER_SNOW
	db 19,ENDURE
	db 28,TAKE_DOWN
	db 33,FURY_ATTACK
	db 42,MIST
	db 56,BLIZZARD
if _CRYSTAL
	db 70,AMNESIA
endc
	db 0 ; no more level-up moves

CorsolaEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 7,HARDEN
	db 13,BUBBLE
	db 19,RECOVER
	db 25,BUBBLEBEAM
	db 31,SPIKE_CANNON
	db 37,MIRROR_COAT
	db 43,ANCIENTPOWER
	db 0 ; no more level-up moves

RemoraidEvosAttacks:
	db EVOLVE_LEVEL,25,OCTILLERY
	db 0 ; no more evolutions
	db 1,WATER_GUN
	db 11,LOCK_ON
	db 22,PSYBEAM
	db 22,AURORA_BEAM
	db 22,BUBBLEBEAM
	db 33,FOCUS_ENERGY
	db 44,ICE_BEAM
	db 55,HYPER_BEAM
	db 0 ; no more level-up moves

OctilleryEvosAttacks:
	db 0 ; no more evolutions
	db 1,WATER_GUN
	db 11,CONSTRICT
	db 22,PSYBEAM
	db 22,AURORA_BEAM
	db 22,BUBBLEBEAM
	db 25,OCTAZOOKA
	db 38,FOCUS_ENERGY
	db 54,ICE_BEAM
	db 70,HYPER_BEAM
	db 0 ; no more level-up moves

DelibirdEvosAttacks:
	db 0 ; no more evolutions
	db 1,PRESENT
	db 0 ; no more level-up moves

MantineEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,BUBBLE
	db 10,SUPERSONIC
	db 18,BUBBLEBEAM
	db 25,TAKE_DOWN
	db 32,AGILITY
	db 40,WING_ATTACK
	db 49,CONFUSE_RAY
	db 0 ; no more level-up moves

SkarmoryEvosAttacks:
	db 0 ; no more evolutions
	db 1,LEER
	db 1,PECK
	db 13,SAND_ATTACK
	db 19,SWIFT
	db 25,AGILITY
	db 37,FURY_ATTACK
	db 49,STEEL_WING
	db 0 ; no more level-up moves

HoundourEvosAttacks:
	db EVOLVE_LEVEL,24,HOUNDOOM
	db 0 ; no more evolutions
	db 1,LEER
	db 1,EMBER
	db 7,ROAR
	db 13,SMOG
	db 20,BITE
	db 27,FAINT_ATTACK
	db 35,FLAMETHROWER
	db 43,CRUNCH
	db 0 ; no more level-up moves

HoundoomEvosAttacks:
	db 0 ; no more evolutions
	db 1,LEER
	db 1,EMBER
	db 7,ROAR
	db 13,SMOG
	db 20,BITE
	db 30,FAINT_ATTACK
	db 41,FLAMETHROWER
	db 52,CRUNCH
	db 0 ; no more level-up moves

KingdraEvosAttacks:
	db 0 ; no more evolutions
	db 1,BUBBLE
	db 1,SMOKESCREEN
	db 1,LEER
	db 1,WATER_GUN
	db 8,SMOKESCREEN
	db 15,LEER
	db 22,WATER_GUN
	db 29,TWISTER
	db 40,AGILITY
	db 51,HYDRO_PUMP
	db 0 ; no more level-up moves

PhanpyEvosAttacks:
	db EVOLVE_LEVEL,25,DONPHAN
	db 0 ; no more evolutions
	db 1,TACKLE
	db 1,GROWL
	db 9,DEFENSE_CURL
	db 17,FLAIL
	db 25,TAKE_DOWN
	db 33,ROLLOUT
	db 41,ENDURE
	db 49,DOUBLE_EDGE
	db 0 ; no more level-up moves

DonphanEvosAttacks:
	db 0 ; no more evolutions
	db 1,HORN_ATTACK
	db 1,GROWL
	db 9,DEFENSE_CURL
	db 17,FLAIL
	db 25,FURY_ATTACK
	db 33,ROLLOUT
	db 41,RAPID_SPIN
	db 49,EARTHQUAKE
	db 0 ; no more level-up moves

Porygon2EvosAttacks:
	db 0 ; no more evolutions
	db 1,CONVERSION2
	db 1,TACKLE
	db 1,CONVERSION
	db 9,AGILITY
	db 12,PSYBEAM
	db 20,RECOVER
	db 24,DEFENSE_CURL
	db 32,LOCK_ON
	db 36,TRI_ATTACK
	db 44,ZAP_CANNON
	db 0 ; no more level-up moves

StantlerEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 8,LEER
	db 15,HYPNOSIS
	db 23,STOMP
	db 31,SAND_ATTACK
	db 40,TAKE_DOWN
	db 49,CONFUSE_RAY
	db 0 ; no more level-up moves

SmeargleEvosAttacks:
	db 0 ; no more evolutions
	db 1,SKETCH
	db 11,SKETCH
	db 21,SKETCH
	db 31,SKETCH
	db 41,SKETCH
	db 51,SKETCH
	db 61,SKETCH
	db 71,SKETCH
	db 81,SKETCH
	db 91,SKETCH
	db 0 ; no more level-up moves

TyrogueEvosAttacks:
	db EVOLVE_STAT,20,ATK_LT_DEF,HITMONCHAN
	db EVOLVE_STAT,20,ATK_GT_DEF,HITMONLEE
	db EVOLVE_STAT,20,ATK_EQ_DEF,HITMONTOP
	db 0 ; no more evolutions
	db 1,TACKLE
	db 0 ; no more level-up moves

HitmontopEvosAttacks:
	db 0 ; no more evolutions
	db 1,ROLLING_KICK
	db 7,FOCUS_ENERGY
	db 13,PURSUIT
	db 19,QUICK_ATTACK
	db 25,RAPID_SPIN
	db 31,COUNTER
	db 37,AGILITY
	db 43,DETECT
	db 49,TRIPLE_KICK
	db 0 ; no more level-up moves

SmoochumEvosAttacks:
	db EVOLVE_LEVEL,30,JYNX
	db 0 ; no more evolutions
	db 1,POUND
	db 1,LICK
	db 9,SWEET_KISS
	db 13,POWDER_SNOW
	db 21,CONFUSION
	db 25,SING
	db 33,MEAN_LOOK
	db 37,PSYCHIC_M
	db 45,PERISH_SONG
	db 49,BLIZZARD
	db 0 ; no more level-up moves

ElekidEvosAttacks:
	db EVOLVE_LEVEL,30,ELECTABUZZ
	db 0 ; no more evolutions
	db 1,QUICK_ATTACK
	db 1,LEER
	db 9,THUNDERPUNCH
	db 17,LIGHT_SCREEN
	db 25,SWIFT
	db 33,SCREECH
	db 41,THUNDERBOLT
	db 49,THUNDER
	db 0 ; no more level-up moves

MagbyEvosAttacks:
	db EVOLVE_LEVEL,30,MAGMAR
	db 0 ; no more evolutions
	db 1,EMBER
	db 7,LEER
	db 13,SMOG
	db 19,FIRE_PUNCH
	db 25,SMOKESCREEN
	db 31,SUNNY_DAY
	db 37,FLAMETHROWER
	db 43,CONFUSE_RAY
	db 49,FIRE_BLAST
	db 0 ; no more level-up moves

MiltankEvosAttacks:
	db 0 ; no more evolutions
	db 1,TACKLE
	db 4,GROWL
	db 8,DEFENSE_CURL
	db 13,STOMP
	db 19,MILK_DRINK
	db 26,BIDE
	db 34,ROLLOUT
	db 43,BODY_SLAM
	db 53,HEAL_BELL
	db 0 ; no more level-up moves

BlisseyEvosAttacks:
	db 0 ; no more evolutions
	db 1,POUND
	db 4,GROWL
	db 7,TAIL_WHIP
	db 10,SOFTBOILED
	db 13,DOUBLESLAP
	db 18,MINIMIZE
	db 23,SING
	db 28,EGG_BOMB
	db 33,DEFENSE_CURL
	db 40,LIGHT_SCREEN
	db 47,DOUBLE_EDGE
	db 0 ; no more level-up moves

RaikouEvosAttacks:
	db 0 ; no more evolutions
	db 1,BITE
	db 1,LEER
	db 11,THUNDERSHOCK
	db 21,ROAR
	db 31,QUICK_ATTACK
	db 41,SPARK
	db 51,REFLECT
	db 61,CRUNCH
	db 71,THUNDER
	db 0 ; no more level-up moves

EnteiEvosAttacks:
	db 0 ; no more evolutions
	db 1,BITE
	db 1,LEER
	db 11,EMBER
	db 21,ROAR
	db 31,FIRE_SPIN
	db 41,STOMP
	db 51,FLAMETHROWER
	db 61,SWAGGER
	db 71,FIRE_BLAST
	db 0 ; no more level-up moves

SuicuneEvosAttacks:
	db 0 ; no more evolutions
	db 1,BITE
	db 1,LEER
if _CRYSTAL
	db 11,BUBBLEBEAM
	db 21,RAIN_DANCE
	db 31,GUST
	db 41,AURORA_BEAM
else
	db 11,WATER_GUN
	db 21,ROAR
	db 31,GUST
	db 41,BUBBLEBEAM
endc
	db 51,MIST
	db 61,MIRROR_COAT
	db 71,HYDRO_PUMP
	db 0 ; no more level-up moves

LarvitarEvosAttacks:
	db EVOLVE_LEVEL,30,PUPITAR
	db 0 ; no more evolutions
	db 1,BITE
	db 1,LEER
	db 8,SANDSTORM
	db 15,SCREECH
	db 22,ROCK_SLIDE
	db 29,THRASH
	db 36,SCARY_FACE
	db 43,CRUNCH
	db 50,EARTHQUAKE
	db 57,HYPER_BEAM
	db 0 ; no more level-up moves

PupitarEvosAttacks:
	db EVOLVE_LEVEL,55,TYRANITAR
	db 0 ; no more evolutions
	db 1,BITE
	db 1,LEER
	db 1,SANDSTORM
	db 1,SCREECH
	db 8,SANDSTORM
	db 15,SCREECH
	db 22,ROCK_SLIDE
	db 29,THRASH
	db 38,SCARY_FACE
	db 47,CRUNCH
	db 56,EARTHQUAKE
	db 65,HYPER_BEAM
	db 0 ; no more level-up moves

TyranitarEvosAttacks:
	db 0 ; no more evolutions
	db 1,BITE
	db 1,LEER
	db 1,SANDSTORM
	db 1,SCREECH
	db 8,SANDSTORM
	db 15,SCREECH
	db 22,ROCK_SLIDE
	db 29,THRASH
	db 38,SCARY_FACE
	db 47,CRUNCH
	db 61,EARTHQUAKE
	db 75,HYPER_BEAM
	db 0 ; no more level-up moves

LugiaEvosAttacks:
	db 0 ; no more evolutions
	db 1,AEROBLAST
	db 11,SAFEGUARD
	db 22,GUST
	db 33,RECOVER
	db 44,HYDRO_PUMP
	db 55,RAIN_DANCE
	db 66,SWIFT
	db 77,WHIRLWIND
	db 88,ANCIENTPOWER
	db 99,FUTURE_SIGHT
	db 0 ; no more level-up moves

HoOhEvosAttacks:
	db 0 ; no more evolutions
	db 1,SACRED_FIRE
	db 11,SAFEGUARD
	db 22,GUST
	db 33,RECOVER
	db 44,FIRE_BLAST
	db 55,SUNNY_DAY
	db 66,SWIFT
	db 77,WHIRLWIND
	db 88,ANCIENTPOWER
	db 99,FUTURE_SIGHT
	db 0 ; no more level-up moves

CelebiEvosAttacks:
	db 0 ; no more evolutions
	db 1,LEECH_SEED
	db 1,CONFUSION
	db 1,RECOVER
	db 1,HEAL_BELL
	db 10,SAFEGUARD
	db 20,ANCIENTPOWER
	db 30,FUTURE_SIGHT
	db 40,BATON_PASS
	db 50,PERISH_SONG
	db 0 ; no more level-up moves


SECTION "bank11",DATA,BANK[$11]

INCBIN "baserom.gbc",$44000,$44378 - $44000

PokedexDataPointerTable: ; 0x44378
	dw BulbasaurPokedexEntry
	dw IvysaurPokedexEntry
	dw VenusaurPokedexEntry
	dw CharmanderPokedexEntry
	dw CharmeleonPokedexEntry
	dw CharizardPokedexEntry
	dw SquirtlePokedexEntry
	dw WartortlePokedexEntry
	dw BlastoisePokedexEntry
	dw CaterpiePokedexEntry
	dw MetapodPokedexEntry
	dw ButterfreePokedexEntry
	dw WeedlePokedexEntry
	dw KakunaPokedexEntry
	dw BeedrillPokedexEntry
	dw PidgeyPokedexEntry
	dw PidgeottoPokedexEntry
	dw PidgeotPokedexEntry
	dw RattataPokedexEntry
	dw RaticatePokedexEntry
	dw SpearowPokedexEntry
	dw FearowPokedexEntry
	dw EkansPokedexEntry
	dw ArbokPokedexEntry
	dw PikachuPokedexEntry
	dw RaichuPokedexEntry
	dw SandshrewPokedexEntry
	dw SandslashPokedexEntry
	dw NidoranFPokedexEntry
	dw NidorinaPokedexEntry
	dw NidoqueenPokedexEntry
	dw NidoranMPokedexEntry
	dw NidorinoPokedexEntry
	dw NidokingPokedexEntry
	dw ClefairyPokedexEntry
	dw ClefablePokedexEntry
	dw VulpixPokedexEntry
	dw NinetalesPokedexEntry
	dw JigglypuffPokedexEntry
	dw WigglytuffPokedexEntry
	dw ZubatPokedexEntry
	dw GolbatPokedexEntry
	dw OddishPokedexEntry
	dw GloomPokedexEntry
	dw VileplumePokedexEntry
	dw ParasPokedexEntry
	dw ParasectPokedexEntry
	dw VenonatPokedexEntry
	dw VenomothPokedexEntry
	dw DiglettPokedexEntry
	dw DugtrioPokedexEntry
	dw MeowthPokedexEntry
	dw PersianPokedexEntry
	dw PsyduckPokedexEntry
	dw GolduckPokedexEntry
	dw MankeyPokedexEntry
	dw PrimeapePokedexEntry
	dw GrowlithePokedexEntry
	dw ArcaninePokedexEntry
	dw PoliwagPokedexEntry
	dw PoliwhirlPokedexEntry
	dw PoliwrathPokedexEntry
	dw AbraPokedexEntry
	dw KadabraPokedexEntry
	dw AlakazamPokedexEntry
	dw MachopPokedexEntry
	dw MachokePokedexEntry
	dw MachampPokedexEntry
	dw BellsproutPokedexEntry
	dw WeepinbellPokedexEntry
	dw VictreebelPokedexEntry
	dw TentacoolPokedexEntry
	dw TentacruelPokedexEntry
	dw GeodudePokedexEntry
	dw GravelerPokedexEntry
	dw GolemPokedexEntry
	dw PonytaPokedexEntry
	dw RapidashPokedexEntry
	dw SlowpokePokedexEntry
	dw SlowbroPokedexEntry
	dw MagnemitePokedexEntry
	dw MagnetonPokedexEntry
	dw FarfetchDPokedexEntry
	dw DoduoPokedexEntry
	dw DodrioPokedexEntry
	dw SeelPokedexEntry
	dw DewgongPokedexEntry
	dw GrimerPokedexEntry
	dw MukPokedexEntry
	dw ShellderPokedexEntry
	dw CloysterPokedexEntry
	dw GastlyPokedexEntry
	dw HaunterPokedexEntry
	dw GengarPokedexEntry
	dw OnixPokedexEntry
	dw DrowzeePokedexEntry
	dw HypnoPokedexEntry
	dw KrabbyPokedexEntry
	dw KinglerPokedexEntry
	dw VoltorbPokedexEntry
	dw ElectrodePokedexEntry
	dw ExeggcutePokedexEntry
	dw ExeggutorPokedexEntry
	dw CubonePokedexEntry
	dw MarowakPokedexEntry
	dw HitmonleePokedexEntry
	dw HitmonchanPokedexEntry
	dw LickitungPokedexEntry
	dw KoffingPokedexEntry
	dw WeezingPokedexEntry
	dw RhyhornPokedexEntry
	dw RhydonPokedexEntry
	dw ChanseyPokedexEntry
	dw TangelaPokedexEntry
	dw KangaskhanPokedexEntry
	dw HorseaPokedexEntry
	dw SeadraPokedexEntry
	dw GoldeenPokedexEntry
	dw SeakingPokedexEntry
	dw StaryuPokedexEntry
	dw StarmiePokedexEntry
	dw MrMimePokedexEntry
	dw ScytherPokedexEntry
	dw JynxPokedexEntry
	dw ElectabuzzPokedexEntry
	dw MagmarPokedexEntry
	dw PinsirPokedexEntry
	dw TaurosPokedexEntry
	dw MagikarpPokedexEntry
	dw GyaradosPokedexEntry
	dw LaprasPokedexEntry
	dw DittoPokedexEntry
	dw EeveePokedexEntry
	dw VaporeonPokedexEntry
	dw JolteonPokedexEntry
	dw FlareonPokedexEntry
	dw PorygonPokedexEntry
	dw OmanytePokedexEntry
	dw OmastarPokedexEntry
	dw KabutoPokedexEntry
	dw KabutopsPokedexEntry
	dw AerodactylPokedexEntry
	dw SnorlaxPokedexEntry
	dw ArticunoPokedexEntry
	dw ZapdosPokedexEntry
	dw MoltresPokedexEntry
	dw DratiniPokedexEntry
	dw DragonairPokedexEntry
	dw DragonitePokedexEntry
	dw MewtwoPokedexEntry
	dw MewPokedexEntry
	dw ChikoritaPokedexEntry
	dw BayleefPokedexEntry
	dw MeganiumPokedexEntry
	dw CyndaquilPokedexEntry
	dw QuilavaPokedexEntry
	dw TyphlosionPokedexEntry
	dw TotodilePokedexEntry
	dw CroconawPokedexEntry
	dw FeraligatrPokedexEntry
	dw SentretPokedexEntry
	dw FurretPokedexEntry
	dw HoothootPokedexEntry
	dw NoctowlPokedexEntry
	dw LedybaPokedexEntry
	dw LedianPokedexEntry
	dw SpinarakPokedexEntry
	dw AriadosPokedexEntry
	dw CrobatPokedexEntry
	dw ChinchouPokedexEntry
	dw LanturnPokedexEntry
	dw PichuPokedexEntry
	dw CleffaPokedexEntry
	dw IgglybuffPokedexEntry
	dw TogepiPokedexEntry
	dw TogeticPokedexEntry
	dw NatuPokedexEntry
	dw XatuPokedexEntry
	dw MareepPokedexEntry
	dw FlaaffyPokedexEntry
	dw AmpharosPokedexEntry
	dw BellossomPokedexEntry
	dw MarillPokedexEntry
	dw AzumarillPokedexEntry
	dw SudowoodoPokedexEntry
	dw PolitoedPokedexEntry
	dw HoppipPokedexEntry
	dw SkiploomPokedexEntry
	dw JumpluffPokedexEntry
	dw AipomPokedexEntry
	dw SunkernPokedexEntry
	dw SunfloraPokedexEntry
	dw YanmaPokedexEntry
	dw WooperPokedexEntry
	dw QuagsirePokedexEntry
	dw EspeonPokedexEntry
	dw UmbreonPokedexEntry
	dw MurkrowPokedexEntry
	dw SlowkingPokedexEntry
	dw MisdreavusPokedexEntry
	dw UnownPokedexEntry
	dw WobbuffetPokedexEntry
	dw GirafarigPokedexEntry
	dw PinecoPokedexEntry
	dw ForretressPokedexEntry
	dw DunsparcePokedexEntry
	dw GligarPokedexEntry
	dw SteelixPokedexEntry
	dw SnubbullPokedexEntry
	dw GranbullPokedexEntry
	dw QwilfishPokedexEntry
	dw ScizorPokedexEntry
	dw ShucklePokedexEntry
	dw HeracrossPokedexEntry
	dw SneaselPokedexEntry
	dw TeddiursaPokedexEntry
	dw UrsaringPokedexEntry
	dw SlugmaPokedexEntry
	dw MagcargoPokedexEntry
	dw SwinubPokedexEntry
	dw PiloswinePokedexEntry
	dw CorsolaPokedexEntry
	dw RemoraidPokedexEntry
	dw OctilleryPokedexEntry
	dw DelibirdPokedexEntry
	dw MantinePokedexEntry
	dw SkarmoryPokedexEntry
	dw HoundourPokedexEntry
	dw HoundoomPokedexEntry
	dw KingdraPokedexEntry
	dw PhanpyPokedexEntry
	dw DonphanPokedexEntry
	dw Porygon2PokedexEntry
	dw StantlerPokedexEntry
	dw SmearglePokedexEntry
	dw TyroguePokedexEntry
	dw HitmontopPokedexEntry
	dw SmoochumPokedexEntry
	dw ElekidPokedexEntry
	dw MagbyPokedexEntry
	dw MiltankPokedexEntry
	dw BlisseyPokedexEntry
	dw RaikouPokedexEntry
	dw EnteiPokedexEntry
	dw SuicunePokedexEntry
	dw LarvitarPokedexEntry
	dw PupitarPokedexEntry
	dw TyranitarPokedexEntry
	dw LugiaPokedexEntry
	dw HoOhPokedexEntry
	dw CelebiPokedexEntry
	
; 0x4456e

INCBIN "baserom.gbc",$4456e,$3a92

SECTION "bank12",DATA,BANK[$12]

INCBIN "baserom.gbc",$48000,$49d24 - $48000

ContinueText: ; 0x49d24
	db "CONTINUE@"
NewGameText: ; 0x49d2d
	db "NEW GAME@"
OptionText: ; 0x49d36
	db "OPTION@"
MysteryGiftText: ; 0x49d3d
	db "MYSTERY GIFT@"
MobileText: ; 0x49d4a
	db "MOBILE@"
MobileStudiumText: ; 0x49d51
	db "MOBILE STUDIUM@"

Label49d60: ; 0x49d60
	dw $5eee ; XXX is this ContinueASM?
	dw $5ee0 ; XXX is this NewGameASM?
	dw $5ee7 ; XXX is this OptionASM?
	dw $5ef5 ; XXX is this MysteryGiftASM?
	dw $5efc ; XXX is this MobileASM?
	dw $6496 ; XXX is this MobileStudiumASM?

NewGameMenu: ; 0x49d6c
	db 2
	db NEW_GAME
	db OPTION
	db $ff

ContinueMenu: ; 0x49d70
	db 3
	db CONTINUE
	db NEW_GAME
	db OPTION
	db $ff

MobileMysteryMenu: ; 0x49d75
	db 5
	db CONTINUE
	db NEW_GAME
	db OPTION
	db MYSTERY_GIFT
	db MOBILE
	db $ff

MobileMenu: ; 0x49d7c
	db 4
	db CONTINUE
	db NEW_GAME
	db OPTION
	db MOBILE
	db $ff

MobileStudiumMenu: ; 0x49d82
	db 5
	db CONTINUE
	db NEW_GAME
	db OPTION
	db MOBILE
	db MOBILE_STUDIUM
	db $ff

MysteryMobileStudiumMenu: ; 0x49d89
	db 6
	db CONTINUE
	db NEW_GAME
	db OPTION
	db MYSTERY_GIFT
	db MOBILE
	db MOBILE_STUDIUM
	db $ff

MysteryMenu: ; 0x49d91
	db 4
	db CONTINUE
	db NEW_GAME
	db OPTION
	db MYSTERY_GIFT
	db $ff

MysteryStudiumMenu: ; 0x49d97
	db 5
	db CONTINUE
	db NEW_GAME
	db OPTION
	db MYSTERY_GIFT
	db MOBILE_STUDIUM
	db $ff

StudiumMenu: ; 0x49d9e
	db 4
	db CONTINUE
	db NEW_GAME
	db OPTION
	db MOBILE_STUDIUM
	db $ff

INCBIN "baserom.gbc",$49da4,$4a6e8 - $49da4

SpecialBeastsCheck: ; 0x4a6e8
; Check if the player owns all three legendary beasts.
; They must exist in either party or PC, and have the player's OT and ID.

; outputs:
; ScriptVar is 1 if the Pokémon exist, otherwise 0.

	ld a, RAIKOU
	ld [ScriptVar], a
	call CheckOwnMonAnywhere
	jr nc, .notexist

	ld a, ENTEI
	ld [ScriptVar], a
	call CheckOwnMonAnywhere
	jr nc, .notexist

	ld a, SUICUNE
	ld [ScriptVar], a
	call CheckOwnMonAnywhere
	jr nc, .notexist

	; they exist
	ld a, $1
	ld [ScriptVar], a
	ret

.notexist
	xor a
	ld [ScriptVar], a
	ret

SpecialMonCheck: ; 0x4a711
; Check if a Pokémon exists in PC or party.
; It must exist in either party or PC, and have the player's OT and ID.

; inputs:
; ScriptVar contains species to search for
	call CheckOwnMonAnywhere
	jr c, .exists

	; doesn't exist
	xor a
	ld [ScriptVar], a
	ret

.exists
	ld a, $1
	ld [ScriptVar], a
	ret

CheckOwnMonAnywhere: ; 0x4a721
	ld a, [PartyCount]
	and a
	ret z ; no pokémon in party

	ld d, a
	ld e, $0
	ld hl, PartyMon1Species
	ld bc, PartyMon1OT

; run CheckOwnMon on each Pokémon in the party
.loop
	call CheckOwnMon
	ret c ; found!

	push bc
	ld bc, PartyMon2 - PartyMon1
	add hl, bc
	pop bc
	call UpdateOTPointer
	dec d
	jr nz, .loop ; 0x4a73d $f0

; XXX the below could use some cleanup
; run CheckOwnMon on each Pokémon in the PC
	ld a, $1
	call GetSRAMBank
	ld a, [$ad10]
	and a
	jr z, .asm_4a766 ; 0x4a748 $1c
	ld d, a
	ld hl, $ad26
	ld bc, $afa6
.asm_4a751
	call CheckOwnMon
	jr nc, .asm_4a75a ; 0x4a754 $4
	call CloseSRAM
	ret
.asm_4a75a
	push bc
	ld bc, $0020
	add hl, bc
	pop bc
	call UpdateOTPointer
	dec d
	jr nz, .asm_4a751 ; 0x4a764 $eb
.asm_4a766
	call CloseSRAM
	ld c, $0
.asm_4a76b
	ld a, [$db72]
	and $f
	cp c
	jr z, .asm_4a7af ; 0x4a771 $3c
	ld hl, $6810
	ld b, $0
	add hl, bc
	add hl, bc
	add hl, bc
	ld a, [hli]
	call GetSRAMBank
	ld a, [hli]
	ld h, [hl]
	ld l, a
	ld a, [hl]
	and a
	jr z, .asm_4a7af ; 0x4a784 $29
	push bc
	push hl
	ld de, $0016
	add hl, de
	ld d, h
	ld e, l
	pop hl
	push de
	ld de, $0296
	add hl, de
	ld b, h
	ld c, l
	pop hl
	ld d, a
.asm_4a798
	call CheckOwnMon
	jr nc, .asm_4a7a2 ; 0x4a79b $5
	pop bc
	call CloseSRAM
	ret
.asm_4a7a2
	push bc
	ld bc, $0020
	add hl, bc
	pop bc
	call UpdateOTPointer
	dec d
	jr nz, .asm_4a798 ; 0x4a7ac $ea
	pop bc
.asm_4a7af
	inc c
	ld a, c
	cp $e
	jr c, .asm_4a76b ; 0x4a7b3 $b6
	call CloseSRAM
	and a ; clear carry
	ret

CheckOwnMon: ; 0x4a7ba
; Check if a Pokémon belongs to the player and is of a specific species.

; inputs:
; hl, pointer to PartyMonNSpecies
; bc, pointer to PartyMonNOT
; ScriptVar should contain the species we're looking for

; outputs:
; sets carry if monster matches species, ID, and OT name.

	push bc
	push hl
	push de
	ld d, b
	ld e, c

; check species
	ld a, [ScriptVar] ; species we're looking for
	ld b, [hl] ; species we have
	cp b
	jr nz, .notfound ; species doesn't match

; check ID number
	ld bc, PartyMon1ID - PartyMon1Species
	add hl, bc ; now hl points to ID number
	ld a, [PlayerID]
	cp [hl]
	jr nz, .notfound ; ID doesn't match
	inc hl
	ld a, [PlayerID + 1]
	cp [hl]
	jr nz, .notfound ; ID doesn't match

; check OT
; This only checks five characters, which is fine for the Japanese version,
; but in the English version the player name is 7 characters, so this is wrong.

	ld hl, PlayerName

	ld a, [de]
	cp [hl]
	jr nz, .notfound
	cp "@"
	jr z, .found ; reached end of string
	inc hl
	inc de

	ld a, [de]
	cp [hl]
	jr nz, .notfound
	cp $50
	jr z, .found
	inc hl
	inc de

	ld a, [de]
	cp [hl]
	jr nz, .notfound
	cp $50
	jr z, .found
	inc hl
	inc de

	ld a, [de]
	cp [hl]
	jr nz, .notfound
	cp $50
	jr z, .found
	inc hl
	inc de

	ld a, [de]
	cp [hl]
	jr z, .found

.notfound
	pop de
	pop hl
	pop bc
	and a ; clear carry
	ret
.found
	pop de
	pop hl
	pop bc
	scf
	ret

; 0x4a810
INCBIN "baserom.gbc", $4a810, $4a83a - $4a810

UpdateOTPointer: ; 0x4a83a
	push hl
	ld hl, PartyMon2OT - PartyMon1OT
	add hl, bc
	ld b, h
	ld c, l
	pop hl
	ret
; 0x4a843

INCBIN "baserom.gbc",$4a843,$4C000 - $4a843

SECTION "bank13",DATA,BANK[$13]

INCBIN "baserom.gbc",$4C000,$4ce1f - $4C000

TileTypeTable: ; 4ce1f
; 256 tiletypes
; 01 = surfable
	db $00, $00, $00, $00, $00, $00, $00, $0f
	db $00, $00, $00, $00, $00, $00, $00, $0f
	db $00, $00, $1f, $00, $00, $1f, $00, $00
	db $00, $00, $1f, $00, $00, $1f, $00, $00
	db $01, $01, $11, $00, $11, $01, $01, $0f
	db $01, $01, $11, $00, $11, $01, $01, $0f
	db $01, $01, $01, $01, $01, $01, $01, $01
	db $01, $01, $01, $01, $01, $01, $01, $01
	
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $0f, $00, $00, $00, $00, $00
	db $00, $00, $0f, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	
	db $0f, $0f, $0f, $0f, $0f, $00, $00, $00
	db $0f, $0f, $0f, $0f, $0f, $00, $00, $00
	db $0f, $0f, $0f, $0f, $0f, $0f, $0f, $0f
	db $0f, $0f, $0f, $0f, $0f, $0f, $0f, $0f
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	
	db $01, $01, $01, $01, $01, $01, $01, $01
	db $01, $01, $01, $01, $01, $01, $01, $01
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $00
	db $00, $00, $00, $00, $00, $00, $00, $0f
; 4cf1f

INCBIN "baserom.gbc",$4cf1f,$50000 - $4cf1f

SECTION "bank14",DATA,BANK[$14]

INCBIN "baserom.gbc",$50000,$5097B-$50000

dw Normal, Fighting, Flying, Poison, Ground, Rock, Bird, Bug, Ghost, Steel
dw Normal, Normal, Normal, Normal, Normal, Normal, Normal, Normal, Normal
dw UnknownType, Fire, Water, Grass, Electric, Psychic, Ice, Dragon, Dark

Normal:
	db "NORMAL@"
Fighting:
	db "FIGHTING@"
Flying:
	db "FLYING@"
Poison:
	db "POISON@"
UnknownType:
	db "???@"
Fire:
	db "FIRE@"
Water:
	db "WATER@"
Grass:
	db "GRASS@"
Electric:
	db "ELECTRIC@"
Psychic:
	db "PSYCHIC@"
Ice:
	db "ICE@"
Ground:
	db "GROUND@"
Rock:
	db "ROCK@"
Bird:
	db "BIRD@"
Bug:
	db "BUG@"
Ghost:
	db "GHOST@"
Steel:
	db "STEEL@"
Dragon:
	db "DRAGON@"
Dark:
	db "DARK@"

INCBIN "baserom.gbc",$50A28, $51424 - $50A28

BulbasaurBaseStats: ; 0x51424
	db BULBASAUR ; 001

	db  45,  49,  49,  45,  65,  65
	;   hp  atk  def  spd  sat  sdf

	db GRASS, POISON
	db 45 ; catch rate
	db 64 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, PLANT ; egg groups

	; tmhm
	db %00100110
	db %00011110
	db %00111101
	db %11000100
	db %10000110
	db %00011000
	db %01000101
	db %00000000
	; end

IvysaurBaseStats: ; 0x51444
	db IVYSAUR ; 002

	db  60,  62,  63,  60,  80,  80
	;   hp  atk  def  spd  sat  sdf

	db GRASS, POISON
	db 45 ; catch rate
	db 141 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, PLANT ; egg groups

	; tmhm
	db %00100110
	db %00011110
	db %00111101
	db %11000100
	db %10000110
	db %00011000
	db %01000101
	db %00000000
	; end

VenusaurBaseStats: ; 0x51464
	db VENUSAUR ; 003

	db  80,  82,  83,  80, 100, 100
	;   hp  atk  def  spd  sat  sdf

	db GRASS, POISON
	db 45 ; catch rate
	db 208 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, PLANT ; egg groups

	; tmhm
	db %00110110
	db %01011110
	db %00111101
	db %11000100
	db %10000110
	db %00011000
	db %01000101
	db %00000000
	; end

CharmanderBaseStats: ; 0x51484
	db CHARMANDER ; 004

	db  39,  52,  43,  65,  60,  50
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 45 ; catch rate
	db 65 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, REPTILE ; egg groups

	; tmhm
	db %10100111
	db %00010110
	db %11011001
	db %11001100
	db %11100110
	db %10011000
	db %00100101
	db %00000010
	; end

CharmeleonBaseStats: ; 0x514a4
	db CHARMELEON ; 005

	db  58,  64,  58,  80,  80,  65
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 45 ; catch rate
	db 142 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, REPTILE ; egg groups

	; tmhm
	db %10100111
	db %00010110
	db %11011001
	db %11001100
	db %11100110
	db %10011000
	db %00100101
	db %00000010
	; end

CharizardBaseStats: ; 0x514c4
	db CHARIZARD ; 006

	db  78,  84,  78, 100, 109,  85
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FLYING
	db 45 ; catch rate
	db 209 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, REPTILE ; egg groups

	; tmhm
	db %10110111
	db %01010110
	db %11011001
	db %11001110
	db %11110110
	db %11011000
	db %00101101
	db %00000010
	; end

SquirtleBaseStats: ; 0x514e4
	db SQUIRTLE ; 007

	db  44,  48,  65,  43,  50,  64
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 45 ; catch rate
	db 66 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %10101111
	db %10110010
	db %01011011
	db %11001100
	db %10000111
	db %00011000
	db %10110000
	db %00001001
	; end

WartortleBaseStats: ; 0x51504
	db WARTORTLE ; 008

	db  59,  63,  80,  58,  65,  80
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 45 ; catch rate
	db 143 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %10101111
	db %10110010
	db %01011011
	db %11001100
	db %10000111
	db %00011000
	db %10110000
	db %00001001
	; end

BlastoiseBaseStats: ; 0x51524
	db BLASTOISE ; 009

	db  79,  83, 100,  78,  85, 105
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 45 ; catch rate
	db 210 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %10111111
	db %11110010
	db %01011011
	db %11001110
	db %10000111
	db %00011000
	db %10110000
	db %00001001
	; end

CaterpieBaseStats: ; 0x51544
	db CATERPIE ; 010

	db  45,  30,  35,  45,  20,  20
	;   hp  atk  def  spd  sat  sdf

	db BUG, BUG
	db 255 ; catch rate
	db 53 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	; end

MetapodBaseStats: ; 0x51564
	db METAPOD ; 011

	db  50,  20,  55,  30,  25,  25
	;   hp  atk  def  spd  sat  sdf

	db BUG, BUG
	db 120 ; catch rate
	db 72 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	; end

ButterfreeBaseStats: ; 0x51584
	db BUTTERFREE ; 012

	db  60,  45,  50,  70,  80,  80
	;   hp  atk  def  spd  sat  sdf

	db BUG, FLYING
	db 45 ; catch rate
	db 160 ; base exp
	db NO_ITEM ; item 1
	db SILVERPOWDER ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00100100
	db %01011110
	db %00111101
	db %10010100
	db %01000110
	db %00011000
	db %01000010
	db %00000000
	; end

WeedleBaseStats: ; 0x515a4
	db WEEDLE ; 013

	db  40,  35,  30,  50,  20,  20
	;   hp  atk  def  spd  sat  sdf

	db BUG, POISON
	db 255 ; catch rate
	db 52 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	; end

KakunaBaseStats: ; 0x515c4
	db KAKUNA ; 014

	db  45,  25,  50,  35,  25,  25
	;   hp  atk  def  spd  sat  sdf

	db BUG, POISON
	db 120 ; catch rate
	db 71 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	; end

BeedrillBaseStats: ; 0x515e4
	db BEEDRILL ; 015

	db  65,  80,  40,  75,  45,  80
	;   hp  atk  def  spd  sat  sdf

	db BUG, POISON
	db 45 ; catch rate
	db 159 ; base exp
	db NO_ITEM ; item 1
	db POISON_BARB ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00100100
	db %01011110
	db %00011101
	db %10000100
	db %01001110
	db %00011000
	db %00000101
	db %00000000
	; end

PidgeyBaseStats: ; 0x51604
	db PIDGEY ; 016

	db  40,  45,  40,  56,  35,  35
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 255 ; catch rate
	db 55 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %00010110
	db %00011001
	db %11000100
	db %01000110
	db %01111100
	db %00001000
	db %00000000
	; end

PidgeottoBaseStats: ; 0x51624
	db PIDGEOTTO ; 017

	db  63,  60,  55,  71,  50,  50
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 120 ; catch rate
	db 113 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %00010110
	db %00011001
	db %11000100
	db %01000110
	db %01111100
	db %00001000
	db %00000000
	; end

PidgeotBaseStats: ; 0x51644
	db PIDGEOT ; 018

	db  83,  80,  75,  91,  70,  70
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 45 ; catch rate
	db 172 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %01010110
	db %00011001
	db %11000100
	db %01000110
	db %01111100
	db %00001000
	db %00000000
	; end

RattataBaseStats: ; 0x51664
	db RATTATA ; 019

	db  30,  56,  35,  72,  25,  35
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 255 ; catch rate
	db 57 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10100110
	db %10110110
	db %01011001
	db %11101101
	db %11000110
	db %00111000
	db %00000000
	db %00000000
	; end

RaticateBaseStats: ; 0x51684
	db RATICATE ; 020

	db  55,  81,  60,  97,  50,  70
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 90 ; catch rate
	db 116 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10110110
	db %11110110
	db %01011001
	db %11101101
	db %11000110
	db %00111000
	db %00100100
	db %00001100
	; end

SpearowBaseStats: ; 0x516a4
	db SPEAROW ; 021

	db  40,  60,  30,  70,  31,  31
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 255 ; catch rate
	db 58 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %00010110
	db %00011001
	db %11000100
	db %01000110
	db %01111100
	db %00001000
	db %00000000
	; end

FearowBaseStats: ; 0x516c4
	db FEAROW ; 022

	db  65,  90,  65, 100,  61,  61
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 90 ; catch rate
	db 162 ; base exp
	db NO_ITEM ; item 1
	db SHARP_BEAK ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %01010110
	db %00011001
	db %11000100
	db %01000110
	db %01111100
	db %00001000
	db %00000000
	; end

EkansBaseStats: ; 0x516e4
	db EKANS ; 023

	db  35,  60,  44,  55,  40,  54
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 255 ; catch rate
	db 62 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, REPTILE ; egg groups

	; tmhm
	db %00100110
	db %00010110
	db %00011101
	db %10001110
	db %00001110
	db %00111000
	db %00100000
	db %00000000
	; end

ArbokBaseStats: ; 0x51704
	db ARBOK ; 024

	db  60,  85,  69,  80,  65,  79
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 90 ; catch rate
	db 147 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, REPTILE ; egg groups

	; tmhm
	db %00100110
	db %01010110
	db %00011101
	db %10001110
	db %00001110
	db %00111000
	db %00100000
	db %00000000
	; end

PikachuBaseStats: ; 0x51724
	db PIKACHU ; 025

	db  35,  55,  30,  90,  50,  40
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 190 ; catch rate
	db 82 ; base exp
	db NO_ITEM ; item 1
	db BERRY ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FAIRY ; egg groups

	; tmhm
	db %01101111
	db %00010010
	db %01011011
	db %11000101
	db %11000110
	db %00011101
	db %01100000
	db %00000100
	; end

RaichuBaseStats: ; 0x51744
	db RAICHU ; 026

	db  60,  90,  55, 100,  90,  80
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 75 ; catch rate
	db 122 ; base exp
	db NO_ITEM ; item 1
	db BERRY ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FAIRY ; egg groups

	; tmhm
	db %01101111
	db %01010010
	db %01011011
	db %11000101
	db %11000110
	db %00111101
	db %01100000
	db %00000100
	; end

SandshrewBaseStats: ; 0x51764
	db SANDSHREW ; 027

	db  50,  75,  85,  40,  20,  30
	;   hp  atk  def  spd  sat  sdf

	db GROUND, GROUND
	db 255 ; catch rate
	db 93 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10101111
	db %00010110
	db %01011001
	db %11001110
	db %11010110
	db %00111100
	db %00100101
	db %00000000
	; end

SandslashBaseStats: ; 0x51784
	db SANDSLASH ; 028

	db  75, 100, 110,  65,  45,  55
	;   hp  atk  def  spd  sat  sdf

	db GROUND, GROUND
	db 90 ; catch rate
	db 163 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10101111
	db %01010110
	db %01011001
	db %11001110
	db %11010110
	db %00111100
	db %00100101
	db %00000000
	; end

Nidoran_FBaseStats: ; 0x517a4
	db NIDORAN_F ; 029

	db  55,  47,  52,  41,  40,  40
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 235 ; catch rate
	db 59 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 254 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, FIELD ; egg groups

	; tmhm
	db %00100110
	db %00110110
	db %01011011
	db %11000101
	db %10000110
	db %00111100
	db %00000000
	db %00000100
	; end

NidorinaBaseStats: ; 0x517c4
	db NIDORINA ; 030

	db  70,  62,  67,  56,  55,  55
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 120 ; catch rate
	db 117 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 254 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %10100110
	db %00110110
	db %01011011
	db %11000101
	db %10000110
	db %00111100
	db %00100000
	db %00001100
	; end

NidoqueenBaseStats: ; 0x517e4
	db NIDOQUEEN ; 031

	db  90,  82,  87,  76,  75,  85
	;   hp  atk  def  spd  sat  sdf

	db POISON, GROUND
	db 45 ; catch rate
	db 194 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 254 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %10110111
	db %11110110
	db %01011011
	db %11100111
	db %10110111
	db %10111101
	db %00110001
	db %00001110
	; end

Nidoran_MBaseStats: ; 0x51804
	db NIDORAN_M ; 032

	db  46,  57,  40,  50,  40,  40
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 235 ; catch rate
	db 60 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 0 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, FIELD ; egg groups

	; tmhm
	db %00100110
	db %00110110
	db %01011011
	db %11000101
	db %10000110
	db %00111100
	db %00000000
	db %00000100
	; end

NidorinoBaseStats: ; 0x51824
	db NIDORINO ; 033

	db  61,  72,  57,  65,  55,  55
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 120 ; catch rate
	db 118 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 0 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, FIELD ; egg groups

	; tmhm
	db %10100110
	db %00110110
	db %01011011
	db %11000101
	db %10000110
	db %00111100
	db %00100000
	db %00001100
	; end

NidokingBaseStats: ; 0x51844
	db NIDOKING ; 034

	db  81,  92,  77,  85,  85,  75
	;   hp  atk  def  spd  sat  sdf

	db POISON, GROUND
	db 45 ; catch rate
	db 195 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 0 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, FIELD ; egg groups

	; tmhm
	db %10110111
	db %11110110
	db %01011011
	db %11100111
	db %10110111
	db %10111101
	db %00110001
	db %00001110
	; end

ClefairyBaseStats: ; 0x51864
	db CLEFAIRY ; 035

	db  70,  45,  48,  35,  60,  65
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 150 ; catch rate
	db 68 ; base exp
	db MYSTERYBERRY ; item 1
	db MOON_STONE ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FAIRY, FAIRY ; egg groups

	; tmhm
	db %01101111
	db %00110111
	db %01111011
	db %11110101
	db %10100111
	db %10011111
	db %01100010
	db %00001110
	; end

ClefableBaseStats: ; 0x51884
	db CLEFABLE ; 036

	db  95,  70,  73,  60,  85,  90
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 25 ; catch rate
	db 129 ; base exp
	db MYSTERYBERRY ; item 1
	db MOON_STONE ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FAIRY, FAIRY ; egg groups

	; tmhm
	db %01101111
	db %01110111
	db %01111011
	db %11110101
	db %10100111
	db %10011111
	db %01100010
	db %00001110
	; end

VulpixBaseStats: ; 0x518a4
	db VULPIX ; 037

	db  38,  41,  40,  65,  50,  65
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 190 ; catch rate
	db 63 ; base exp
	db BURNT_BERRY ; item 1
	db BURNT_BERRY ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00100110
	db %00010110
	db %01011001
	db %10001100
	db %01100110
	db %00011000
	db %00000000
	db %00000010
	; end

NinetalesBaseStats: ; 0x518c4
	db NINETALES ; 038

	db  73,  76,  75, 100,  81, 100
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 75 ; catch rate
	db 178 ; base exp
	db BURNT_BERRY ; item 1
	db BURNT_BERRY ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00110110
	db %01010110
	db %01011001
	db %10001100
	db %01100110
	db %00011000
	db %00000000
	db %00000010
	; end

JigglypuffBaseStats: ; 0x518e4
	db JIGGLYPUFF ; 039

	db 115,  45,  20,  20,  45,  25
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 170 ; catch rate
	db 76 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FAIRY, FAIRY ; egg groups

	; tmhm
	db %01101111
	db %00110111
	db %00111011
	db %11110101
	db %10100111
	db %10011111
	db %01100010
	db %00001110
	; end

WigglytuffBaseStats: ; 0x51904
	db WIGGLYTUFF ; 040

	db 140,  70,  45,  45,  75,  50
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 50 ; catch rate
	db 109 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FAIRY, FAIRY ; egg groups

	; tmhm
	db %01101111
	db %01110111
	db %00111011
	db %11110101
	db %10100111
	db %10011111
	db %01100010
	db %00001110
	; end

ZubatBaseStats: ; 0x51924
	db ZUBAT ; 041

	db  40,  45,  35,  55,  30,  40
	;   hp  atk  def  spd  sat  sdf

	db POISON, FLYING
	db 255 ; catch rate
	db 54 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %00010110
	db %00011101
	db %10000100
	db %01000110
	db %01111100
	db %00000000
	db %00000000
	; end

GolbatBaseStats: ; 0x51944
	db GOLBAT ; 042

	db  75,  80,  70,  90,  65,  75
	;   hp  atk  def  spd  sat  sdf

	db POISON, FLYING
	db 90 ; catch rate
	db 171 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %01010110
	db %00011101
	db %10000100
	db %01000110
	db %01111100
	db %00000000
	db %00000000
	; end

OddishBaseStats: ; 0x51964
	db ODDISH ; 043

	db  45,  50,  55,  30,  75,  65
	;   hp  atk  def  spd  sat  sdf

	db GRASS, POISON
	db 255 ; catch rate
	db 78 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100100
	db %00011110
	db %00111101
	db %10000100
	db %00001110
	db %00011000
	db %01000100
	db %00000000
	; end

GloomBaseStats: ; 0x51984
	db GLOOM ; 044

	db  60,  65,  70,  40,  85,  75
	;   hp  atk  def  spd  sat  sdf

	db GRASS, POISON
	db 120 ; catch rate
	db 132 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100100
	db %00011110
	db %00111101
	db %10000100
	db %00001110
	db %00011000
	db %01000100
	db %00000000
	; end

VileplumeBaseStats: ; 0x519a4
	db VILEPLUME ; 045

	db  75,  80,  85,  50, 100,  90
	;   hp  atk  def  spd  sat  sdf

	db GRASS, POISON
	db 45 ; catch rate
	db 184 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100100
	db %01011110
	db %00111101
	db %10000100
	db %00001110
	db %00011000
	db %01000100
	db %00000000
	; end

ParasBaseStats: ; 0x519c4
	db PARAS ; 046

	db  35,  70,  55,  25,  45,  55
	;   hp  atk  def  spd  sat  sdf

	db BUG, GRASS
	db 190 ; catch rate
	db 70 ; base exp
	db TINYMUSHROOM ; item 1
	db BIG_MUSHROOM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, PLANT ; egg groups

	; tmhm
	db %10100100
	db %00011110
	db %00111101
	db %10001100
	db %00001110
	db %00111000
	db %01000101
	db %00000000
	; end

ParasectBaseStats: ; 0x519e4
	db PARASECT ; 047

	db  60,  95,  80,  30,  60,  80
	;   hp  atk  def  spd  sat  sdf

	db BUG, GRASS
	db 75 ; catch rate
	db 128 ; base exp
	db TINYMUSHROOM ; item 1
	db BIG_MUSHROOM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, PLANT ; egg groups

	; tmhm
	db %10100100
	db %01011110
	db %00111101
	db %10001100
	db %00001110
	db %00111000
	db %01000101
	db %00000000
	; end

VenonatBaseStats: ; 0x51a04
	db VENONAT ; 048

	db  60,  55,  50,  45,  40,  55
	;   hp  atk  def  spd  sat  sdf

	db BUG, POISON
	db 190 ; catch rate
	db 75 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00100100
	db %00011110
	db %00111101
	db %10010100
	db %01001110
	db %00111000
	db %00000000
	db %00000000
	; end

VenomothBaseStats: ; 0x51a24
	db VENOMOTH ; 049

	db  70,  65,  60,  90,  90,  75
	;   hp  atk  def  spd  sat  sdf

	db BUG, POISON
	db 75 ; catch rate
	db 138 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00100100
	db %01011110
	db %00111101
	db %10010100
	db %01001110
	db %00111000
	db %01000000
	db %00000000
	; end

DiglettBaseStats: ; 0x51a44
	db DIGLETT ; 050

	db  10,  55,  25,  95,  35,  45
	;   hp  atk  def  spd  sat  sdf

	db GROUND, GROUND
	db 255 ; catch rate
	db 81 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10100100
	db %00010110
	db %00011001
	db %11001110
	db %00001110
	db %00111000
	db %00000100
	db %00000000
	; end

DugtrioBaseStats: ; 0x51a64
	db DUGTRIO ; 051

	db  35,  80,  50, 120,  50,  70
	;   hp  atk  def  spd  sat  sdf

	db GROUND, GROUND
	db 50 ; catch rate
	db 153 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10100100
	db %01010110
	db %00011001
	db %11001110
	db %00001110
	db %00111000
	db %00000100
	db %00000000
	; end

MeowthBaseStats: ; 0x51a84
	db MEOWTH ; 052

	db  40,  45,  35,  90,  40,  40
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 255 ; catch rate
	db 69 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %01100110
	db %10010111
	db %01011001
	db %11100101
	db %11000110
	db %00111110
	db %00000010
	db %00000100
	; end

PersianBaseStats: ; 0x51aa4
	db PERSIAN ; 053

	db  65,  70,  60, 115,  65,  65
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 90 ; catch rate
	db 148 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %01110110
	db %11010111
	db %01011001
	db %11100101
	db %11000110
	db %00111110
	db %00000010
	db %00000100
	; end

PsyduckBaseStats: ; 0x51ac4
	db PSYDUCK ; 054

	db  50,  52,  48,  55,  65,  50
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 190 ; catch rate
	db 80 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, FIELD ; egg groups

	; tmhm
	db %10100111
	db %10110011
	db %01011011
	db %11001100
	db %01000111
	db %00011000
	db %11110000
	db %00001001
	; end

GolduckBaseStats: ; 0x51ae4
	db GOLDUCK ; 055

	db  80,  82,  78,  85,  95,  80
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 75 ; catch rate
	db 174 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, FIELD ; egg groups

	; tmhm
	db %10100111
	db %11110011
	db %01011011
	db %11001100
	db %01000111
	db %00011000
	db %11110001
	db %00001001
	; end

MankeyBaseStats: ; 0x51b04
	db MANKEY ; 056

	db  40,  80,  35,  70,  35,  45
	;   hp  atk  def  spd  sat  sdf

	db FIGHTING, FIGHTING
	db 190 ; catch rate
	db 74 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10100111
	db %00010111
	db %01011001
	db %11001101
	db %11000111
	db %10111101
	db %00100000
	db %00000100
	; end

PrimeapeBaseStats: ; 0x51b24
	db PRIMEAPE ; 057

	db  65, 105,  60,  95,  60,  70
	;   hp  atk  def  spd  sat  sdf

	db FIGHTING, FIGHTING
	db 75 ; catch rate
	db 149 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10100111
	db %01010111
	db %01011001
	db %11001101
	db %11000111
	db %10111101
	db %00100000
	db %00000100
	; end

GrowlitheBaseStats: ; 0x51b44
	db GROWLITHE ; 058

	db  55,  70,  45,  60,  70,  50
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 190 ; catch rate
	db 91 ; base exp
	db BURNT_BERRY ; item 1
	db BURNT_BERRY ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10110110
	db %00010110
	db %11011001
	db %10001100
	db %01100110
	db %00011000
	db %00000000
	db %00000010
	; end

ArcanineBaseStats: ; 0x51b64
	db ARCANINE ; 059

	db  90, 110,  80,  95, 100,  80
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 75 ; catch rate
	db 213 ; base exp
	db BURNT_BERRY ; item 1
	db BURNT_BERRY ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10110110
	db %01010110
	db %11011001
	db %10001100
	db %01100110
	db %00011000
	db %00000000
	db %00000010
	; end

PoliwagBaseStats: ; 0x51b84
	db POLIWAG ; 060

	db  40,  50,  40,  90,  40,  40
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 255 ; catch rate
	db 77 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AMPHIBIAN, AMPHIBIAN ; egg groups

	; tmhm
	db %00100110
	db %10110010
	db %00011011
	db %10010100
	db %10000110
	db %00111000
	db %10010000
	db %00001001
	; end

PoliwhirlBaseStats: ; 0x51ba4
	db POLIWHIRL ; 061

	db  65,  65,  65,  90,  50,  50
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 120 ; catch rate
	db 131 ; base exp
	db NO_ITEM ; item 1
	db KINGS_ROCK ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AMPHIBIAN, AMPHIBIAN ; egg groups

	; tmhm
	db %10100110
	db %10110010
	db %00011011
	db %11010110
	db %10000111
	db %00111100
	db %10110000
	db %00001001
	; end

PoliwrathBaseStats: ; 0x51bc4
	db POLIWRATH ; 062

	db  90,  85,  95,  70,  70,  90
	;   hp  atk  def  spd  sat  sdf

	db WATER, FIGHTING
	db 45 ; catch rate
	db 185 ; base exp
	db NO_ITEM ; item 1
	db KINGS_ROCK ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AMPHIBIAN, AMPHIBIAN ; egg groups

	; tmhm
	db %10100111
	db %11110010
	db %00011011
	db %11010110
	db %10000111
	db %00111100
	db %10110000
	db %00001001
	; end

AbraBaseStats: ; 0x51be4
	db ABRA ; 063

	db  25,  20,  15,  90, 105,  55
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 200 ; catch rate
	db 73 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %01100111
	db %00010111
	db %00011011
	db %10110100
	db %00000111
	db %10111011
	db %01000010
	db %00000000
	; end

KadabraBaseStats: ; 0x51c04
	db KADABRA ; 064

	db  40,  35,  30, 105, 120,  70
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 100 ; catch rate
	db 145 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %01100111
	db %00010111
	db %00011011
	db %10111100
	db %00000111
	db %10111011
	db %01000010
	db %00000000
	; end

AlakazamBaseStats: ; 0x51c24
	db ALAKAZAM ; 065

	db  55,  50,  45, 120, 135,  85
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 50 ; catch rate
	db 186 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %01100111
	db %01010111
	db %00011011
	db %10111100
	db %00000111
	db %10111011
	db %01000010
	db %00000000
	; end

MachopBaseStats: ; 0x51c44
	db MACHOP ; 066

	db  70,  80,  50,  35,  35,  35
	;   hp  atk  def  spd  sat  sdf

	db FIGHTING, FIGHTING
	db 180 ; catch rate
	db 88 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %10100111
	db %00010110
	db %00011001
	db %11001110
	db %00100111
	db %10111101
	db %00100000
	db %00000010
	; end

MachokeBaseStats: ; 0x51c64
	db MACHOKE ; 067

	db  80, 100,  70,  45,  50,  60
	;   hp  atk  def  spd  sat  sdf

	db FIGHTING, FIGHTING
	db 90 ; catch rate
	db 146 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %10100111
	db %00010110
	db %00011001
	db %11001110
	db %00100111
	db %10111101
	db %00100000
	db %00000010
	; end

MachampBaseStats: ; 0x51c84
	db MACHAMP ; 068

	db  90, 130,  80,  55,  65,  85
	;   hp  atk  def  spd  sat  sdf

	db FIGHTING, FIGHTING
	db 45 ; catch rate
	db 193 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %10100111
	db %01010110
	db %00011001
	db %11001110
	db %00100111
	db %10111101
	db %00100000
	db %00000010
	; end

BellsproutBaseStats: ; 0x51ca4
	db BELLSPROUT ; 069

	db  50,  75,  35,  40,  70,  30
	;   hp  atk  def  spd  sat  sdf

	db GRASS, POISON
	db 255 ; catch rate
	db 84 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100100
	db %00011110
	db %00111101
	db %10000100
	db %00001110
	db %00011000
	db %01000100
	db %00000000
	; end

WeepinbellBaseStats: ; 0x51cc4
	db WEEPINBELL ; 070

	db  65,  90,  50,  55,  85,  45
	;   hp  atk  def  spd  sat  sdf

	db GRASS, POISON
	db 120 ; catch rate
	db 151 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100100
	db %00011110
	db %00111101
	db %10000100
	db %00001110
	db %00011000
	db %01000100
	db %00000000
	; end

VictreebelBaseStats: ; 0x51ce4
	db VICTREEBEL ; 071

	db  80, 105,  65,  70, 100,  60
	;   hp  atk  def  spd  sat  sdf

	db GRASS, POISON
	db 45 ; catch rate
	db 191 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100100
	db %01011110
	db %00111101
	db %10000100
	db %00001110
	db %00011000
	db %01000100
	db %00000000
	; end

TentacoolBaseStats: ; 0x51d04
	db TENTACOOL ; 072

	db  40,  40,  35,  70,  50, 100
	;   hp  atk  def  spd  sat  sdf

	db WATER, POISON
	db 190 ; catch rate
	db 105 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn INVERTEBRATE, INVERTEBRATE ; egg groups

	; tmhm
	db %00100100
	db %10110010
	db %00011111
	db %10000100
	db %00001110
	db %00011000
	db %10010100
	db %00001000
	; end

TentacruelBaseStats: ; 0x51d24
	db TENTACRUEL ; 073

	db  80,  70,  65, 100,  80, 120
	;   hp  atk  def  spd  sat  sdf

	db WATER, POISON
	db 60 ; catch rate
	db 205 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn INVERTEBRATE, INVERTEBRATE ; egg groups

	; tmhm
	db %00100100
	db %11110010
	db %00011111
	db %10000100
	db %00001110
	db %00011000
	db %10010100
	db %00001000
	; end

GeodudeBaseStats: ; 0x51d44
	db GEODUDE ; 074

	db  40,  80, 100,  20,  30,  30
	;   hp  atk  def  spd  sat  sdf

	db ROCK, GROUND
	db 255 ; catch rate
	db 86 ; base exp
	db NO_ITEM ; item 1
	db EVERSTONE ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %10101111
	db %00010110
	db %00011001
	db %11001110
	db %10110110
	db %10011000
	db %00100000
	db %00000010
	; end

GravelerBaseStats: ; 0x51d64
	db GRAVELER ; 075

	db  55,  95, 115,  35,  45,  45
	;   hp  atk  def  spd  sat  sdf

	db ROCK, GROUND
	db 120 ; catch rate
	db 134 ; base exp
	db NO_ITEM ; item 1
	db EVERSTONE ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %10101111
	db %00010110
	db %00011001
	db %11001110
	db %10110110
	db %10011000
	db %00100000
	db %00000010
	; end

GolemBaseStats: ; 0x51d84
	db GOLEM ; 076

	db  80, 110, 130,  45,  55,  65
	;   hp  atk  def  spd  sat  sdf

	db ROCK, GROUND
	db 45 ; catch rate
	db 177 ; base exp
	db NO_ITEM ; item 1
	db EVERSTONE ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %10111111
	db %01010110
	db %00011001
	db %11001110
	db %10110110
	db %10011000
	db %00100001
	db %00000010
	; end

PonytaBaseStats: ; 0x51da4
	db PONYTA ; 077

	db  50,  85,  55,  90,  65,  65
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 190 ; catch rate
	db 152 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00100110
	db %00010110
	db %01011001
	db %10000100
	db %01100110
	db %00011000
	db %00000000
	db %00000010
	; end

RapidashBaseStats: ; 0x51dc4
	db RAPIDASH ; 078

	db  65, 100,  70, 105,  80,  80
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 60 ; catch rate
	db 192 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00100110
	db %01010110
	db %01011001
	db %10000100
	db %01100110
	db %00011000
	db %00000000
	db %00000010
	; end

SlowpokeBaseStats: ; 0x51de4
	db SLOWPOKE ; 079

	db  90,  65,  65,  15,  40,  40
	;   hp  atk  def  spd  sat  sdf

	db WATER, PSYCHIC
	db 190 ; catch rate
	db 99 ; base exp
	db NO_ITEM ; item 1
	db KINGS_ROCK ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %01100110
	db %10110111
	db %01011011
	db %11111110
	db %01100110
	db %00011010
	db %01110010
	db %00001010
	; end

SlowbroBaseStats: ; 0x51e04
	db SLOWBRO ; 080

	db  95,  75, 110,  30, 100,  80
	;   hp  atk  def  spd  sat  sdf

	db WATER, PSYCHIC
	db 75 ; catch rate
	db 164 ; base exp
	db NO_ITEM ; item 1
	db KINGS_ROCK ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %11100111
	db %11110111
	db %01011011
	db %11111110
	db %01100111
	db %00011010
	db %01110011
	db %00001010
	; end

MagnemiteBaseStats: ; 0x51e24
	db MAGNEMITE ; 081

	db  25,  35,  70,  45,  95,  55
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, STEEL
	db 190 ; catch rate
	db 89 ; base exp
	db NO_ITEM ; item 1
	db METAL_COAT ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %01101100
	db %00010010
	db %00011011
	db %10000101
	db %01000110
	db %00001000
	db %01000000
	db %00000100
	; end

MagnetonBaseStats: ; 0x51e44
	db MAGNETON ; 082

	db  50,  60,  95,  70, 120,  70
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, STEEL
	db 60 ; catch rate
	db 161 ; base exp
	db NO_ITEM ; item 1
	db METAL_COAT ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %01101100
	db %01010010
	db %00011011
	db %10000101
	db %01000110
	db %00001000
	db %01000000
	db %00000100
	; end

Farfetch_DBaseStats: ; 0x51e64
	db FARFETCH_D ; 083

	db  52,  65,  55,  60,  58,  62
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 45 ; catch rate
	db 94 ; base exp
	db NO_ITEM ; item 1
	db STICK ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, FIELD ; egg groups

	; tmhm
	db %00100110
	db %00010111
	db %01011001
	db %11000100
	db %01000110
	db %01111100
	db %00001100
	db %00000000
	; end

DoduoBaseStats: ; 0x51e84
	db DODUO ; 084

	db  35,  85,  45,  75,  35,  35
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 190 ; catch rate
	db 96 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %00010110
	db %00011001
	db %11000100
	db %01000110
	db %01111000
	db %00001000
	db %00000000
	; end

DodrioBaseStats: ; 0x51ea4
	db DODRIO ; 085

	db  60, 110,  70, 100,  60,  60
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 45 ; catch rate
	db 158 ; base exp
	db NO_ITEM ; item 1
	db SHARP_BEAK ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %01010110
	db %00011001
	db %11000100
	db %01000110
	db %01111000
	db %00001000
	db %00000000
	; end

SeelBaseStats: ; 0x51ec4
	db SEEL ; 086

	db  65,  45,  55,  45,  45,  70
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 190 ; catch rate
	db 100 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, FIELD ; egg groups

	; tmhm
	db %00100110
	db %10110010
	db %00011011
	db %10000100
	db %00000110
	db %00011000
	db %10010000
	db %00001001
	; end

DewgongBaseStats: ; 0x51ee4
	db DEWGONG ; 087

	db  90,  70,  80,  70,  70,  95
	;   hp  atk  def  spd  sat  sdf

	db WATER, ICE
	db 75 ; catch rate
	db 176 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, FIELD ; egg groups

	; tmhm
	db %00100110
	db %11110010
	db %00011011
	db %10000100
	db %00000110
	db %00011000
	db %10010000
	db %00001001
	; end

GrimerBaseStats: ; 0x51f04
	db GRIMER ; 088

	db  80,  80,  50,  25,  40,  50
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 190 ; catch rate
	db 90 ; base exp
	db NO_ITEM ; item 1
	db NUGGET ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %01100101
	db %00010110
	db %00011101
	db %11000101
	db %00101111
	db %10111001
	db %00000000
	db %00000110
	; end

MukBaseStats: ; 0x51f24
	db MUK ; 089

	db 105, 105,  75,  50,  65, 100
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 75 ; catch rate
	db 157 ; base exp
	db NO_ITEM ; item 1
	db NUGGET ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %01100101
	db %01010110
	db %00011101
	db %11000101
	db %00101111
	db %10111001
	db %00000000
	db %00000110
	; end

ShellderBaseStats: ; 0x51f44
	db SHELLDER ; 090

	db  30,  65, 100,  40,  45,  25
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 190 ; catch rate
	db 97 ; base exp
	db PEARL ; item 1
	db BIG_PEARL ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn INVERTEBRATE, INVERTEBRATE ; egg groups

	; tmhm
	db %00100100
	db %10110010
	db %00011011
	db %10000100
	db %01000110
	db %00011000
	db %10010000
	db %00001000
	; end

CloysterBaseStats: ; 0x51f64
	db CLOYSTER ; 091

	db  50,  95, 180,  70,  85,  45
	;   hp  atk  def  spd  sat  sdf

	db WATER, ICE
	db 60 ; catch rate
	db 203 ; base exp
	db PEARL ; item 1
	db BIG_PEARL ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn INVERTEBRATE, INVERTEBRATE ; egg groups

	; tmhm
	db %00100100
	db %11110010
	db %00011011
	db %10000100
	db %01000110
	db %00011000
	db %10010000
	db %00001000
	; end

GastlyBaseStats: ; 0x51f84
	db GASTLY ; 092

	db  30,  35,  30,  80, 100,  35
	;   hp  atk  def  spd  sat  sdf

	db GHOST, POISON
	db 190 ; catch rate
	db 95 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %01100100
	db %00010111
	db %00011111
	db %10110101
	db %00000110
	db %00111010
	db %00000010
	db %00000100
	; end

HaunterBaseStats: ; 0x51fa4
	db HAUNTER ; 093

	db  45,  50,  45,  95, 115,  55
	;   hp  atk  def  spd  sat  sdf

	db GHOST, POISON
	db 90 ; catch rate
	db 126 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %01100100
	db %00010111
	db %00011111
	db %10110101
	db %00000110
	db %00111010
	db %00000010
	db %00000100
	; end

GengarBaseStats: ; 0x51fc4
	db GENGAR ; 094

	db  60,  65,  60, 110, 130,  75
	;   hp  atk  def  spd  sat  sdf

	db GHOST, POISON
	db 45 ; catch rate
	db 190 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %11100111
	db %01010111
	db %00011111
	db %10110101
	db %00000111
	db %10111011
	db %00100010
	db %00000100
	; end

OnixBaseStats: ; 0x51fe4
	db ONIX ; 095

	db  35,  45, 160,  70,  30,  45
	;   hp  atk  def  spd  sat  sdf

	db ROCK, GROUND
	db 45 ; catch rate
	db 108 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %10110110
	db %00010110
	db %01011001
	db %11001110
	db %00010110
	db %00011000
	db %00100000
	db %00000000
	; end

DrowzeeBaseStats: ; 0x52004
	db DROWZEE ; 096

	db  60,  48,  45,  42,  43,  90
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 190 ; catch rate
	db 102 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %01100111
	db %00010111
	db %00011011
	db %10110100
	db %00000111
	db %10011011
	db %01000010
	db %00000000
	; end

HypnoBaseStats: ; 0x52024
	db HYPNO ; 097

	db  85,  73,  70,  67,  73, 115
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 75 ; catch rate
	db 165 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %01100111
	db %01010111
	db %00011011
	db %10110100
	db %00000111
	db %10011011
	db %01000010
	db %00000000
	; end

KrabbyBaseStats: ; 0x52044
	db KRABBY ; 098

	db  30, 105,  90,  50,  25,  25
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 225 ; catch rate
	db 115 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INVERTEBRATE, INVERTEBRATE ; egg groups

	; tmhm
	db %10100100
	db %10110010
	db %00011011
	db %11000100
	db %00000110
	db %00111000
	db %10110101
	db %00001000
	; end

KinglerBaseStats: ; 0x52064
	db KINGLER ; 099

	db  55, 130, 115,  75,  50,  50
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 60 ; catch rate
	db 206 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INVERTEBRATE, INVERTEBRATE ; egg groups

	; tmhm
	db %10100100
	db %11110010
	db %00011011
	db %11000100
	db %00000110
	db %00111000
	db %10110101
	db %00001000
	; end

VoltorbBaseStats: ; 0x52084
	db VOLTORB ; 100

	db  40,  30,  50, 100,  55,  55
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 190 ; catch rate
	db 103 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %01101110
	db %00010010
	db %00011011
	db %10000101
	db %01000110
	db %00001000
	db %01000000
	db %00000100
	; end

ElectrodeBaseStats: ; 0x520a4
	db ELECTRODE ; 101

	db  60,  50,  70, 140,  80,  80
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 60 ; catch rate
	db 150 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %01101110
	db %01010010
	db %00011011
	db %10000101
	db %01000110
	db %00001000
	db %01000000
	db %00000100
	; end

ExeggcuteBaseStats: ; 0x520c4
	db EXEGGCUTE ; 102

	db  60,  40,  80,  40,  60,  45
	;   hp  atk  def  spd  sat  sdf

	db GRASS, PSYCHIC
	db 90 ; catch rate
	db 98 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00101100
	db %00010111
	db %00111101
	db %10010100
	db %00001110
	db %00111010
	db %01100010
	db %00000000
	; end

ExeggutorBaseStats: ; 0x520e4
	db EXEGGUTOR ; 103

	db  95,  95,  85,  55, 125,  65
	;   hp  atk  def  spd  sat  sdf

	db GRASS, PSYCHIC
	db 45 ; catch rate
	db 212 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00101110
	db %01010111
	db %00111101
	db %10010100
	db %00001110
	db %00111010
	db %01100010
	db %00000000
	; end

CuboneBaseStats: ; 0x52104
	db CUBONE ; 104

	db  50,  50,  95,  35,  40,  50
	;   hp  atk  def  spd  sat  sdf

	db GROUND, GROUND
	db 190 ; catch rate
	db 87 ; base exp
	db NO_ITEM ; item 1
	db THICK_CLUB ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn MONSTER, MONSTER ; egg groups

	; tmhm
	db %10100111
	db %10110110
	db %01011001
	db %11001110
	db %00110110
	db %10111101
	db %00100000
	db %00001010
	; end

MarowakBaseStats: ; 0x52124
	db MAROWAK ; 105

	db  60,  80, 110,  45,  50,  80
	;   hp  atk  def  spd  sat  sdf

	db GROUND, GROUND
	db 75 ; catch rate
	db 124 ; base exp
	db NO_ITEM ; item 1
	db THICK_CLUB ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn MONSTER, MONSTER ; egg groups

	; tmhm
	db %10100111
	db %11110110
	db %01011001
	db %11001110
	db %00110110
	db %10111101
	db %00100000
	db %00001010
	; end

HitmonleeBaseStats: ; 0x52144
	db HITMONLEE ; 106

	db  50, 120,  53,  87,  35, 110
	;   hp  atk  def  spd  sat  sdf

	db FIGHTING, FIGHTING
	db 45 ; catch rate
	db 139 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 0 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %10100111
	db %00010110
	db %00011001
	db %11000100
	db %01000110
	db %00111100
	db %00100000
	db %00000000
	; end

HitmonchanBaseStats: ; 0x52164
	db HITMONCHAN ; 107

	db  50, 105,  79,  76,  35, 110
	;   hp  atk  def  spd  sat  sdf

	db FIGHTING, FIGHTING
	db 45 ; catch rate
	db 140 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 0 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %10100111
	db %00010110
	db %00011001
	db %11000100
	db %01000111
	db %10111101
	db %00100000
	db %00000000
	; end

LickitungBaseStats: ; 0x52184
	db LICKITUNG ; 108

	db  90,  55,  75,  30,  60,  75
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 127 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn MONSTER, MONSTER ; egg groups

	; tmhm
	db %10101111
	db %11110111
	db %01011011
	db %11100111
	db %10110111
	db %10111011
	db %00110110
	db %00001110
	; end

KoffingBaseStats: ; 0x521a4
	db KOFFING ; 109

	db  40,  65,  95,  35,  60,  45
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 190 ; catch rate
	db 114 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %01101100
	db %00010110
	db %00011001
	db %10000101
	db %00101110
	db %00111000
	db %00000000
	db %00000110
	; end

WeezingBaseStats: ; 0x521c4
	db WEEZING ; 110

	db  65,  90, 120,  60,  85,  70
	;   hp  atk  def  spd  sat  sdf

	db POISON, POISON
	db 60 ; catch rate
	db 173 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %01101100
	db %01010110
	db %00011001
	db %10000101
	db %00101110
	db %00111000
	db %00000000
	db %00000110
	; end

RhyhornBaseStats: ; 0x521e4
	db RHYHORN ; 111

	db  80,  85,  95,  25,  30,  30
	;   hp  atk  def  spd  sat  sdf

	db GROUND, ROCK
	db 120 ; catch rate
	db 135 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn MONSTER, FIELD ; egg groups

	; tmhm
	db %11111110
	db %10110110
	db %01011001
	db %11001111
	db %00110110
	db %00011000
	db %00100000
	db %00001110
	; end

RhydonBaseStats: ; 0x52204
	db RHYDON ; 112

	db 105, 130, 120,  40,  45,  45
	;   hp  atk  def  spd  sat  sdf

	db GROUND, ROCK
	db 60 ; catch rate
	db 204 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn MONSTER, FIELD ; egg groups

	; tmhm
	db %11111111
	db %11110110
	db %01011001
	db %11001111
	db %00110110
	db %10011001
	db %00110001
	db %00001110
	; end

ChanseyBaseStats: ; 0x52224
	db CHANSEY ; 113

	db 250,  05,  05,  50,  35, 105
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 30 ; catch rate
	db 255 ; base exp
	db NO_ITEM ; item 1
	db LUCKY_EGG ; item 2
	db 254 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FAIRY, FAIRY ; egg groups

	; tmhm
	db %11101111
	db %11110111
	db %01111011
	db %11110101
	db %10110110
	db %00011010
	db %01100000
	db %00001110
	; end

TangelaBaseStats: ; 0x52244
	db TANGELA ; 114

	db  65,  55, 115,  60, 100,  40
	;   hp  atk  def  spd  sat  sdf

	db GRASS, GRASS
	db 45 ; catch rate
	db 166 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100110
	db %01011111
	db %00111101
	db %10000100
	db %00001110
	db %00111000
	db %01000100
	db %00000000
	; end

KangaskhanBaseStats: ; 0x52264
	db KANGASKHAN ; 115

	db 105,  95,  80,  90,  40,  80
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 175 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 254 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn MONSTER, MONSTER ; egg groups

	; tmhm
	db %11110111
	db %11110110
	db %01011011
	db %11100111
	db %00110111
	db %10011001
	db %00110001
	db %00001110
	; end

HorseaBaseStats: ; 0x52284
	db HORSEA ; 116

	db  30,  40,  70,  60,  70,  25
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 225 ; catch rate
	db 83 ; base exp
	db NO_ITEM ; item 1
	db DRAGON_SCALE ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, REPTILE ; egg groups

	; tmhm
	db %00100110
	db %10110010
	db %10011011
	db %10000100
	db %01000110
	db %00011000
	db %10010000
	db %00001001
	; end

SeadraBaseStats: ; 0x522a4
	db SEADRA ; 117

	db  55,  65,  95,  85,  95,  45
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 75 ; catch rate
	db 155 ; base exp
	db NO_ITEM ; item 1
	db DRAGON_SCALE ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, REPTILE ; egg groups

	; tmhm
	db %00100110
	db %11110010
	db %10011011
	db %10000100
	db %01000110
	db %00011000
	db %10010000
	db %00001001
	; end

GoldeenBaseStats: ; 0x522c4
	db GOLDEEN ; 118

	db  45,  67,  60,  63,  35,  50
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 225 ; catch rate
	db 111 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FISH, FISH ; egg groups

	; tmhm
	db %00100100
	db %10110010
	db %00011011
	db %10000100
	db %01000110
	db %00011000
	db %00010000
	db %00001001
	; end

SeakingBaseStats: ; 0x522e4
	db SEAKING ; 119

	db  80,  92,  65,  68,  65,  80
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 60 ; catch rate
	db 170 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FISH, FISH ; egg groups

	; tmhm
	db %00100100
	db %11110010
	db %00011011
	db %10000100
	db %01000110
	db %00011000
	db %00010000
	db %00001001
	; end

StaryuBaseStats: ; 0x52304
	db STARYU ; 120

	db  30,  45,  55,  85,  70,  55
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 225 ; catch rate
	db 106 ; base exp
	db STARDUST ; item 1
	db STAR_PIECE ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn INVERTEBRATE, INVERTEBRATE ; egg groups

	; tmhm
	db %01100100
	db %10110011
	db %00011011
	db %10010101
	db %01000110
	db %00011000
	db %11010000
	db %00001101
	; end

StarmieBaseStats: ; 0x52324
	db STARMIE ; 121

	db  60,  75,  85, 115, 100,  85
	;   hp  atk  def  spd  sat  sdf

	db WATER, PSYCHIC
	db 60 ; catch rate
	db 207 ; base exp
	db STARDUST ; item 1
	db STAR_PIECE ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn INVERTEBRATE, INVERTEBRATE ; egg groups

	; tmhm
	db %01100100
	db %11110011
	db %00011011
	db %10010101
	db %01000110
	db %00011010
	db %11010010
	db %00001101
	; end

Mr__MimeBaseStats: ; 0x52344
	db MR__MIME ; 122

	db  40,  45,  65,  90, 100, 120
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 45 ; catch rate
	db 136 ; base exp
	db NO_ITEM ; item 1
	db MYSTERYBERRY ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %01100111
	db %01010111
	db %00111001
	db %11110101
	db %00000111
	db %10111011
	db %01000010
	db %00000100
	; end

ScytherBaseStats: ; 0x52364
	db SCYTHER ; 123

	db  70, 110,  80, 105,  55,  80
	;   hp  atk  def  spd  sat  sdf

	db BUG, FLYING
	db 45 ; catch rate
	db 187 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %10100110
	db %01010110
	db %00011001
	db %10000100
	db %01000110
	db %01111100
	db %00000101
	db %00000000
	; end

JynxBaseStats: ; 0x52384
	db JYNX ; 124

	db  65,  50,  35,  95, 115,  95
	;   hp  atk  def  spd  sat  sdf

	db ICE, PSYCHIC
	db 45 ; catch rate
	db 137 ; base exp
	db ICE_BERRY ; item 1
	db ICE_BERRY ; item 2
	db 254 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %00100111
	db %11111011
	db %00011011
	db %11110100
	db %00000111
	db %00111010
	db %00000010
	db %00001000
	; end

ElectabuzzBaseStats: ; 0x523a4
	db ELECTABUZZ ; 125

	db  65,  83,  57, 105,  95,  85
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 45 ; catch rate
	db 156 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %11100111
	db %01010010
	db %01011011
	db %11010101
	db %01000111
	db %10111101
	db %01100000
	db %00000100
	; end

MagmarBaseStats: ; 0x523c4
	db MAGMAR ; 126

	db  65,  95,  57,  93, 100,  85
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 45 ; catch rate
	db 167 ; base exp
	db BURNT_BERRY ; item 1
	db BURNT_BERRY ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %10100111
	db %01010110
	db %01011001
	db %11010100
	db %00100110
	db %10111101
	db %00100000
	db %00000010
	; end

PinsirBaseStats: ; 0x523e4
	db PINSIR ; 127

	db  65, 125, 100,  85,  55,  70
	;   hp  atk  def  spd  sat  sdf

	db BUG, BUG
	db 45 ; catch rate
	db 200 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %10100110
	db %01010110
	db %00011001
	db %10000100
	db %00000110
	db %00111000
	db %00100101
	db %00000000
	; end

TaurosBaseStats: ; 0x52404
	db TAUROS ; 128

	db  75, 100,  95, 110,  40,  70
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 211 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 0 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %11100110
	db %11110110
	db %01011001
	db %10000111
	db %00100110
	db %00011000
	db %00110000
	db %00001110
	; end

MagikarpBaseStats: ; 0x52424
	db MAGIKARP ; 129

	db  20,  10,  55,  80,  15,  20
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 255 ; catch rate
	db 20 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 5 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FISH, REPTILE ; egg groups

	; tmhm
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	; end

GyaradosBaseStats: ; 0x52444
	db GYARADOS ; 130

	db  95, 125,  79,  81,  60, 100
	;   hp  atk  def  spd  sat  sdf

	db WATER, FLYING
	db 45 ; catch rate
	db 214 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 5 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FISH, REPTILE ; egg groups

	; tmhm
	db %11110110
	db %11110010
	db %10011011
	db %10000101
	db %00110110
	db %00011000
	db %10110000
	db %00001111
	; end

LaprasBaseStats: ; 0x52464
	db LAPRAS ; 131

	db 130,  85,  80,  60,  85,  95
	;   hp  atk  def  spd  sat  sdf

	db WATER, ICE
	db 45 ; catch rate
	db 219 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %11100110
	db %11110010
	db %11011011
	db %10010101
	db %00000110
	db %00011010
	db %10110010
	db %00001100
	; end

DittoBaseStats: ; 0x52484
	db DITTO ; 132

	db  48,  48,  48,  48,  48,  48
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 35 ; catch rate
	db 61 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn LADIES_MAN, LADIES_MAN ; egg groups

	; tmhm
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	; end

EeveeBaseStats: ; 0x524a4
	db EEVEE ; 133

	db  55,  55,  50,  55,  45,  65
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 92 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 35 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00100110
	db %00010110
	db %01011011
	db %11100100
	db %01000110
	db %00011100
	db %00000000
	db %00000000
	; end

VaporeonBaseStats: ; 0x524c4
	db VAPOREON ; 134

	db 130,  65,  60,  65, 110,  95
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 45 ; catch rate
	db 196 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 35 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00110110
	db %11110110
	db %01011011
	db %11100100
	db %01000110
	db %00011100
	db %10010000
	db %00001001
	; end

JolteonBaseStats: ; 0x524e4
	db JOLTEON ; 135

	db  65,  65,  60, 130, 110,  95
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 45 ; catch rate
	db 197 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 35 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %01110110
	db %01010110
	db %01011011
	db %11100101
	db %01000110
	db %00011100
	db %01000000
	db %00000100
	; end

FlareonBaseStats: ; 0x52504
	db FLAREON ; 136

	db  65, 130,  60,  65,  95, 110
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 45 ; catch rate
	db 198 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 35 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %01110110
	db %01010110
	db %01011011
	db %11100100
	db %01100110
	db %00011100
	db %00000000
	db %00000010
	; end

PorygonBaseStats: ; 0x52524
	db PORYGON ; 137

	db  65,  60,  70,  40,  85,  75
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 130 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %01100100
	db %11110111
	db %01011011
	db %10010101
	db %01000110
	db %00101010
	db %01000010
	db %00001100
	; end

OmanyteBaseStats: ; 0x52544
	db OMANYTE ; 138

	db  35,  40, 100,  35,  90,  55
	;   hp  atk  def  spd  sat  sdf

	db ROCK, WATER
	db 45 ; catch rate
	db 120 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 30 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, INVERTEBRATE ; egg groups

	; tmhm
	db %10101110
	db %10110010
	db %00011011
	db %10000100
	db %00010110
	db %00111000
	db %10010000
	db %00001000
	; end

OmastarBaseStats: ; 0x52564
	db OMASTAR ; 139

	db  70,  60, 125,  55, 115,  70
	;   hp  atk  def  spd  sat  sdf

	db ROCK, WATER
	db 45 ; catch rate
	db 199 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 30 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, INVERTEBRATE ; egg groups

	; tmhm
	db %10101110
	db %11110010
	db %00011011
	db %10000100
	db %00010110
	db %00111000
	db %10010000
	db %00001000
	; end

KabutoBaseStats: ; 0x52584
	db KABUTO ; 140

	db  30,  80,  90,  55,  55,  45
	;   hp  atk  def  spd  sat  sdf

	db ROCK, WATER
	db 45 ; catch rate
	db 119 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 30 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, INVERTEBRATE ; egg groups

	; tmhm
	db %10101100
	db %10110010
	db %00011111
	db %10000100
	db %00010110
	db %00111000
	db %00000000
	db %00001000
	; end

KabutopsBaseStats: ; 0x525a4
	db KABUTOPS ; 141

	db  60, 115, 105,  80,  65,  70
	;   hp  atk  def  spd  sat  sdf

	db ROCK, WATER
	db 45 ; catch rate
	db 201 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 30 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, INVERTEBRATE ; egg groups

	; tmhm
	db %10101110
	db %11110010
	db %00011111
	db %10000100
	db %00010110
	db %00111000
	db %10010101
	db %00001000
	; end

AerodactylBaseStats: ; 0x525c4
	db AERODACTYL ; 142

	db  80, 105,  65, 130,  60,  75
	;   hp  atk  def  spd  sat  sdf

	db ROCK, FLYING
	db 45 ; catch rate
	db 202 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 35 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %10110110
	db %01010010
	db %11011011
	db %10000110
	db %01110110
	db %01011100
	db %00001000
	db %00000010
	; end

SnorlaxBaseStats: ; 0x525e4
	db SNORLAX ; 143

	db 160, 110,  65,  30,  65, 110
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 25 ; catch rate
	db 154 ; base exp
	db LEFTOVERS ; item 1
	db LEFTOVERS ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn MONSTER, MONSTER ; egg groups

	; tmhm
	db %11101111
	db %11110111
	db %00111011
	db %11110111
	db %10110111
	db %10011001
	db %00110000
	db %00001110
	; end

ArticunoBaseStats: ; 0x52604
	db ARTICUNO ; 144

	db  90,  85, 100,  85,  95, 125
	;   hp  atk  def  spd  sat  sdf

	db ICE, FLYING
	db 3 ; catch rate
	db 215 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 80 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %10110100
	db %11110110
	db %00011011
	db %11000100
	db %01010110
	db %01001100
	db %00001000
	db %00001000
	; end

ZapdosBaseStats: ; 0x52624
	db ZAPDOS ; 145

	db  90,  90,  85, 100, 125,  90
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, FLYING
	db 3 ; catch rate
	db 216 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 80 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %11110100
	db %01010110
	db %00011011
	db %11000101
	db %01010110
	db %01001100
	db %01001000
	db %00000100
	; end

MoltresBaseStats: ; 0x52644
	db MOLTRES ; 146

	db  90, 100,  90,  90, 125,  85
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FLYING
	db 3 ; catch rate
	db 217 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 80 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %10110100
	db %01010110
	db %00011011
	db %11000100
	db %01110110
	db %01001100
	db %00001000
	db %00000010
	; end

DratiniBaseStats: ; 0x52664
	db DRATINI ; 147

	db  41,  64,  45,  50,  50,  50
	;   hp  atk  def  spd  sat  sdf

	db DRAGON, DRAGON
	db 45 ; catch rate
	db 67 ; base exp
	db NO_ITEM ; item 1
	db DRAGON_SCALE ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn AMPHIBIAN, REPTILE ; egg groups

	; tmhm
	db %01100110
	db %10110010
	db %11011011
	db %10000101
	db %01100110
	db %00011100
	db %00010000
	db %00001111
	; end

DragonairBaseStats: ; 0x52684
	db DRAGONAIR ; 148

	db  61,  84,  65,  70,  70,  70
	;   hp  atk  def  spd  sat  sdf

	db DRAGON, DRAGON
	db 45 ; catch rate
	db 144 ; base exp
	db NO_ITEM ; item 1
	db DRAGON_SCALE ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn AMPHIBIAN, REPTILE ; egg groups

	; tmhm
	db %01100110
	db %10110010
	db %11011011
	db %10000101
	db %01100110
	db %00011100
	db %00010000
	db %00001111
	; end

DragoniteBaseStats: ; 0x526a4
	db DRAGONITE ; 149

	db  91, 134,  95,  80, 100, 100
	;   hp  atk  def  spd  sat  sdf

	db DRAGON, FLYING
	db 45 ; catch rate
	db 218 ; base exp
	db NO_ITEM ; item 1
	db DRAGON_SCALE ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn AMPHIBIAN, REPTILE ; egg groups

	; tmhm
	db %11100111
	db %11110010
	db %11011011
	db %11000101
	db %01110111
	db %11011101
	db %10111001
	db %00001111
	; end

MewtwoBaseStats: ; 0x526c4
	db MEWTWO ; 150

	db 106, 110,  90, 130, 154,  90
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 3 ; catch rate
	db 220 ; base exp
	db NO_ITEM ; item 1
	db BERSERK_GENE ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 120 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %11100111
	db %11110111
	db %01111011
	db %11110101
	db %01100111
	db %10001111
	db %01100010
	db %00001110
	; end

MewBaseStats: ; 0x526e4
	db MEW ; 151

	db 100, 100, 100, 100, 100, 100
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 45 ; catch rate
	db 64 ; base exp
	db NO_ITEM ; item 1
	db MIRACLEBERRY ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 120 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %11111111
	db %11111111
	db %11111111
	db %11111111
	db %11111111
	db %11111111
	db %11111111
	db %00001111
	; end

ChikoritaBaseStats: ; 0x52704
	db CHIKORITA ; 152

	db  45,  49,  65,  45,  49,  65
	;   hp  atk  def  spd  sat  sdf

	db GRASS, GRASS
	db 45 ; catch rate
	db 64 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, PLANT ; egg groups

	; tmhm
	db %00100110
	db %00011110
	db %01111101
	db %11000100
	db %00000110
	db %00011100
	db %01000100
	db %00000000
	; end

BayleefBaseStats: ; 0x52724
	db BAYLEEF ; 153

	db  60,  62,  80,  60,  63,  80
	;   hp  atk  def  spd  sat  sdf

	db GRASS, GRASS
	db 45 ; catch rate
	db 141 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, PLANT ; egg groups

	; tmhm
	db %10100110
	db %00011110
	db %01111101
	db %11000100
	db %00000110
	db %00011100
	db %01100101
	db %00000000
	; end

MeganiumBaseStats: ; 0x52744
	db MEGANIUM ; 154

	db  80,  82, 100,  80,  83, 100
	;   hp  atk  def  spd  sat  sdf

	db GRASS, GRASS
	db 45 ; catch rate
	db 208 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, PLANT ; egg groups

	; tmhm
	db %10100110
	db %01011110
	db %01111101
	db %11000110
	db %00000110
	db %00011100
	db %01100101
	db %00000000
	; end

CyndaquilBaseStats: ; 0x52764
	db CYNDAQUIL ; 155

	db  39,  52,  43,  65,  60,  50
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 45 ; catch rate
	db 65 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00101110
	db %00010110
	db %01011001
	db %11001100
	db %11100110
	db %00011100
	db %00000100
	db %00000010
	; end

QuilavaBaseStats: ; 0x52784
	db QUILAVA ; 156

	db  58,  64,  58,  80,  80,  65
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 45 ; catch rate
	db 142 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10111110
	db %00010110
	db %01011001
	db %11001100
	db %11100110
	db %00011100
	db %00100101
	db %00000010
	; end

TyphlosionBaseStats: ; 0x527a4
	db TYPHLOSION ; 157

	db  78,  84,  78, 100, 109,  85
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 45 ; catch rate
	db 209 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10111111
	db %01010110
	db %01011001
	db %11001110
	db %11100110
	db %10011101
	db %00100101
	db %00000010
	; end

TotodileBaseStats: ; 0x527c4
	db TOTODILE ; 158

	db  50,  65,  64,  43,  44,  48
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 45 ; catch rate
	db 66 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %00100111
	db %10110010
	db %01011011
	db %11001100
	db %00000111
	db %00011100
	db %10010100
	db %00001000
	; end

CroconawBaseStats: ; 0x527e4
	db CROCONAW ; 159

	db  65,  80,  80,  58,  59,  63
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 45 ; catch rate
	db 143 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %10110111
	db %10110010
	db %01011011
	db %11001100
	db %00000111
	db %00011100
	db %10110101
	db %00001000
	; end

FeraligatrBaseStats: ; 0x52804
	db FERALIGATR ; 160

	db  85, 105, 100,  78,  79,  83
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 45 ; catch rate
	db 210 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %10110111
	db %11110010
	db %01011011
	db %11001110
	db %00000111
	db %00011100
	db %10110101
	db %00001000
	; end

SentretBaseStats: ; 0x52824
	db SENTRET ; 161

	db  35,  46,  34,  20,  35,  45
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 255 ; catch rate
	db 57 ; base exp
	db NO_ITEM ; item 1
	db BERRY ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00101111
	db %00010110
	db %01011001
	db %11101100
	db %11000111
	db %10111101
	db %00010101
	db %00000000
	; end

FurretBaseStats: ; 0x52844
	db FURRET ; 162

	db  85,  76,  64,  90,  45,  55
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 90 ; catch rate
	db 116 ; base exp
	db BERRY ; item 1
	db GOLD_BERRY ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00101111
	db %01010110
	db %01011001
	db %11101100
	db %11000111
	db %10111101
	db %00110101
	db %00000000
	; end

HoothootBaseStats: ; 0x52864
	db HOOTHOOT ; 163

	db  60,  30,  30,  50,  36,  56
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 255 ; catch rate
	db 58 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %00010110
	db %00011001
	db %11000100
	db %01000110
	db %01111110
	db %01001010
	db %00000000
	; end

NoctowlBaseStats: ; 0x52884
	db NOCTOWL ; 164

	db 100,  50,  50,  70,  76,  96
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 90 ; catch rate
	db 162 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %01010110
	db %00011001
	db %11000100
	db %01000110
	db %01111110
	db %01001010
	db %00000000
	; end

LedybaBaseStats: ; 0x528a4
	db LEDYBA ; 165

	db  40,  20,  30,  55,  40,  80
	;   hp  atk  def  spd  sat  sdf

	db BUG, FLYING
	db 255 ; catch rate
	db 54 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00101111
	db %00011110
	db %00111101
	db %10001100
	db %01000111
	db %00111001
	db %01000000
	db %00000000
	; end

LedianBaseStats: ; 0x528c4
	db LEDIAN ; 166

	db  55,  35,  50,  85,  55, 110
	;   hp  atk  def  spd  sat  sdf

	db BUG, FLYING
	db 90 ; catch rate
	db 134 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00101111
	db %01011110
	db %00111101
	db %10001100
	db %01000111
	db %00111001
	db %01000000
	db %00000000
	; end

SpinarakBaseStats: ; 0x528e4
	db SPINARAK ; 167

	db  40,  60,  40,  30,  40,  40
	;   hp  atk  def  spd  sat  sdf

	db BUG, POISON
	db 255 ; catch rate
	db 54 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00100100
	db %00010110
	db %00111101
	db %10011100
	db %00001110
	db %00111000
	db %01000000
	db %00000000
	; end

AriadosBaseStats: ; 0x52904
	db ARIADOS ; 168

	db  70,  90,  70,  40,  60,  60
	;   hp  atk  def  spd  sat  sdf

	db BUG, POISON
	db 90 ; catch rate
	db 134 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00100100
	db %01010110
	db %00111101
	db %10011100
	db %00001110
	db %00111000
	db %01000000
	db %00000000
	; end

CrobatBaseStats: ; 0x52924
	db CROBAT ; 169

	db  85,  90,  80, 130,  70,  80
	;   hp  atk  def  spd  sat  sdf

	db POISON, FLYING
	db 90 ; catch rate
	db 204 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 15 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %01010110
	db %00011101
	db %10000100
	db %01000110
	db %01111100
	db %00001000
	db %00000000
	; end

ChinchouBaseStats: ; 0x52944
	db CHINCHOU ; 170

	db  75,  38,  38,  67,  56,  56
	;   hp  atk  def  spd  sat  sdf

	db WATER, ELECTRIC
	db 190 ; catch rate
	db 90 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FISH, FISH ; egg groups

	; tmhm
	db %01100100
	db %00010010
	db %00011011
	db %10000101
	db %00000110
	db %00011000
	db %11010000
	db %00001101
	; end

LanturnBaseStats: ; 0x52964
	db LANTURN ; 171

	db 125,  58,  58,  67,  76,  76
	;   hp  atk  def  spd  sat  sdf

	db WATER, ELECTRIC
	db 75 ; catch rate
	db 156 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FISH, FISH ; egg groups

	; tmhm
	db %01100100
	db %01010010
	db %00011011
	db %10000101
	db %00000110
	db %00011000
	db %11010000
	db %00001101
	; end

PichuBaseStats: ; 0x52984
	db PICHU ; 172

	db  20,  40,  15,  60,  35,  35
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 190 ; catch rate
	db 42 ; base exp
	db NO_ITEM ; item 1
	db BERRY ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %01101110
	db %00010010
	db %01011011
	db %11000101
	db %11000110
	db %00011100
	db %01000000
	db %00000100
	; end

CleffaBaseStats: ; 0x529a4
	db CLEFFA ; 173

	db  50,  25,  28,  15,  45,  55
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 150 ; catch rate
	db 37 ; base exp
	db MYSTERYBERRY ; item 1
	db MOON_STONE ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %01101110
	db %10010111
	db %01111011
	db %11110100
	db %10100110
	db %00011110
	db %01000010
	db %00000010
	; end

IgglybuffBaseStats: ; 0x529c4
	db IGGLYBUFF ; 174

	db  90,  30,  15,  15,  40,  20
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 170 ; catch rate
	db 39 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %01101110
	db %10010111
	db %00111011
	db %11110100
	db %10100110
	db %00011110
	db %01000010
	db %00000010
	; end

TogepiBaseStats: ; 0x529e4
	db TOGEPI ; 175

	db  35,  20,  65,  20,  40,  65
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 190 ; catch rate
	db 74 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %11101110
	db %00010111
	db %00111011
	db %11110100
	db %11100110
	db %00011110
	db %01000000
	db %00000010
	; end

TogeticBaseStats: ; 0x52a04
	db TOGETIC ; 176

	db  55,  40,  85,  40,  80, 105
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, FLYING
	db 75 ; catch rate
	db 114 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 10 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn AVIAN, FAIRY ; egg groups

	; tmhm
	db %11101110
	db %01010111
	db %00111011
	db %11110100
	db %11100110
	db %01011110
	db %01001000
	db %00000010
	; end

NatuBaseStats: ; 0x52a24
	db NATU ; 177

	db  40,  50,  45,  70,  70,  45
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, FLYING
	db 190 ; catch rate
	db 73 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %00010111
	db %00111101
	db %10010100
	db %01000110
	db %00111110
	db %01000010
	db %00000000
	; end

XatuBaseStats: ; 0x52a44
	db XATU ; 178

	db  65,  75,  70,  95,  95,  70
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, FLYING
	db 75 ; catch rate
	db 171 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %01010111
	db %00111101
	db %10010100
	db %01000110
	db %00111110
	db %01001010
	db %00000000
	; end

MareepBaseStats: ; 0x52a64
	db MAREEP ; 179

	db  55,  40,  40,  35,  65,  45
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 235 ; catch rate
	db 59 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, FIELD ; egg groups

	; tmhm
	db %01100110
	db %00010010
	db %01011011
	db %10000101
	db %11000110
	db %00011000
	db %01000000
	db %00000100
	; end

FlaaffyBaseStats: ; 0x52a84
	db FLAAFFY ; 180

	db  70,  55,  55,  45,  80,  60
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 120 ; catch rate
	db 117 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, FIELD ; egg groups

	; tmhm
	db %11100111
	db %00010010
	db %01011011
	db %10000101
	db %11000110
	db %10011001
	db %01100000
	db %00000100
	; end

AmpharosBaseStats: ; 0x52aa4
	db AMPHAROS ; 181

	db  90,  75,  75,  55, 115,  90
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 45 ; catch rate
	db 194 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn MONSTER, FIELD ; egg groups

	; tmhm
	db %11100111
	db %01010010
	db %01011011
	db %10000101
	db %11000110
	db %10011001
	db %01100000
	db %00000100
	; end

BellossomBaseStats: ; 0x52ac4
	db BELLOSSOM ; 182

	db  75,  80,  85,  50,  90, 100
	;   hp  atk  def  spd  sat  sdf

	db GRASS, GRASS
	db 45 ; catch rate
	db 184 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100100
	db %01011110
	db %00111101
	db %10000100
	db %00000110
	db %00011000
	db %01000100
	db %00000000
	; end

MarillBaseStats: ; 0x52ae4
	db MARILL ; 183

	db  70,  20,  50,  40,  20,  50
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 190 ; catch rate
	db 58 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn AMPHIBIAN, FAIRY ; egg groups

	; tmhm
	db %00101111
	db %10110010
	db %01011011
	db %11000100
	db %11000111
	db %00011000
	db %10010000
	db %00001001
	; end

AzumarillBaseStats: ; 0x52b04
	db AZUMARILL ; 184

	db 100,  50,  80,  50,  50,  80
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 75 ; catch rate
	db 153 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn AMPHIBIAN, FAIRY ; egg groups

	; tmhm
	db %10101111
	db %11110010
	db %01011011
	db %11000100
	db %11000111
	db %00011000
	db %10110000
	db %00001001
	; end

SudowoodoBaseStats: ; 0x52b24
	db SUDOWOODO ; 185

	db  70, 100, 115,  30,  30,  65
	;   hp  atk  def  spd  sat  sdf

	db ROCK, ROCK
	db 65 ; catch rate
	db 135 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %10101111
	db %00010111
	db %00011001
	db %11001110
	db %10010111
	db %10111001
	db %00100000
	db %00000000
	; end

PolitoedBaseStats: ; 0x52b44
	db POLITOED ; 186

	db  90,  75,  75,  70,  90, 100
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 45 ; catch rate
	db 185 ; base exp
	db NO_ITEM ; item 1
	db KINGS_ROCK ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AMPHIBIAN, AMPHIBIAN ; egg groups

	; tmhm
	db %10100111
	db %11110010
	db %00011011
	db %11010110
	db %10000111
	db %00111100
	db %10110000
	db %00001001
	; end

HoppipBaseStats: ; 0x52b64
	db HOPPIP ; 187

	db  35,  35,  40,  50,  35,  55
	;   hp  atk  def  spd  sat  sdf

	db GRASS, FLYING
	db 255 ; catch rate
	db 74 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn FAIRY, PLANT ; egg groups

	; tmhm
	db %00100110
	db %00011110
	db %00111101
	db %10000100
	db %10000110
	db %00011000
	db %01000000
	db %00000000
	; end

SkiploomBaseStats: ; 0x52b84
	db SKIPLOOM ; 188

	db  55,  45,  50,  80,  45,  65
	;   hp  atk  def  spd  sat  sdf

	db GRASS, FLYING
	db 120 ; catch rate
	db 136 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn FAIRY, PLANT ; egg groups

	; tmhm
	db %00100110
	db %00011110
	db %00111101
	db %10000100
	db %10000110
	db %00011000
	db %01000000
	db %00000000
	; end

JumpluffBaseStats: ; 0x52ba4
	db JUMPLUFF ; 189

	db  75,  55,  70, 110,  55,  85
	;   hp  atk  def  spd  sat  sdf

	db GRASS, FLYING
	db 45 ; catch rate
	db 176 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn FAIRY, PLANT ; egg groups

	; tmhm
	db %00100110
	db %01011110
	db %00111101
	db %10000100
	db %10000110
	db %00011000
	db %01000000
	db %00000000
	; end

AipomBaseStats: ; 0x52bc4
	db AIPOM ; 190

	db  55,  70,  55,  85,  40,  55
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 94 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %11100111
	db %00010110
	db %01011001
	db %11100101
	db %11000111
	db %10111111
	db %00100111
	db %00000100
	; end

SunkernBaseStats: ; 0x52be4
	db SUNKERN ; 191

	db  30,  30,  30,  30,  30,  30
	;   hp  atk  def  spd  sat  sdf

	db GRASS, GRASS
	db 235 ; catch rate
	db 52 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100100
	db %00011110
	db %00111101
	db %10000100
	db %00001110
	db %00011000
	db %01000100
	db %00000000
	; end

SunfloraBaseStats: ; 0x52c04
	db SUNFLORA ; 192

	db  75,  75,  55,  30, 105,  85
	;   hp  atk  def  spd  sat  sdf

	db GRASS, GRASS
	db 120 ; catch rate
	db 146 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn PLANT, PLANT ; egg groups

	; tmhm
	db %00100100
	db %01011110
	db %00111101
	db %10000100
	db %00001110
	db %00011000
	db %01000100
	db %00000000
	; end

YanmaBaseStats: ; 0x52c24
	db YANMA ; 193

	db  65,  65,  45,  95,  75,  45
	;   hp  atk  def  spd  sat  sdf

	db BUG, FLYING
	db 75 ; catch rate
	db 147 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %00100110
	db %00010110
	db %00111101
	db %10000100
	db %01000110
	db %00111100
	db %01000000
	db %00000000
	; end

WooperBaseStats: ; 0x52c44
	db WOOPER ; 194

	db  55,  45,  45,  15,  25,  25
	;   hp  atk  def  spd  sat  sdf

	db WATER, GROUND
	db 255 ; catch rate
	db 52 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, FIELD ; egg groups

	; tmhm
	db %10101111
	db %00010010
	db %01011011
	db %11001110
	db %10011111
	db %00011000
	db %11010000
	db %00001000
	; end

QuagsireBaseStats: ; 0x52c64
	db QUAGSIRE ; 195

	db  95,  85,  85,  35,  65,  65
	;   hp  atk  def  spd  sat  sdf

	db WATER, GROUND
	db 90 ; catch rate
	db 137 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, FIELD ; egg groups

	; tmhm
	db %10101111
	db %01010010
	db %01011011
	db %11001110
	db %10011111
	db %00011000
	db %11110000
	db %00001000
	; end

EspeonBaseStats: ; 0x52c84
	db ESPEON ; 196

	db  65,  65,  60, 110, 130,  95
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 45 ; catch rate
	db 197 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 35 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %01100110
	db %01010111
	db %01011011
	db %11110100
	db %01000110
	db %00011110
	db %01000110
	db %00000000
	; end

UmbreonBaseStats: ; 0x52ca4
	db UMBREON ; 197

	db  95,  65, 110,  65,  60, 130
	;   hp  atk  def  spd  sat  sdf

	db DARK, DARK
	db 45 ; catch rate
	db 197 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 31 ; gender
	db 100 ; unknown
	db 35 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %01100110
	db %01010111
	db %01011011
	db %11110100
	db %01000110
	db %00011110
	db %01000110
	db %00000000
	; end

MurkrowBaseStats: ; 0x52cc4
	db MURKROW ; 198

	db  60,  85,  42,  91,  85,  42
	;   hp  atk  def  spd  sat  sdf

	db DARK, FLYING
	db 30 ; catch rate
	db 107 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %10010111
	db %00011001
	db %11100100
	db %01000110
	db %01111110
	db %00001010
	db %00000000
	; end

SlowkingBaseStats: ; 0x52ce4
	db SLOWKING ; 199

	db  95,  75,  80,  30, 100, 110
	;   hp  atk  def  spd  sat  sdf

	db WATER, PSYCHIC
	db 70 ; catch rate
	db 164 ; base exp
	db NO_ITEM ; item 1
	db KINGS_ROCK ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn MONSTER, AMPHIBIAN ; egg groups

	; tmhm
	db %11100111
	db %11110111
	db %01011011
	db %11111110
	db %01100111
	db %00011010
	db %11110011
	db %00001010
	; end

MisdreavusBaseStats: ; 0x52d04
	db MISDREAVUS ; 200

	db  60,  60,  60,  85,  85,  85
	;   hp  atk  def  spd  sat  sdf

	db GHOST, GHOST
	db 45 ; catch rate
	db 147 ; base exp
	db NO_ITEM ; item 1
	db SPELL_TAG ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %01100110
	db %00010111
	db %00011011
	db %10110101
	db %11000110
	db %00111010
	db %01000010
	db %00000100
	; end

UnownBaseStats: ; 0x52d24
	db UNOWN ; 201

	db  48,  72,  48,  48,  72,  48
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 225 ; catch rate
	db 61 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	; end

WobbuffetBaseStats: ; 0x52d44
	db WOBBUFFET ; 202

	db 190,  33,  58,  33,  33,  58
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, PSYCHIC
	db 45 ; catch rate
	db 177 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	; end

GirafarigBaseStats: ; 0x52d64
	db GIRAFARIG ; 203

	db  70,  80,  65,  85,  90,  65
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, PSYCHIC
	db 60 ; catch rate
	db 149 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %11100110
	db %00010111
	db %01011001
	db %11110111
	db %01000110
	db %00111010
	db %00100010
	db %00000100
	; end

PinecoBaseStats: ; 0x52d84
	db PINECO ; 204

	db  50,  65,  90,  15,  35,  35
	;   hp  atk  def  spd  sat  sdf

	db BUG, BUG
	db 190 ; catch rate
	db 60 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %10101110
	db %00011110
	db %00111101
	db %10000100
	db %10000110
	db %00011000
	db %00100000
	db %00000000
	; end

ForretressBaseStats: ; 0x52da4
	db FORRETRESS ; 205

	db  75,  90, 140,  40,  60,  60
	;   hp  atk  def  spd  sat  sdf

	db BUG, STEEL
	db 75 ; catch rate
	db 118 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %10101110
	db %01011110
	db %00111101
	db %10000100
	db %10010110
	db %00011000
	db %00100000
	db %00000000
	; end

DunsparceBaseStats: ; 0x52dc4
	db DUNSPARCE ; 206

	db 100,  70,  70,  45,  65,  65
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 190 ; catch rate
	db 75 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %11101110
	db %00010111
	db %01111011
	db %11001101
	db %10000110
	db %00111010
	db %00100010
	db %00000110
	; end

GligarBaseStats: ; 0x52de4
	db GLIGAR ; 207

	db  65,  75, 105,  85,  35,  65
	;   hp  atk  def  spd  sat  sdf

	db GROUND, FLYING
	db 60 ; catch rate
	db 108 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %10100110
	db %00010110
	db %01011001
	db %10000100
	db %01011110
	db %00111100
	db %00100101
	db %00000000
	; end

SteelixBaseStats: ; 0x52e04
	db STEELIX ; 208

	db  75,  85, 200,  30,  55,  65
	;   hp  atk  def  spd  sat  sdf

	db STEEL, GROUND
	db 25 ; catch rate
	db 196 ; base exp
	db NO_ITEM ; item 1
	db METAL_COAT ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %10111110
	db %01010110
	db %11011001
	db %11001110
	db %10010110
	db %00011000
	db %00100100
	db %00000000
	; end

SnubbullBaseStats: ; 0x52e24
	db SNUBBULL ; 209

	db  60,  80,  50,  30,  40,  40
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 190 ; catch rate
	db 63 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FIELD, FAIRY ; egg groups

	; tmhm
	db %11110111
	db %00010110
	db %00011011
	db %11100101
	db %10001111
	db %10111101
	db %00100000
	db %00000100
	; end

GranbullBaseStats: ; 0x52e44
	db GRANBULL ; 210

	db  90, 120,  75,  45,  60,  60
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 75 ; catch rate
	db 178 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FIELD, FAIRY ; egg groups

	; tmhm
	db %11110111
	db %01010110
	db %00011011
	db %11100101
	db %10001111
	db %10111101
	db %00100000
	db %00000100
	; end

QwilfishBaseStats: ; 0x52e64
	db QWILFISH ; 211

	db  65,  95,  75,  85,  55,  55
	;   hp  atk  def  spd  sat  sdf

	db WATER, POISON
	db 45 ; catch rate
	db 100 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FISH, FISH ; egg groups

	; tmhm
	db %00101110
	db %10110010
	db %00011011
	db %10000100
	db %11001110
	db %00011000
	db %10010000
	db %00001001
	; end

ScizorBaseStats: ; 0x52e84
	db SCIZOR ; 212

	db  70, 130, 100,  65,  55,  80
	;   hp  atk  def  spd  sat  sdf

	db BUG, STEEL
	db 25 ; catch rate
	db 200 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %10100110
	db %01010110
	db %00011001
	db %10000100
	db %01010110
	db %01111100
	db %00100101
	db %00000000
	; end

ShuckleBaseStats: ; 0x52ea4
	db SHUCKLE ; 213

	db  20,  10, 230,  05,  10, 230
	;   hp  atk  def  spd  sat  sdf

	db BUG, ROCK
	db 190 ; catch rate
	db 80 ; base exp
	db BERRY ; item 1
	db BERRY ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %10101110
	db %00010110
	db %00011001
	db %11001110
	db %10011110
	db %00011000
	db %01100000
	db %00000000
	; end

HeracrossBaseStats: ; 0x52ec4
	db HERACROSS ; 214

	db  80, 125,  75,  85,  40,  95
	;   hp  atk  def  spd  sat  sdf

	db BUG, FIGHTING
	db 45 ; catch rate
	db 200 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn INSECT, INSECT ; egg groups

	; tmhm
	db %10100110
	db %00010110
	db %00011001
	db %10000110
	db %00000110
	db %00111100
	db %00100101
	db %00000000
	; end

SneaselBaseStats: ; 0x52ee4
	db SNEASEL ; 215

	db  55,  95,  55, 115,  35,  75
	;   hp  atk  def  spd  sat  sdf

	db DARK, ICE
	db 60 ; catch rate
	db 132 ; base exp
	db NO_ITEM ; item 1
	db QUICK_CLAW ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10100111
	db %10110011
	db %01011011
	db %11101100
	db %11000111
	db %00111110
	db %00110111
	db %00001000
	; end

TeddiursaBaseStats: ; 0x52f04
	db TEDDIURSA ; 216

	db  60,  80,  50,  40,  50,  50
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 120 ; catch rate
	db 124 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %11111111
	db %00010110
	db %00011001
	db %11001110
	db %11000111
	db %10111001
	db %00100101
	db %00000000
	; end

UrsaringBaseStats: ; 0x52f24
	db URSARING ; 217

	db  90, 130,  75,  55,  75,  75
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 60 ; catch rate
	db 189 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %11111111
	db %01010110
	db %00011001
	db %11001110
	db %11000111
	db %10111001
	db %00100101
	db %00000000
	; end

SlugmaBaseStats: ; 0x52f44
	db SLUGMA ; 218

	db  40,  40,  40,  20,  70,  40
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 190 ; catch rate
	db 78 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %10101100
	db %00010110
	db %00011001
	db %11000100
	db %10100110
	db %00011000
	db %00000000
	db %00000010
	; end

MagcargoBaseStats: ; 0x52f64
	db MAGCARGO ; 219

	db  50,  50, 120,  30,  80,  80
	;   hp  atk  def  spd  sat  sdf

	db FIRE, ROCK
	db 75 ; catch rate
	db 154 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMORPHOUS, AMORPHOUS ; egg groups

	; tmhm
	db %10101100
	db %01010110
	db %00011001
	db %11000110
	db %10100110
	db %00011000
	db %00100000
	db %00000010
	; end

SwinubBaseStats: ; 0x52f84
	db SWINUB ; 220

	db  50,  50,  40,  50,  30,  30
	;   hp  atk  def  spd  sat  sdf

	db ICE, GROUND
	db 225 ; catch rate
	db 78 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10110110
	db %10110010
	db %00011011
	db %11000110
	db %10000110
	db %00011100
	db %00100000
	db %00001000
	; end

PiloswineBaseStats: ; 0x52fa4
	db PILOSWINE ; 221

	db 100, 100,  80,  50,  60,  60
	;   hp  atk  def  spd  sat  sdf

	db ICE, GROUND
	db 75 ; catch rate
	db 160 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10110110
	db %11110010
	db %00011011
	db %11000110
	db %10000110
	db %00011100
	db %00100000
	db %00001000
	; end

CorsolaBaseStats: ; 0x52fc4
	db CORSOLA ; 222

	db  55,  55,  85,  35,  65,  85
	;   hp  atk  def  spd  sat  sdf

	db WATER, ROCK
	db 60 ; catch rate
	db 113 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 191 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn AMPHIBIAN, INVERTEBRATE ; egg groups

	; tmhm
	db %10101110
	db %00010110
	db %00011011
	db %11010110
	db %10010110
	db %00011000
	db %10110000
	db %00001000
	; end

RemoraidBaseStats: ; 0x52fe4
	db REMORAID ; 223

	db  35,  65,  35,  65,  65,  35
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 190 ; catch rate
	db 78 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, FISH ; egg groups

	; tmhm
	db %00100100
	db %01010010
	db %00011011
	db %11000100
	db %11000110
	db %00111000
	db %10010000
	db %00001010
	; end

OctilleryBaseStats: ; 0x53004
	db OCTILLERY ; 224

	db  75, 105,  75,  45, 105,  75
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 75 ; catch rate
	db 164 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, FISH ; egg groups

	; tmhm
	db %00100100
	db %01010010
	db %00011011
	db %11000100
	db %11000110
	db %00111000
	db %10010000
	db %00001010
	; end

DelibirdBaseStats: ; 0x53024
	db DELIBIRD ; 225

	db  45,  55,  45,  75,  65,  45
	;   hp  atk  def  spd  sat  sdf

	db ICE, FLYING
	db 45 ; catch rate
	db 183 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn AMPHIBIAN, FIELD ; egg groups

	; tmhm
	db %00100110
	db %10110010
	db %00011011
	db %11000100
	db %01000110
	db %00111100
	db %00001000
	db %00001000
	; end

MantineBaseStats: ; 0x53044
	db MANTINE ; 226

	db  65,  40,  70,  70,  80, 140
	;   hp  atk  def  spd  sat  sdf

	db WATER, FLYING
	db 25 ; catch rate
	db 168 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn AMPHIBIAN, AMPHIBIAN ; egg groups

	; tmhm
	db %00100110
	db %10110010
	db %00011011
	db %11000100
	db %01000110
	db %00011000
	db %10010000
	db %00001001
	; end

SkarmoryBaseStats: ; 0x53064
	db SKARMORY ; 227

	db  65,  80, 140,  70,  40,  70
	;   hp  atk  def  spd  sat  sdf

	db STEEL, FLYING
	db 25 ; catch rate
	db 168 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn AVIAN, AVIAN ; egg groups

	; tmhm
	db %00100100
	db %00010110
	db %00011001
	db %11000100
	db %01010110
	db %01111100
	db %00001100
	db %00000000
	; end

HoundourBaseStats: ; 0x53084
	db HOUNDOUR ; 228

	db  45,  60,  30,  65,  80,  50
	;   hp  atk  def  spd  sat  sdf

	db DARK, FIRE
	db 120 ; catch rate
	db 114 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10110110
	db %00010110
	db %01111001
	db %11100100
	db %01101110
	db %00111110
	db %00000010
	db %00000010
	; end

HoundoomBaseStats: ; 0x530a4
	db HOUNDOOM ; 229

	db  75,  90,  50,  95, 110,  80
	;   hp  atk  def  spd  sat  sdf

	db DARK, FIRE
	db 45 ; catch rate
	db 204 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10110110
	db %01010110
	db %01111001
	db %11100100
	db %01101110
	db %00111110
	db %00100010
	db %00000010
	; end

KingdraBaseStats: ; 0x530c4
	db KINGDRA ; 230

	db  75,  95,  95,  85,  95,  95
	;   hp  atk  def  spd  sat  sdf

	db WATER, DRAGON
	db 45 ; catch rate
	db 207 ; base exp
	db NO_ITEM ; item 1
	db DRAGON_SCALE ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn AMPHIBIAN, REPTILE ; egg groups

	; tmhm
	db %00100110
	db %11110010
	db %10011011
	db %10000100
	db %01000110
	db %00011000
	db %10010000
	db %00001001
	; end

PhanpyBaseStats: ; 0x530e4
	db PHANPY ; 231

	db  90,  60,  60,  40,  40,  40
	;   hp  atk  def  spd  sat  sdf

	db GROUND, GROUND
	db 120 ; catch rate
	db 124 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10111110
	db %00010110
	db %00011001
	db %11000110
	db %10010110
	db %00011000
	db %00100000
	db %00000000
	; end

DonphanBaseStats: ; 0x53104
	db DONPHAN ; 232

	db  90, 120, 120,  50,  60,  60
	;   hp  atk  def  spd  sat  sdf

	db GROUND, GROUND
	db 60 ; catch rate
	db 189 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %10111110
	db %01010110
	db %00011001
	db %11000110
	db %10010110
	db %00011000
	db %00100000
	db %00000000
	; end

Porygon2BaseStats: ; 0x53124
	db PORYGON2 ; 233

	db  85,  80,  90,  60, 105,  95
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 180 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn INANIMATE, INANIMATE ; egg groups

	; tmhm
	db %01100100
	db %11110111
	db %01011011
	db %10010101
	db %11000110
	db %00101010
	db %01000010
	db %00001100
	; end

StantlerBaseStats: ; 0x53144
	db STANTLER ; 234

	db  73,  95,  62,  85,  85,  65
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 165 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00110110
	db %00010111
	db %00011011
	db %11010110
	db %01000110
	db %00111110
	db %01000010
	db %00000000
	; end

SmeargleBaseStats: ; 0x53164
	db SMEARGLE ; 235

	db  55,  20,  35,  75,  20,  45
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 106 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	db %00000000
	; end

TyrogueBaseStats: ; 0x53184
	db TYROGUE ; 236

	db  35,  35,  35,  35,  35,  35
	;   hp  atk  def  spd  sat  sdf

	db FIGHTING, FIGHTING
	db 75 ; catch rate
	db 91 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 0 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %10100110
	db %00010110
	db %00011001
	db %11000100
	db %01000110
	db %00111100
	db %00100000
	db %00000000
	; end

HitmontopBaseStats: ; 0x531a4
	db HITMONTOP ; 237

	db  50,  95,  95,  70,  35, 110
	;   hp  atk  def  spd  sat  sdf

	db FIGHTING, FIGHTING
	db 45 ; catch rate
	db 138 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 0 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn HUMANSHAPE, HUMANSHAPE ; egg groups

	; tmhm
	db %10100110
	db %00010110
	db %00011001
	db %11001100
	db %01000110
	db %00111100
	db %00100000
	db %00000000
	; end

SmoochumBaseStats: ; 0x531c4
	db SMOOCHUM ; 238

	db  45,  30,  15,  65,  85,  65
	;   hp  atk  def  spd  sat  sdf

	db ICE, PSYCHIC
	db 45 ; catch rate
	db 87 ; base exp
	db ICE_BERRY ; item 1
	db ICE_BERRY ; item 2
	db 254 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %00100101
	db %10111011
	db %00011011
	db %11110100
	db %00000111
	db %00111010
	db %00000010
	db %00001000
	; end

ElekidBaseStats: ; 0x531e4
	db ELEKID ; 239

	db  45,  63,  37,  95,  65,  55
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 45 ; catch rate
	db 106 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %01100111
	db %00010010
	db %00011011
	db %11010101
	db %01000111
	db %10111101
	db %01000000
	db %00000100
	; end

MagbyBaseStats: ; 0x53204
	db MAGBY ; 240

	db  45,  75,  37,  83,  70,  55
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 45 ; catch rate
	db 117 ; base exp
	db BURNT_BERRY ; item 1
	db BURNT_BERRY ; item 2
	db 63 ; gender
	db 100 ; unknown
	db 25 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 0 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %00100111
	db %00010110
	db %01011001
	db %11010100
	db %00100110
	db %10111101
	db %00000000
	db %00000010
	; end

MiltankBaseStats: ; 0x53224
	db MILTANK ; 241

	db  95,  80, 105, 100,  40,  70
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 45 ; catch rate
	db 200 ; base exp
	db MOOMOO_MILK ; item 1
	db MOOMOO_MILK ; item 2
	db 254 ; gender
	db 100 ; unknown
	db 20 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn FIELD, FIELD ; egg groups

	; tmhm
	db %11101111
	db %11111111
	db %01011011
	db %11100111
	db %10010111
	db %10011001
	db %00110000
	db %00001100
	; end

BlisseyBaseStats: ; 0x53244
	db BLISSEY ; 242

	db 255,  10,  10,  55,  75, 135
	;   hp  atk  def  spd  sat  sdf

	db NORMAL, NORMAL
	db 30 ; catch rate
	db 255 ; base exp
	db NO_ITEM ; item 1
	db LUCKY_EGG ; item 2
	db 254 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 4 ; growth rate
	dn FAIRY, FAIRY ; egg groups

	; tmhm
	db %11101111
	db %11110110
	db %00111011
	db %11110101
	db %10110110
	db %00011010
	db %01100000
	db %00001110
	; end

RaikouBaseStats: ; 0x53264
	db RAIKOU ; 243

	db  90,  85,  75, 115, 115, 100
	;   hp  atk  def  spd  sat  sdf

	db ELECTRIC, ELECTRIC
	db 3 ; catch rate
	db 216 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 80 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %11110110
	db %01010111
	db %01011011
	db %11001101
	db %01010110
	db %00001100
	db %01100100
	db %00000100
	; end

EnteiBaseStats: ; 0x53284
	db ENTEI ; 244

	db 115, 115,  85, 100,  90,  75
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FIRE
	db 3 ; catch rate
	db 217 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 80 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %10110110
	db %01010111
	db %01111011
	db %11001100
	db %01110110
	db %00001100
	db %01100100
	db %00000010
	; end

SuicuneBaseStats: ; 0x532a4
	db SUICUNE ; 245

	db 100,  75, 115,  85,  90, 115
	;   hp  atk  def  spd  sat  sdf

	db WATER, WATER
	db 3 ; catch rate
	db 215 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 80 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %10110110
	db %11110111
	db %01011011
	db %11001100
	db %01010110
	db %00001100
	db %10010100
	db %00001001
	; end

LarvitarBaseStats: ; 0x532c4
	db LARVITAR ; 246

	db  50,  64,  50,  41,  45,  50
	;   hp  atk  def  spd  sat  sdf

	db ROCK, GROUND
	db 45 ; catch rate
	db 67 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 5, 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn MONSTER, MONSTER ; egg groups

	; tmhm
	db %00100110
	db %01010110
	db %00011011
	db %11001110
	db %00010110
	db %00011100
	db %00000000
	db %00000000
	; end

PupitarBaseStats: ; 0x532e4
	db PUPITAR ; 247

	db  70,  84,  70,  51,  65,  70
	;   hp  atk  def  spd  sat  sdf

	db ROCK, GROUND
	db 45 ; catch rate
	db 144 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 6, 6 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn MONSTER, MONSTER ; egg groups

	; tmhm
	db %00100110
	db %01010110
	db %00011011
	db %11001110
	db %00010110
	db %00011100
	db %00000000
	db %00000000
	; end

TyranitarBaseStats: ; 0x53304
	db TYRANITAR ; 248

	db 100, 134, 110,  61,  95, 100
	;   hp  atk  def  spd  sat  sdf

	db ROCK, DARK
	db 45 ; catch rate
	db 218 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 127 ; gender
	db 100 ; unknown
	db 40 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn MONSTER, MONSTER ; egg groups

	; tmhm
	db %10110111
	db %01010110
	db %11011011
	db %11001110
	db %00110110
	db %10011100
	db %00110111
	db %00001110
	; end

LugiaBaseStats: ; 0x53324
	db LUGIA ; 249

	db 106,  90, 130, 110,  90, 154
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, FLYING
	db 3 ; catch rate
	db 220 ; base exp
	db NO_ITEM ; item 1
	db NO_ITEM ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 120 ; step cycles to hatch
	db 5 ; unknown
	dn 7, 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %11110110
	db %11110111
	db %11011111
	db %11110111
	db %01010110
	db %01001110
	db %10111010
	db %00001101
	; end

Ho_OhBaseStats: ; 0x53344
	db HO_OH ; 250

	db 106, 130,  90,  90, 110, 154
	;   hp  atk  def  spd  sat  sdf

	db FIRE, FLYING
	db 3 ; catch rate
	db 220 ; base exp
	db SACRED_ASH ; item 1
	db SACRED_ASH ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 120 ; step cycles to hatch
	db 5 ; unknown
	dn 7 , 7 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 5 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %11110100
	db %01010111
	db %10111111
	db %11110111
	db %01110110
	db %01001110
	db %01101010
	db %00000110
	; end

CelebiBaseStats: ; 0x53364
	db CELEBI ; 251

	db 100, 100, 100, 100, 100, 100
	;   hp  atk  def  spd  sat  sdf

	db PSYCHIC, GRASS
	db 45 ; catch rate
	db 64 ; base exp
	db NO_ITEM ; item 1
	db MIRACLEBERRY ; item 2
	db 255 ; gender
	db 100 ; unknown
	db 120 ; step cycles to hatch
	db 5 ; unknown
	dn 5 , 5 ; frontpic dimensions
	db 0, 0, 0, 0 ; padding
	db 3 ; growth rate
	dn NO_EGGS, NO_EGGS ; egg groups

	; tmhm
	db %00100100
	db %01011111
	db %00111111
	db %11110100
	db %11010110
	db %00001110
	db %01000010
	db %00000000
	; end


PokemonNames:
	db "BULBASAUR@"
	db "IVYSAUR@@@"
	db "VENUSAUR@@"
	db "CHARMANDER"
	db "CHARMELEON"
	db "CHARIZARD@"
	db "SQUIRTLE@@"
	db "WARTORTLE@"
	db "BLASTOISE@"
	db "CATERPIE@@"
	db "METAPOD@@@"
	db "BUTTERFREE"
	db "WEEDLE@@@@"
	db "KAKUNA@@@@"
	db "BEEDRILL@@"
	db "PIDGEY@@@@"
	db "PIDGEOTTO@"
	db "PIDGEOT@@@"
	db "RATTATA@@@"
	db "RATICATE@@"
	db "SPEAROW@@@"
	db "FEAROW@@@@"
	db "EKANS@@@@@"
	db "ARBOK@@@@@"
	db "PIKACHU@@@"
	db "RAICHU@@@@"
	db "SANDSHREW@"
	db "SANDSLASH@"
	db "NIDORAN♀@@"
	db "NIDORINA@@"
	db "NIDOQUEEN@"
	db "NIDORAN♂@@"
	db "NIDORINO@@"
	db "NIDOKING@@"
	db "CLEFAIRY@@"
	db "CLEFABLE@@"
	db "VULPIX@@@@"
	db "NINETALES@"
	db "JIGGLYPUFF"
	db "WIGGLYTUFF"
	db "ZUBAT@@@@@"
	db "GOLBAT@@@@"
	db "ODDISH@@@@"
	db "GLOOM@@@@@"
	db "VILEPLUME@"
	db "PARAS@@@@@"
	db "PARASECT@@"
	db "VENONAT@@@"
	db "VENOMOTH@@"
	db "DIGLETT@@@"
	db "DUGTRIO@@@"
	db "MEOWTH@@@@"
	db "PERSIAN@@@"
	db "PSYDUCK@@@"
	db "GOLDUCK@@@"
	db "MANKEY@@@@"
	db "PRIMEAPE@@"
	db "GROWLITHE@"
	db "ARCANINE@@"
	db "POLIWAG@@@"
	db "POLIWHIRL@"
	db "POLIWRATH@"
	db "ABRA@@@@@@"
	db "KADABRA@@@"
	db "ALAKAZAM@@"
	db "MACHOP@@@@"
	db "MACHOKE@@@"
	db "MACHAMP@@@"
	db "BELLSPROUT"
	db "WEEPINBELL"
	db "VICTREEBEL"
	db "TENTACOOL@"
	db "TENTACRUEL"
	db "GEODUDE@@@"
	db "GRAVELER@@"
	db "GOLEM@@@@@"
	db "PONYTA@@@@"
	db "RAPIDASH@@"
	db "SLOWPOKE@@"
	db "SLOWBRO@@@"
	db "MAGNEMITE@"
	db "MAGNETON@@"
	db "FARFETCH'D"
	db "DODUO@@@@@"
	db "DODRIO@@@@"
	db "SEEL@@@@@@"
	db "DEWGONG@@@"
	db "GRIMER@@@@"
	db "MUK@@@@@@@"
	db "SHELLDER@@"
	db "CLOYSTER@@"
	db "GASTLY@@@@"
	db "HAUNTER@@@"
	db "GENGAR@@@@"
	db "ONIX@@@@@@"
	db "DROWZEE@@@"
	db "HYPNO@@@@@"
	db "KRABBY@@@@"
	db "KINGLER@@@"
	db "VOLTORB@@@"
	db "ELECTRODE@"
	db "EXEGGCUTE@"
	db "EXEGGUTOR@"
	db "CUBONE@@@@"
	db "MAROWAK@@@"
	db "HITMONLEE@"
	db "HITMONCHAN"
	db "LICKITUNG@"
	db "KOFFING@@@"
	db "WEEZING@@@"
	db "RHYHORN@@@"
	db "RHYDON@@@@"
	db "CHANSEY@@@"
	db "TANGELA@@@"
	db "KANGASKHAN"
	db "HORSEA@@@@"
	db "SEADRA@@@@"
	db "GOLDEEN@@@"
	db "SEAKING@@@"
	db "STARYU@@@@"
	db "STARMIE@@@"
	db "MR.MIME@@@"
	db "SCYTHER@@@"
	db "JYNX@@@@@@"
	db "ELECTABUZZ"
	db "MAGMAR@@@@"
	db "PINSIR@@@@"
	db "TAUROS@@@@"
	db "MAGIKARP@@"
	db "GYARADOS@@"
	db "LAPRAS@@@@"
	db "DITTO@@@@@"
	db "EEVEE@@@@@"
	db "VAPOREON@@"
	db "JOLTEON@@@"
	db "FLAREON@@@"
	db "PORYGON@@@"
	db "OMANYTE@@@"
	db "OMASTAR@@@"
	db "KABUTO@@@@"
	db "KABUTOPS@@"
	db "AERODACTYL"
	db "SNORLAX@@@"
	db "ARTICUNO@@"
	db "ZAPDOS@@@@"
	db "MOLTRES@@@"
	db "DRATINI@@@"
	db "DRAGONAIR@"
	db "DRAGONITE@"
	db "MEWTWO@@@@"
	db "MEW@@@@@@@"
	db "CHIKORITA@"
	db "BAYLEEF@@@"
	db "MEGANIUM@@"
	db "CYNDAQUIL@"
	db "QUILAVA@@@"
	db "TYPHLOSION"
	db "TOTODILE@@"
	db "CROCONAW@@"
	db "FERALIGATR"
	db "SENTRET@@@"
	db "FURRET@@@@"
	db "HOOTHOOT@@"
	db "NOCTOWL@@@"
	db "LEDYBA@@@@"
	db "LEDIAN@@@@"
	db "SPINARAK@@"
	db "ARIADOS@@@"
	db "CROBAT@@@@"
	db "CHINCHOU@@"
	db "LANTURN@@@"
	db "PICHU@@@@@"
	db "CLEFFA@@@@"
	db "IGGLYBUFF@"
	db "TOGEPI@@@@"
	db "TOGETIC@@@"
	db "NATU@@@@@@"
	db "XATU@@@@@@"
	db "MAREEP@@@@"
	db "FLAAFFY@@@"
	db "AMPHAROS@@"
	db "BELLOSSOM@"
	db "MARILL@@@@"
	db "AZUMARILL@"
	db "SUDOWOODO@"
	db "POLITOED@@"
	db "HOPPIP@@@@"
	db "SKIPLOOM@@"
	db "JUMPLUFF@@"
	db "AIPOM@@@@@"
	db "SUNKERN@@@"
	db "SUNFLORA@@"
	db "YANMA@@@@@"
	db "WOOPER@@@@"
	db "QUAGSIRE@@"
	db "ESPEON@@@@"
	db "UMBREON@@@"
	db "MURKROW@@@"
	db "SLOWKING@@"
	db "MISDREAVUS"
	db "UNOWN@@@@@"
	db "WOBBUFFET@"
	db "GIRAFARIG@"
	db "PINECO@@@@"
	db "FORRETRESS"
	db "DUNSPARCE@"
	db "GLIGAR@@@@"
	db "STEELIX@@@"
	db "SNUBBULL@@"
	db "GRANBULL@@"
	db "QWILFISH@@"
	db "SCIZOR@@@@"
	db "SHUCKLE@@@"
	db "HERACROSS@"
	db "SNEASEL@@@"
	db "TEDDIURSA@"
	db "URSARING@@"
	db "SLUGMA@@@@"
	db "MAGCARGO@@"
	db "SWINUB@@@@"
	db "PILOSWINE@"
	db "CORSOLA@@@"
	db "REMORAID@@"
	db "OCTILLERY@"
	db "DELIBIRD@@"
	db "MANTINE@@@"
	db "SKARMORY@@"
	db "HOUNDOUR@@"
	db "HOUNDOOM@@"
	db "KINGDRA@@@"
	db "PHANPY@@@@"
	db "DONPHAN@@@"
	db "PORYGON2@@"
	db "STANTLER@@"
	db "SMEARGLE@@"
	db "TYROGUE@@@"
	db "HITMONTOP@"
	db "SMOOCHUM@@"
	db "ELEKID@@@@"
	db "MAGBY@@@@@"
	db "MILTANK@@@"
	db "BLISSEY@@@"
	db "RAIKOU@@@@"
	db "ENTEI@@@@@"
	db "SUICUNE@@@"
	db "LARVITAR@@"
	db "PUPITAR@@@"
	db "TYRANITAR@"
	db "LUGIA@@@@@"
	db "HO-OH@@@@@"
	db "CELEBI@@@@"
	db "?????@@@@@"
	db "EGG@@@@@@@"
	db "?????@@@@@"
	db "?????@@@@@"
	db "?????@@@@@"

INCBIN "baserom.gbc",$53D84,$54000 - $53D84

SECTION "bank15",DATA,BANK[$15]

GoldenrodGym_MapScriptHeader: ; 0x54000
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x5400a, $0000
	dw UnknownScript_0x5400b, $0000

	; callback count
	db 0
; 0x5400a

UnknownScript_0x5400a: ; 0x5400a
	end
; 0x5400b

UnknownScript_0x5400b: ; 0x5400b
	end
; 0x5400c

UnknownScript_0x5400c: ; 0x5400c
	faceplayer
	checkbit1 $04bf
	iftrue UnknownScript_0x54037
	loadfont
	2writetext UnknownText_0x54122
	closetext
	loadmovesprites
	winlosstext UnknownText_0x541a5, $0000
	loadtrainer WHITNEY, 1
	startbattle
	returnafterbattle
	setbit1 $04bf
	setbit1 $0028
	dotrigger $1
	setbit1 $04ad
	setbit1 $04ae
	setbit1 $0515
	setbit1 $0516
UnknownScript_0x54037: ; 0x54037
	loadfont
	checkbit1 $0028
	iffalse UnknownScript_0x54044
	2writetext UnknownText_0x541f4
	closetext
	loadmovesprites
	end
; 0x54044

UnknownScript_0x54044: ; 0x54044
	checkbit1 $000b
	iftrue UnknownScript_0x54077
	checkbit2 $001d
	iftrue UnknownScript_0x54064
	2writetext UnknownText_0x54222
	keeptextopen
	waitbutton
	2writetext UnknownText_0x54273
	playsound $009c
	waitbutton
	setbit2 $001d
	checkcode $7
	2call UnknownScript_0x5407d
UnknownScript_0x54064: ; 0x54064
	2writetext UnknownText_0x5428b
	keeptextopen
	verbosegiveitem TM_45, 1
	iffalse UnknownScript_0x5407b
	setbit1 $000b
	2writetext UnknownText_0x54302
	closetext
	loadmovesprites
	end
; 0x54077

UnknownScript_0x54077: ; 0x54077
	2writetext UnknownText_0x54360
	closetext
UnknownScript_0x5407b: ; 0x5407b
	loadmovesprites
	end
; 0x5407d

UnknownScript_0x5407d: ; 0x5407d
	if_equal $7, UnknownScript_0x54089
	if_equal $6, UnknownScript_0x54086
	end
; 0x54086

UnknownScript_0x54086: ; 0x54086
	jumpstd $0012
; 0x54089

UnknownScript_0x54089: ; 0x54089
	jumpstd $0013
; 0x5408c

TrainerLassCarrie: ; 0x5408c
	; bit/flag number
	dw $515

	; trainer group && trainer id
	db LASS, CARRIE

	; text when seen
	dw LassCarrieSeenText

	; text when trainer beaten
	dw LassCarrieBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw LassCarrieScript
; 0x54098

LassCarrieScript: ; 0x54098
	talkaftercancel
	loadfont
	2writetext LassCarrieOWText
	closetext
	loadmovesprites
	end
; 0x540a0

WhitneyCriesScript: ; 0x540a0
	showemote $0, $4, 15
	applymovement $4, BridgetWalksUpMovement
	spriteface $0, $0
	loadfont
	2writetext BridgetWhitneyCriesText
	closetext
	loadmovesprites
	applymovement $4, BridgetWalksAwayMovement
	dotrigger $0
	clearbit1 $0028
	end
; 0x540bb

TrainerLassBridget: ; 0x540bb
	; bit/flag number
	dw $516

	; trainer group && trainer id
	db LASS, BRIDGET

	; text when seen
	dw LassBridgetSeenText

	; text when trainer beaten
	dw LassBridgetBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw LassBridgetScript
; 0x540c7

LassBridgetScript: ; 0x540c7
	talkaftercancel
	loadfont
	2writetext LassBridgetOWText
	closetext
	loadmovesprites
	end
; 0x540cf

TrainerBeautyVictoria: ; 0x540cf
	; bit/flag number
	dw $4ad

	; trainer group && trainer id
	db BEAUTY, VICTORIA

	; text when seen
	dw BeautyVictoriaSeenText

	; text when trainer beaten
	dw BeautyVictoriaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BeautyVictoriaScript
; 0x540db

BeautyVictoriaScript: ; 0x540db
	talkaftercancel
	loadfont
	2writetext BeautyVictoriaOWText
	closetext
	loadmovesprites
	end
; 0x540e3

TrainerBeautySamantha: ; 0x540e3
	; bit/flag number
	dw $4ae

	; trainer group && trainer id
	db BEAUTY, SAMANTHA

	; text when seen
	dw BeautySamanthaSeenText

	; text when trainer beaten
	dw BeautySamanthaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BeautySamanthaScript
; 0x540ef

BeautySamanthaScript: ; 0x540ef
	talkaftercancel
	loadfont
	2writetext BeautySamanthaOWText
	closetext
	loadmovesprites
	end
; 0x540f7

GoldenrodGymGuyScript: ; 0x540f7
	faceplayer
	checkbit1 $04bf
	iftrue .GoldenrodGymGuyWinScript
	loadfont
	2writetext GoldenrodGymGuyText
	closetext
	loadmovesprites
	end

.GoldenrodGymGuyWinScript
	loadfont
	2writetext GoldenrodGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x5410c

MapGoldenrodGymSignpost1Script: ; 0x5410c
	checkbit2 $001d
	iftrue UnknownScript_0x54115
	jumpstd $002d
; 0x54115

UnknownScript_0x54115: ; 0x54115
	trainertotext WHITNEY, 1, $1
	jumpstd $002e
; 0x5411c

BridgetWalksUpMovement: ; 0x5411c
	step_left
	turn_head_up
	step_end
; 0x5411f

BridgetWalksAwayMovement: ; 0x5411f
	step_right
	turn_head_left
	step_end
; 0x54122

UnknownText_0x54122: ; 0x54122
	db $0, "Hi! I'm WHITNEY!", $51
	db "Everyone was into", $4f
	db "#MON, so I got", $55
	db "into it too!", $51
	db "#MON are", $4f
	db "super-cute!", $51
	db "You want to bat-", $4f
	db "tle? I'm warning", $55
	db "you--I'm good!", $57
; 0x541a5

UnknownText_0x541a5: ; 0x541a5
	db $0, "Sob…", $51
	db "…Waaaaaaah!", $4f
	db "You're mean!", $51
	db "You shouldn't be", $4f
	db "so serious! You…", $55
	db "you child, you!", $57
; 0x541f4

UnknownText_0x541f4: ; 0x541f4
	db $0, "Waaaaah!", $51
	db "Waaaaah!", $51
	db "…Snivel, hic…", $4f
	db "…You meanie!", $57
; 0x54222

UnknownText_0x54222: ; 0x54222
	db $0, "…Sniff…", $51
	db "What? What do you", $4f
	db "want? A BADGE?", $51
	db "Oh, right.", $4f
	db "I forgot. Here's", $55
	db "PLAINBADGE.", $57
; 0x54273

UnknownText_0x54273: ; 0x54273
	db $0, $52, " received", $4f
	db "PLAINBADGE.", $57
; 0x5428b

UnknownText_0x5428b: ; 0x5428b
	db $0, "PLAINBADGE lets", $4f
	db "your #MON use", $51
	db "STRENGTH outside", $4f
	db "of battle.", $51
	db "It also boosts", $4f
	db "your #MON's", $55
	db "SPEED.", $51
	db "Oh, you can have", $4f
	db "this too!", $57
; 0x54302

UnknownText_0x54302: ; 0x54302
	db $0, "It's ATTRACT!", $4f
	db "It makes full use", $51
	db "of a #MON's", $4f
	db "charm.", $51
	db "Isn't it just per-", $4f
	db "fect for a cutie", $55
	db "like me?", $57
; 0x54360

UnknownText_0x54360: ; 0x54360
	db $0, "Ah, that was a", $4f
	db "good cry!", $51
	db "Come for a visit", $4f
	db "again! Bye-bye!", $57
; 0x5439b

LassCarrieSeenText: ; 0x5439b
	db $0, "Don't let my", $4f
	db "#MON's cute", $51
	db "looks fool you.", $4f
	db "They can whip you!", $57
; 0x543d6

LassCarrieBeatenText: ; 0x543d6
	db $0, "Darn… I thought", $4f
	db "you were weak…", $57
; 0x543f6

LassCarrieOWText: ; 0x543f6
	db $0, "Do my #MON", $4f
	db "think I'm cute?", $57
; 0x54411

LassBridgetSeenText: ; 0x54411
	db $0, "I like cute #-", $4f
	db "MON better than", $55
	db "strong #MON.", $51
	db "But I have strong", $4f
	db "and cute #MON!", $57
; 0x5445f

LassBridgetBeatenText: ; 0x5445f
	db $0, "Oh, no, no, no!", $57
; 0x54470

LassBridgetOWText: ; 0x54470
	db $0, "I'm trying to beat", $4f
	db "WHITNEY, but…", $55
	db "It's depressing.", $51
	db "I'm okay! If I", $4f
	db "lose, I'll just", $51
	db "try harder next", $4f
	db "time!", $57
; 0x544d4

BridgetWhitneyCriesText: ; 0x544d4
	db $0, "Oh, no. You made", $4f
	db "WHITNEY cry.", $51
	db "It's OK. She'll", $4f
	db "stop soon. She", $51
	db "always cries when", $4f
	db "she loses.", $57
; 0x5452d

BeautyVictoriaSeenText: ; 0x5452d
	db $0, "Oh, you are a cute", $4f
	db "little trainer! ", $51
	db "I like you, but I", $4f
	db "won't hold back!", $57
; 0x54574

BeautyVictoriaBeatenText: ; 0x54574
	db $0, "Let's see… Oops,", $4f
	db "it's over?", $57
; 0x5458f

BeautyVictoriaOWText: ; 0x5458f
	db $0, "Wow, you must be", $4f
	db "good to beat me!", $55
	db "Keep it up!", $57
; 0x545be

BeautySamanthaSeenText: ; 0x545be
	db $0, "Give it your best", $4f
	db "shot, or I'll take", $55
	db "you down!", $57
; 0x545ed

BeautySamanthaBeatenText: ; 0x545ed
	db $0, "No! Oh, MEOWTH,", $4f
	db "I'm so sorry!", $57
; 0x5460b

BeautySamanthaOWText: ; 0x5460b
	db $0, "I taught MEOWTH", $4f
	db "moves for taking", $55
	db "on any type…", $57
; 0x5463a

GoldenrodGymGuyText: ; 0x5463a
	db $0, "Yo! CHAMP in", $4f
	db "making!", $51
	db "This GYM is home", $4f
	db "to normal-type", $55
	db "#MON trainers.", $51
	db "I recommend you", $4f
	db "use fighting-type", $55
	db "#MON.", $57
; 0x546a7

GoldenrodGymGuyWinText: ; 0x546a7
	db $0, "You won? Great! I", $4f
	db "was busy admiring", $55
	db "the ladies here.", $57
; 0x546dd

GoldenrodGym_MapEventHeader: ; 0x546dd
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $11, $2, 1, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $11, $3, 1, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 1
	xy_trigger 1, $5, $8, $0, WhitneyCriesScript, $0, $0

	; signposts
	db 2
	signpost 15, 1, $0, MapGoldenrodGymSignpost1Script
	signpost 15, 4, $0, MapGoldenrodGymSignpost1Script

	; people-events
	db 6
	person_event $13, 7, 12, $6, $0, 255, 255, $80, 0, UnknownScript_0x5400c, $ffff
	person_event $28, 17, 13, $9, $0, 255, 255, $92, 4, TrainerLassCarrie, $ffff
	person_event $28, 10, 13, $8, $0, 255, 255, $92, 1, TrainerLassBridget, $ffff
	person_event $2a, 6, 4, $6, $0, 255, 255, $92, 3, TrainerBeautyVictoria, $ffff
	person_event $2a, 9, 23, $6, $0, 255, 255, $92, 3, TrainerBeautySamantha, $ffff
	person_event $48, 19, 9, $6, $0, 255, 255, $80, 0, GoldenrodGymGuyScript, $ffff
; 0x5474d

GoldenrodBikeShop_MapScriptHeader: ; 0x5474d
	; trigger count
	db 0

	; callback count
	db 0
; 0x5474f

UnknownScript_0x5474f: ; 0x5474f
	end
; 0x54750

UnknownScript_0x54750: ; 0x54750
	faceplayer
	loadfont
	checkbit1 $005b
	iftrue UnknownScript_0x54775
	2writetext UnknownText_0x54787
	yesorno
	iffalse UnknownScript_0x5477b
	2writetext UnknownText_0x547f8
	keeptextopen
	waitbutton
	giveitem BICYCLE, $1
	2writetext UnknownText_0x54848
	playsound $0091
	waitbutton
	itemnotify
	setbit2 $0014
	setbit1 $005b
UnknownScript_0x54775: ; 0x54775
	2writetext UnknownText_0x5485f
	closetext
	loadmovesprites
	end
; 0x5477b

UnknownScript_0x5477b: ; 0x5477b
	2writetext UnknownText_0x54898
	closetext
	loadmovesprites
	end
; 0x54781

; possibly unused
UnknownScript_0x54781: ; 0x54781
	jumptext UnknownText_0x548c0
; 0x54784

MapGoldenrodBikeShopSignpost8Script: ; 0x54784
	jumptext UnknownText_0x548ed
; 0x54787

UnknownText_0x54787: ; 0x54787
	db $0, "…sigh… I moved", $4f
	db "here, but I can't", $51
	db "sell my BICYCLES.", $4f
	db "Why is that?", $51
	db "Could you ride a", $4f
	db "BICYCLE and adver-", $55
	db "tise for me?", $57
; 0x547f8

UnknownText_0x547f8: ; 0x547f8
	db $0, "Really? Great!", $51
	db "Give me your name", $4f
	db "and phone number,", $51
	db "and I'll loan you", $4f
	db "a BICYCLE.", $57
; 0x54848

UnknownText_0x54848: ; 0x54848
	db $0, $52, " borrowed a", $4f
	db "BICYCLE.", $57
; 0x5485f

UnknownText_0x5485f: ; 0x5485f
	db $0, "My BICYCLES are", $4f
	db "first-rate! You", $51
	db "can ride them", $4f
	db "anywhere.", $57
; 0x54898

UnknownText_0x54898: ; 0x54898
	db $0, "…sigh… Oh, for", $4f
	db "the kindness of", $55
	db "people…", $57
; 0x548c0

; possibly unused
UnknownText_0x548c0: ; 0x548c0
	db $0, "Just released!", $51
	db "First-rate compact", $4f
	db "BICYCLES!", $57
; 0x548ed

UnknownText_0x548ed: ; 0x548ed
	db $0, "It's a shiny new", $4f
	db "BICYCLE!", $57
; 0x54907

GoldenrodBikeShop_MapEventHeader: ; 0x54907
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $3, 2, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 0

	; signposts
	db 9
	signpost 2, 1, $0, MapGoldenrodBikeShopSignpost8Script
	signpost 3, 0, $0, MapGoldenrodBikeShopSignpost8Script
	signpost 3, 1, $0, MapGoldenrodBikeShopSignpost8Script
	signpost 5, 0, $0, MapGoldenrodBikeShopSignpost8Script
	signpost 5, 1, $0, MapGoldenrodBikeShopSignpost8Script
	signpost 6, 0, $0, MapGoldenrodBikeShopSignpost8Script
	signpost 6, 1, $0, MapGoldenrodBikeShopSignpost8Script
	signpost 6, 6, $0, MapGoldenrodBikeShopSignpost8Script
	signpost 6, 7, $0, MapGoldenrodBikeShopSignpost8Script

	; people-events
	db 1
	person_event $39, 6, 11, $8, $0, 255, 255, $80, 0, UnknownScript_0x54750, $ffff
; 0x54951

GoldenrodHappinessRater_MapScriptHeader: ; 0x54951
	; trigger count
	db 0

	; callback count
	db 0
; 0x54953

UnknownScript_0x54953: ; 0x54953
	faceplayer
	loadfont
	special $0059
	2writetext UnknownText_0x549a3
	keeptextopen
	if_less_than $f9, UnknownScript_0x54973
	if_less_than $c7, UnknownScript_0x54979
	if_less_than $95, UnknownScript_0x5497f
	if_less_than $63, UnknownScript_0x54985
	if_less_than $31, UnknownScript_0x5498b
	2jump UnknownScript_0x54991
; 0x54973

UnknownScript_0x54973: ; 0x54973
	2writetext UnknownText_0x549fc
	closetext
	loadmovesprites
	end
; 0x54979

UnknownScript_0x54979: ; 0x54979
	2writetext UnknownText_0x54a2c
	closetext
	loadmovesprites
	end
; 0x5497f

UnknownScript_0x5497f: ; 0x5497f
	2writetext UnknownText_0x54a5a
	closetext
	loadmovesprites
	end
; 0x54985

UnknownScript_0x54985: ; 0x54985
	2writetext UnknownText_0x54a8e
	closetext
	loadmovesprites
	end
; 0x5498b

UnknownScript_0x5498b: ; 0x5498b
	2writetext UnknownText_0x54a9f
	closetext
	loadmovesprites
	end
; 0x54991

UnknownScript_0x54991: ; 0x54991
	2writetext UnknownText_0x54ad1
	closetext
	loadmovesprites
	end
; 0x54997

UnknownScript_0x54997: ; 0x54997
	jumptextfaceplayer UnknownText_0x54b04
; 0x5499a

UnknownScript_0x5499a: ; 0x5499a
	jumptextfaceplayer UnknownText_0x54b67
; 0x5499d

MapGoldenrodHappinessRaterSignpost1Script: ; 0x5499d
	jumpstd $0001
; 0x549a0

MapGoldenrodHappinessRaterSignpost2Script: ; 0x549a0
	jumpstd $000c
; 0x549a3

UnknownText_0x549a3: ; 0x549a3
	db $0, "If you treat your", $4f
	db "#MON nicely,", $51
	db "they will love you", $4f
	db "in return.", $51
	db "Oh? Let me see", $4f
	db "your @"
	text_from_ram $d099
	db $0, "…", $57
; 0x549fc

UnknownText_0x549fc: ; 0x549fc
	db $0, "It looks really", $4f
	db "happy! It must", $55
	db "love you a lot.", $57
; 0x54a2c

UnknownText_0x54a2c: ; 0x54a2c
	db $0, "I get the feeling", $4f
	db "that it really", $55
	db "trusts you.", $57
; 0x54a5a

UnknownText_0x54a5a: ; 0x54a5a
	db $0, "It's friendly to-", $4f
	db "ward you. It looks", $55
	db "sort of happy.", $57
; 0x54a8e

UnknownText_0x54a8e: ; 0x54a8e
	db $0, "It's quite cute.", $57
; 0x54a9f

UnknownText_0x54a9f: ; 0x54a9f
	db $0, "You should treat", $4f
	db "it better. It's", $55
	db "not used to you.", $57
; 0x54ad1

UnknownText_0x54ad1: ; 0x54ad1
	db $0, "It doesn't seem to", $4f
	db "like you at all.", $55
	db "It looks mean.", $57
; 0x54b04

UnknownText_0x54b04: ; 0x54b04
	db $0, "I keep losing in", $4f
	db "battles, and my", $51
	db "#MON end up", $4f
	db "fainting…", $51
	db "Maybe that's why", $4f
	db "my #MON don't", $55
	db "like me much…", $57
; 0x54b67

UnknownText_0x54b67: ; 0x54b67
	db $0, "When I use an item", $4f
	db "on my #MON, it", $55
	db "acts really glad!", $57
; 0x54b9c

GoldenrodHappinessRater_MapEventHeader: ; 0x54b9c
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $3, 3, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 1, 0, $0, MapGoldenrodHappinessRaterSignpost1Script
	signpost 1, 1, $0, MapGoldenrodHappinessRaterSignpost1Script
	signpost 1, 7, $0, MapGoldenrodHappinessRaterSignpost2Script

	; people-events
	db 3
	person_event $29, 8, 6, $6, $0, 255, 255, $90, 0, UnknownScript_0x54953, $ffff
	person_event $2d, 7, 9, $8, $0, 255, 255, $0, 0, UnknownScript_0x54997, $ffff
	person_event $26, 10, 9, $5, $1, 255, 255, $a0, 0, UnknownScript_0x5499a, $ffff
; 0x54be2

GoldenrodBillsHouse_MapScriptHeader: ; 0x54be2
	; trigger count
	db 0

	; callback count
	db 0
; 0x54be4

UnknownScript_0x54be4: ; 0x54be4
	faceplayer
	loadfont
	checkbit1 $004f
	iftrue UnknownScript_0x54c1f
	2writetext UnknownText_0x54c74
	yesorno
	iffalse UnknownScript_0x54c19
	2writetext UnknownText_0x54d3f
	keeptextopen
	waitbutton
	checkcode $1
	if_equal $6, UnknownScript_0x54c13
	2writetext UnknownText_0x54dae
	playsound $0002
	waitbutton
	givepoke EEVEE, 20, 0, 0
	setbit1 $004f
	2writetext UnknownText_0x54dc1
	closetext
	loadmovesprites
	end
; 0x54c13

UnknownScript_0x54c13: ; 0x54c13
	2writetext UnknownText_0x54e02
	closetext
	loadmovesprites
	end
; 0x54c19

UnknownScript_0x54c19: ; 0x54c19
	2writetext UnknownText_0x54e2d
	closetext
	loadmovesprites
	end
; 0x54c1f

UnknownScript_0x54c1f: ; 0x54c1f
	2writetext UnknownText_0x54e42
	closetext
	loadmovesprites
	end
; 0x54c25

UnknownScript_0x54c25: ; 0x54c25
	faceplayer
	loadfont
	checkbit1 $0712
	iffalse UnknownScript_0x54c33
	2writetext UnknownText_0x54ea8
	closetext
	loadmovesprites
	end
; 0x54c33

UnknownScript_0x54c33: ; 0x54c33
	2writetext UnknownText_0x54f4e
	closetext
	loadmovesprites
	end
; 0x54c39

UnknownScript_0x54c39: ; 0x54c39
	faceplayer
	loadfont
	checkcellnum $3
	iftrue UnknownScript_0x54c58
	2writetext UnknownText_0x54f9e
	askforphonenumber $3
	if_equal $1, UnknownScript_0x54c64
	if_equal $2, UnknownScript_0x54c5e
	waitbutton
	addcellnum $3
	2writetext UnknownText_0x54fd9
	playsound $0093
	waitbutton
	keeptextopen
UnknownScript_0x54c58: ;0x54c58
	2writetext UnknownText_0x55069
	closetext
	loadmovesprites
	end
; 0x54c5e

UnknownScript_0x54c5e: ; 0x54c5e
	2writetext UnknownText_0x54ff3
	closetext
	loadmovesprites
	end
; 0x54c64

UnknownScript_0x54c64: ; 0x54c64
	2writetext UnknownText_0x55046
	keeptextopen
	2jump UnknownScript_0x54c5e
; 0x54c6b

MapGoldenrodBillsHouseSignpost1Script: ; 0x54c6b
	jumpstd $0002
; 0x54c6e

MapGoldenrodBillsHouseSignpost0Script: ; 0x54c6e
	jumpstd $0003
; 0x54c71

MapGoldenrodBillsHouseSignpost2Script: ; 0x54c71
	jumpstd $000c
; 0x54c74

UnknownText_0x54c74: ; 0x54c74
	db $0, "BILL: Hi, ", $52, "!", $4f
	db "Do us a favor and", $55
	db "take this EEVEE.", $51
	db "It came over when", $4f
	db "I was adjusting", $55
	db "the TIME CAPSULE.", $51
	db "Someone has to", $4f
	db "take care of it,", $51
	db "but I don't like", $4f
	db "being outside.", $51
	db "Can I count on you", $4f
	db "to play with it,", $55
	db $52, "?", $57
; 0x54d3f

UnknownText_0x54d3f: ; 0x54d3f
	db $0, "BILL: I knew you'd", $4f
	db "come through!", $51
	db "Way to go! You're", $4f
	db "the real deal!", $51
	db "OK, I'm counting", $4f
	db "on you.", $51
	db "Take good care of", $4f
	db "it!", $57
; 0x54dae

UnknownText_0x54dae: ; 0x54dae
	db $0, $52, " received", $4f
	db "EEVEE!", $57
; 0x54dc1

UnknownText_0x54dc1: ; 0x54dc1
	db $0, "BILL: PROF.ELM", $4f
	db "claims EEVEE may", $51
	db "evolve in new and", $4f
	db "unknown ways.", $57
; 0x54e02

UnknownText_0x54e02: ; 0x54e02
	db $0, "Whoa, wait. You", $4f
	db "can't carry any", $55
	db "more #MON.", $57
; 0x54e2d

UnknownText_0x54e2d: ; 0x54e2d
	db $0, "Oh… Now what to", $4f
	db "do?", $57
; 0x54e42

UnknownText_0x54e42: ; 0x54e42
	db $0, "BILL: My pop, he", $4f
	db "won't work. All he", $51
	db "does is goof off", $4f
	db "all day long.", $51
	db "He's getting to be", $4f
	db "a real headache…", $57
; 0x54ea8

UnknownText_0x54ea8: ; 0x54ea8
	db $0, "Oh, you collect", $4f
	db "#MON? My son", $55
	db "BILL is an expert.", $51
	db "He just got called", $4f
	db "to the #MON", $51
	db "CENTER in ECRUTEAK", $4f
	db "CITY.", $51
	db "My husband went", $4f
	db "off to the GAME", $51
	db "CORNER without", $4f
	db "being called…", $57
; 0x54f4e

UnknownText_0x54f4e: ; 0x54f4e
	db $0, "My husband was", $4f
	db "once known as a", $51
	db "#MANIAC.", $4f
	db "BILL must have", $51
	db "taken after his", $4f
	db "father.", $57
; 0x54f9e

UnknownText_0x54f9e: ; 0x54f9e
	db $0, "Are you a trainer?", $51
	db "I've got a useful", $4f
	db "phone number for", $55
	db "you.", $57
; 0x54fd9

UnknownText_0x54fd9: ; 0x54fd9
	db $0, $52, " recorded", $4f
	db "BILL's number.", $57
; 0x54ff3

UnknownText_0x54ff3: ; 0x54ff3
	db $0, "My brother made", $4f
	db "the PC #MON", $55
	db "storage system.", $51
	db "I was going to", $4f
	db "give you BILL's", $55
	db "number…", $57
; 0x55046

UnknownText_0x55046: ; 0x55046
	db $0, "You can't record", $4f
	db "any more numbers.", $57
; 0x55069

UnknownText_0x55069: ; 0x55069
	db $0, "My big brother", $4f
	db "BILL made the PC", $51
	db "#MON storage", $4f
	db "system.", $57
; 0x5509f

GoldenrodBillsHouse_MapEventHeader: ; 0x5509f
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $3, 4, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 1, 0, $0, MapGoldenrodBillsHouseSignpost0Script
	signpost 1, 1, $0, MapGoldenrodBillsHouseSignpost1Script
	signpost 1, 7, $0, MapGoldenrodBillsHouseSignpost2Script

	; people-events
	db 3
	person_event $8, 7, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x54be4, $0712
	person_event $2e, 7, 9, $6, $0, 255, 255, $0, 0, UnknownScript_0x54c25, $ffff
	person_event $26, 8, 9, $2, $11, 255, 255, $a0, 0, UnknownScript_0x54c39, $ffff
; 0x550e5

GoldenrodMagnetTrainStation_MapScriptHeader: ; 0x550e5
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x550eb, $0000

	; callback count
	db 0
; 0x550eb

UnknownScript_0x550eb: ; 0x550eb
	end
; 0x550ec

UnknownScript_0x550ec: ; 0x550ec
	faceplayer
	loadfont
	checkbit1 $00cd
	iftrue UnknownScript_0x550fa
	2writetext UnknownText_0x55160
	closetext
	loadmovesprites
	end
; 0x550fa

UnknownScript_0x550fa: ; 0x550fa
	2writetext UnknownText_0x551b7
	yesorno
	iffalse UnknownScript_0x5512a
	checkitem PASS
	iffalse UnknownScript_0x55124
	2writetext UnknownText_0x551ed
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x55146
	applymovement $0, MovementData_0x5514f
	writebyte $0
	special $0023
	warpcheck
	newloadmap $f9
	applymovement $0, MovementData_0x55122
	unknown0xa8 $14
	end
; 0x55122

MovementData_0x55122: ; 0x55122
	turn_head_down
	step_end
; 0x55124

UnknownScript_0x55124: ; 0x55124
	2writetext UnknownText_0x5522c
	closetext
	loadmovesprites
	end
; 0x5512a

UnknownScript_0x5512a: ; 0x5512a
	2writetext UnknownText_0x5524f
	closetext
	loadmovesprites
	end
; 0x55130

UnknownScript_0x55130: ; 0x55130
	applymovement $2, MovementData_0x55146
	applymovement $0, MovementData_0x55158
	applymovement $2, MovementData_0x5514b
	loadfont
	2writetext UnknownText_0x5526a
	closetext
	loadmovesprites
	end
; 0x55143

UnknownScript_0x55143: ; 0x55143
	jumptextfaceplayer UnknownText_0x552a3
; 0x55146

MovementData_0x55146: ; 0x55146
	step_up
	step_up
	step_right
	turn_head_left
	step_end
; 0x5514b

MovementData_0x5514b: ; 0x5514b
	step_left
	step_down
	step_down
	step_end
; 0x5514f

MovementData_0x5514f: ; 0x5514f
	step_up
	step_up
	step_up
	step_left
	step_left
	step_left
	step_up
	step_up
	step_end
; 0x55158

MovementData_0x55158: ; 0x55158
	step_left
	step_left
	step_down
	step_down
	step_down
	step_down
	turn_head_up
	step_end
; 0x55160

UnknownText_0x55160: ; 0x55160
	db $0, "The train hasn't", $4f
	db "come in…", $51
	db "I know! I'll carry", $4f
	db "the passengers on", $55
	db "my back!", $51
	db "That won't work.", $57
; 0x551b7

UnknownText_0x551b7: ; 0x551b7
	db $0, "We'll soon depart", $4f
	db "for SAFFRON.", $51
	db "Are you coming", $4f
	db "aboard?", $57
; 0x551ed

UnknownText_0x551ed: ; 0x551ed
	db $0, "May I see your", $4f
	db "rail PASS, please?", $51
	db "OK. Right this", $4f
	db "way, please.", $57
; 0x5522c

UnknownText_0x5522c: ; 0x5522c
	db $0, "Sorry. You don't", $4f
	db "have a rail PASS.", $57
; 0x5524f

UnknownText_0x5524f: ; 0x5524f
	db $0, "We hope to see you", $4f
	db "again!", $57
; 0x5526a

UnknownText_0x5526a: ; 0x5526a
	db $0, "We have arrived in", $4f
	db "GOLDENROD.", $51
	db "We hope to see you", $4f
	db "again.", $57
; 0x552a3

UnknownText_0x552a3: ; 0x552a3
	db $0, "I'm the PRESIDENT.", $51
	db "My dream was to", $4f
	db "build a train that", $51
	db "is faster than any", $4f
	db "#MON.", $51
	db "It really brings", $4f
	db "JOHTO much closer", $55
	db "to KANTO.", $57
; 0x5531f

GoldenrodMagnetTrainStation_MapEventHeader: ; 0x5531f
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $11, $8, 5, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $11, $9, 5, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $5, $6, 4, GROUP_SAFFRON_TRAIN_STATION, MAP_SAFFRON_TRAIN_STATION
	warp_def $5, $b, 3, GROUP_SAFFRON_TRAIN_STATION, MAP_SAFFRON_TRAIN_STATION

	; xy triggers
	db 1
	xy_trigger 0, $6, $b, $0, UnknownScript_0x55130, $0, $0

	; signposts
	db 0

	; people-events
	db 2
	person_event $43, 13, 13, $6, $0, 255, 255, $0, 0, UnknownScript_0x550ec, $ffff
	person_event $40, 18, 15, $2, $22, 255, 255, $0, 0, UnknownScript_0x55143, $0749
; 0x5535b

GoldenrodFlowerShop_MapScriptHeader: ; 0x5535b
	; trigger count
	db 0

	; callback count
	db 0
; 0x5535d

UnknownScript_0x5535d: ; 0x5535d
	checkbit1 $002a
	iftrue UnknownScript_0x5538f
	checkbit1 $005c
	iftrue UnknownScript_0x55399
	checkbit1 $00b9
	iffalse UnknownScript_0x5539f
	checkbit1 $00ba
	iffalse UnknownScript_0x5538f
	checkbit2 $001d
	iffalse UnknownScript_0x5539c
	faceplayer
	loadfont
	2writetext UnknownText_0x554c2
	keeptextopen
	verbosegiveitem SQUIRTBOTTLE, 1
	setbit1 $005c
	loadmovesprites
	setbit1 $0769
	clearbit1 $0768
	end
; 0x5538f

UnknownScript_0x5538f: ; 0x5538f
	spriteface $2, $2
	loadfont
	2writetext UnknownText_0x5552e
	closetext
	loadmovesprites
	end
; 0x55399

UnknownScript_0x55399: ; 0x55399
	jumptextfaceplayer UnknownText_0x5550d
; 0x5539c

UnknownScript_0x5539c: ; 0x5539c
	jumptextfaceplayer UnknownText_0x55463
; 0x5539f

UnknownScript_0x5539f: ; 0x5539f
	jumptextfaceplayer UnknownText_0x553d4
; 0x553a2

UnknownScript_0x553a2: ; 0x553a2
	faceplayer
	loadfont
	checkbit1 $002a
	iftrue UnknownScript_0x553c5
	checkbit1 $005c
	iftrue UnknownScript_0x553bf
	2writetext UnknownText_0x55561
	closetext
	loadmovesprites
	setbit1 $00ba
	setbit1 $0768
	clearbit1 $0769
	end
; 0x553bf

UnknownScript_0x553bf: ; 0x553bf
	2writetext UnknownText_0x555e6
	closetext
	loadmovesprites
	end
; 0x553c5

UnknownScript_0x553c5: ; 0x553c5
	2writetext UnknownText_0x55604
	closetext
	loadmovesprites
	end
; 0x553cb

UnknownScript_0x553cb: ; 0x553cb
	jumpstd $0002
; 0x553ce

UnknownScript_0x553ce: ; 0x553ce
	jumpstd $0003
; 0x553d1

UnknownScript_0x553d1: ; 0x553d1
	jumpstd $000c
; 0x553d4

UnknownText_0x553d4: ; 0x553d4
	db $0, "Have you seen that", $4f
	db "wiggly tree that's", $51
	db "growing on ROUTE", $4f
	db "36?", $51
	db "My little sister", $4f
	db "got all excited", $51
	db "and went to see", $4f
	db "it…", $51
	db "I'm worried… Isn't", $4f
	db "it dangerous?", $57
; 0x55463

UnknownText_0x55463: ; 0x55463
	db $0, "Do you want to", $4f
	db "borrow the water", $51
	db "bottle too?", $4f
	db "I don't want you", $51
	db "doing anything", $4f
	db "dangerous with it.", $57
; 0x554c2

UnknownText_0x554c2: ; 0x554c2
	db $0, "Oh, you're better", $4f
	db "than WHITNEY…", $51
	db "You'll be OK,", $4f
	db "then. Here's the", $55
	db "SQUIRTBOTTLE!", $57
; 0x5550d

UnknownText_0x5550d: ; 0x5550d
	db $0, "Don't do anything", $4f
	db "too dangerous!", $57
; 0x5552e

UnknownText_0x5552e: ; 0x5552e
	db $0, "Lalala lalalala.", $4f
	db "Have plenty of", $55
	db "water, my lovely!", $57
; 0x55561

UnknownText_0x55561: ; 0x55561
	db $0, "When I told my sis", $4f
	db "about the jiggly", $51
	db "tree, she told me", $4f
	db "it's dangerous.", $51
	db "If I beat WHITNEY,", $4f
	db "I wonder if she'll", $51
	db "lend me her water", $4f
	db "bottle…", $57
; 0x555e6

UnknownText_0x555e6: ; 0x555e6
	db $0, "Wow, you beat", $4f
	db "WHITNEY? Cool!", $57
; 0x55604

UnknownText_0x55604: ; 0x55604
	db $0, "So it really was a", $4f
	db "#MON!", $57
; 0x5561e

GoldenrodFlowerShop_MapEventHeader: ; 0x5561e
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 6, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $3, 6, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $29, 8, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x5535d, $ffff
	person_event $28, 10, 9, $2, $11, 255, 255, $90, 0, UnknownScript_0x553a2, $0768
; 0x55648

GoldenrodPPSpeechHouse_MapScriptHeader: ; 0x55648
	; trigger count
	db 0

	; callback count
	db 0
; 0x5564a

UnknownScript_0x5564a: ; 0x5564a
	jumptextfaceplayer UnknownText_0x55659
; 0x5564d

UnknownScript_0x5564d: ; 0x5564d
	jumptextfaceplayer UnknownText_0x556ca
; 0x55650

MapGoldenrodPPSpeechHouseSignpost1Script: ; 0x55650
	jumpstd $0001
; 0x55653

MapGoldenrodPPSpeechHouseSignpost0Script: ; 0x55653
	jumpstd $0003
; 0x55656

MapGoldenrodPPSpeechHouseSignpost2Script: ; 0x55656
	jumpstd $000c
; 0x55659

UnknownText_0x55659: ; 0x55659
	db $0, "Once while I was", $4f
	db "battling, my", $51
	db "#MON couldn't", $4f
	db "make any moves.", $51
	db "The POWER POINTS,", $4f
	db "or PP, of its", $51
	db "moves were all", $4f
	db "gone.", $57
; 0x556ca

UnknownText_0x556ca: ; 0x556ca
	db $0, "Sometimes, a", $4f
	db "healthy #MON", $51
	db "may be unable to", $4f
	db "use its moves.", $51
	db "If that happens,", $4f
	db "heal it at a #-", $55
	db "MON CENTER or use", $55
	db "an item.", $57
; 0x55741

GoldenrodPPSpeechHouse_MapEventHeader: ; 0x55741
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 7, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $3, 7, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 1, 0, $0, MapGoldenrodPPSpeechHouseSignpost0Script
	signpost 1, 1, $0, MapGoldenrodPPSpeechHouseSignpost1Script
	signpost 1, 7, $0, MapGoldenrodPPSpeechHouseSignpost2Script

	; people-events
	db 2
	person_event $3a, 8, 6, $4, $10, 255, 255, $a0, 0, UnknownScript_0x5564a, $ffff
	person_event $28, 7, 9, $8, $10, 255, 255, $0, 0, UnknownScript_0x5564d, $ffff
; 0x5577a

GoldenrodNameRatersHouse_MapScriptHeader: ; 0x5577a
	; trigger count
	db 0

	; callback count
	db 0
; 0x5577c

UnknownScript_0x5577c: ; 0x5577c
	faceplayer
	loadfont
	special $0057
	closetext
	loadmovesprites
	end
; 0x55784

MapGoldenrodNameRatersHouseSignpost1Script: ; 0x55784
	jumpstd $0001
; 0x55787

MapGoldenrodNameRatersHouseSignpost2Script: ; 0x55787
	jumpstd $000c
; 0x5578a

INCLUDE "text/sweethoney.asm"

GoldenrodNameRatersHouse_MapEventHeader: ; 0x55953
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 8, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $3, 8, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 1, 0, $0, MapGoldenrodNameRatersHouseSignpost1Script
	signpost 1, 1, $0, MapGoldenrodNameRatersHouseSignpost1Script
	signpost 1, 7, $0, MapGoldenrodNameRatersHouseSignpost2Script

	; people-events
	db 1
	person_event $40, 8, 6, $6, $2, 255, 255, $0, 0, UnknownScript_0x5577c, $ffff
; 0x5597f

GoldenrodDeptStore1F_MapScriptHeader: ; 0x5597f
	; trigger count
	db 0

	; callback count
	db 0
; 0x55981

UnknownScript_0x55981: ; 0x55981
	jumptextfaceplayer UnknownText_0x55993
; 0x55984

UnknownScript_0x55984: ; 0x55984
	jumptextfaceplayer UnknownText_0x559b7
; 0x55987

UnknownScript_0x55987: ; 0x55987
	jumptextfaceplayer UnknownText_0x55a1a
; 0x5598a

UnknownScript_0x5598a: ; 0x5598a
	jumptextfaceplayer UnknownText_0x55a3a
; 0x5598d

MapGoldenrodDeptStore1FSignpost0Script: ; 0x5598d
	jumptext UnknownText_0x55a80
; 0x55990

MapGoldenrodDeptStore1FSignpost1Script: ; 0x55990
	jumpstd $0014
; 0x55993

UnknownText_0x55993: ; 0x55993
	db $0, "Welcome to GOLDEN-", $4f
	db "ROD DEPT.STORE.", $57
; 0x559b7

UnknownText_0x559b7: ; 0x559b7
	db $0, "The DEPT.STORE", $4f
	db "has a decent se-", $55
	db "lection.", $51
	db "But some items", $4f
	db "are only available", $51
	db "as GAME CORNER", $4f
	db "prizes.", $57
; 0x55a1a

UnknownText_0x55a1a: ; 0x55a1a
	db $0, "I'm raring to shop", $4f
	db "again today!", $57
; 0x55a3a

UnknownText_0x55a3a: ; 0x55a3a
	db $0, "Mom's good at", $4f
	db "bargain hunting.", $51
	db "She always buys", $4f
	db "stuff at lower", $55
	db "prices.", $57
; 0x55a80

UnknownText_0x55a80: ; 0x55a80
	db $0, "1F SERVICE COUNTER", $51
	db "2F TRAINER'S", $4f
	db "   MARKET", $51
	db "3F BATTLE", $4f
	db "   COLLECTION", $51
	db "4F MEDICINE BOX", $51
	db "5F TM CORNER", $51
	db "6F TRANQUIL SQUARE", $51
	db "ROOFTOP LOOKOUT", $57
; 0x55b03

GoldenrodDeptStore1F_MapEventHeader: ; 0x55b03
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $7, $7, 9, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $8, 9, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $0, $f, 2, GROUP_GOLDENROD_DEPT_STORE_2F, MAP_GOLDENROD_DEPT_STORE_2F
	warp_def $0, $2, 1, GROUP_GOLDENROD_DEPT_STORE_ELEVATOR, MAP_GOLDENROD_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapGoldenrodDeptStore1FSignpost0Script
	signpost 0, 3, $0, MapGoldenrodDeptStore1FSignpost1Script

	; people-events
	db 4
	person_event $42, 5, 14, $6, $0, 255, 255, $0, 0, UnknownScript_0x55981, $ffff
	person_event $2e, 8, 9, $6, $0, 255, 255, $0, 0, UnknownScript_0x55987, $ffff
	person_event $25, 9, 9, $5, $1, 255, 255, $a0, 0, UnknownScript_0x5598a, $ffff
	person_event $40, 9, 15, $2, $11, 255, 255, $0, 0, UnknownScript_0x55984, $ffff
; 0x55b5b

GoldenrodDeptStore2F_MapScriptHeader: ; 0x55b5b
	; trigger count
	db 0

	; callback count
	db 0
; 0x55b5d

UnknownScript_0x55b5d: ; 0x55b5d
	faceplayer
	loadfont
	pokemart $0, $0005
	loadmovesprites
	end
; 0x55b65

UnknownScript_0x55b65: ; 0x55b65
	faceplayer
	loadfont
	pokemart $0, $0006
	loadmovesprites
	end
; 0x55b6d

UnknownScript_0x55b6d: ; 0x55b6d
	jumptextfaceplayer UnknownText_0x55c25
; 0x55b70

UnknownScript_0x55b70: ; 0x55b70
	jumptextfaceplayer UnknownText_0x55c7b
; 0x55b73

UnknownScript_0x55b73: ; 0x55b73
	jumptextfaceplayer UnknownText_0x55cb7
; 0x55b76

MapGoldenrodDeptStore2FSignpost0Script: ; 0x55b76
	jumptext UnknownText_0x55d28
; 0x55b79

MapGoldenrodDeptStore2FSignpost1Script: ; 0x55b79
	jumpstd $0014
; 0x55b7c

; possibly unused
UnknownText_0x55b7c: ; 0x55b7c
	db $0, "We intend to sell", $4f
	db "items for #MON", $55
	db "to hold.", $51
	db "This is a free", $4f
	db "gift. Have a #-", $55
	db "MON hold it.", $57
; 0x55bd3

; possibly unused
UnknownText_0x55bd3: ; 0x55bd3
	db $0, "By giving #MON", $4f
	db "items to hold, I", $51
	db "bet trainers will", $4f
	db "develop new battle", $55
	db "techniques.", $57
; 0x55c25

UnknownText_0x55c25: ; 0x55c25
	db $0, "#GEAR can store", $4f
	db "up to ten phone", $55
	db "numbers.", $51
	db "It's hard to de-", $4f
	db "cide which numbers", $55
	db "to keep.", $57
; 0x55c7b

UnknownText_0x55c7b: ; 0x55c7b
	db $0, "I got my ABRA at", $4f
	db "the GAME CORNER.", $51
	db "Now it's my best", $4f
	db "partner.", $57
; 0x55cb7

UnknownText_0x55cb7: ; 0x55cb7
	db $0, "This DEPT.STORE", $4f
	db "makes me realize", $51
	db "that GOLDENROD is", $4f
	db "a big city.", $51
	db "The selection here", $4f
	db "is unmatched any-", $55
	db "where else.", $57
; 0x55d28

UnknownText_0x55d28: ; 0x55d28
	db $0, "Your Travel", $4f
	db "Companion", $51
	db "2F TRAINER'S", $4f
	db "   MARKET", $57
; 0x55d56

GoldenrodDeptStore2F_MapEventHeader: ; 0x55d56
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $c, 1, GROUP_GOLDENROD_DEPT_STORE_3F, MAP_GOLDENROD_DEPT_STORE_3F
	warp_def $0, $f, 3, GROUP_GOLDENROD_DEPT_STORE_1F, MAP_GOLDENROD_DEPT_STORE_1F
	warp_def $0, $2, 1, GROUP_GOLDENROD_DEPT_STORE_ELEVATOR, MAP_GOLDENROD_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapGoldenrodDeptStore2FSignpost0Script
	signpost 0, 3, $0, MapGoldenrodDeptStore2FSignpost1Script

	; people-events
	db 5
	person_event $39, 9, 17, $7, $0, 255, 255, $0, 0, UnknownScript_0x55b5d, $ffff
	person_event $39, 10, 17, $8, $0, 255, 255, $0, 0, UnknownScript_0x55b65, $ffff
	person_event $27, 10, 13, $4, $10, 255, 255, $0, 0, UnknownScript_0x55b6d, $ffff
	person_event $24, 6, 10, $5, $2, 255, 255, $80, 0, UnknownScript_0x55b70, $ffff
	person_event $40, 10, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x55b73, $ffff
; 0x55db6

GoldenrodDeptStore3F_MapScriptHeader: ; 0x55db6
	; trigger count
	db 0

	; callback count
	db 0
; 0x55db8

UnknownScript_0x55db8: ; 0x55db8
	faceplayer
	loadfont
	pokemart $0, $0007
	loadmovesprites
	end
; 0x55dc0

UnknownScript_0x55dc0: ; 0x55dc0
	jumptextfaceplayer UnknownText_0x55dcc
; 0x55dc3

UnknownScript_0x55dc3: ; 0x55dc3
	jumptextfaceplayer UnknownText_0x55e15
; 0x55dc6

MapGoldenrodDeptStore3FSignpost0Script: ; 0x55dc6
	jumptext UnknownText_0x55e74
; 0x55dc9

MapGoldenrodDeptStore3FSignpost1Script: ; 0x55dc9
	jumpstd $0014
; 0x55dcc

UnknownText_0x55dcc: ; 0x55dcc
	db $0, "I, I, I'm really", $4f
	db "impatient!", $51
	db "I use X SPEED in", $4f
	db "battle to speed up", $55
	db "my #MON.", $57
; 0x55e15

UnknownText_0x55e15: ; 0x55e15
	db $0, "Hey! When you bat-", $4f
	db "tle, do you use X", $55
	db "SPECIAL?", $51
	db "It's awesome. It", $4f
	db "really jacks up", $55
	db "SPECIAL ATTACK!", $57
; 0x55e74

UnknownText_0x55e74: ; 0x55e74
	db $0, "For Victory", $4f
	db "Seekers", $51
	db "3F BATTLE", $4f
	db "   COLLECTION", $57
; 0x55ea1

GoldenrodDeptStore3F_MapEventHeader: ; 0x55ea1
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $c, 1, GROUP_GOLDENROD_DEPT_STORE_2F, MAP_GOLDENROD_DEPT_STORE_2F
	warp_def $0, $f, 2, GROUP_GOLDENROD_DEPT_STORE_4F, MAP_GOLDENROD_DEPT_STORE_4F
	warp_def $0, $2, 1, GROUP_GOLDENROD_DEPT_STORE_ELEVATOR, MAP_GOLDENROD_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapGoldenrodDeptStore3FSignpost0Script
	signpost 0, 3, $0, MapGoldenrodDeptStore3FSignpost1Script

	; people-events
	db 3
	person_event $39, 5, 10, $6, $0, 255, 255, $0, 0, UnknownScript_0x55db8, $ffff
	person_event $2b, 9, 16, $a, $10, 255, 255, $80, 0, UnknownScript_0x55dc0, $ffff
	person_event $2c, 9, 6, $4, $10, 255, 255, $0, 0, UnknownScript_0x55dc3, $ffff
; 0x55ee7

GoldenrodDeptStore4F_MapScriptHeader: ; 0x55ee7
	; trigger count
	db 0

	; callback count
	db 0
; 0x55ee9

UnknownScript_0x55ee9: ; 0x55ee9
	faceplayer
	loadfont
	pokemart $0, $0008
	loadmovesprites
	end
; 0x55ef1

UnknownScript_0x55ef1: ; 0x55ef1
	jumptextfaceplayer UnknownText_0x55f08
; 0x55ef4

UnknownScript_0x55ef4: ; 0x55ef4
	jumptextfaceplayer UnknownText_0x55f52
; 0x55ef7

UnknownScript_0x55ef7: ; 0x55ef7
	faceplayer
	loadfont
	2writetext UnknownText_0x55f74
	closetext
	loadmovesprites
	spriteface $5, $0
	end
; 0x55f02

MapGoldenrodDeptStore4FSignpost0Script: ; 0x55f02
	jumptext UnknownText_0x5600d
; 0x55f05

MapGoldenrodDeptStore4FSignpost1Script: ; 0x55f05
	jumpstd $0014
; 0x55f08

UnknownText_0x55f08: ; 0x55f08
	db $0, "Hey. I love strong", $4f
	db "#MON.", $51
	db "I feed them PRO-", $4f
	db "TEIN to crank up", $55
	db "their ATTACK.", $57
; 0x55f52

UnknownText_0x55f52: ; 0x55f52
	db $0, "IRON adds to your", $4f
	db "#MON's DEFENSE.", $57
; 0x55f74

UnknownText_0x55f74: ; 0x55f74
	db $0, "Some #MON", $4f
	db "evolve only by", $51
	db "being traded via a", $4f
	db "Game Link cable.", $51
	db "I know of four:", $4f
	db "MACHOKE, KADABRA,", $51
	db "HAUNTER and, um,", $4f
	db "GRAVELER.", $51
	db "I heard there are", $4f
	db "others too.", $57
; 0x5600d

UnknownText_0x5600d: ; 0x5600d
	db $0, "Let Us Pump Up", $4f
	db "Your #MON!", $51
	db "4F MEDICINE BOX", $57
; 0x56038

GoldenrodDeptStore4F_MapEventHeader: ; 0x56038
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $c, 1, GROUP_GOLDENROD_DEPT_STORE_5F, MAP_GOLDENROD_DEPT_STORE_5F
	warp_def $0, $f, 2, GROUP_GOLDENROD_DEPT_STORE_3F, MAP_GOLDENROD_DEPT_STORE_3F
	warp_def $0, $2, 1, GROUP_GOLDENROD_DEPT_STORE_ELEVATOR, MAP_GOLDENROD_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapGoldenrodDeptStore4FSignpost0Script
	signpost 0, 3, $0, MapGoldenrodDeptStore4FSignpost1Script

	; people-events
	db 4
	person_event $39, 9, 17, $7, $0, 255, 255, $0, 0, UnknownScript_0x55ee9, $ffff
	person_event $23, 11, 15, $9, $0, 255, 255, $0, 0, UnknownScript_0x55ef1, $ffff
	person_event $25, 6, 11, $5, $1, 255, 255, $0, 0, UnknownScript_0x55ef4, $ffff
	person_event $3, 5, 9, $6, $0, 255, 255, $0, 0, UnknownScript_0x55ef7, $ffff
; 0x5608b

GoldenrodDeptStore5F_MapScriptHeader: ; 0x5608b
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x56090
; 0x56090

UnknownScript_0x56090: ; 0x56090
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x56099
	disappear $7
	return
; 0x56099

UnknownScript_0x56099: ; 0x56099
	appear $7
	return
; 0x5609c

UnknownScript_0x5609c: ; 0x5609c
	faceplayer
	loadfont
	checkbit1 $005f
	iftrue UnknownScript_0x560ad
	checkbit1 $004b
	iftrue UnknownScript_0x560c2
	2jump UnknownScript_0x560b6
; 0x560ad

UnknownScript_0x560ad: ; 0x560ad
	checkbit1 $004b
	iftrue UnknownScript_0x560c8
	2jump UnknownScript_0x560bc
; 0x560b6

UnknownScript_0x560b6: ; 0x560b6
	pokemart $0, $0009
	loadmovesprites
	end
; 0x560bc

UnknownScript_0x560bc: ; 0x560bc
	pokemart $0, $000a
	loadmovesprites
	end
; 0x560c2

UnknownScript_0x560c2: ; 0x560c2
	pokemart $0, $000b
	loadmovesprites
	end
; 0x560c8

UnknownScript_0x560c8: ; 0x560c8
	pokemart $0, $000c
	loadmovesprites
	end
; 0x560ce

UnknownScript_0x560ce: ; 0x560ce
	faceplayer
	loadfont
	checkcode $b
	if_not_equal SUNDAY, UnknownScript_0x56112
	checkbit2 $005b
	iftrue UnknownScript_0x56112
	special $0059
	2writetext UnknownText_0x56143
	keeptextopen
	if_less_than $95, UnknownScript_0x560ee
	if_less_than $31, UnknownScript_0x560fd
	2jump UnknownScript_0x56103
; 0x560ee

UnknownScript_0x560ee: ; 0x560ee
	2writetext UnknownText_0x5615a
	keeptextopen
	verbosegiveitem TM_27, 1
	iffalse UnknownScript_0x56116
	setbit2 $005b
	loadmovesprites
	end
; 0x560fd

UnknownScript_0x560fd: ; 0x560fd
	2writetext UnknownText_0x561a6
	closetext
	loadmovesprites
	end
; 0x56103

UnknownScript_0x56103: ; 0x56103
	2writetext UnknownText_0x561d8
	keeptextopen
	verbosegiveitem TM_21, 1
	iffalse UnknownScript_0x56116
	setbit2 $005b
	loadmovesprites
	end
; 0x56112

UnknownScript_0x56112: ; 0x56112
	2writetext UnknownText_0x56202
	closetext
UnknownScript_0x56116: ; 0x56116
	loadmovesprites
	end
; 0x56118

UnknownScript_0x56118: ; 0x56118
	faceplayer
	loadfont
	special $0066
	if_not_equal $2, UnknownScript_0x5612a
	2writetext UnknownText_0x56241
	closetext
	loadmovesprites
	special $0013
	end
; 0x5612a

UnknownScript_0x5612a: ; 0x5612a
	2writetext UnknownText_0x56279
	closetext
	loadmovesprites
	end
; 0x56130

UnknownScript_0x56130: ; 0x56130
	jumptextfaceplayer UnknownText_0x562ad
; 0x56133

UnknownScript_0x56133: ; 0x56133
	faceplayer
	loadfont
	trade $0
	closetext
	loadmovesprites
	end
; 0x5613a

UnknownScript_0x5613a: ; 0x5613a
	jumptextfaceplayer UnknownText_0x562f3
; 0x5613d

MapGoldenrodDeptStore5FSignpost0Script: ; 0x5613d
	jumptext UnknownText_0x56364
; 0x56140

MapGoldenrodDeptStore5FSignpost1Script: ; 0x56140
	jumpstd $0014
; 0x56143

UnknownText_0x56143: ; 0x56143
	db $0, "Hello. Oh, your", $4f
	db "#MON…", $57
; 0x5615a

UnknownText_0x5615a: ; 0x5615a
	db $0, "It's very attached", $4f
	db "to you.", $51
	db "This move should", $4f
	db "be perfect for a", $55
	db "pair like you.", $57
; 0x561a6

UnknownText_0x561a6: ; 0x561a6
	db $0, "It's adorable!", $51
	db "You should teach", $4f
	db "it good TM moves.", $57
; 0x561d8

UnknownText_0x561d8: ; 0x561d8
	db $0, "It looks evil. How", $4f
	db "about this TM for", $55
	db "it?", $57
; 0x56202

UnknownText_0x56202: ; 0x56202
	db $0, "There are sure to", $4f
	db "be TMs that are", $51
	db "just perfect for", $4f
	db "your #MON.", $57
; 0x56241

UnknownText_0x56241: ; 0x56241
	db $0, "MYSTERY GIFT.", $51
	db "With just a", $4f
	db "little beep, you", $55
	db "get a gift.", $57
; 0x56279

UnknownText_0x56279: ; 0x56279
	db $0, "The MYSTERY GIFT", $4f
	db "option requires a", $55
	db "Game Boy Color.", $57
; 0x562ad

UnknownText_0x562ad: ; 0x562ad
	db $0, "On Sundays, a lady", $4f
	db "comes to check out", $55
	db "#MON.", $51
	db "She even gives", $4f
	db "away TMs!", $57
; 0x562f3

UnknownText_0x562f3: ; 0x562f3
	db $0, "You can't rename a", $4f
	db "#MON you get in", $55
	db "a trade.", $51
	db "The name is a re-", $4f
	db "flection of the", $51
	db "original trainer's", $4f
	db "feelings for it.", $57
; 0x56364

UnknownText_0x56364: ; 0x56364
	db $0, "Customize Your", $4f
	db "#MON", $51
	db "5F TM CORNER", $57
; 0x56386

GoldenrodDeptStore5F_MapEventHeader: ; 0x56386
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $c, 1, GROUP_GOLDENROD_DEPT_STORE_4F, MAP_GOLDENROD_DEPT_STORE_4F
	warp_def $0, $f, 1, GROUP_GOLDENROD_DEPT_STORE_6F, MAP_GOLDENROD_DEPT_STORE_6F
	warp_def $0, $2, 1, GROUP_GOLDENROD_DEPT_STORE_ELEVATOR, MAP_GOLDENROD_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapGoldenrodDeptStore5FSignpost0Script
	signpost 0, 3, $0, MapGoldenrodDeptStore5FSignpost1Script

	; people-events
	db 6
	person_event $39, 9, 12, $7, $0, 255, 255, $0, 0, UnknownScript_0x5609c, $ffff
	person_event $28, 10, 7, $2, $11, 255, 255, $0, 0, UnknownScript_0x56130, $ffff
	person_event $23, 7, 10, $3, $0, 255, 255, $0, 0, UnknownScript_0x56133, $ffff
	person_event $2d, 9, 17, $2, $22, 255, 255, $0, 0, UnknownScript_0x5613a, $ffff
	person_event $26, 5, 13, $6, $0, 255, 255, $a0, 0, UnknownScript_0x56118, $ffff
	person_event $42, 9, 11, $7, $0, 255, 255, $80, 0, UnknownScript_0x560ce, $0763
; 0x563f3

GoldenrodDeptStore6F_MapScriptHeader: ; 0x563f3
	; trigger count
	db 0

	; callback count
	db 0
; 0x563f5

MapGoldenrodDeptStore6FSignpost5Script: ; 0x563f5
	loadfont
	2writetext UnknownText_0x564cb
UnknownScript_0x563f9: ; 0x563f9
	special $0051
	loadmenudata $6478
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x5640f
	if_equal $2, UnknownScript_0x56429
	if_equal $3, UnknownScript_0x56443
	loadmovesprites
	end
; 0x5640f

UnknownScript_0x5640f: ; 0x5640f
	checkmoney $0, 200
	if_equal $2, UnknownScript_0x5646a
	giveitem FRESH_WATER, $1
	iffalse UnknownScript_0x56471
	takemoney $0, 200
	itemtotext FRESH_WATER, $0
	2jump UnknownScript_0x5645d
; 0x56429

UnknownScript_0x56429: ; 0x56429
	checkmoney $0, 300
	if_equal $2, UnknownScript_0x5646a
	giveitem SODA_POP, $1
	iffalse UnknownScript_0x56471
	takemoney $0, 300
	itemtotext SODA_POP, $0
	2jump UnknownScript_0x5645d
; 0x56443

UnknownScript_0x56443: ; 0x56443
	checkmoney $0, 350
	if_equal $2, UnknownScript_0x5646a
	giveitem LEMONADE, $1
	iffalse UnknownScript_0x56471
	takemoney $0, 350
	itemtotext LEMONADE, $0
	2jump UnknownScript_0x5645d
; 0x5645d

UnknownScript_0x5645d: ; 0x5645d
	pause 10
	playsound $001f
	2writetext UnknownText_0x564ef
	keeptextopen
	itemnotify
	2jump UnknownScript_0x563f9
; 0x5646a

UnknownScript_0x5646a: ; 0x5646a
	2writetext UnknownText_0x56512
	closetext
	2jump UnknownScript_0x563f9
; 0x56471

UnknownScript_0x56471: ; 0x56471
	2writetext UnknownText_0x5652b
	closetext
	2jump UnknownScript_0x563f9
; 0x56478

; menu data
INCBIN "baserom.gbc",$56478,$564bf - $56478

UnknownScript_0x564bf: ; 0x564bf
	jumptextfaceplayer UnknownText_0x5654b
; 0x564c2

UnknownScript_0x564c2: ; 0x564c2
	jumptextfaceplayer UnknownText_0x565ca
; 0x564c5

MapGoldenrodDeptStore6FSignpost0Script: ; 0x564c5
	jumptext UnknownText_0x5661a
; 0x564c8

MapGoldenrodDeptStore6FSignpost1Script: ; 0x564c8
	jumpstd $0014
; 0x564cb

UnknownText_0x564cb: ; 0x564cb
	db $0, "A vending machine!", $4f
	db "Here's the menu.", $57
; 0x564ef

UnknownText_0x564ef: ; 0x564ef
	db $0, "Clang! A can of", $4f
	db "@"
	text_from_ram $d099
	db $0, $55
	db "popped out!", $57
; 0x56512

UnknownText_0x56512: ; 0x56512
	db $0, "Oops, not enough", $4f
	db "money.", $57
; 0x5652b

UnknownText_0x5652b: ; 0x5652b
	db $0, "There's no more", $4f
	db "room for stuff.", $57
; 0x5654b

UnknownText_0x5654b: ; 0x5654b
	db $0, "Do you listen to", $4f
	db "LUCKY CHANNEL?", $51
	db "If you want to", $4f
	db "win, trade #MON", $51
	db "with as many peo-", $4f
	db "ple as possible to", $51
	db "get different ID", $4f
	db "numbers.", $57
; 0x565ca

UnknownText_0x565ca: ; 0x565ca
	db $0, "If you're tired,", $4f
	db "try the vending", $55
	db "machine's drinks.", $51
	db "Your #MON will", $4f
	db "love them too.", $57
; 0x5661a

UnknownText_0x5661a: ; 0x5661a
	db $0, "Take a Break from", $4f
	db "Shopping!", $51
	db "6F TRANQUIL SQUARE", $57
; 0x5664a

GoldenrodDeptStore6F_MapEventHeader: ; 0x5664a
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $f, 2, GROUP_GOLDENROD_DEPT_STORE_5F, MAP_GOLDENROD_DEPT_STORE_5F
	warp_def $0, $2, 1, GROUP_GOLDENROD_DEPT_STORE_ELEVATOR, MAP_GOLDENROD_DEPT_STORE_ELEVATOR
	warp_def $0, $d, 1, GROUP_GOLDENROD_DEPT_STORE_ROOF, MAP_GOLDENROD_DEPT_STORE_ROOF

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 0, 14, $0, MapGoldenrodDeptStore6FSignpost0Script
	signpost 0, 3, $0, MapGoldenrodDeptStore6FSignpost1Script
	signpost 1, 8, $1, MapGoldenrodDeptStore6FSignpost5Script
	signpost 1, 9, $1, MapGoldenrodDeptStore6FSignpost5Script
	signpost 1, 10, $1, MapGoldenrodDeptStore6FSignpost5Script
	signpost 1, 11, $1, MapGoldenrodDeptStore6FSignpost5Script

	; people-events
	db 2
	person_event $28, 6, 14, $5, $1, 255, 255, $a0, 0, UnknownScript_0x564bf, $ffff
	person_event $2b, 6, 12, $7, $0, 255, 255, $80, 0, UnknownScript_0x564c2, $ffff
; 0x56697

GoldenrodDeptStoreElevator_MapScriptHeader: ; 0x56697
	; trigger count
	db 0

	; callback count
	db 0
; 0x56699

MapGoldenrodDeptStoreElevatorSignpost0Script: ; 0x56699
	loadfont
	elevator $66e0
	loadmovesprites
	iffalse UnknownScript_0x566df
	pause 5
	playsound $006e
	earthquake 60
	waitbutton
	checkbit1 $0307
	iftrue UnknownScript_0x566df
	checkbit1 $0304
	iftrue UnknownScript_0x566cb
	checkbit1 $0305
	iftrue UnknownScript_0x566d5
	checkbit1 $0306
	iftrue UnknownScript_0x566c1
UnknownScript_0x566c1: ;0x566c1
	setbit1 $0304
	clearbit1 $0305
	clearbit1 $0306
	end
; 0x566cb

UnknownScript_0x566cb: ; 0x566cb
	clearbit1 $0304
	setbit1 $0305
	clearbit1 $0306
	end
; 0x566d5

UnknownScript_0x566d5: ; 0x566d5
	clearbit1 $0304
	clearbit1 $0305
	setbit1 $0306
	end
; 0x566df

UnknownScript_0x566df: ; 0x566df
	end
; 0x566e0

INCBIN "baserom.gbc",$566e0,$566fe - $566e0

GoldenrodDeptStoreElevator_MapEventHeader: ; 0x566fe
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $1, 255, GROUP_GOLDENROD_DEPT_STORE_1F, MAP_GOLDENROD_DEPT_STORE_1F
	warp_def $3, $2, 255, GROUP_GOLDENROD_DEPT_STORE_1F, MAP_GOLDENROD_DEPT_STORE_1F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 0, 3, $0, MapGoldenrodDeptStoreElevatorSignpost0Script

	; people-events
	db 0
; 0x56713

GoldenrodDeptStoreRoof_MapScriptHeader: ; 0x56713
	; trigger count
	db 0

	; callback count
	db 2

	; callbacks

	dbw 1, UnknownScript_0x5671b

	dbw 2, UnknownScript_0x5672b
; 0x5671b

UnknownScript_0x5671b: ; 0x5671b
	checkbit2 $0061
	iftrue UnknownScript_0x56722
	return
; 0x56722

UnknownScript_0x56722: ; 0x56722
	changeblock $0, $2, $3f
	changeblock $0, $4, $f
	return
; 0x5672b

UnknownScript_0x5672b: ; 0x5672b
	checkbit2 $0061
	iftrue UnknownScript_0x56738
	setbit1 $06f0
	clearbit1 $06f1
	return
; 0x56738

UnknownScript_0x56738: ; 0x56738
	clearbit1 $06f0
	setbit1 $06f1
	return
; 0x5673f

UnknownScript_0x5673f: ; 0x5673f
	loadfont
	pokemart $4, $0000
	loadmovesprites
	end
; 0x56746

UnknownScript_0x56746: ; 0x56746
	jumptextfaceplayer UnknownText_0x5677f
; 0x56749

UnknownScript_0x56749: ; 0x56749
	faceplayer
	loadfont
	2writetext UnknownText_0x567d2
	closetext
	loadmovesprites
	spriteface $4, $1
	end
; 0x56754

UnknownScript_0x56754: ; 0x56754
	jumptextfaceplayer UnknownText_0x56839
; 0x56757

UnknownScript_0x56757: ; 0x56757
	loadfont
	2writetext UnknownText_0x56867
	closetext
	loadmovesprites
	spriteface $6, $1
	loadfont
	2writetext UnknownText_0x56871
	closetext
	loadmovesprites
	spriteface $6, $3
	end
; 0x5676a

UnknownScript_0x5676a: ; 0x5676a
	jumptextfaceplayer UnknownText_0x5688e
; 0x5676d

UnknownScript_0x5676d: ; 0x5676d
	jumptextfaceplayer UnknownText_0x56901
; 0x56770

UnknownScript_0x56770: ; 0x56770
	jumptextfaceplayer UnknownText_0x56942
; 0x56773

MapGoldenrodDeptStoreRoofSignpost0Script: ; 0x56773
	jumptext UnknownText_0x569c3
; 0x56776

MapGoldenrodDeptStoreRoofSignpost1Script: ; 0x56776
	jumptext UnknownText_0x56a2b
; 0x56779

MapGoldenrodDeptStoreRoofSignpost2Script: ; 0x56779
	jumptext UnknownText_0x56aa6
; 0x5677c

MapGoldenrodDeptStoreRoofSignpost3Script: ; 0x5677c
	jumptext UnknownText_0x56b11
; 0x5677f

UnknownText_0x5677f: ; 0x5677f
	db $0, "Whew, I'm tired.", $51
	db "I sometimes come", $4f
	db "up to the rooftop", $51
	db "to take a break", $4f
	db "from shopping.", $57
; 0x567d2

UnknownText_0x567d2: ; 0x567d2
	db $0, "Pardon? Who says", $4f
	db "an adult can't get", $55
	db "into this?", $51
	db "I'm going to be", $4f
	db "back every day to", $51
	db "collect all the", $4f
	db "dolls!", $57
; 0x56839

UnknownText_0x56839: ; 0x56839
	db $0, "They have bargain", $4f
	db "sales here every", $55
	db "so often.", $57
; 0x56867

UnknownText_0x56867: ; 0x56867
	db $0, "Oh, wow!", $57
; 0x56871

UnknownText_0x56871: ; 0x56871
	db $0, "Will you quit", $4f
	db "bothering me?", $57
; 0x5688e

UnknownText_0x5688e: ; 0x5688e
	db $0, "There's something", $4f
	db "I really want, but", $51
	db "I don't have the", $4f
	db "necessary cash…", $51
	db "Maybe I'll sell", $4f
	db "off the BERRIES", $55
	db "I've collected…", $57
; 0x56901

UnknownText_0x56901: ; 0x56901
	db $0, "Oh, everything is", $4f
	db "so cheap!", $51
	db "I bought so much,", $4f
	db "my PACK's crammed!", $57
; 0x56942

UnknownText_0x56942: ; 0x56942
	db $0, "My #MON always", $4f
	db "get paralyzed or", $51
	db "poisoned when the", $4f
	db "chips are down…", $51
	db "So I came to buy", $4f
	db "some FULL HEAL.", $51
	db "I wonder if", $4f
	db "there's any left?", $57
; 0x569c3

UnknownText_0x569c3: ; 0x569c3
	db $0, "These binoculars", $4f
	db "let me see far", $51
	db "away. Maybe I can", $4f
	db "see my own house.", $51
	db "Is it the one with", $4f
	db "the green roof?", $57
; 0x56a2b

UnknownText_0x56a2b: ; 0x56a2b
	db $0, "Hey! Some trainers", $4f
	db "are battling on", $55
	db "the road!", $51
	db "A #MON fired a", $4f
	db "flurry of leaves!", $51
	db "That makes me feel", $4f
	db "like battling", $55
	db "right now!", $57
; 0x56aa6

UnknownText_0x56aa6: ; 0x56aa6
	db $0, "A FISHER caught a", $4f
	db "lot of MAGIKARP…", $51
	db "They're SPLASHing", $4f
	db "at the same time!", $51
	db "Look at the water", $4f
	db "going everywhere!", $57
; 0x56b11

UnknownText_0x56b11: ; 0x56b11
	db $0, "A vending machine", $4f
	db "for #MON dolls?", $51
	db "Insert money, then", $4f
	db "turn the crank…", $51
	db "But it's almost", $4f
	db "empty…", $57
; 0x56b6d

GoldenrodDeptStoreRoof_MapEventHeader: ; 0x56b6d
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $1, $d, 3, GROUP_GOLDENROD_DEPT_STORE_6F, MAP_GOLDENROD_DEPT_STORE_6F

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 3, 15, $3, MapGoldenrodDeptStoreRoofSignpost0Script
	signpost 5, 15, $3, MapGoldenrodDeptStoreRoofSignpost1Script
	signpost 6, 15, $3, MapGoldenrodDeptStoreRoofSignpost2Script
	signpost 0, 3, $1, MapGoldenrodDeptStoreRoofSignpost3Script

	; people-events
	db 8
	person_event $39, 8, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x5673f, $06f0
	person_event $2e, 7, 14, $5, $1, 255, 255, $80, 0, UnknownScript_0x56746, $ffff
	person_event $3a, 5, 6, $7, $0, 255, 255, $90, 0, UnknownScript_0x56749, $ffff
	person_event $26, 8, 7, $2, $11, 255, 255, $a0, 0, UnknownScript_0x56754, $06f1
	person_event $2b, 10, 18, $9, $0, 255, 255, $a0, 0, UnknownScript_0x56757, $06f1
	person_event $2d, 4, 11, $5, $1, 255, 255, $0, 0, UnknownScript_0x5676a, $06f0
	person_event $29, 7, 9, $2, $11, 255, 255, $a0, 0, UnknownScript_0x5676d, $06f0
	person_event $25, 10, 5, $7, $0, 255, 255, $80, 0, UnknownScript_0x56770, $06f0
; 0x56bf4

GoldenrodGameCorner_MapScriptHeader: ; 0x56bf4
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x56bf9
; 0x56bf9

UnknownScript_0x56bf9: ; 0x56bf9
	checkbit1 $0044
	iffalse UnknownScript_0x56c19
	checkitem COIN_CASE
	iffalse UnknownScript_0x56c0e
	checkcode $b
	if_equal WEDNESDAY, UnknownScript_0x56c11
	if_equal SATURDAY, UnknownScript_0x56c11
UnknownScript_0x56c0e: ; 0x56c0e
	appear $d
	return
; 0x56c11

UnknownScript_0x56c11: ; 0x56c11
	checkbit2 $005e
	iftrue UnknownScript_0x56c19
	disappear $d
UnknownScript_0x56c19: ;0x56c19
	return
; 0x56c1a

UnknownScript_0x56c1a: ; 0x56c1a
	faceplayer
	loadfont
	2writetext UnknownText_0x5718a
	closetext
	loadmovesprites
	spriteface $d, $3
	end
; 0x56c25

UnknownScript_0x56c25: ; 0x56c25
	jumpstd $0032
; 0x56c28

UnknownScript_0x56c28: ; 0x56c28
	faceplayer
	loadfont
	2writetext UnknownText_0x56e50
	closetext
	checkitem COIN_CASE
	iffalse UnknownScript_0x56cc3
	2writetext UnknownText_0x56e8b
UnknownScript_0x56c36: ; 056c36
	special $004f
	loadmenudata $6cc9
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x56c4d
	if_equal $2, UnknownScript_0x56c69
	if_equal $3, UnknownScript_0x56c85
	2jump UnknownScript_0x56cbd
; 0x56c4d

UnknownScript_0x56c4d: ; 0x56c4d
	checkcoins 5500
	if_equal $2, UnknownScript_0x56cb1
	itemtotext TM_25, $0
	2call UnknownScript_0x56ca1
	iffalse UnknownScript_0x56cbd
	giveitem TM_25, $1
	iffalse UnknownScript_0x56cb7
	takecoins 5500
	2jump UnknownScript_0x56ca6
; 0x56c69

UnknownScript_0x56c69: ; 0x56c69
	checkcoins 5500
	if_equal $2, UnknownScript_0x56cb1
	itemtotext TM_14, $0
	2call UnknownScript_0x56ca1
	iffalse UnknownScript_0x56cbd
	giveitem TM_14, $1
	iffalse UnknownScript_0x56cb7
	takecoins 5500
	2jump UnknownScript_0x56ca6
; 0x56c85

UnknownScript_0x56c85: ; 0x56c85
	checkcoins 5500
	if_equal $2, UnknownScript_0x56cb1
	itemtotext TM_38, $0
	2call UnknownScript_0x56ca1
	iffalse UnknownScript_0x56cbd
	giveitem TM_38, $1
	iffalse UnknownScript_0x56cb7
	takecoins 5500
	2jump UnknownScript_0x56ca6
; 0x56ca1

UnknownScript_0x56ca1: ; 0x56ca1
	2writetext UnknownText_0x56ea8
	yesorno
	end
; 0x56ca6

UnknownScript_0x56ca6: ; 0x56ca6
	waitbutton
	playsound $0022
	2writetext UnknownText_0x56ebd
	closetext
	2jump UnknownScript_0x56c36
; 0x56cb1

UnknownScript_0x56cb1: ; 0x56cb1
	2writetext UnknownText_0x56ecb
	closetext
	loadmovesprites
	end
; 0x56cb7

UnknownScript_0x56cb7: ; 0x56cb7
	2writetext UnknownText_0x56ee8
	closetext
	loadmovesprites
	end
; 0x56cbd

UnknownScript_0x56cbd: ; 0x56cbd
	2writetext UnknownText_0x56f09
	closetext
	loadmovesprites
	end
; 0x56cc3

UnknownScript_0x56cc3: ; 0x56cc3
	2writetext UnknownText_0x56f35
	closetext
	loadmovesprites
	end
; 0x56cc9

; menu data
INCBIN "baserom.gbc",$56cc9,$38

UnknownScript_0x56d01: ; 0x56d01
	faceplayer
	loadfont
	2writetext UnknownText_0x56e50
	closetext
	checkitem COIN_CASE
	iffalse UnknownScript_0x56cc3
UnknownScript_0x56d0c: ; 0x56d0c
	2writetext UnknownText_0x56e8b
	special $004f
	loadmenudata $6db0
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x56d26
	if_equal $2, UnknownScript_0x56d54
	if_equal $3, UnknownScript_0x56d82
	2jump UnknownScript_0x56cbd
; 0x56d26

UnknownScript_0x56d26: ; 0x56d26
	checkcoins 100
	if_equal $2, UnknownScript_0x56cb1
	checkcode $1
	if_equal $6, UnknownScript_0x56cb7
	pokenamemem ABRA, $0
	2call UnknownScript_0x56ca1
	iffalse UnknownScript_0x56cbd
	waitbutton
	playsound $0022
	2writetext UnknownText_0x56ebd
	closetext
	writebyte ABRA
	special $0039
	givepoke ABRA, 5, 0, 0
	takecoins 100
	2jump UnknownScript_0x56d0c
; 0x56d54

UnknownScript_0x56d54: ; 0x56d54
	checkcoins 800
	if_equal $2, UnknownScript_0x56cb1
	checkcode $1
	if_equal $6, UnknownScript_0x56cb7
	pokenamemem CUBONE, $0
	2call UnknownScript_0x56ca1
	iffalse UnknownScript_0x56cbd
	waitbutton
	playsound $0022
	2writetext UnknownText_0x56ebd
	closetext
	writebyte CUBONE
	special $0039
	givepoke CUBONE, 15, 0, 0
	takecoins 800
	2jump UnknownScript_0x56d0c
; 0x56d82

UnknownScript_0x56d82: ; 0x56d82
	checkcoins 1500
	if_equal $2, UnknownScript_0x56cb1
	checkcode $1
	if_equal $6, UnknownScript_0x56cb7
	pokenamemem WOBBUFFET, $0
	2call UnknownScript_0x56ca1
	iffalse UnknownScript_0x56cbd
	waitbutton
	playsound $0022
	2writetext UnknownText_0x56ebd
	closetext
	writebyte WOBBUFFET
	special $0039
	givepoke WOBBUFFET, 15, 0, 0
	takecoins 1500
	2jump UnknownScript_0x56d0c
; 0x56db0

; menu data
INCBIN "baserom.gbc",$56db0,$56df1 - $56db0

UnknownScript_0x56df1: ; 0x56df1
	faceplayer
	loadfont
	2writetext UnknownText_0x56f55
	closetext
	loadmovesprites
	spriteface $fe, $2
	end
; 0x56dfc

UnknownScript_0x56dfc: ; 0x56dfc
	faceplayer
	loadfont
	2writetext UnknownText_0x56f9e
	closetext
	loadmovesprites
	spriteface $7, $3
	end
; 0x56e07

UnknownScript_0x56e07: ; 0x56e07
	faceplayer
	loadfont
	2writetext UnknownText_0x56ff4
	closetext
	loadmovesprites
	spriteface $8, $2
	end
; 0x56e12

UnknownScript_0x56e12: ; 0x56e12
	faceplayer
	loadfont
	2writetext UnknownText_0x5702b
	closetext
	loadmovesprites
	spriteface $9, $3
	end
; 0x56e1d

UnknownScript_0x56e1d: ; 0x56e1d
	jumptextfaceplayer UnknownText_0x57097
; 0x56e20

UnknownScript_0x56e20: ; 0x56e20
	faceplayer
	loadfont
	2writetext UnknownText_0x570b1
	closetext
	loadmovesprites
	spriteface $b, $3
	end
; 0x56e2b

UnknownScript_0x56e2b: ; 0x56e2b
	jumptextfaceplayer UnknownText_0x5710d
; 0x56e2e

MapGoldenrodGameCornerSignpost30Script: ; 0x56e2e
	jumptext UnknownText_0x571af
; 0x56e31

MapGoldenrodGameCornerSignpost17Script: ; 0x56e31
	random $6
	if_equal $0, MapGoldenrodGameCornerSignpost7Script
	refreshscreen $0
	writebyte $0
	special $002a
	loadmovesprites
	end
; 0x56e40

MapGoldenrodGameCornerSignpost7Script: ; 0x56e40
	refreshscreen $0
	writebyte $1
	special $002a
	loadmovesprites
	end
; 0x56e49

MapGoldenrodGameCornerSignpost29Script: ; 0x56e49
	refreshscreen $0
	special $002b
	loadmovesprites
	end
; 0x56e50

UnknownText_0x56e50: ; 0x56e50
	db $0, "Welcome!", $51
	db "We exchange your", $4f
	db "game coins for", $55
	db "fabulous prizes!", $57
; 0x56e8b

UnknownText_0x56e8b: ; 0x56e8b
	db $0, "Which prize would", $4f
	db "you like?", $57
; 0x56ea8

UnknownText_0x56ea8: ; 0x56ea8
	text_from_ram $d099
	db $0, ".", $4f
	db "Is that right?", $57
; 0x56ebd

UnknownText_0x56ebd: ; 0x56ebd
	db $0, "Here you go!", $57
; 0x56ecb

UnknownText_0x56ecb: ; 0x56ecb
	db $0, "Sorry! You need", $4f
	db "more coins.", $57
; 0x56ee8

UnknownText_0x56ee8: ; 0x56ee8
	db $0, "Sorry. You can't", $4f
	db "carry any more.", $57
; 0x56f09

UnknownText_0x56f09: ; 0x56f09
	db $0, "OK. Please save", $4f
	db "your coins and", $55
	db "come again!", $57
; 0x56f35

UnknownText_0x56f35: ; 0x56f35
	db $0, "Oh? You don't have", $4f
	db "a COIN CASE.", $57
; 0x56f55

UnknownText_0x56f55: ; 0x56f55
	db $0, "I always play this", $4f
	db "slot machine. It", $51
	db "pays out more than", $4f
	db "others, I think.", $57
; 0x56f9e

UnknownText_0x56f9e: ; 0x56f9e
	db $0, "I just love this", $4f
	db "new slot machine.", $51
	db "It's more of a", $4f
	db "challenge than the", $55
	db "ones in CELADON.", $57
; 0x56ff4

UnknownText_0x56ff4: ; 0x56ff4
	db $0, "Life is a gamble.", $4f
	db "I'm going to flip", $55
	db "cards till I drop!", $57
; 0x5702b

UnknownText_0x5702b: ; 0x5702b
	db $0, "Card flip…", $51
	db "I prefer it over", $4f
	db "the slots because", $51
	db "it's easier to", $4f
	db "figure the odds.", $51
	db "But the payout is", $4f
	db "much lower.", $57
; 0x57097

UnknownText_0x57097: ; 0x57097
	db $0, "I won't quit until", $4f
	db "I win!", $57
; 0x570b1

UnknownText_0x570b1: ; 0x570b1
	db $0, "I taught BLIZZARD", $4f
	db "to my #MON.", $51
	db "It was hard to get", $4f
	db "enough coins for", $51
	db "it, but it was", $4f
	db "worth it.", $57
; 0x5710d

UnknownText_0x5710d: ; 0x5710d
	db $0, "I couldn't win at", $4f
	db "the slots, and I", $51
	db "blew it on card", $4f
	db "flipping…", $51
	db "I got so furious,", $4f
	db "I tossed out my", $51
	db "COIN CASE in the", $4f
	db "UNDERGROUND.", $57
; 0x5718a

UnknownText_0x5718a: ; 0x5718a
	db $0, "Wahahah! The coins", $4f
	db "keep rolling in!", $57
; 0x571af

UnknownText_0x571af: ; 0x571af
	db $0, "Someone left their", $4f
	db "drink.", $51
	db "It smells sweet.", $57
; 0x571db

GoldenrodGameCorner_MapEventHeader: ; 0x571db
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $d, $2, 10, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $d, $3, 10, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 0

	; signposts
	db 31
	signpost 6, 6, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 7, 6, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 8, 6, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 9, 6, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 10, 6, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 11, 6, $3, MapGoldenrodGameCornerSignpost17Script
	signpost 6, 7, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 7, 7, $0, MapGoldenrodGameCornerSignpost7Script
	signpost 8, 7, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 9, 7, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 10, 7, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 11, 7, $4, MapGoldenrodGameCornerSignpost17Script
	signpost 6, 12, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 7, 12, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 8, 12, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 9, 12, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 10, 12, $0, MapGoldenrodGameCornerSignpost17Script
	signpost 11, 12, $3, MapGoldenrodGameCornerSignpost17Script
	signpost 6, 13, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 7, 13, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 8, 13, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 9, 13, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 10, 13, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 11, 13, $4, MapGoldenrodGameCornerSignpost29Script
	signpost 6, 18, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 7, 18, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 8, 18, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 9, 18, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 10, 18, $0, MapGoldenrodGameCornerSignpost29Script
	signpost 11, 18, $3, MapGoldenrodGameCornerSignpost29Script
	signpost 1, 12, $4, MapGoldenrodGameCornerSignpost30Script

	; people-events
	db 12
	person_event $39, 6, 7, $6, $0, 255, 255, $80, 0, UnknownScript_0x56c25, $ffff
	person_event $42, 6, 20, $6, $0, 255, 255, $80, 0, UnknownScript_0x56c28, $ffff
	person_event $42, 6, 22, $6, $0, 255, 255, $80, 0, UnknownScript_0x56d01, $ffff
	person_event $4b, 11, 12, $8, $0, 255, 2, $90, 0, UnknownScript_0x56df1, $ffff
	person_event $4b, 11, 12, $8, $0, 255, 4, $90, 0, UnknownScript_0x56df1, $ffff
	person_event $2d, 14, 15, $9, $0, 255, 255, $b0, 0, UnknownScript_0x56dfc, $ffff
	person_event $23, 12, 18, $8, $0, 255, 255, $90, 0, UnknownScript_0x56e07, $ffff
	person_event $2e, 10, 21, $9, $0, 255, 255, $80, 0, UnknownScript_0x56e12, $ffff
	person_event $24, 7, 14, $2, $12, 255, 255, $a0, 0, UnknownScript_0x56e1d, $ffff
	person_event $40, 14, 9, $9, $0, 255, 255, $90, 0, UnknownScript_0x56e20, $ffff
	person_event $2d, 13, 6, $2, $11, 255, 255, $b0, 0, UnknownScript_0x56e2b, $ffff
	person_event $2d, 14, 21, $9, $0, 255, 255, $80, 0, UnknownScript_0x56c1a, $076b
; 0x57322

SECTION "bank16",DATA,BANK[$16]

RuinsofAlphOutside_MapScriptHeader: ; 0x58000
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x5800d, $0000
	dw UnknownScript_0x5800e, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x5800f
; 0x5800d

UnknownScript_0x5800d: ; 0x5800d
	end
; 0x5800e

UnknownScript_0x5800e: ; 0x5800e
	end
; 0x5800f

UnknownScript_0x5800f: ; 0x5800f
	checkbit2 $000c
	iftrue UnknownScript_0x5802c
	checkbit1 $002e
	iftrue UnknownScript_0x5801e
	2jump UnknownScript_0x5802c
; 0x5801e

UnknownScript_0x5801e: ; 0x5801e
	checkcode $e
	if_less_than $2, UnknownScript_0x58027
	2jump UnknownScript_0x5802c
; 0x58027

UnknownScript_0x58027: ; 0x58027
	appear $3
	dotrigger $1
	return
; 0x5802c

UnknownScript_0x5802c: ; 0x5802c
	disappear $3
	dotrigger $0
	return
; 0x58031

UnknownScript_0x58031: ; 0x58031
	spriteface $3, $1
	spriteface $0, $0
	2jump UnknownScript_0x58044
; 0x5803a

UnknownScript_0x5803a: ; 0x5803a
	spriteface $3, $2
	spriteface $0, $3
	2jump UnknownScript_0x58044
; 0x58043

UnknownScript_0x58043: ; 0x58043
	faceplayer
UnknownScript_0x58044: ; 0x58044
	loadfont
	2writetext UnknownText_0x580c7
	closetext
	loadmovesprites
	playmusic $0011
	follow $3, $0
	applymovement $3, MovementData_0x580ba
	disappear $3
	stopfollow
	applymovement $0, MovementData_0x580c5
	domaptrigger GROUP_RUINS_OF_ALPH_RESEARCH_CENTER, MAP_RUINS_OF_ALPH_RESEARCH_CENTER, $1
	warpcheck
	end
; 0x58061

UnknownScript_0x58061: ; 0x58061
	faceplayer
	loadfont
	checkbit1 $00bc
	iftrue UnknownScript_0x58070
	setbit1 $00bc
	2writetext UnknownText_0x583a4
	keeptextopen
UnknownScript_0x58070: ;0x58070
	2writetext UnknownText_0x58420
	closetext
	loadmovesprites
	end
; 0x58076

UnknownScript_0x58076: ; 0x58076
	faceplayer
	loadfont
	2writetext UnknownText_0x58449
	closetext
	loadmovesprites
	end
; 0x5807e

UnknownScript_0x5807e: ; 0x5807e
	faceplayer
	loadfont
	2writetext UnknownText_0x5848e
	closetext
	loadmovesprites
	spriteface $6, $1
	end
; 0x58089

TrainerPsychicNathan: ; 0x58089
	; bit/flag number
	dw $43a

	; trainer group && trainer id
	db PSYCHIC_T, NATHAN

	; text when seen
	dw PsychicNathanSeenText

	; text when trainer beaten
	dw PsychicNathanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicNathanScript
; 0x58095

PsychicNathanScript: ; 0x58095
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5830e
	closetext
	loadmovesprites
	end
; 0x5809d

UnknownScript_0x5809d: ; 0x5809d
	musicfadeout $2905, $1
; 0x580a2

; probably not a script?
UnknownScript_0x580a2: ; 0x580a2
	db $e5
	itemtotext THUNDERSTONE, $42
	2call $a900
	pokenamemem EXEGGCUTE, $47
	2writetext UnknownText_0x58250
	closetext
	loadmovesprites
	end
; 0x580b1

MapRuinsofAlphOutsideSignpost0Script: ; 0x580b1
	jumptext UnknownText_0x58325
; 0x580b4

MapRuinsofAlphOutsideSignpost1Script: ; 0x580b4
	jumptext UnknownText_0x58342
; 0x580b7

MapRuinsofAlphOutsideSignpost2Script: ; 0x580b7
	jumptext UnknownText_0x58362
; 0x580ba

MovementData_0x580ba: ; 0x580ba
	step_right
	step_right
	step_right
	step_right
	step_up
	step_up
	step_right
	step_right
	step_up
	step_up
	step_end
; 0x580c5

MovementData_0x580c5: ; 0x580c5
	step_up
	step_end
; 0x580c7

UnknownText_0x580c7: ; 0x580c7
	db $0, "Hm? That's a #-", $4f
	db "DEX, isn't it?", $55
	db "May I see it?", $51
	db "There are so many", $4f
	db "kinds of #MON.", $51
	db "Hm? What's this?", $51
	db "What is this", $4f
	db "#MON?", $51
	db "It looks like the", $4f
	db "strange writing on", $51
	db "the walls of the", $4f
	db "RUINS.", $51
	db "If those drawings", $4f
	db "are really #-", $55
	db "MON, there should", $55
	db "be many more.", $51
	db "I know! Let me up-", $4f
	db "grade your #-", $55
	db "DEX. Follow me.", $57
; 0x581e5

UnknownText_0x581e5: ; 0x581e5
	db $0, "What do you want?", $4f
	db "I'm studying--", $55
	db "don't disturb me!", $57
; 0x58217

UnknownText_0x58217: ; 0x58217
	db $0, "Sorry…", $4f
	db "I'm frustrated by", $51
	db "our lack of real", $4f
	db "understanding…", $57
; 0x58250

UnknownText_0x58250: ; 0x58250
	db $0, "The RUINS are from", $4f
	db "about 1500 years", $55
	db "ago.", $51
	db "Nobody knows who", $4f
	db "built them.", $51
	db "It's also not", $4f
	db "known if the #-", $55
	db "MON statues have", $55
	db "any meaning.", $51
	db "It's all one big", $4f
	db "mystery…", $57
; 0x582eb

PsychicNathanSeenText: ; 0x582eb
	db $0, "Hmmm… This is a", $4f
	db "strange place.", $57
; 0x5830b

PsychicNathanBeatenText: ; 0x5830b
	db $0, "…", $57
; 0x5830e

UnknownText_0x5830e: ; 0x5830e
	db $0, "I like thinking", $4f
	db "here.", $57
; 0x58325

UnknownText_0x58325: ; 0x58325
	db $0, "MYSTERY STONE", $4f
	db "PANEL CHAMBER", $57
; 0x58342

UnknownText_0x58342: ; 0x58342
	db $0, "RUINS OF ALPH", $4f
	db "VISITORS WELCOME", $57
; 0x58362

UnknownText_0x58362: ; 0x58362
	db $0, "RUINS OF ALPH", $4f
	db "RESEARCH CENTER", $51
	db "THE AUTHORITY ON", $4f
	db "THE RUINS OF ALPH", $57
; 0x583a4

UnknownText_0x583a4: ; 0x583a4
	db $0, "While exploring", $4f
	db "the RUINS, we", $51
	db "suddenly noticed", $4f
	db "an odd presence.", $51
	db "We all got scared", $4f
	db "and ran away.", $51
	db "You should be", $4f
	db "careful too.", $57
; 0x58420

UnknownText_0x58420: ; 0x58420
	db $0, "The RUINS hide a", $4f
	db "huge secret!", $51
	db "…I think…", $57
; 0x58449

UnknownText_0x58449: ; 0x58449
	db $0, "There are many", $4f
	db "kinds of UNOWN, so", $51
	db "we use them for", $4f
	db "our secret codes.", $57
; 0x5848e

UnknownText_0x5848e: ; 0x5848e
	db $0, "A… H… E… A… D…", $4f
	db "Hmm…", $51
	db "What?", $51
	db "I'm decoding this", $4f
	db "message!", $57
; 0x584c3

RuinsofAlphOutside_MapEventHeader: ; 0x584c3
	; filler
	db 0, 0

	; warps
	db 11
	warp_def $11, $2, 1, GROUP_RUINS_OF_ALPH_HO_OH_CHAMBER, MAP_RUINS_OF_ALPH_HO_OH_CHAMBER
	warp_def $7, $e, 1, GROUP_RUINS_OF_ALPH_KABUTO_CHAMBER, MAP_RUINS_OF_ALPH_KABUTO_CHAMBER
	warp_def $1d, $2, 1, GROUP_RUINS_OF_ALPH_OMANYTE_CHAMBER, MAP_RUINS_OF_ALPH_OMANYTE_CHAMBER
	warp_def $21, $10, 1, GROUP_RUINS_OF_ALPH_AERODACTYL_CHAMBER, MAP_RUINS_OF_ALPH_AERODACTYL_CHAMBER
	warp_def $d, $a, 1, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	warp_def $b, $11, 1, GROUP_RUINS_OF_ALPH_RESEARCH_CENTER, MAP_RUINS_OF_ALPH_RESEARCH_CENTER
	warp_def $13, $6, 1, GROUP_UNION_CAVE_B1F, MAP_UNION_CAVE_B1F
	warp_def $1b, $6, 2, GROUP_UNION_CAVE_B1F, MAP_UNION_CAVE_B1F
	warp_def $5, $7, 3, GROUP_ROUTE_36_RUINS_OF_ALPH_GATE, MAP_ROUTE_36_RUINS_OF_ALPH_GATE
	warp_def $14, $d, 1, GROUP_ROUTE_32_RUINS_OF_ALPH_GATE, MAP_ROUTE_32_RUINS_OF_ALPH_GATE
	warp_def $15, $d, 2, GROUP_ROUTE_32_RUINS_OF_ALPH_GATE, MAP_ROUTE_32_RUINS_OF_ALPH_GATE

	; xy triggers
	db 2
	xy_trigger 1, $e, $b, $0, UnknownScript_0x58031, $0, $0
	xy_trigger 1, $f, $a, $0, UnknownScript_0x5803a, $0, $0

	; signposts
	db 3
	signpost 8, 16, $0, MapRuinsofAlphOutsideSignpost0Script
	signpost 16, 12, $0, MapRuinsofAlphOutsideSignpost1Script
	signpost 12, 18, $0, MapRuinsofAlphOutsideSignpost2Script

	; people-events
	db 5
	person_event $27, 24, 8, $6, $0, 255, 255, $2, 1, TrainerPsychicNathan, $ffff
	person_event $3c, 19, 15, $7, $0, 255, 255, $0, 0, UnknownScript_0x58043, $0703
	person_event $3a, 21, 17, $3, $0, 255, 255, $a0, 0, UnknownScript_0x58061, $078e
	person_event $27, 15, 18, $2, $11, 255, 255, $b0, 0, UnknownScript_0x58076, $078f
	person_event $27, 12, 16, $7, $0, 255, 255, $80, 0, UnknownScript_0x5807e, $078f
; 0x58560

RuinsofAlphHoOhChamber_MapScriptHeader: ; 0x58560
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x5856d, $0000
	dw UnknownScript_0x5857b, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x5857c
; 0x5856d

UnknownScript_0x5856d: ; 0x5856d
	special $008d
	checkbit1 $0326
	iftrue UnknownScript_0x58577
	end
; 0x58577

UnknownScript_0x58577: ; 0x58577
	priorityjump UnknownScript_0x58596
	end
; 0x5857b

UnknownScript_0x5857b: ; 0x5857b
	end
; 0x5857c

UnknownScript_0x5857c: ; 0x5857c
	checkbit1 $0326
	iftrue UnknownScript_0x58586
	changeblock $4, $0, $2e
UnknownScript_0x58586: ; 0x58586
	checkbit1 $02a0
	iffalse UnknownScript_0x5858d
	return
; 0x5858d

UnknownScript_0x5858d: ; 0x5858d
	changeblock $2, $2, $1
	changeblock $4, $2, $2
	return
; 0x58596

UnknownScript_0x58596: ; 0x58596
	pause 30
	earthquake 30
	showemote $0, $0, 20
	pause 30
	playsound $001b
	changeblock $4, $0, $30
	reloadmappart
	earthquake 50
	dotrigger $1
	loadmovesprites
	end
; 0x585ae

MapRuinsofAlphHoOhChamberSignpost2Script: ; 0x585ae
	refreshscreen $0
	writebyte $3
	special $0029
	loadmovesprites
	iftrue UnknownScript_0x585ba
	end
; 0x585ba

UnknownScript_0x585ba: ; 0x585ba
	setbit1 $0705
	setbit1 $02a0
	setbit2 $002e
	domaptrigger GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER, $1
	earthquake 30
	showemote $0, $0, 15
	changeblock $2, $2, $18
	changeblock $4, $2, $19
	reloadmappart
	playsound $001b
	earthquake 80
	applymovement $0, MovementData_0x58610
	playsound $002f
	waitbutton
	pause 20
	warpcheck
	end
; 0x585e7

MapRuinsofAlphHoOhChamberSignpost1Script: ; 0x585e7
	jumptext UnknownText_0x58685
; 0x585ea

MapRuinsofAlphHoOhChamberSignpost3Script: ; 0x585ea
	jumptext UnknownText_0x586aa
; 0x585ed

MapRuinsofAlphHoOhChamberSignpost4Script: ; 0x585ed
	loadfont
	2writetext UnknownText_0x58612
	writebyte $3
	special $0087
	loadmovesprites
	end
; 0x585f8

MapRuinsofAlphHoOhChamberSignpost5Script: ; 0x585f8
	checkbit1 $0326
	iftrue UnknownScript_0x58609
	loadfont
	2writetext UnknownText_0x58644
	writebyte $3
	special $0087
	loadmovesprites
	end
; 0x58609

UnknownScript_0x58609: ; 0x58609
	loadfont
	2writetext UnknownText_0x58665
	closetext
	loadmovesprites
	end
; 0x58610

MovementData_0x58610: ; 0x58610
	db $59 ; movement
	step_end
; 0x58612

UnknownText_0x58612: ; 0x58612
	db $0, "Patterns appeared", $4f
	db "on the walls…", $57
; 0x58633

; possibly unused
UnknownText_0x58633: ; 0x58633
	db $0, "It's UNOWN text!", $57
; 0x58644

UnknownText_0x58644: ; 0x58644
	db $0, "Patterns appeared", $4f
	db "on the walls…", $57
; 0x58665

UnknownText_0x58665: ; 0x58665
	db $0, "There's a big hole", $4f
	db "in the wall!", $57
; 0x58685

UnknownText_0x58685: ; 0x58685
	db $0, "It's a replica of", $4f
	db "an ancient #-", $55
	db "MON.", $57
; 0x586aa

UnknownText_0x586aa: ; 0x586aa
	db $0, "A #MON that", $4f
	db "flew gracefully on", $51
	db "rainbow-colored", $4f
	db "wings.", $57
; 0x586e1

RuinsofAlphHoOhChamber_MapEventHeader: ; 0x586e1
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $9, $3, 1, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $9, $4, 1, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $3, $3, 2, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	warp_def $3, $4, 3, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	warp_def $0, $4, 1, GROUP_RUINS_OF_ALPH_HO_OH_ITEM_ROOM, MAP_RUINS_OF_ALPH_HO_OH_ITEM_ROOM

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 3, 2, $0, MapRuinsofAlphHoOhChamberSignpost1Script
	signpost 3, 5, $0, MapRuinsofAlphHoOhChamberSignpost1Script
	signpost 2, 3, $1, MapRuinsofAlphHoOhChamberSignpost2Script
	signpost 2, 4, $1, MapRuinsofAlphHoOhChamberSignpost3Script
	signpost 0, 3, $1, MapRuinsofAlphHoOhChamberSignpost4Script
	signpost 0, 4, $1, MapRuinsofAlphHoOhChamberSignpost5Script

	; people-events
	db 0
; 0x5871e

RuinsofAlphKabutoChamber_MapScriptHeader: ; 0x5871e
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x5872b, $0000
	dw UnknownScript_0x58736, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x58737
; 0x5872b

UnknownScript_0x5872b: ; 0x5872b
	checkbit1 $0327
	iftrue UnknownScript_0x58732
	end
; 0x58732

UnknownScript_0x58732: ; 0x58732
	priorityjump UnknownScript_0x58751
; 0x58735

UnknownScript_0x58735: ; 0x58735
	end
; 0x58736

UnknownScript_0x58736: ; 0x58736
	end
; 0x58737

UnknownScript_0x58737: ; 0x58737
	checkbit1 $0327
	iftrue UnknownScript_0x58741
	changeblock $4, $0, $2e
UnknownScript_0x58741: ; 0x58741
	checkbit1 $02a1
	iffalse UnknownScript_0x58748
	return
; 0x58748

UnknownScript_0x58748: ; 0x58748
	changeblock $2, $2, $1
	changeblock $4, $2, $2
	return
; 0x58751

UnknownScript_0x58751: ; 0x58751
	pause 30
	earthquake 30
	showemote $0, $0, 20
	pause 30
	playsound $001b
	changeblock $4, $0, $30
	reloadmappart
	earthquake 50
	dotrigger $1
	loadmovesprites
	end
; 0x58769

UnknownScript_0x58769: ; 0x58769
	jumptextfaceplayer UnknownText_0x58800
; 0x5876c

MapRuinsofAlphKabutoChamberSignpost2Script: ; 0x5876c
	refreshscreen $0
	writebyte $0
	special $0029
	loadmovesprites
	iftrue UnknownScript_0x58778
	end
; 0x58778

UnknownScript_0x58778: ; 0x58778
	setbit1 $0705
	setbit1 $02a1
	setbit2 $002b
	setbit1 $074e
	domaptrigger GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER, $1
	earthquake 30
	showemote $0, $0, 15
	changeblock $2, $2, $18
	changeblock $4, $2, $19
	reloadmappart
	playsound $001b
	earthquake 80
	applymovement $0, MovementData_0x587fe
	playsound $002f
	waitbutton
	pause 20
	warpcheck
	end
; 0x587a8

UnknownScript_0x587a8: ; 0x587a8
	faceplayer
	loadfont
	checkcode $e
	if_equal 26, UnknownScript_0x587cf
	checkbit1 $0327
	iftrue UnknownScript_0x587c9
	checkbit1 $02a1
	iffalse UnknownScript_0x587c0
	2writetext UnknownText_0x589b8
	keeptextopen
UnknownScript_0x587c0: ; 0x587c0
	2writetext UnknownText_0x588f5
	closetext
	loadmovesprites
	spriteface $3, $1
	end
; 0x587c9

UnknownScript_0x587c9: ; 0x587c9
	2writetext UnknownText_0x5897c
	closetext
	loadmovesprites
	end
; 0x587cf

UnknownScript_0x587cf: ; 0x587cf
	2writetext UnknownText_0x594cb
	closetext
	loadmovesprites
	end
; 0x587d5

MapRuinsofAlphKabutoChamberSignpost1Script: ; 0x587d5
	jumptext UnknownText_0x58b1a
; 0x587d8

MapRuinsofAlphKabutoChamberSignpost3Script: ; 0x587d8
	jumptext UnknownText_0x58b3f
; 0x587db

MapRuinsofAlphKabutoChamberSignpost4Script: ; 0x587db
	loadfont
	2writetext UnknownText_0x58aa7
	writebyte $0
	special $0087
	loadmovesprites
	end
; 0x587e6

MapRuinsofAlphKabutoChamberSignpost5Script: ; 0x587e6
	checkbit1 $0327
	iftrue UnknownScript_0x587f7
	loadfont
	2writetext UnknownText_0x58ad9
	writebyte $0
	special $0087
	loadmovesprites
	end
; 0x587f7

UnknownScript_0x587f7: ; 0x587f7
	loadfont
	2writetext UnknownText_0x58afa
	closetext
	loadmovesprites
	end
; 0x587fe

MovementData_0x587fe: ; 0x587fe
	db $59 ; movement
	step_end
; 0x58800

UnknownText_0x58800: ; 0x58800
	db $0, "Welcome to this", $4f
	db "chamber.", $51
	db "There are sliding", $4f
	db "panels that depict", $51
	db "a #MON drawn by", $4f
	db "the ancients.", $51
	db "Slide the panels", $4f
	db "around to form the", $55
	db "picture.", $51
	db "To the right is a", $4f
	db "description of the", $55
	db "#MON.", $51
	db "Scientists in the", $4f
	db "back are examining", $51
	db "some newly found", $4f
	db "patterns.", $57
; 0x588f5

UnknownText_0x588f5: ; 0x588f5
	db $0, "Recently, strange,", $4f
	db "cryptic patterns", $55
	db "have appeared.", $51
	db "It's odd. They", $4f
	db "weren't here a", $55
	db "little while ago…", $51
	db "You should take a", $4f
	db "look at the walls.", $57
; 0x5897c

UnknownText_0x5897c: ; 0x5897c
	db $0, "Ah! Here's another", $4f
	db "huge hole!", $51
	db "It's big enough to", $4f
	db "go through!", $57
; 0x589b8

UnknownText_0x589b8: ; 0x589b8
	db $0, "That tremor was", $4f
	db "pretty scary!", $51
	db "But I'm more", $4f
	db "concerned about", $55
	db "this wall here…", $57
; 0x58a03

; possibly unused
UnknownText_0x58a03: ; 0x58a03
	db $0, "The patterns on", $4f
	db "the wall appear to", $55
	db "be words!", $51
	db "And those sliding", $4f
	db "stone panels seem", $51
	db "to be signals of", $4f
	db "some kind.", $51
	db "I think they make", $4f
	db "#MON appear,", $51
	db "but it's not clear", $4f
	db "yet…", $57
; 0x58aa7

UnknownText_0x58aa7: ; 0x58aa7
	db $0, "Patterns appeared", $4f
	db "on the walls…", $57
; 0x58ac8

; possibly unused
UnknownText_0x58ac8: ; 0x58ac8
	db $0, "It's UNOWN text!", $57
; 0x58ad9

UnknownText_0x58ad9: ; 0x58ad9
	db $0, "Patterns appeared", $4f
	db "on the walls…", $57
; 0x58afa

UnknownText_0x58afa: ; 0x58afa
	db $0, "There's a big hole", $4f
	db "in the wall!", $57
; 0x58b1a

UnknownText_0x58b1a: ; 0x58b1a
	db $0, "It's a replica of", $4f
	db "an ancient #-", $55
	db "MON.", $57
; 0x58b3f

UnknownText_0x58b3f: ; 0x58b3f
	db $0, "A #MON that hid", $4f
	db "on the sea floor.", $51
	db "Eyes on its back", $4f
	db "scanned the area.", $57
; 0x58b85

RuinsofAlphKabutoChamber_MapEventHeader: ; 0x58b85
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $9, $3, 2, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $9, $4, 2, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $3, $3, 4, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	warp_def $3, $4, 5, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	warp_def $0, $4, 1, GROUP_RUINS_OF_ALPH_KABUTO_ITEM_ROOM, MAP_RUINS_OF_ALPH_KABUTO_ITEM_ROOM

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 3, 2, $0, MapRuinsofAlphKabutoChamberSignpost1Script
	signpost 3, 5, $0, MapRuinsofAlphKabutoChamberSignpost1Script
	signpost 2, 3, $1, MapRuinsofAlphKabutoChamberSignpost2Script
	signpost 2, 4, $1, MapRuinsofAlphKabutoChamberSignpost3Script
	signpost 0, 3, $1, MapRuinsofAlphKabutoChamberSignpost4Script
	signpost 0, 4, $1, MapRuinsofAlphKabutoChamberSignpost5Script

	; people-events
	db 2
	person_event $42, 9, 9, $6, $0, 255, 255, $0, 0, UnknownScript_0x58769, $074e
	person_event $3c, 5, 7, $7, $0, 255, 255, $90, 0, UnknownScript_0x587a8, $ffff
; 0x58bdc

RuinsofAlphOmanyteChamber_MapScriptHeader: ; 0x58bdc
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x58be9, $0000
	dw UnknownScript_0x58bf7, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x58bf8
; 0x58be9

UnknownScript_0x58be9: ; 0x58be9
	special $0084
	checkbit1 $0328
	iftrue UnknownScript_0x58bf3
	end
; 0x58bf3

UnknownScript_0x58bf3: ; 0x58bf3
	priorityjump UnknownScript_0x58c12
	end
; 0x58bf7

UnknownScript_0x58bf7: ; 0x58bf7
	end
; 0x58bf8

UnknownScript_0x58bf8: ; 0x58bf8
	checkbit1 $0328
	iftrue UnknownScript_0x58c02
	changeblock $4, $0, $2e
UnknownScript_0x58c02: ; 0x58c02
	checkbit1 $02a2
	iffalse UnknownScript_0x58c09
	return
; 0x58c09

UnknownScript_0x58c09: ; 0x58c09
	changeblock $2, $2, $1
	changeblock $4, $2, $2
	return
; 0x58c12

UnknownScript_0x58c12: ; 0x58c12
	pause 30
	earthquake 30
	showemote $0, $0, 20
	pause 30
	playsound $001b
	changeblock $4, $0, $30
	reloadmappart
	earthquake 50
	dotrigger $1
	loadmovesprites
	end
; 0x58c2a

MapRuinsofAlphOmanyteChamberSignpost2Script: ; 0x58c2a
	refreshscreen $0
	writebyte $1
	special $0029
	loadmovesprites
	iftrue UnknownScript_0x58c36
	end
; 0x58c36

UnknownScript_0x58c36: ; 0x58c36
	setbit1 $0705
	setbit1 $02a2
	setbit2 $002c
	domaptrigger GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER, $1
	earthquake 30
	showemote $0, $0, 15
	changeblock $2, $2, $18
	changeblock $4, $2, $19
	reloadmappart
	playsound $001b
	earthquake 80
	applymovement $0, MovementData_0x58c8c
	playsound $002f
	waitbutton
	pause 20
	warpcheck
	end
; 0x58c63

MapRuinsofAlphOmanyteChamberSignpost1Script: ; 0x58c63
	jumptext UnknownText_0x58d01
; 0x58c66

MapRuinsofAlphOmanyteChamberSignpost3Script: ; 0x58c66
	jumptext UnknownText_0x58d26
; 0x58c69

MapRuinsofAlphOmanyteChamberSignpost4Script: ; 0x58c69
	loadfont
	2writetext UnknownText_0x58c8e
	writebyte $2
	special $0087
	loadmovesprites
	end
; 0x58c74

MapRuinsofAlphOmanyteChamberSignpost5Script: ; 0x58c74
	checkbit1 $0328
	iftrue UnknownScript_0x58c85
	loadfont
	2writetext UnknownText_0x58cc0
	writebyte $2
	special $0087
	loadmovesprites
	end
; 0x58c85

UnknownScript_0x58c85: ; 0x58c85
	loadfont
	2writetext UnknownText_0x58ce1
	closetext
	loadmovesprites
	end
; 0x58c8c

MovementData_0x58c8c: ; 0x58c8c
	db $59 ; movement
	step_end
; 0x58c8e

UnknownText_0x58c8e: ; 0x58c8e
	db $0, "Patterns appeared", $4f
	db "on the walls…", $57
; 0x58caf

; possibly unused.. this again?
UnknownText_0x58caf: ; 0x58caf
	db $0, "It's UNOWN text!", $57
; 0x58cc0

UnknownText_0x58cc0: ; 0x58cc0
	db $0, "Patterns appeared", $4f
	db "on the walls…", $57
; 0x58ce1

UnknownText_0x58ce1: ; 0x58ce1
	db $0, "There's a big hole", $4f
	db "in the wall!", $57
; 0x58d01

UnknownText_0x58d01: ; 0x58d01
	db $0, "It's a replica of", $4f
	db "an ancient #-", $55
	db "MON.", $57
; 0x58d26

UnknownText_0x58d26: ; 0x58d26
	db $0, "This #MON", $4f
	db "drifted in the", $51
	db "sea by twisting", $4f
	db "its ten tentacles.", $57
; 0x58d63

RuinsofAlphOmanyteChamber_MapEventHeader: ; 0x58d63
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $9, $3, 3, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $9, $4, 3, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $3, $3, 6, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	warp_def $3, $4, 7, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	warp_def $0, $4, 1, GROUP_RUINS_OF_ALPH_OMANYTE_ITEM_ROOM, MAP_RUINS_OF_ALPH_OMANYTE_ITEM_ROOM

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 3, 2, $0, MapRuinsofAlphOmanyteChamberSignpost1Script
	signpost 3, 5, $0, MapRuinsofAlphOmanyteChamberSignpost1Script
	signpost 2, 3, $1, MapRuinsofAlphOmanyteChamberSignpost2Script
	signpost 2, 4, $1, MapRuinsofAlphOmanyteChamberSignpost3Script
	signpost 0, 3, $1, MapRuinsofAlphOmanyteChamberSignpost4Script
	signpost 0, 4, $1, MapRuinsofAlphOmanyteChamberSignpost5Script

	; people-events
	db 0
; 0x58da0

RuinsofAlphAerodactylChamber_MapScriptHeader: ; 0x58da0
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x58dad, $0000
	dw UnknownScript_0x58db8, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x58db9
; 0x58dad

UnknownScript_0x58dad: ; 0x58dad
	checkbit1 $0329
	iftrue UnknownScript_0x58db4
	end
; 0x58db4

UnknownScript_0x58db4: ; 0x58db4
	priorityjump UnknownScript_0x58dd3
	end
; 0x58db8

UnknownScript_0x58db8: ; 0x58db8
	end
; 0x58db9

UnknownScript_0x58db9: ; 0x58db9
	checkbit1 $0329
	iftrue UnknownScript_0x58dc3
	changeblock $4, $0, $2e
UnknownScript_0x58dc3: ; 0x58dc3
	checkbit1 $02a3
	iffalse UnknownScript_0x58dca
	return
; 0x58dca

UnknownScript_0x58dca: ; 0x58dca
	changeblock $2, $2, $1
	changeblock $4, $2, $2
	return
; 0x58dd3

UnknownScript_0x58dd3: ; 0x58dd3
	pause 30
	earthquake 30
	showemote $0, $0, 20
	pause 30
	playsound $001b
	changeblock $4, $0, $30
	reloadmappart
	earthquake 50
	dotrigger $1
	loadmovesprites
	end
; 0x58deb

MapRuinsofAlphAerodactylChamberSignpost2Script: ; 0x58deb
	refreshscreen $0
	writebyte $2
	special $0029
	loadmovesprites
	iftrue UnknownScript_0x58df7
	end
; 0x58df7

UnknownScript_0x58df7: ; 0x58df7
	setbit1 $0705
	setbit1 $02a3
	setbit2 $002d
	domaptrigger GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER, $1
	earthquake 30
	showemote $0, $0, 15
	changeblock $2, $2, $18
	changeblock $4, $2, $19
	reloadmappart
	playsound $001b
	earthquake 80
	applymovement $0, MovementData_0x58e4d
	playsound $002f
	waitbutton
	pause 20
	warpcheck
	end
; 0x58e24

MapRuinsofAlphAerodactylChamberSignpost1Script: ; 0x58e24
	jumptext UnknownText_0x58ec2
; 0x58e27

MapRuinsofAlphAerodactylChamberSignpost3Script: ; 0x58e27
	jumptext UnknownText_0x58ee7
; 0x58e2a

MapRuinsofAlphAerodactylChamberSignpost4Script: ; 0x58e2a
	loadfont
	2writetext UnknownText_0x58e4f
	writebyte $1
	special $0087
	loadmovesprites
	end
; 0x58e35

MapRuinsofAlphAerodactylChamberSignpost5Script: ; 0x58e35
	checkbit1 $0329
	iftrue UnknownScript_0x58e46
	loadfont
	2writetext UnknownText_0x58e81
	writebyte $1
	special $0087
	loadmovesprites
	end
; 0x58e46

UnknownScript_0x58e46: ; 0x58e46
	loadfont
	2writetext UnknownText_0x58ea2
	closetext
	loadmovesprites
	end
; 0x58e4d

MovementData_0x58e4d: ; 0x58e4d
	db $59 ; movement
	step_end
; 0x58e4f

UnknownText_0x58e4f: ; 0x58e4f
	db $0, "Patterns appeared", $4f
	db "on the walls…", $57
; 0x58e70

; possibly unused.. again?
UnknownText_0x58e70: ; 0x58e70
	db $0, "It's UNOWN text!", $57
; 0x58e81

UnknownText_0x58e81: ; 0x58e81
	db $0, "Patterns appeared", $4f
	db "on the walls…", $57
; 0x58ea2

UnknownText_0x58ea2: ; 0x58ea2
	db $0, "There's a big hole", $4f
	db "in the wall!", $57
; 0x58ec2

UnknownText_0x58ec2: ; 0x58ec2
	db $0, "It's a replica of", $4f
	db "an ancient #-", $55
	db "MON.", $57
; 0x58ee7

UnknownText_0x58ee7: ; 0x58ee7
	db $0, "This flying #-", $4f
	db "MON attacked its", $51
	db "prey with saw-like", $4f
	db "fangs.", $57
; 0x58f22

RuinsofAlphAerodactylChamber_MapEventHeader: ; 0x58f22
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $9, $3, 4, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $9, $4, 4, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $3, $3, 8, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	warp_def $3, $4, 9, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER
	warp_def $0, $4, 1, GROUP_RUINS_OF_ALPH_AERODACTYL_ITEM_ROOM, MAP_RUINS_OF_ALPH_AERODACTYL_ITEM_ROOM

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 3, 2, $0, MapRuinsofAlphAerodactylChamberSignpost1Script
	signpost 3, 5, $0, MapRuinsofAlphAerodactylChamberSignpost1Script
	signpost 2, 3, $1, MapRuinsofAlphAerodactylChamberSignpost2Script
	signpost 2, 4, $1, MapRuinsofAlphAerodactylChamberSignpost3Script
	signpost 0, 3, $1, MapRuinsofAlphAerodactylChamberSignpost4Script
	signpost 0, 4, $1, MapRuinsofAlphAerodactylChamberSignpost5Script

	; people-events
	db 0
; 0x58f5f

RuinsofAlphInnerChamber_MapScriptHeader: ; 0x58f5f
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x58f69, $0000
	dw UnknownScript_0x58f6a, $0000

	; callback count
	db 0
; 0x58f69

UnknownScript_0x58f69: ; 0x58f69
	end
; 0x58f6a

UnknownScript_0x58f6a: ; 0x58f6a
	priorityjump UnknownScript_0x58f6e
; 0x58f6d

UnknownScript_0x58f6d: ; 0x58f6d
	end
; 0x58f6e

UnknownScript_0x58f6e: ; 0x58f6e
	loadfont
	2writetext UnknownText_0x58f89
	closetext
	loadmovesprites
	dotrigger $0
	setbit1 $002e
	clearbit1 $078e
	end
; 0x58f7d

UnknownScript_0x58f7d: ; 0x58f7d
	jumptextfaceplayer UnknownText_0x58fac
; 0x58f80

UnknownScript_0x58f80: ; 0x58f80
	jumptextfaceplayer UnknownText_0x58fda
; 0x58f83

UnknownScript_0x58f83: ; 0x58f83
	jumptextfaceplayer UnknownText_0x59024
; 0x58f86

MapRuinsofAlphInnerChamberSignpost25Script: ; 0x58f86
	jumptext UnknownText_0x59072
; 0x58f89

UnknownText_0x58f89: ; 0x58f89
	db $0, "There is a strange", $4f
	db "presence here…", $57
; 0x58fac

UnknownText_0x58fac: ; 0x58fac
	db $0, "This is a big", $4f
	db "room, but there's", $55
	db "nothing here.", $57
; 0x58fda

UnknownText_0x58fda: ; 0x58fda
	db $0, "This place has a", $4f
	db "mystical quality", $55
	db "to it.", $51
	db "It feels sort of", $4f
	db "ethereal even.", $57
; 0x59024

UnknownText_0x59024: ; 0x59024
	db $0, "Ancient buildings", $4f
	db "are often tombs of", $55
	db "kings.", $51
	db "Like the pyramids,", $4f
	db "for instance.", $57
; 0x59072

UnknownText_0x59072: ; 0x59072
	db $0, "It's a replica of", $4f
	db "an ancient #-", $55
	db "MON.", $57
; 0x59097

RuinsofAlphInnerChamber_MapEventHeader: ; 0x59097
	; filler
	db 0, 0

	; warps
	db 9
	warp_def $d, $a, 5, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $f, $3, 3, GROUP_RUINS_OF_ALPH_HO_OH_CHAMBER, MAP_RUINS_OF_ALPH_HO_OH_CHAMBER
	warp_def $f, $4, 4, GROUP_RUINS_OF_ALPH_HO_OH_CHAMBER, MAP_RUINS_OF_ALPH_HO_OH_CHAMBER
	warp_def $3, $f, 3, GROUP_RUINS_OF_ALPH_KABUTO_CHAMBER, MAP_RUINS_OF_ALPH_KABUTO_CHAMBER
	warp_def $3, $10, 4, GROUP_RUINS_OF_ALPH_KABUTO_CHAMBER, MAP_RUINS_OF_ALPH_KABUTO_CHAMBER
	warp_def $15, $3, 3, GROUP_RUINS_OF_ALPH_OMANYTE_CHAMBER, MAP_RUINS_OF_ALPH_OMANYTE_CHAMBER
	warp_def $15, $4, 4, GROUP_RUINS_OF_ALPH_OMANYTE_CHAMBER, MAP_RUINS_OF_ALPH_OMANYTE_CHAMBER
	warp_def $18, $f, 3, GROUP_RUINS_OF_ALPH_AERODACTYL_CHAMBER, MAP_RUINS_OF_ALPH_AERODACTYL_CHAMBER
	warp_def $18, $10, 4, GROUP_RUINS_OF_ALPH_AERODACTYL_CHAMBER, MAP_RUINS_OF_ALPH_AERODACTYL_CHAMBER

	; xy triggers
	db 0

	; signposts
	db 26
	signpost 3, 2, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 3, 5, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 3, 8, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 3, 11, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 3, 14, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 3, 17, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 8, 2, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 8, 5, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 8, 8, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 8, 11, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 8, 14, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 8, 17, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 13, 2, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 13, 17, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 18, 2, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 18, 5, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 18, 8, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 18, 11, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 18, 14, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 18, 17, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 24, 2, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 24, 5, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 24, 8, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 24, 11, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 24, 14, $0, MapRuinsofAlphInnerChamberSignpost25Script
	signpost 24, 17, $0, MapRuinsofAlphInnerChamberSignpost25Script

	; people-events
	db 3
	person_event $3a, 11, 7, $3, $0, 255, 255, $a0, 0, UnknownScript_0x58f7d, $0705
	person_event $29, 17, 18, $2, $11, 255, 255, $0, 0, UnknownScript_0x58f80, $0705
	person_event $2f, 23, 15, $7, $0, 255, 255, $b0, 0, UnknownScript_0x58f83, $0705
; 0x59173

RuinsofAlphResearchCenter_MapScriptHeader: ; 0x59173
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x59180, $0000
	dw UnknownScript_0x59181, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x59185
; 0x59180

UnknownScript_0x59180: ; 0x59180
	end
; 0x59181

UnknownScript_0x59181: ; 0x59181
	priorityjump UnknownScript_0x59192
	end
; 0x59185

UnknownScript_0x59185: ; 0x59185
	checktriggers
	if_equal $1, UnknownScript_0x5918b
	return
; 0x5918b

UnknownScript_0x5918b: ; 0x5918b
	moveperson $4, $3, $7
	appear $4
	return
; 0x59192

UnknownScript_0x59192: ; 0x59192
	applymovement $4, MovementData_0x5926f
	playsound $000d
	pause 60
	playsound $0020
	pause 30
	playsound $0021
	pause 30
	playsound $0022
	pause 30
	spriteface $4, $0
	loadfont
	2writetext UnknownText_0x59278
	closetext
	loadmovesprites
	applymovement $4, MovementData_0x59274
	loadfont
	2writetext UnknownText_0x592fa
	playsound $0001
	waitbutton
	setbit2 $000c
	2writetext UnknownText_0x59311
	closetext
	loadmovesprites
	applymovement $4, MovementData_0x59276
	dotrigger $0
	special $003d
	end
; 0x591d1

UnknownScript_0x591d1: ; 0x591d1
	faceplayer
	loadfont
	checkcode $e
	if_equal 26, UnknownScript_0x591df
	2writetext UnknownText_0x59311
	closetext
	loadmovesprites
	end
; 0x591df

UnknownScript_0x591df: ; 0x591df
	2writetext UnknownText_0x5935f
	closetext
	loadmovesprites
	end
; 0x591e5

UnknownScript_0x591e5: ; 0x591e5
	faceplayer
	loadfont
	checkcode $e
	if_equal 26, UnknownScript_0x5920b
	checkbit2 $000c
	iftrue UnknownScript_0x59205
	checkbit1 $002e
	iftrue UnknownScript_0x591ff
	2writetext UnknownText_0x593ed
	closetext
	loadmovesprites
	end
; 0x591ff

UnknownScript_0x591ff: ; 0x591ff
	2writetext UnknownText_0x59478
	closetext
	loadmovesprites
	end
; 0x59205

UnknownScript_0x59205: ; 0x59205
	2writetext UnknownText_0x59445
	closetext
	loadmovesprites
	end
; 0x5920b

UnknownScript_0x5920b: ; 0x5920b
	2writetext UnknownText_0x594cb
	closetext
	loadmovesprites
	clearbit1 $078f
	end
; 0x59214

UnknownScript_0x59214: ; 0x59214
	faceplayer
	loadfont
	checkcode $e
	if_equal 26, UnknownScript_0x5922e
	checkbit1 $002e
	iftrue UnknownScript_0x59228
	2writetext UnknownText_0x5954f
	closetext
	loadmovesprites
	end
; 0x59228

UnknownScript_0x59228: ; 0x59228
	2writetext UnknownText_0x595cb
	closetext
	loadmovesprites
	end
; 0x5922e

UnknownScript_0x5922e: ; 0x5922e
	2writetext UnknownText_0x59769
	closetext
	loadmovesprites
	end
; 0x59234

MapRuinsofAlphResearchCenterSignpost1Script: ; 0x59234
	loadfont
	checkbit1 $0704
	iftrue UnknownScript_0x59241
	checkcode $e
	if_equal 26, UnknownScript_0x59247
UnknownScript_0x59241: ; 0x59241
	2writetext UnknownText_0x597b6
	closetext
	loadmovesprites
	end
; 0x59247

UnknownScript_0x59247: ; 0x59247
	2writetext UnknownText_0x597d9
	closetext
	loadmovesprites
	end
; 0x5924d

MapRuinsofAlphResearchCenterSignpost2Script: ; 0x5924d
	loadfont
	checkbit1 $0704
	iftrue UnknownScript_0x5925a
	checkcode $e
	if_equal 26, UnknownScript_0x59260
UnknownScript_0x5925a: ; 0x5925a
	2writetext UnknownText_0x5980e
	closetext
	loadmovesprites
	end
; 0x59260

UnknownScript_0x59260: ; 0x59260
	2writetext UnknownText_0x5982d
	closetext
	special $0027
	loadmovesprites
	end
; 0x59269

UnknownScript_0x59269: ; 0x59269
	jumptext UnknownText_0x59848
; 0x5926c

MapRuinsofAlphResearchCenterSignpost0Script: ; 0x5926c
	jumptext UnknownText_0x59886
; 0x5926f

MovementData_0x5926f: ; 0x5926f
	step_up
	step_up
	step_left
	turn_head_up
	step_end
; 0x59274

MovementData_0x59274: ; 0x59274
	step_down
	step_end
; 0x59276

MovementData_0x59276: ; 0x59276
	step_up
	step_end
; 0x59278

UnknownText_0x59278: ; 0x59278
	db $0, "Done!", $51
	db "I modified your", $4f
	db "#DEX.", $51
	db "I added an", $4f
	db "optional #DEX", $51
	db "to store UNOWN", $4f
	db "data.", $51
	db "It records them in", $4f
	db "the sequence that", $55
	db "they were caught.", $57
; 0x592fa

UnknownText_0x592fa: ; 0x592fa
	db $0, $52, "'s #DEX", $4f
	db "was upgraded.", $57
; 0x59311

UnknownText_0x59311: ; 0x59311
	db $0, "The UNOWN you", $4f
	db "catch will all be", $55
	db "recorded.", $51
	db "Check to see how", $4f
	db "many kinds exist.", $57
; 0x5935f

UnknownText_0x5935f: ; 0x5935f
	db $0, "You caught all the", $4f
	db "UNOWN variations?", $51
	db "That's a great", $4f
	db "achievement!", $51
	db "I've set up the", $4f
	db "printer here for", $55
	db "handling UNOWN.", $51
	db "Feel free to use", $4f
	db "it anytime.", $57
; 0x593ed

UnknownText_0x593ed: ; 0x593ed
	db $0, "The RUINS are", $4f
	db "about 1500 years", $55
	db "old.", $51
	db "But it's not known", $4f
	db "why they were", $55
	db "built--or by whom.", $57
; 0x59445

UnknownText_0x59445: ; 0x59445
	db $0, "I wonder how many", $4f
	db "kinds of #MON", $55
	db "are in the RUINS?", $57
; 0x59478

UnknownText_0x59478: ; 0x59478
	db $0, "#MON appeared", $4f
	db "in the RUINS?", $51
	db "That's incredible", $4f
	db "news!", $51
	db "We'll need to", $4f
	db "investigate this.", $57
; 0x594cb

UnknownText_0x594cb: ; 0x594cb
	db $0, "Our investigation,", $4f
	db "with your help, is", $51
	db "giving us insight", $4f
	db "into the RUINS.", $51
	db "The RUINS appear", $4f
	db "to have been built", $51
	db "as a habitat for", $4f
	db "#MON.", $57
; 0x5954f

UnknownText_0x5954f: ; 0x5954f
	db $0, "There are odd pat-", $4f
	db "terns drawn on the", $51
	db "walls of the", $4f
	db "RUINS.", $51
	db "They must be the", $4f
	db "keys for unravel-", $55
	db "ing the mystery", $55
	db "of the RUINS.", $57
; 0x595cb

UnknownText_0x595cb: ; 0x595cb
	db $0, "The strange #-", $4f
	db "MON you saw in the", $55
	db "RUINS?", $51
	db "They appear to be", $4f
	db "very much like the", $51
	db "drawings on the", $4f
	db "walls there.", $51
	db "Hmm…", $51
	db "That must mean", $4f
	db "there are many", $55
	db "kinds of them…", $57
; 0x59669

; possibly unused
UnknownText_0x59669: ; 0x59669
	db $0, "We think something", $4f
	db "caused the cryptic", $51
	db "patterns to appear", $4f
	db "in the RUINS.", $51
	db "We've focused our", $4f
	db "studies on that.", $57
; 0x596d3

; possibly unused
UnknownText_0x596d3: ; 0x596d3
	db $0, "According to my", $4f
	db "research…", $51
	db "Those mysterious", $4f
	db "patterns appeared", $51
	db "when the #COM", $4f
	db "CENTER was built.", $51
	db "It must mean that", $4f
	db "radio waves have", $51
	db "some sort of a", $4f
	db "link…", $57
; 0x59769

UnknownText_0x59769: ; 0x59769
	db $0, "Why did those", $4f
	db "ancient patterns", $51
	db "appear on the wall", $4f
	db "now?", $51
	db "The mystery", $4f
	db "deepens…", $57
; 0x597b6

UnknownText_0x597b6: ; 0x597b6
	db $0, "RUINS OF ALPH", $51
	db "Exploration", $4f
	db "Year 10", $57
; 0x597d9

UnknownText_0x597d9: ; 0x597d9
	db $0, "Mystery #MON", $4f
	db "Name: UNOWN", $51
	db "A total of 26", $4f
	db "kinds found.", $57
; 0x5980e

UnknownText_0x5980e: ; 0x5980e
	db $0, "This doesn't seem", $4f
	db "to work yet.", $57
; 0x5982d

UnknownText_0x5982d: ; 0x5982d
	db $0, "UNOWN may be", $4f
	db "printed out.", $57
; 0x59848

; possibly unused
UnknownText_0x59848: ; 0x59848
	db $0, "It's a photo of", $4f
	db "the RESEARCH", $51
	db "CENTER'S founder,", $4f
	db "PROF.SILKTREE.", $57
; 0x59886

UnknownText_0x59886: ; 0x59886
	db $0, "There are many", $4f
	db "academic books.", $51
	db "Ancient Ruins…", $4f
	db "Mysteries of the", $55
	db "Ancients…", $57
; 0x598d0

RuinsofAlphResearchCenter_MapEventHeader: ; 0x598d0
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 6, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $7, $3, 6, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 5, 6, $0, MapRuinsofAlphResearchCenterSignpost0Script
	signpost 4, 3, $0, MapRuinsofAlphResearchCenterSignpost1Script
	signpost 1, 7, $0, MapRuinsofAlphResearchCenterSignpost2Script

	; people-events
	db 3
	person_event $3c, 9, 8, $7, $0, 255, 255, $90, 0, UnknownScript_0x591e5, $ffff
	person_event $3c, 6, 9, $2, $12, 255, 255, $90, 0, UnknownScript_0x59214, $ffff
	person_event $3c, 9, 6, $7, $0, 255, 255, $90, 0, UnknownScript_0x591d1, $0704
; 0x59916

RuinsofAlphHoOhItemRoom_MapScriptHeader: ; 0x59916
	; trigger count
	db 0

	; callback count
	db 0
; 0x59918

ItemFragment_0x59918: ; 0x59918
	db GOLD_BERRY, 1
; 0x5991a

ItemFragment_0x5991a: ; 0x5991a
	db MYSTERYBERRY, 1
; 0x5991c

ItemFragment_0x5991c: ; 0x5991c
	db REVIVAL_HERB, 1
; 0x5991e

ItemFragment_0x5991e: ; 0x5991e
	db CHARCOAL, 1
; 0x59920

MapRuinsofAlphHoOhItemRoomSignpost1Script: ; 0x59920
	jumptext UnknownText_0x59923
; 0x59923

UnknownText_0x59923: ; 0x59923
	db $0, "It's a replica of", $4f
	db "an ancient #-", $55
	db "MON.", $57
; 0x59948

RuinsofAlphHoOhItemRoom_MapEventHeader: ; 0x59948
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $9, $3, 5, GROUP_RUINS_OF_ALPH_HO_OH_CHAMBER, MAP_RUINS_OF_ALPH_HO_OH_CHAMBER
	warp_def $9, $4, 5, GROUP_RUINS_OF_ALPH_HO_OH_CHAMBER, MAP_RUINS_OF_ALPH_HO_OH_CHAMBER
	warp_def $1, $3, 1, GROUP_RUINS_OF_ALPH_HO_OH_WORD_ROOM, MAP_RUINS_OF_ALPH_HO_OH_WORD_ROOM
	warp_def $1, $4, 2, GROUP_RUINS_OF_ALPH_HO_OH_WORD_ROOM, MAP_RUINS_OF_ALPH_HO_OH_WORD_ROOM

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 2, $0, MapRuinsofAlphHoOhItemRoomSignpost1Script
	signpost 1, 5, $0, MapRuinsofAlphHoOhItemRoomSignpost1Script

	; people-events
	db 4
	person_event $54, 10, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x59918, $0794
	person_event $54, 10, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x5991a, $0795
	person_event $54, 8, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x5991c, $0796
	person_event $54, 8, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x5991e, $0797
; 0x599a0

RuinsofAlphKabutoItemRoom_MapScriptHeader: ; 0x599a0
	; trigger count
	db 0

	; callback count
	db 0
; 0x599a2

ItemFragment_0x599a2: ; 0x599a2
	db BERRY, 1
; 0x599a4

ItemFragment_0x599a4: ; 0x599a4
	db PSNCUREBERRY, 1
; 0x599a6

ItemFragment_0x599a6: ; 0x599a6
	db HEAL_POWDER, 1
; 0x599a8

ItemFragment_0x599a8: ; 0x599a8
	db ENERGYPOWDER, 1
; 0x599aa

MapRuinsofAlphKabutoItemRoomSignpost1Script: ; 0x599aa
	jumptext UnknownText_0x599ad
; 0x599ad

UnknownText_0x599ad: ; 0x599ad
	db $0, "It's a replica of", $4f
	db "an ancient #-", $55
	db "MON.", $57
; 0x599d2

RuinsofAlphKabutoItemRoom_MapEventHeader: ; 0x599d2
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $9, $3, 5, GROUP_RUINS_OF_ALPH_KABUTO_CHAMBER, MAP_RUINS_OF_ALPH_KABUTO_CHAMBER
	warp_def $9, $4, 5, GROUP_RUINS_OF_ALPH_KABUTO_CHAMBER, MAP_RUINS_OF_ALPH_KABUTO_CHAMBER
	warp_def $1, $3, 1, GROUP_RUINS_OF_ALPH_KABUTO_WORD_ROOM, MAP_RUINS_OF_ALPH_KABUTO_WORD_ROOM
	warp_def $1, $4, 2, GROUP_RUINS_OF_ALPH_KABUTO_WORD_ROOM, MAP_RUINS_OF_ALPH_KABUTO_WORD_ROOM

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 2, $0, MapRuinsofAlphKabutoItemRoomSignpost1Script
	signpost 1, 5, $0, MapRuinsofAlphKabutoItemRoomSignpost1Script

	; people-events
	db 4
	person_event $54, 10, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x599a2, $0798
	person_event $54, 10, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x599a4, $0799
	person_event $54, 8, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x599a6, $079a
	person_event $54, 8, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x599a8, $079b
; 0x59a2a

RuinsofAlphOmanyteItemRoom_MapScriptHeader: ; 0x59a2a
	; trigger count
	db 0

	; callback count
	db 0
; 0x59a2c

ItemFragment_0x59a2c: ; 0x59a2c
	db MYSTERYBERRY, 1
; 0x59a2e

ItemFragment_0x59a2e: ; 0x59a2e
	db MYSTIC_WATER, 1
; 0x59a30

ItemFragment_0x59a30: ; 0x59a30
	db STARDUST, 1
; 0x59a32

ItemFragment_0x59a32: ; 0x59a32
	db STAR_PIECE, 1
; 0x59a34

MapRuinsofAlphOmanyteItemRoomSignpost1Script: ; 0x59a34
	jumptext UnknownText_0x59a37
; 0x59a37

UnknownText_0x59a37: ; 0x59a37
	db $0, "It's a replica of", $4f
	db "an ancient #-", $55
	db "MON.", $57
; 0x59a5c

RuinsofAlphOmanyteItemRoom_MapEventHeader: ; 0x59a5c
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $9, $3, 5, GROUP_RUINS_OF_ALPH_OMANYTE_CHAMBER, MAP_RUINS_OF_ALPH_OMANYTE_CHAMBER
	warp_def $9, $4, 5, GROUP_RUINS_OF_ALPH_OMANYTE_CHAMBER, MAP_RUINS_OF_ALPH_OMANYTE_CHAMBER
	warp_def $1, $3, 1, GROUP_RUINS_OF_ALPH_OMANYTE_WORD_ROOM, MAP_RUINS_OF_ALPH_OMANYTE_WORD_ROOM
	warp_def $1, $4, 2, GROUP_RUINS_OF_ALPH_OMANYTE_WORD_ROOM, MAP_RUINS_OF_ALPH_OMANYTE_WORD_ROOM

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 2, $0, MapRuinsofAlphOmanyteItemRoomSignpost1Script
	signpost 1, 5, $0, MapRuinsofAlphOmanyteItemRoomSignpost1Script

	; people-events
	db 4
	person_event $54, 10, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x59a2c, $079c
	person_event $54, 10, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x59a2e, $079d
	person_event $54, 8, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x59a30, $079e
	person_event $54, 8, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x59a32, $079f
; 0x59ab4

RuinsofAlphAerodactylItemRoom_MapScriptHeader: ; 0x59ab4
	; trigger count
	db 0

	; callback count
	db 0
; 0x59ab6

ItemFragment_0x59ab6: ; 0x59ab6
	db GOLD_BERRY, 1
; 0x59ab8

ItemFragment_0x59ab8: ; 0x59ab8
	db MOON_STONE, 1
; 0x59aba

ItemFragment_0x59aba: ; 0x59aba
	db HEAL_POWDER, 1
; 0x59abc

ItemFragment_0x59abc: ; 0x59abc
	db ENERGY_ROOT, 1
; 0x59abe

MapRuinsofAlphAerodactylItemRoomSignpost1Script: ; 0x59abe
	jumptext UnknownText_0x59ac1
; 0x59ac1

UnknownText_0x59ac1: ; 0x59ac1
	db $0, "It's a replica of", $4f
	db "an ancient #-", $55
	db "MON.", $57
; 0x59ae6

RuinsofAlphAerodactylItemRoom_MapEventHeader: ; 0x59ae6
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $9, $3, 5, GROUP_RUINS_OF_ALPH_AERODACTYL_CHAMBER, MAP_RUINS_OF_ALPH_AERODACTYL_CHAMBER
	warp_def $9, $4, 5, GROUP_RUINS_OF_ALPH_AERODACTYL_CHAMBER, MAP_RUINS_OF_ALPH_AERODACTYL_CHAMBER
	warp_def $1, $3, 1, GROUP_RUINS_OF_ALPH_AERODACTYL_WORD_ROOM, MAP_RUINS_OF_ALPH_AERODACTYL_WORD_ROOM
	warp_def $1, $4, 2, GROUP_RUINS_OF_ALPH_AERODACTYL_WORD_ROOM, MAP_RUINS_OF_ALPH_AERODACTYL_WORD_ROOM

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 2, $0, MapRuinsofAlphAerodactylItemRoomSignpost1Script
	signpost 1, 5, $0, MapRuinsofAlphAerodactylItemRoomSignpost1Script

	; people-events
	db 4
	person_event $54, 10, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x59ab6, $07a0
	person_event $54, 10, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x59ab8, $07a1
	person_event $54, 8, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x59aba, $07a2
	person_event $54, 8, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x59abc, $07a3
; 0x59b3e

RuinsofAlphHoOhWordRoom_MapScriptHeader: ; 0x59b3e
	; trigger count
	db 0

	; callback count
	db 0
; 0x59b40

RuinsofAlphHoOhWordRoom_MapEventHeader: ; 0x59b40
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $9, $9, 3, GROUP_RUINS_OF_ALPH_HO_OH_ITEM_ROOM, MAP_RUINS_OF_ALPH_HO_OH_ITEM_ROOM
	warp_def $9, $a, 4, GROUP_RUINS_OF_ALPH_HO_OH_ITEM_ROOM, MAP_RUINS_OF_ALPH_HO_OH_ITEM_ROOM
	warp_def $15, $11, 2, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x59b55

RuinsofAlphKabutoWordRoom_MapScriptHeader: ; 0x59b55
	; trigger count
	db 0

	; callback count
	db 0
; 0x59b57

RuinsofAlphKabutoWordRoom_MapEventHeader: ; 0x59b57
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $5, $9, 3, GROUP_RUINS_OF_ALPH_KABUTO_ITEM_ROOM, MAP_RUINS_OF_ALPH_KABUTO_ITEM_ROOM
	warp_def $5, $a, 4, GROUP_RUINS_OF_ALPH_KABUTO_ITEM_ROOM, MAP_RUINS_OF_ALPH_KABUTO_ITEM_ROOM
	warp_def $b, $11, 4, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x59b6c

RuinsofAlphOmanyteWordRoom_MapScriptHeader: ; 0x59b6c
	; trigger count
	db 0

	; callback count
	db 0
; 0x59b6e

RuinsofAlphOmanyteWordRoom_MapEventHeader: ; 0x59b6e
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $9, 3, GROUP_RUINS_OF_ALPH_OMANYTE_ITEM_ROOM, MAP_RUINS_OF_ALPH_OMANYTE_ITEM_ROOM
	warp_def $7, $a, 4, GROUP_RUINS_OF_ALPH_OMANYTE_ITEM_ROOM, MAP_RUINS_OF_ALPH_OMANYTE_ITEM_ROOM
	warp_def $d, $11, 6, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x59b83

RuinsofAlphAerodactylWordRoom_MapScriptHeader: ; 0x59b83
	; trigger count
	db 0

	; callback count
	db 0
; 0x59b85

RuinsofAlphAerodactylWordRoom_MapEventHeader: ; 0x59b85
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $5, $9, 3, GROUP_RUINS_OF_ALPH_AERODACTYL_ITEM_ROOM, MAP_RUINS_OF_ALPH_AERODACTYL_ITEM_ROOM
	warp_def $5, $a, 4, GROUP_RUINS_OF_ALPH_AERODACTYL_ITEM_ROOM, MAP_RUINS_OF_ALPH_AERODACTYL_ITEM_ROOM
	warp_def $b, $11, 8, GROUP_RUINS_OF_ALPH_INNER_CHAMBER, MAP_RUINS_OF_ALPH_INNER_CHAMBER

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x59b9a

UnionCave1F_MapScriptHeader: ; 0x59b9a
	; trigger count
	db 0

	; callback count
	db 0
; 0x59b9c

TrainerPokemaniacLarry: ; 0x59b9c
	; bit/flag number
	dw $4e4

	; trainer group && trainer id
	db POKEMANIAC, LARRY

	; text when seen
	dw PokemaniacLarrySeenText

	; text when trainer beaten
	dw PokemaniacLarryBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacLarryScript
; 0x59ba8

PokemaniacLarryScript: ; 0x59ba8
	talkaftercancel
	loadfont
	2writetext UnknownText_0x59d31
	closetext
	loadmovesprites
	end
; 0x59bb0

TrainerHikerRussell: ; 0x59bb0
	; bit/flag number
	dw $525

	; trainer group && trainer id
	db HIKER, RUSSELL

	; text when seen
	dw HikerRussellSeenText

	; text when trainer beaten
	dw HikerRussellBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerRussellScript
; 0x59bbc

HikerRussellScript: ; 0x59bbc
	talkaftercancel
	loadfont
	2writetext UnknownText_0x59c6c
	closetext
	loadmovesprites
	end
; 0x59bc4

TrainerHikerDaniel: ; 0x59bc4
	; bit/flag number
	dw $535

	; trainer group && trainer id
	db HIKER, DANIEL

	; text when seen
	dw HikerDanielSeenText

	; text when trainer beaten
	dw HikerDanielBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerDanielScript
; 0x59bd0

HikerDanielScript: ; 0x59bd0
	talkaftercancel
	loadfont
	2writetext UnknownText_0x59dc9
	closetext
	loadmovesprites
	end
; 0x59bd8

TrainerFirebreatherBill: ; 0x59bd8
	; bit/flag number
	dw $44a

	; trainer group && trainer id
	db FIREBREATHER, BILL

	; text when seen
	dw FirebreatherBillSeenText

	; text when trainer beaten
	dw FirebreatherBillBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FirebreatherBillScript
; 0x59be4

FirebreatherBillScript: ; 0x59be4
	talkaftercancel
	loadfont
	2writetext UnknownText_0x59e6f
	closetext
	loadmovesprites
	end
; 0x59bec

TrainerFirebreatherRay: ; 0x59bec
	; bit/flag number
	dw $44c

	; trainer group && trainer id
	db FIREBREATHER, RAY

	; text when seen
	dw FirebreatherRaySeenText

	; text when trainer beaten
	dw FirebreatherRayBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FirebreatherRayScript
; 0x59bf8

FirebreatherRayScript: ; 0x59bf8
	talkaftercancel
	loadfont
	2writetext UnknownText_0x59efc
	closetext
	loadmovesprites
	end
; 0x59c00

ItemFragment_0x59c00: ; 0x59c00
	db GREAT_BALL, 1
; 0x59c02

ItemFragment_0x59c02: ; 0x59c02
	db X_ATTACK, 1
; 0x59c04

ItemFragment_0x59c04: ; 0x59c04
	db POTION, 1
; 0x59c06

ItemFragment_0x59c06: ; 0x59c06
	db AWAKENING, 1
; 0x59c08

UnknownScript_0x59c08: ; 0x59c08
	jumptext UnknownText_0x59f29
; 0x59c0b

HikerRussellSeenText: ; 0x59c0b
	db $0, "You're headed to", $4f
	db "AZALEA, are you?", $51
	db "Let my #MON see", $4f
	db "if you are good", $55
	db "enough to battle.", $57
; 0x59c5f

HikerRussellBeatenText: ; 0x59c5f
	db $0, "Oh, oh, oh!", $57
; 0x59c6c

UnknownText_0x59c6c: ; 0x59c6c
	db $0, "All right, then!", $4f
	db "I've decided.", $51
	db "I'm not leaving", $4f
	db "until my #MON", $55
	db "get tougher!", $57
; 0x59cb5

PokemaniacLarrySeenText: ; 0x59cb5
	db $0, "I roam far and", $4f
	db "wide in search of", $55
	db "#MON.", $51
	db "Are you looking", $4f
	db "for #MON too?", $51
	db "Then you're my", $4f
	db "collecting rival!", $57
; 0x59d1b

PokemaniacLarryBeatenText: ; 0x59d1b
	db $0, "Ugh. My poor #-", $4f
	db "MON…", $57
; 0x59d31

UnknownText_0x59d31: ; 0x59d31
	db $0, "Every Friday, you", $4f
	db "can hear #MON", $51
	db "roars from deep", $4f
	db "inside the cave.", $57
; 0x59d73

HikerDanielSeenText: ; 0x59d73
	db $0, "Whoa! What a", $4f
	db "surprise!", $51
	db "I didn't expect to", $4f
	db "see anyone here!", $57
; 0x59dae

HikerDanielBeatenText: ; 0x59dae
	db $0, "Whoa! I'm beaten", $4f
	db "big time!", $57
; 0x59dc9

UnknownText_0x59dc9: ; 0x59dc9
	db $0, "I was conned into", $4f
	db "buying a SLOWPOKE-", $55
	db "TAIL.", $51
	db "I feel sorry for", $4f
	db "the poor #MON.", $57
; 0x59e15

FirebreatherBillSeenText: ; 0x59e15
	db $0, "ZUBAT's SUPERSONIC", $4f
	db "keeps confusing", $55
	db "my #MON.", $51
	db "I'm seriously", $4f
	db "upset about that!", $57
; 0x59e60

FirebreatherBillBeatenText: ; 0x59e60
	db $0, "I flamed out!", $57
; 0x59e6f

UnknownText_0x59e6f: ; 0x59e6f
	db $0, "On weekends, you", $4f
	db "can hear strange", $51
	db "roars from deep in", $4f
	db "the cave.", $57
; 0x59eaf

FirebreatherRaySeenText: ; 0x59eaf
	db $0, "If it's light, a", $4f
	db "cave isn't scary.", $51
	db "If you're strong,", $4f
	db "#MON aren't", $55
	db "scary.", $57
; 0x59ef4

FirebreatherRayBeatenText: ; 0x59ef4
	db $0, "FLASH!", $57
; 0x59efc

UnknownText_0x59efc: ; 0x59efc
	db $0, "It's my #MON's", $4f
	db "fire that lights", $55
	db "up this cave.", $57
; 0x59f29

UnknownText_0x59f29: ; 0x59f29
	db $0, "UNION CAVE", $57
; 0x59f35

UnionCave1F_MapEventHeader: ; 0x59f35
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $13, $5, 3, GROUP_UNION_CAVE_B1F, MAP_UNION_CAVE_B1F
	warp_def $21, $3, 4, GROUP_UNION_CAVE_B1F, MAP_UNION_CAVE_B1F
	warp_def $1f, $11, 1, GROUP_ROUTE_33, MAP_ROUTE_33
	warp_def $3, $11, 4, GROUP_ROUTE_32, MAP_ROUTE_32

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 9
	person_event $2d, 10, 7, $9, $0, 255, 255, $b2, 2, TrainerHikerDaniel, $ffff
	person_event $2b, 25, 8, $a, $0, 255, 255, $92, 3, TrainerPokemaniacLarry, $ffff
	person_event $2d, 12, 15, $a, $0, 255, 255, $b2, 1, TrainerHikerRussell, $ffff
	person_event $3a, 31, 19, $8, $0, 255, 255, $82, 4, TrainerFirebreatherRay, $ffff
	person_event $3a, 23, 18, $7, $0, 255, 255, $82, 4, TrainerFirebreatherBill, $ffff
	person_event $54, 25, 21, $1, $0, 255, 255, $1, 0, ItemFragment_0x59c00, $065a
	person_event $54, 6, 8, $1, $0, 255, 255, $1, 0, ItemFragment_0x59c02, $065b
	person_event $54, 21, 8, $1, $0, 255, 255, $1, 0, ItemFragment_0x59c04, $065c
	person_event $54, 37, 16, $1, $0, 255, 255, $1, 0, ItemFragment_0x59c06, $065d
; 0x59fc4

UnionCaveB1F_MapScriptHeader: ; 0x59fc4
	; trigger count
	db 0

	; callback count
	db 0
; 0x59fc6

TrainerPokemaniacAndrew: ; 0x59fc6
	; bit/flag number
	dw $4e5

	; trainer group && trainer id
	db POKEMANIAC, ANDREW

	; text when seen
	dw PokemaniacAndrewSeenText

	; text when trainer beaten
	dw PokemaniacAndrewBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacAndrewScript
; 0x59fd2

PokemaniacAndrewScript: ; 0x59fd2
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5a181
	closetext
	loadmovesprites
	end
; 0x59fda

TrainerPokemaniacCalvin: ; 0x59fda
	; bit/flag number
	dw $4e6

	; trainer group && trainer id
	db POKEMANIAC, CALVIN

	; text when seen
	dw PokemaniacCalvinSeenText

	; text when trainer beaten
	dw PokemaniacCalvinBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacCalvinScript
; 0x59fe6

PokemaniacCalvinScript: ; 0x59fe6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5a230
	closetext
	loadmovesprites
	end
; 0x59fee

TrainerHikerPhillip: ; 0x59fee
	; bit/flag number
	dw $526

	; trainer group && trainer id
	db HIKER, PHILLIP

	; text when seen
	dw HikerPhillipSeenText

	; text when trainer beaten
	dw HikerPhillipBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerPhillipScript
; 0x59ffa

HikerPhillipScript: ; 0x59ffa
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5a073
	closetext
	loadmovesprites
	end
; 0x5a002

TrainerHikerLeonard: ; 0x5a002
	; bit/flag number
	dw $527

	; trainer group && trainer id
	db HIKER, LEONARD

	; text when seen
	dw HikerLeonardSeenText

	; text when trainer beaten
	dw HikerLeonardBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerLeonardScript
; 0x5a00e

HikerLeonardScript: ; 0x5a00e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5a0fb
	closetext
	loadmovesprites
	end
; 0x5a016

ItemFragment_0x5a016: ; 0x5a016
	db TM_39, 1
; 0x5a018

ItemFragment_0x5a018: ; 0x5a018
	db X_DEFEND, 1
; 0x5a01a

UnknownScript_0x5a01a: ; 0x5a01a
	jumpstd $000e
; 0x5a01d

HikerPhillipSeenText: ; 0x5a01d
	db $0, "It's been a while", $4f
	db "since I last saw", $55
	db "another person.", $51
	db "Don't be shy.", $4f
	db "Let's battle!", $57
; 0x5a06a

HikerPhillipBeatenText: ; 0x5a06a
	db $0, "Uurggh…", $57
; 0x5a073

UnknownText_0x5a073: ; 0x5a073
	db $0, "I've been lost for", $4f
	db "a long time…", $51
	db "I don't mind it", $4f
	db "here, but I am", $55
	db "soooo hungry!", $57
; 0x5a0bf

HikerLeonardSeenText: ; 0x5a0bf
	db $0, "What do you know!", $4f
	db "A visitor!", $57
; 0x5a0dd

HikerLeonardBeatenText: ; 0x5a0dd
	db $0, "Wahahah! You're a", $4f
	db "feisty one!", $57
; 0x5a0fb

UnknownText_0x5a0fb: ; 0x5a0fb
	db $0, "I live down here.", $51
	db "You can, too, if", $4f
	db "you'd like.", $51
	db "There's plenty of", $4f
	db "room, you see.", $57
; 0x5a14a

PokemaniacAndrewSeenText: ; 0x5a14a
	db $0, "Who's there?", $51
	db "Leave me and my", $4f
	db "#MON alone!", $57
; 0x5a173

PokemaniacAndrewBeatenText: ; 0x5a173
	db $0, "Go…", $4f
	db "Go away!", $57
; 0x5a181

UnknownText_0x5a181: ; 0x5a181
	db $0, "Just me and my", $4f
	db "#MON. I'm de-", $55
	db "lirious with joy.", $57
; 0x5a1b0

PokemaniacCalvinSeenText: ; 0x5a1b0
	db $0, "I came all the way", $4f
	db "here to conduct my", $55
	db "#MON research.", $51
	db "Let me demonstrate", $4f
	db "my findings in a", $55
	db "real battle!", $57
; 0x5a217

PokemaniacCalvinBeatenText: ; 0x5a217
	db $0, "You demonstrated", $4f
	db "on me!", $57
; 0x5a230

UnknownText_0x5a230: ; 0x5a230
	db $0, "I should compile", $4f
	db "and announce my", $55
	db "study findings.", $51
	db "I might even be-", $4f
	db "come famous like", $55
	db "PROF.ELM.", $57
; 0x5a28e

UnionCaveB1F_MapEventHeader: ; 0x5a28e
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $3, $3, 7, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $b, $3, 8, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $13, $7, 1, GROUP_UNION_CAVE_1F, MAP_UNION_CAVE_1F
	warp_def $21, $3, 2, GROUP_UNION_CAVE_1F, MAP_UNION_CAVE_1F
	warp_def $1f, $11, 1, GROUP_UNION_CAVE_B2F, MAP_UNION_CAVE_B2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 7
	person_event $2d, 8, 13, $a, $0, 255, 255, $b2, 3, TrainerHikerPhillip, $ffff
	person_event $2d, 11, 20, $6, $0, 255, 255, $b2, 3, TrainerHikerLeonard, $ffff
	person_event $2b, 36, 9, $8, $0, 255, 255, $92, 3, TrainerPokemaniacAndrew, $ffff
	person_event $2b, 34, 21, $8, $0, 255, 255, $92, 3, TrainerPokemaniacCalvin, $ffff
	person_event $54, 20, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x5a016, $065e
	person_event $5a, 14, 11, $19, $0, 255, 255, $0, 0, UnknownScript_0x5a01a, $ffff
	person_event $54, 27, 21, $1, $0, 255, 255, $1, 0, ItemFragment_0x5a018, $065f
; 0x5a308

UnionCaveB2F_MapScriptHeader: ; 0x5a308
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x5a30d
; 0x5a30d

UnknownScript_0x5a30d: ; 0x5a30d
	checkbit2 $0059
	iftrue UnknownScript_0x5a319
	checkcode $b
	if_equal FRIDAY, UnknownScript_0x5a31c
UnknownScript_0x5a319: ; 0x5a319
	disappear $7
	return
; 0x5a31c

UnknownScript_0x5a31c: ; 0x5a31c
	appear $7
	return
; 0x5a31f

UnknownScript_0x5a31f: ; 0x5a31f
	faceplayer
	cry LAPRAS
	loadpokedata LAPRAS, 20
	startbattle
	disappear $7
	setbit2 $0059
	returnafterbattle
	end
; 0x5a32e

TrainerCooltrainermNick: ; 0x5a32e
	; bit/flag number
	dw $548

	; trainer group && trainer id
	db COOLTRAINERM, NICK

	; text when seen
	dw CooltrainermNickSeenText

	; text when trainer beaten
	dw CooltrainermNickBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermNickScript
; 0x5a33a

CooltrainermNickScript: ; 0x5a33a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5a3f0
	closetext
	loadmovesprites
	end
; 0x5a342

TrainerCooltrainerfGwen: ; 0x5a342
	; bit/flag number
	dw $55b

	; trainer group && trainer id
	db COOLTRAINERF, GWEN

	; text when seen
	dw CooltrainerfGwenSeenText

	; text when trainer beaten
	dw CooltrainerfGwenBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfGwenScript
; 0x5a34e

CooltrainerfGwenScript: ; 0x5a34e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5a488
	closetext
	loadmovesprites
	end
; 0x5a356

TrainerCooltrainerfEmma: ; 0x5a356
	; bit/flag number
	dw $569

	; trainer group && trainer id
	db COOLTRAINERF, EMMA

	; text when seen
	dw CooltrainerfEmmaSeenText

	; text when trainer beaten
	dw CooltrainerfEmmaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfEmmaScript
; 0x5a362

CooltrainerfEmmaScript: ; 0x5a362
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5a52b
	closetext
	loadmovesprites
	end
; 0x5a36a

ItemFragment_0x5a36a: ; 0x5a36a
	db ELIXER, 1
; 0x5a36c

ItemFragment_0x5a36c: ; 0x5a36c
	db HYPER_POTION, 1
; 0x5a36e

CooltrainermNickSeenText: ; 0x5a36e
	db $0, "There are two", $4f
	db "kinds of people.", $51
	db "Those who have", $4f
	db "style, and those", $55
	db "who don't.", $51
	db "What kind of", $4f
	db "person are you?", $57
; 0x5a3d5

CooltrainermNickBeatenText: ; 0x5a3d5
	db $0, "You've got", $4f
	db "dazzling style!", $57
; 0x5a3f0

UnknownText_0x5a3f0: ; 0x5a3f0
	db $0, "Your #MON style", $4f
	db "is stunning and", $55
	db "colorful, I admit.", $51
	db "You'll just keep", $4f
	db "getting better!", $57
; 0x5a444

CooltrainerfGwenSeenText: ; 0x5a444
	db $0, "I'm in training.", $4f
	db "Care for a round?", $57
; 0x5a467

CooltrainerfGwenBeatenText: ; 0x5a467
	db $0, "Aww, no! You're", $4f
	db "too good for me.", $57
; 0x5a488

UnknownText_0x5a488: ; 0x5a488
	db $0, "I'm going to train", $4f
	db "by myself until I", $55
	db "improve.", $57
; 0x5a4b6

CooltrainerfEmmaSeenText: ; 0x5a4b6
	db $0, "If the #MON I", $4f
	db "liked were there,", $55
	db "I'd go anywhere.", $51
	db "That's what a real", $4f
	db "trainer does.", $57
; 0x5a507

CooltrainerfEmmaBeatenText: ; 0x5a507
	db $0, "I'd rather pet my", $4f
	db "babies than this!", $57
; 0x5a52b

UnknownText_0x5a52b: ; 0x5a52b
	db $0, "Just once a week,", $4f
	db "a #MON comes to", $55
	db "the water's edge.", $51
	db "I wanted to see", $4f
	db "that #MON…", $57
; 0x5a57a

UnionCaveB2F_MapEventHeader: ; 0x5a57a
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $3, $5, 5, GROUP_UNION_CAVE_B1F, MAP_UNION_CAVE_B1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 6
	person_event $2c, 23, 19, $6, $0, 255, 255, $82, 3, TrainerCooltrainermNick, $ffff
	person_event $24, 17, 9, $a, $0, 255, 255, $82, 1, TrainerCooltrainerfGwen, $ffff
	person_event $24, 34, 7, $7, $0, 255, 255, $82, 3, TrainerCooltrainerfEmma, $ffff
	person_event $54, 6, 20, $1, $0, 255, 255, $1, 0, ItemFragment_0x5a36a, $0660
	person_event $54, 23, 16, $1, $0, 255, 255, $1, 0, ItemFragment_0x5a36c, $0661
	person_event $53, 35, 15, $24, $11, 255, 255, $90, 0, UnknownScript_0x5a31f, $0760
; 0x5a5d3

SlowpokeWellB1F_MapScriptHeader: ; 0x5a5d3
	; trigger count
	db 0

	; callback count
	db 0
; 0x5a5d5

UnknownScript_0x5a5d5: ; 0x5a5d5
	jumptextfaceplayer UnknownText_0x5a6b5
; 0x5a5d8

TrainerGruntM29: ; 0x5a5d8
	; bit/flag number
	dw $50d

	; trainer group && trainer id
	db GRUNTM, 29

	; text when seen
	dw GruntM29SeenText

	; text when trainer beaten
	dw GruntM29BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM29Script
; 0x5a5e4

GruntM29Script: ; 0x5a5e4
	talkaftercancel
	loadfont
	2writetext TrainerGruntM29SlowpokeProfitText
	closetext
	loadmovesprites
	end
; 0x5a5ec

TrainerGruntM1: ; 0x5a5ec
	; bit/flag number
	dw $4f1

	; trainer group && trainer id
	db GRUNTM, 1

	; text when seen
	dw GruntM1SeenText

	; text when trainer beaten
	dw GruntM1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM1Script
; 0x5a5f8

GruntM1Script: ; 0x5a5f8
	loadfont
	2writetext TrainerGruntM1WhenTalkText
	closetext
	loadmovesprites
	special $0030
	special $0033
	disappear $2
	disappear $3
	disappear $4
	disappear $5
	pause 15
	special $0032
	disappear $8
	moveperson $8, $b, $6
	appear $8
	applymovement $8, KurtSlowpokeWellVictoryMovementData
	spriteface $0, $3
	loadfont
	2writetext KurtLeaveSlowpokeWellText
	closetext
	loadmovesprites
	setbit1 $002b
	variablesprite $6, $4
	domaptrigger GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN, $1
	clearbit1 $06f3
	clearbit1 $06e9
	setbit1 $06f5
	setbit1 $06f6
	setbit1 $06fb
	setbit1 $0740
	clearbit1 $06f9
	clearbit1 $06fd
	clearbit1 $073e
	special $002e
	special $001b
	pause 15
	warp GROUP_KURTS_HOUSE, MAP_KURTS_HOUSE, $3, $3
	end
; 0x5a659

TrainerGruntM2: ; 0x5a659
	; bit/flag number
	dw $4f2

	; trainer group && trainer id
	db GRUNTM, 2

	; text when seen
	dw GruntM2SeenText

	; text when trainer beaten
	dw GruntM2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM2Script
; 0x5a665

GruntM2Script: ; 0x5a665
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5aaf2
	closetext
	loadmovesprites
	end
; 0x5a66d

TrainerGruntF1: ; 0x5a66d
	; bit/flag number
	dw $510

	; trainer group && trainer id
	db GRUNTF, 1

	; text when seen
	dw GruntF1SeenText

	; text when trainer beaten
	dw GruntF1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntF1Script
; 0x5a679

GruntF1Script: ; 0x5a679
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5ab8d
	closetext
	loadmovesprites
	end
; 0x5a681

UnknownScript_0x5a681: ; 0x5a681
	faceplayer
	loadfont
	cry SLOWPOKE
	2writetext UnknownText_0x5abcb
	yesorno
	iftrue UnknownScript_0x5a68f
	loadmovesprites
	end
; 0x5a68f

UnknownScript_0x5a68f: ; 0x5a68f
	2writetext UnknownText_0x5ac09
	closetext
	loadmovesprites
	end
; 0x5a695

UnknownScript_0x5a695: ; 0x5a695
	faceplayer
	loadfont
	2writetext UnknownText_0x5ac61
	cry SLOWPOKE
	closetext
	loadmovesprites
	end
; 0x5a6a0

UnknownScript_0x5a6a0: ; 0x5a6a0
	jumpstd $000e
; 0x5a6a3

ItemFragment_0x5a6a3: ; 0x5a6a3
	db SUPER_POTION, 1
; 0x5a6a5

KurtSlowpokeWellVictoryMovementData: ; 0x5a6a5
	step_left
	step_left
	step_left
	step_left
	step_up
	accelerate_last
	accelerate_last
	accelerate_last
	step_left
	step_up
	step_up
	accelerate_last
	accelerate_last
	accelerate_last
	turn_head_left
	step_end
; 0x5a6b5

UnknownText_0x5a6b5: ; 0x5a6b5
	db $0, "KURT: Hey there,", $4f
	db $52, "!", $51
	db "The guard up top", $4f
	db "took off when I", $55
	db "shouted at him.", $51
	db "But then I took a", $4f
	db "tumble down the", $55
	db "WELL.", $51
	db "I slammed down", $4f
	db "hard on my back,", $55
	db "so I can't move.", $51
	db "Rats! If I were", $4f
	db "fit, my #MON", $51
	db "would've punished", $4f
	db "them…", $51
	db "Ah, it can't be", $4f
	db "helped.", $51
	db $52, ", show them", $4f
	db "how gutsy you are", $55
	db "in my place!", $57
; 0x5a7ca

KurtLeaveSlowpokeWellText: ; 0x5a7ca
	db $0, "KURT: Way to go,", $4f
	db $52, "!", $51
	db "TEAM ROCKET has", $4f
	db "taken off.", $51
	db "My back's better", $4f
	db "too. Let's get out", $55
	db "of here.", $57
; 0x5a825

GruntM29SeenText: ; 0x5a825
	db $0, "Darn! I was stand-", $4f
	db "ing guard up top", $51
	db "when some old coot", $4f
	db "yelled at me.", $51
	db "He startled me so", $4f
	db "much that I fell", $55
	db "down here.", $51
	db "I think I'll vent", $4f
	db "my anger by taking", $55
	db "it out on you!", $57
; 0x5a8cc

GruntM29BeatenText: ; 0x5a8cc
	db $0, "Arrgh! This is NOT", $4f
	db "my day!", $57
; 0x5a8e8

TrainerGruntM29SlowpokeProfitText: ; 0x5a8e8
	db $0, "Sure, we've been", $4f
	db "hacking the tails", $51
	db "off SLOWPOKE and", $4f
	db "selling them.", $51
	db "Everything we do", $4f
	db "is for profit.", $51
	db "That's right!", $4f
	db "We're TEAM ROCKET,", $51
	db "and we'll do any-", $4f
	db "thing for money!", $57
; 0x5a98b

GruntM1SeenText: ; 0x5a98b
	db $0, "What do you want?", $51
	db "If you interrupt", $4f
	db "our work, don't", $55
	db "expect any mercy!", $57
; 0x5a9d0

GruntM1BeatenText: ; 0x5a9d0
	db $0, "You did OK today,", $4f
	db "but wait till next", $55
	db "time!", $57
; 0x5a9fc

TrainerGruntM1WhenTalkText: ; 0x5a9fc
	db $0, "Yeah, TEAM ROCKET", $4f
	db "was broken up", $55
	db "three years ago.", $51
	db "But we continued", $4f
	db "our activities", $55
	db "underground.", $51
	db "Now you can have", $4f
	db "fun watching us", $55
	db "stir up trouble!", $57
; 0x5aa8d

GruntM2SeenText: ; 0x5aa8d
	db $0, "Quit taking SLOW-", $4f
	db "POKETAILS?", $51
	db "If we obeyed you,", $4f
	db "TEAM ROCKET's rep", $55
	db "would be ruined!", $57
; 0x5aadf

GruntM2BeatenText: ; 0x5aadf
	db $0, "Just…", $4f
	db "Too strong…", $57
; 0x5aaf2

UnknownText_0x5aaf2: ; 0x5aaf2
	db $0, "We need the money,", $4f
	db "but selling SLOW-", $55
	db "POKETAILS?", $51
	db "It's tough being a", $4f
	db "ROCKET GRUNT!", $57
; 0x5ab43

GruntF1SeenText: ; 0x5ab43
	db $0, "Stop taking TAILS?", $51
	db "Yeah, just try to", $4f
	db "defeat all of us!", $57
; 0x5ab7b

GruntF1BeatenText: ; 0x5ab7b
	db $0, "You rotten brat!", $57
; 0x5ab8d

UnknownText_0x5ab8d: ; 0x5ab8d
	db $0, "SLOWPOKETAILS", $4f
	db "grow back fast!", $51
	db "What's wrong with", $4f
	db "selling them?", $57
; 0x5abcb

UnknownText_0x5abcb: ; 0x5abcb
	db $0, "A SLOWPOKE with", $4f
	db "its TAIL cut off…", $51
	db "Huh? It has MAIL.", $4f
	db "Read it?", $57
; 0x5ac09

UnknownText_0x5ac09: ; 0x5ac09
	db $0, $52, " read the", $4f
	db "MAIL.", $51
	db "Be good and look", $4f
	db "after the house", $51
	db "with Grandpa and", $4f
	db "SLOWPOKE.", $51
	db "Love, Dad", $57
; 0x5ac61

UnknownText_0x5ac61: ; 0x5ac61
	db $0, "A SLOWPOKE with", $4f
	db "its TAIL cut off…", $57
; 0x5ac84

SlowpokeWellB1F_MapEventHeader: ; 0x5ac84
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $f, $11, 6, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN
	warp_def $b, $7, 1, GROUP_SLOWPOKE_WELL_B2F, MAP_SLOWPOKE_WELL_B2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 9
	person_event $35, 11, 19, $6, $0, 255, 255, $2, 3, TrainerGruntM29, $06fc
	person_event $35, 6, 9, $6, $0, 255, 255, $2, 1, TrainerGruntM1, $06fc
	person_event $35, 10, 9, $9, $0, 255, 255, $2, 2, TrainerGruntM2, $06fc
	person_event $36, 8, 14, $9, $0, 255, 255, $82, 4, TrainerGruntF1, $06fc
	person_event $45, 8, 11, $1, $0, 255, 255, $80, 0, UnknownScript_0x5a681, $06fb
	person_event $45, 6, 10, $1, $0, 255, 255, $80, 0, UnknownScript_0x5a695, $06fb
	person_event $b, 18, 20, $7, $0, 255, 255, $0, 0, UnknownScript_0x5a5d5, $0740
	person_event $5a, 6, 7, $19, $0, 255, 255, $0, 0, UnknownScript_0x5a6a0, $ffff
	person_event $54, 7, 14, $1, $0, 255, 255, $1, 0, ItemFragment_0x5a6a3, $0662
; 0x5ad09

SlowpokeWellB2F_MapScriptHeader: ; 0x5ad09
	; trigger count
	db 0

	; callback count
	db 0
; 0x5ad0b

UnknownScript_0x5ad0b: ; 0x5ad0b
	faceplayer
	loadfont
	checkbit1 $0073
	iftrue UnknownScript_0x5ad22
	2writetext UnknownText_0x5ad2a
	keeptextopen
	verbosegiveitem KINGS_ROCK, 1
	iffalse UnknownScript_0x5ad20
	setbit1 $0073
UnknownScript_0x5ad20: ; 0x5ad20
	loadmovesprites
	end
; 0x5ad22

UnknownScript_0x5ad22: ; 0x5ad22
	2writetext UnknownText_0x5adf2
	closetext
	loadmovesprites
	end
; 0x5ad28

ItemFragment_0x5ad28: ; 0x5ad28
	db TM_18, 1
; 0x5ad2a

UnknownText_0x5ad2a: ; 0x5ad2a
	db $0, "I'm waiting to see", $4f
	db "SLOWPOKE's moment", $55
	db "of evolution.", $51
	db "Through observa-", $4f
	db "tion, I made a new", $55
	db "discovery.", $51
	db "A SLOWPOKE with a", $4f
	db "KING'S ROCK often", $51
	db "gets bitten by a", $4f
	db "SHELLDER.", $51
	db "Here, I'll share a", $4f
	db "KING'S ROCK with", $55
	db "you.", $57
; 0x5adf2

UnknownText_0x5adf2: ; 0x5adf2
	db $0, "I'm going to be", $4f
	db "like SLOWPOKE.", $51
	db "I'll wait patient-", $4f
	db "ly, so I can see", $55
	db "one evolve.", $57
; 0x5ae40

SlowpokeWellB2F_MapEventHeader: ; 0x5ae40
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $b, $9, 2, GROUP_SLOWPOKE_WELL_B1F, MAP_SLOWPOKE_WELL_B1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $48, 8, 9, $2, $21, 255, 255, $0, 1, UnknownScript_0x5ad0b, $ffff
	person_event $54, 9, 19, $1, $0, 255, 255, $1, 0, ItemFragment_0x5ad28, $0663
; 0x5ae65

OlivineLighthouse1F_MapScriptHeader: ; 0x5ae65
	; trigger count
	db 0

	; callback count
	db 0
; 0x5ae67

UnknownScript_0x5ae67: ; 0x5ae67
	jumptextfaceplayer UnknownText_0x5ae6d
; 0x5ae6a

UnknownScript_0x5ae6a: ; 0x5ae6a
	jumptextfaceplayer UnknownText_0x5aec2
; 0x5ae6d

UnknownText_0x5ae6d: ; 0x5ae6d
	db $0, "People train at", $4f
	db "this LIGHTHOUSE.", $51
	db "It's not easy to", $4f
	db "climb because of", $55
	db "all the trainers.", $57
; 0x5aec2

UnknownText_0x5aec2: ; 0x5aec2
	db $0, "In the past, #-", $4f
	db "MON used to light", $51
	db "the sea around", $4f
	db "OLIVINE at night.", $51
	db "The LIGHTHOUSE was", $4f
	db "made in honor of", $55
	db "those #MON.", $57
; 0x5af36

OlivineLighthouse1F_MapEventHeader: ; 0x5af36
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $11, $a, 9, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $11, $b, 9, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $b, $3, 1, GROUP_OLIVINE_LIGHTHOUSE_2F, MAP_OLIVINE_LIGHTHOUSE_2F
	warp_def $d, $10, 3, GROUP_OLIVINE_LIGHTHOUSE_2F, MAP_OLIVINE_LIGHTHOUSE_2F
	warp_def $d, $11, 4, GROUP_OLIVINE_LIGHTHOUSE_2F, MAP_OLIVINE_LIGHTHOUSE_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $49, 6, 12, $6, $0, 255, 255, $0, 0, UnknownScript_0x5ae67, $ffff
	person_event $2e, 13, 20, $4, $20, 255, 255, $0, 0, UnknownScript_0x5ae6a, $ffff
; 0x5af6f

OlivineLighthouse2F_MapScriptHeader: ; 0x5af6f
	; trigger count
	db 0

	; callback count
	db 0
; 0x5af71

TrainerGentlemanAlfred: ; 0x5af71
	; bit/flag number
	dw $49e

	; trainer group && trainer id
	db GENTLEMAN, ALFRED

	; text when seen
	dw GentlemanAlfredSeenText

	; text when trainer beaten
	dw GentlemanAlfredBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GentlemanAlfredScript
; 0x5af7d

GentlemanAlfredScript: ; 0x5af7d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5b13e
	closetext
	loadmovesprites
	end
; 0x5af85

TrainerSailorHuey1: ; 0x5af85
	; bit/flag number
	dw $576

	; trainer group && trainer id
	db SAILOR, HUEY1

	; text when seen
	dw SailorHuey1SeenText

	; text when trainer beaten
	dw SailorHuey1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SailorHuey1Script
; 0x5af91

SailorHuey1Script: ; 0x5af91
	writecode $17, $7
	talkaftercancel
	loadfont
	checkbit2 $0066
	iftrue UnknownScript_0x5afc7
	checkcellnum $7
	iftrue UnknownScript_0x5b05f
	checkbit1 $0263
	iftrue UnknownScript_0x5afb0
	setbit1 $0263
	2call UnknownScript_0x5b053
	2jump UnknownScript_0x5afb3
; 0x5afb0

UnknownScript_0x5afb0: ; 0x5afb0
	2call UnknownScript_0x5b057
UnknownScript_0x5afb3: ; 0x5afb3
	askforphonenumber $7
	if_equal $1, UnknownScript_0x5b067
	if_equal $2, UnknownScript_0x5b063
	trainertotext SAILOR, HUEY1, $0
	2call UnknownScript_0x5b05b
	2jump UnknownScript_0x5b05f
; 0x5afc7

UnknownScript_0x5afc7: ; 0x5afc7
	2call UnknownScript_0x5b06b
	winlosstext SailorHuey1BeatenText, $0000
	copybytetovar $d9f4
	if_equal $3, UnknownScript_0x5afe2
	if_equal $2, UnknownScript_0x5afe8
	if_equal $1, UnknownScript_0x5afee
	if_equal $0, UnknownScript_0x5aff4
UnknownScript_0x5afe2: ; 0x5afe2
	checkbit1 $00cd
	iftrue UnknownScript_0x5b01b
UnknownScript_0x5afe8: ; 0x5afe8
	checkbit1 $0044
	iftrue UnknownScript_0x5b00e
UnknownScript_0x5afee: ; 0x5afee
	checkbit1 $0021
	iftrue UnknownScript_0x5b001
UnknownScript_0x5aff4: ; 0x5aff4
	loadtrainer SAILOR, HUEY1
	startbattle
	returnafterbattle
	loadvar $d9f4, $1
	clearbit2 $0066
	end
; 0x5b001

UnknownScript_0x5b001: ; 0x5b001
	loadtrainer SAILOR, HUEY2
	startbattle
	returnafterbattle
	loadvar $d9f4, $2
	clearbit2 $0066
	end
; 0x5b00e

UnknownScript_0x5b00e: ; 0x5b00e
	loadtrainer SAILOR, HUEY3
	startbattle
	returnafterbattle
	loadvar $d9f4, $3
	clearbit2 $0066
	end
; 0x5b01b

UnknownScript_0x5b01b: ; 0x5b01b
	loadtrainer SAILOR, HUEY4
	startbattle
	returnafterbattle
	clearbit2 $0066
	checkbit1 $0337
	iftrue UnknownScript_0x5b03f
	checkbit1 $0265
	iftrue UnknownScript_0x5b03e
	2call UnknownScript_0x5b076
	verbosegiveitem PROTEIN, 1
	iffalse UnknownScript_0x5b06f
	setbit1 $0265
	2jump UnknownScript_0x5b05f
; 0x5b03e

UnknownScript_0x5b03e: ; 0x5b03e
	end
; 0x5b03f

UnknownScript_0x5b03f: ; 0x5b03f
	loadfont
	2writetext UnknownText_0x5b1b6
	closetext
	verbosegiveitem PROTEIN, 1
	iffalse UnknownScript_0x5b06f
	clearbit1 $0337
	setbit1 $0265
	2jump UnknownScript_0x5b05f
; 0x5b053

UnknownScript_0x5b053: ; 0x5b053
	jumpstd $0019
	end
; 0x5b057

UnknownScript_0x5b057: ; 0x5b057
	jumpstd $001a
	end
; 0x5b05b

UnknownScript_0x5b05b: ; 0x5b05b
	jumpstd $001b
	end
; 0x5b05f

UnknownScript_0x5b05f: ; 0x5b05f
	jumpstd $001c
	end
; 0x5b063

UnknownScript_0x5b063: ; 0x5b063
	jumpstd $001d
	end
; 0x5b067

UnknownScript_0x5b067: ; 0x5b067
	jumpstd $001e
	end
; 0x5b06b

UnknownScript_0x5b06b: ; 0x5b06b
	jumpstd $001f
	end
; 0x5b06f

UnknownScript_0x5b06f: ; 0x5b06f
	setbit1 $0337
	jumpstd $0021
	end
; 0x5b076

UnknownScript_0x5b076: ; 0x5b076
	jumpstd $0022
	end
; 0x5b07a

SailorHuey1SeenText: ; 0x5b07a
	db $0, "Men of the sea are", $4f
	db "always spoiling", $55
	db "for a good fight!", $57
; 0x5b0b0

SailorHuey1BeatenText: ; 0x5b0b0
	db $0, "Urf!", $4f
	db "I lose!", $57
; 0x5b0be

; possibly unused
UnknownText_0x5b0be: ; 0x5b0be
	db $0, "What power!", $4f
	db "How would you like", $51
	db "to sail the seas", $4f
	db "with me?", $57
; 0x5b0f8

GentlemanAlfredSeenText: ; 0x5b0f8
	db $0, "Hm? This is no", $4f
	db "place for playing.", $57
; 0x5b11b

GentlemanAlfredBeatenText: ; 0x5b11b
	db $0, "Ah! I can see that", $4f
	db "you're serious.", $57
; 0x5b13e

UnknownText_0x5b13e: ; 0x5b13e
	db $0, "Up top is a #-", $4f
	db "MON that keeps the", $55
	db "LIGHTHOUSE lit.", $51
	db "But I hear that", $4f
	db "it's sick now and", $51
	db "can't be cured by", $4f
	db "ordinary medicine.", $57
; 0x5b1b6

UnknownText_0x5b1b6: ; 0x5b1b6
	db $0, "Man! You're as", $4f
	db "tough as ever!", $51
	db "Anyway, here's", $4f
	db "that medicine from", $55
	db "before.", $57
; 0x5b1fd

OlivineLighthouse2F_MapEventHeader: ; 0x5b1fd
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $b, $3, 3, GROUP_OLIVINE_LIGHTHOUSE_1F, MAP_OLIVINE_LIGHTHOUSE_1F
	warp_def $3, $5, 2, GROUP_OLIVINE_LIGHTHOUSE_3F, MAP_OLIVINE_LIGHTHOUSE_3F
	warp_def $d, $10, 4, GROUP_OLIVINE_LIGHTHOUSE_1F, MAP_OLIVINE_LIGHTHOUSE_1F
	warp_def $d, $11, 5, GROUP_OLIVINE_LIGHTHOUSE_1F, MAP_OLIVINE_LIGHTHOUSE_1F
	warp_def $b, $10, 4, GROUP_OLIVINE_LIGHTHOUSE_3F, MAP_OLIVINE_LIGHTHOUSE_3F
	warp_def $b, $11, 5, GROUP_OLIVINE_LIGHTHOUSE_3F, MAP_OLIVINE_LIGHTHOUSE_3F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $49, 7, 13, $9, $0, 255, 255, $92, 3, TrainerSailorHuey1, $ffff
	person_event $40, 12, 21, $8, $0, 255, 255, $92, 3, TrainerGentlemanAlfred, $ffff
; 0x5b23b

OlivineLighthouse3F_MapScriptHeader: ; 0x5b23b
	; trigger count
	db 0

	; callback count
	db 0
; 0x5b23d

TrainerBird_keeperTheo: ; 0x5b23d
	; bit/flag number
	dw $3fe

	; trainer group && trainer id
	db BIRD_KEEPER, THEO

	; text when seen
	dw Bird_keeperTheoSeenText

	; text when trainer beaten
	dw Bird_keeperTheoBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperTheoScript
; 0x5b249

Bird_keeperTheoScript: ; 0x5b249
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5b2df
	closetext
	loadmovesprites
	end
; 0x5b251

TrainerGentlemanPreston: ; 0x5b251
	; bit/flag number
	dw $49a

	; trainer group && trainer id
	db GENTLEMAN, PRESTON

	; text when seen
	dw GentlemanPrestonSeenText

	; text when trainer beaten
	dw GentlemanPrestonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GentlemanPrestonScript
; 0x5b25d

GentlemanPrestonScript: ; 0x5b25d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5b457
	closetext
	loadmovesprites
	end
; 0x5b265

TrainerSailorTerrell: ; 0x5b265
	; bit/flag number
	dw $577

	; trainer group && trainer id
	db SAILOR, TERRELL

	; text when seen
	dw SailorTerrellSeenText

	; text when trainer beaten
	dw SailorTerrellBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SailorTerrellScript
; 0x5b271

SailorTerrellScript: ; 0x5b271
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5b384
	closetext
	loadmovesprites
	end
; 0x5b279

ItemFragment_0x5b279: ; 0x5b279
	db ETHER, 1
; 0x5b27b

Bird_keeperTheoSeenText: ; 0x5b27b
	db $0, "Why are you here?", $4f
	db "Are you just going", $51
	db "to gawk? I suggest", $4f
	db "that you leave!", $57
; 0x5b2c4

Bird_keeperTheoBeatenText: ; 0x5b2c4
	db $0, "You really are", $4f
	db "concerned…", $57
; 0x5b2df

UnknownText_0x5b2df: ; 0x5b2df
	db $0, "How the heck do", $4f
	db "you go up?", $51
	db "I want to visit", $4f
	db "the sick #MON,", $51
	db "but I can't get up", $4f
	db "there…", $57
; 0x5b333

SailorTerrellSeenText: ; 0x5b333
	db $0, "Sailors are both", $4f
	db "kind and strong.", $55
	db "How about you?", $57
; 0x5b365

SailorTerrellBeatenText: ; 0x5b365
	db $0, "You are both kind", $4f
	db "and strong…", $57
; 0x5b384

UnknownText_0x5b384: ; 0x5b384
	db $0, "Every time I come", $4f
	db "back to OLIVINE, I", $55
	db "visit the GYM.", $51
	db "The GYM LEADER's", $4f
	db "#MON type has", $51
	db "changed without me", $4f
	db "noticing.", $57
; 0x5b3f4

GentlemanPrestonSeenText: ; 0x5b3f4
	db $0, "I travel the world", $4f
	db "to train my #-", $55
	db "MON. I wish to", $55
	db "battle with you.", $57
; 0x5b437

GentlemanPrestonBeatenText: ; 0x5b437
	db $0, "…sigh… I must", $4f
	db "train some more…", $57
; 0x5b457

UnknownText_0x5b457: ; 0x5b457
	db $0, "JASMINE used to", $4f
	db "use rock #MON", $55
	db "like ONIX.", $57
; 0x5b481

OlivineLighthouse3F_MapEventHeader: ; 0x5b481
	; filler
	db 0, 0

	; warps
	db 9
	warp_def $3, $d, 1, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F
	warp_def $3, $5, 2, GROUP_OLIVINE_LIGHTHOUSE_2F, MAP_OLIVINE_LIGHTHOUSE_2F
	warp_def $5, $9, 4, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F
	warp_def $b, $10, 5, GROUP_OLIVINE_LIGHTHOUSE_2F, MAP_OLIVINE_LIGHTHOUSE_2F
	warp_def $b, $11, 6, GROUP_OLIVINE_LIGHTHOUSE_2F, MAP_OLIVINE_LIGHTHOUSE_2F
	warp_def $9, $10, 5, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F
	warp_def $9, $11, 6, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F
	warp_def $3, $8, 7, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F
	warp_def $3, $9, 8, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $49, 6, 13, $6, $0, 255, 255, $92, 1, TrainerSailorTerrell, $ffff
	person_event $40, 9, 17, $9, $0, 255, 255, $92, 4, TrainerGentlemanPreston, $ffff
	person_event $27, 13, 7, $7, $0, 255, 255, $92, 3, TrainerBird_keeperTheo, $ffff
	person_event $54, 6, 12, $1, $0, 255, 255, $1, 0, ItemFragment_0x5b279, $0664
; 0x5b4e8

OlivineLighthouse4F_MapScriptHeader: ; 0x5b4e8
	; trigger count
	db 0

	; callback count
	db 0
; 0x5b4ea

TrainerLassConnie1: ; 0x5b4ea
	; bit/flag number
	dw $519

	; trainer group && trainer id
	db LASS, CONNIE1

	; text when seen
	dw LassConnie1SeenText

	; text when trainer beaten
	dw LassConnie1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw LassConnie1Script
; 0x5b4f6

LassConnie1Script: ; 0x5b4f6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5b63c
	closetext
	loadmovesprites
	end
; 0x5b4fe

TrainerSailorKent: ; 0x5b4fe
	; bit/flag number
	dw $578

	; trainer group && trainer id
	db SAILOR, KENT

	; text when seen
	dw SailorKentSeenText

	; text when trainer beaten
	dw SailorKentBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SailorKentScript
; 0x5b50a

SailorKentScript: ; 0x5b50a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5b584
	closetext
	loadmovesprites
	end
; 0x5b512

SailorKentSeenText: ; 0x5b512
	db $0, "JASMINE must be", $4f
	db "worried sick about", $55
	db "the #MON here.", $51
	db "She won't even", $4f
	db "smile these days.", $57
; 0x5b565

SailorKentBeatenText: ; 0x5b565
	db $0, "I can't manage a", $4f
	db "smile either…", $57
; 0x5b584

UnknownText_0x5b584: ; 0x5b584
	db $0, "Speaking of sick,", $4f
	db "I've heard there's", $51
	db "a good PHARMACY in", $4f
	db "CIANWOOD.", $57
; 0x5b5c5

LassConnie1SeenText: ; 0x5b5c5
	db $0, "JASMINE is this", $4f
	db "city's GYM LEADER.", $51
	db "I mean to bring", $4f
	db "her back with me.", $51
	db "Nobody had better", $4f
	db "get in my way!", $57
; 0x5b62b

LassConnie1BeatenText: ; 0x5b62b
	db $0, "Aaack! My #MON!", $57
; 0x5b63c

UnknownText_0x5b63c: ; 0x5b63c
	db $0, "Right. Anybody", $4f
	db "would be worried", $55
	db "if his or her own", $55
	db "#MON were hurt.", $51
	db "I'll pray for the", $4f
	db "#MON here, so", $51
	db "JASMINE can come", $4f
	db "back to the GYM.", $57
; 0x5b6c0

OlivineLighthouse4F_MapEventHeader: ; 0x5b6c0
	; filler
	db 0, 0

	; warps
	db 10
	warp_def $3, $d, 1, GROUP_OLIVINE_LIGHTHOUSE_3F, MAP_OLIVINE_LIGHTHOUSE_3F
	warp_def $5, $3, 2, GROUP_OLIVINE_LIGHTHOUSE_5F, MAP_OLIVINE_LIGHTHOUSE_5F
	warp_def $7, $9, 3, GROUP_OLIVINE_LIGHTHOUSE_5F, MAP_OLIVINE_LIGHTHOUSE_5F
	warp_def $5, $9, 3, GROUP_OLIVINE_LIGHTHOUSE_3F, MAP_OLIVINE_LIGHTHOUSE_3F
	warp_def $9, $10, 6, GROUP_OLIVINE_LIGHTHOUSE_3F, MAP_OLIVINE_LIGHTHOUSE_3F
	warp_def $9, $11, 7, GROUP_OLIVINE_LIGHTHOUSE_3F, MAP_OLIVINE_LIGHTHOUSE_3F
	warp_def $3, $8, 8, GROUP_OLIVINE_LIGHTHOUSE_3F, MAP_OLIVINE_LIGHTHOUSE_3F
	warp_def $3, $9, 9, GROUP_OLIVINE_LIGHTHOUSE_3F, MAP_OLIVINE_LIGHTHOUSE_3F
	warp_def $7, $10, 4, GROUP_OLIVINE_LIGHTHOUSE_5F, MAP_OLIVINE_LIGHTHOUSE_5F
	warp_def $7, $11, 5, GROUP_OLIVINE_LIGHTHOUSE_5F, MAP_OLIVINE_LIGHTHOUSE_5F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $49, 18, 11, $8, $0, 255, 255, $92, 3, TrainerSailorKent, $ffff
	person_event $28, 6, 15, $6, $0, 255, 255, $92, 1, TrainerLassConnie1, $ffff
; 0x5b712

SECTION "bank17",DATA,BANK[$17]

NationalPark_MapScriptHeader: ; 0x5c000
	; trigger count
	db 0

	; callback count
	db 0
; 0x5c002

UnknownScript_0x5c002: ; 0x5c002
	jumptextfaceplayer UnknownText_0x5c1d3
; 0x5c005

UnknownScript_0x5c005: ; 0x5c005
	jumptextfaceplayer UnknownText_0x5c22e
; 0x5c008

UnknownScript_0x5c008: ; 0x5c008
	faceplayer
	loadfont
	checkbit1 $0057
	iftrue UnknownScript_0x5c01d
	2writetext UnknownText_0x5c265
	keeptextopen
	verbosegiveitem QUICK_CLAW, 1
	iffalse UnknownScript_0x5c021
	setbit1 $0057
UnknownScript_0x5c01d: ; 0x5c01d
	2writetext UnknownText_0x5c30d
	closetext
UnknownScript_0x5c021: ; 0x5c021
	loadmovesprites
	end
; 0x5c023

UnknownScript_0x5c023: ; 0x5c023
	jumptextfaceplayer UnknownText_0x5c35d
; 0x5c026

UnknownScript_0x5c026: ; 0x5c026
	jumptextfaceplayer UnknownText_0x5c38f
; 0x5c029

UnknownScript_0x5c029: ; 0x5c029
	jumptextfaceplayer UnknownText_0x5c3bc
; 0x5c02c

UnknownScript_0x5c02c: ; 0x5c02c
	faceplayer
	loadfont
	2writetext UnknownText_0x5c416
	cry PERSIAN
	closetext
	loadmovesprites
	end
; 0x5c037

UnknownScript_0x5c037: ; 0x5c037
	faceplayer
	loadfont
	2writetext UnknownText_0x5c42a
	closetext
	loadmovesprites
	spriteface $e, $0
	end
; 0x5c042

TrainerSchoolboyJack1: ; 0x5c042
	; bit/flag number
	dw $46c

	; trainer group && trainer id
	db SCHOOLBOY, JACK1

	; text when seen
	dw SchoolboyJack1SeenText

	; text when trainer beaten
	dw SchoolboyJack1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyJack1Script
; 0x5c04e

SchoolboyJack1Script: ; 0x5c04e
	writecode $17, $5
	talkaftercancel
	loadfont
	checkbit2 $0065
	iftrue UnknownScript_0x5c088
	checkcellnum $5
	iftrue UnknownScript_0x5c108
	checkbit1 $025f
	iftrue UnknownScript_0x5c071
	2writetext UnknownText_0x5c4f3
	keeptextopen
	setbit1 $025f
	2call UnknownScript_0x5c0fc
	2jump UnknownScript_0x5c074
; 0x5c071

UnknownScript_0x5c071: ; 0x5c071
	2call UnknownScript_0x5c100
UnknownScript_0x5c074: ; 0x5c074
	askforphonenumber $5
	if_equal $1, UnknownScript_0x5c110
	if_equal $2, UnknownScript_0x5c10c
	trainertotext SCHOOLBOY, JACK1, $0
	2call UnknownScript_0x5c104
	2jump UnknownScript_0x5c108
; 0x5c088

UnknownScript_0x5c088: ; 0x5c088
	2call UnknownScript_0x5c114
	winlosstext SchoolboyJack1BeatenText, $0000
	copybytetovar $d9f2
	if_equal $4, UnknownScript_0x5c0a7
	if_equal $3, UnknownScript_0x5c0ad
	if_equal $2, UnknownScript_0x5c0b3
	if_equal $1, UnknownScript_0x5c0b9
	if_equal $0, UnknownScript_0x5c0bf
UnknownScript_0x5c0a7: ; 0x5c0a7
	checkbit1 $00cd
	iftrue UnknownScript_0x5c0f3
UnknownScript_0x5c0ad: ; 0x5c0ad
	checkbit1 $0044
	iftrue UnknownScript_0x5c0e6
UnknownScript_0x5c0b3: ; 0x5c0b3
	checkbit1 $0021
	iftrue UnknownScript_0x5c0d9
UnknownScript_0x5c0b9: ; 0x5c0b9
	checkbit2 $0047
	iftrue UnknownScript_0x5c0cc
UnknownScript_0x5c0bf: ; 0x5c0bf
	loadtrainer SCHOOLBOY, JACK1
	startbattle
	returnafterbattle
	loadvar $d9f2, $1
	clearbit2 $0065
	end
; 0x5c0cc

UnknownScript_0x5c0cc: ; 0x5c0cc
	loadtrainer SCHOOLBOY, JACK2
	startbattle
	returnafterbattle
	loadvar $d9f2, $2
	clearbit2 $0065
	end
; 0x5c0d9

UnknownScript_0x5c0d9: ; 0x5c0d9
	loadtrainer SCHOOLBOY, JACK3
	startbattle
	returnafterbattle
	loadvar $d9f2, $3
	clearbit2 $0065
	end
; 0x5c0e6

UnknownScript_0x5c0e6: ; 0x5c0e6
	loadtrainer SCHOOLBOY, JACK4
	startbattle
	returnafterbattle
	loadvar $d9f2, $4
	clearbit2 $0065
	end
; 0x5c0f3

UnknownScript_0x5c0f3: ; 0x5c0f3
	loadtrainer SCHOOLBOY, JACK5
	startbattle
	returnafterbattle
	clearbit2 $0065
	end
; 0x5c0fc

UnknownScript_0x5c0fc: ; 0x5c0fc
	jumpstd $0019
	end
; 0x5c100

UnknownScript_0x5c100: ; 0x5c100
	jumpstd $001a
	end
; 0x5c104

UnknownScript_0x5c104: ; 0x5c104
	jumpstd $001b
	end
; 0x5c108

UnknownScript_0x5c108: ; 0x5c108
	jumpstd $001c
	end
; 0x5c10c

UnknownScript_0x5c10c: ; 0x5c10c
	jumpstd $001d
	end
; 0x5c110

UnknownScript_0x5c110: ; 0x5c110
	jumpstd $001e
	end
; 0x5c114

UnknownScript_0x5c114: ; 0x5c114
	jumpstd $001f
	end
; 0x5c118

TrainerPokefanmWilliam: ; 0x5c118
	; bit/flag number
	dw $4cd

	; trainer group && trainer id
	db POKEFANM, WILLIAM

	; text when seen
	dw PokefanmWilliamSeenText

	; text when trainer beaten
	dw PokefanmWilliamBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmWilliamScript
; 0x5c124

PokefanmWilliamScript: ; 0x5c124
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5c645
	closetext
	loadmovesprites
	end
; 0x5c12c

TrainerPokefanfBeverly1: ; 0x5c12c
	; bit/flag number
	dw $4d9

	; trainer group && trainer id
	db POKEFANF, BEVERLY1

	; text when seen
	dw PokefanfBeverly1SeenText

	; text when trainer beaten
	dw PokefanfBeverly1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanfBeverly1Script
; 0x5c138

PokefanfBeverly1Script: ; 0x5c138
	writecode $17, $6
	talkaftercancel
	loadfont
	checkbit2 $007d
	iftrue UnknownScript_0x5c177
	checkcellnum $6
	iftrue UnknownScript_0x5c19b
	checkpoke MARILL
	iffalse UnknownScript_0x5c189
	checkbit1 $0261
	iftrue UnknownScript_0x5c160
	2writetext UnknownText_0x5c5bd
	keeptextopen
	setbit1 $0261
	2call UnknownScript_0x5c18f
	2jump UnknownScript_0x5c163
; 0x5c160

UnknownScript_0x5c160: ; 0x5c160
	2call UnknownScript_0x5c193
UnknownScript_0x5c163: ; 0x5c163
	askforphonenumber $6
	if_equal $1, UnknownScript_0x5c1a3
	if_equal $2, UnknownScript_0x5c19f
	trainertotext POKEFANF, BEVERLY1, $0
	2call UnknownScript_0x5c197
	2jump UnknownScript_0x5c19b
; 0x5c177

UnknownScript_0x5c177: ; 0x5c177
	2call UnknownScript_0x5c1a7
	verbosegiveitem NUGGET, 1
	iffalse UnknownScript_0x5c186
	clearbit2 $007d
	2jump UnknownScript_0x5c19b
; 0x5c186

UnknownScript_0x5c186: ; 0x5c186
	2jump UnknownScript_0x5c1ab
; 0x5c189

UnknownScript_0x5c189: ; 0x5c189
	2writetext UnknownText_0x5c68a
	closetext
	loadmovesprites
	end
; 0x5c18f

UnknownScript_0x5c18f: ; 0x5c18f
	jumpstd $0023
	end
; 0x5c193

UnknownScript_0x5c193: ; 0x5c193
	jumpstd $0024
	end
; 0x5c197

UnknownScript_0x5c197: ; 0x5c197
	jumpstd $0025
	end
; 0x5c19b

UnknownScript_0x5c19b: ; 0x5c19b
	jumpstd $0026
	end
; 0x5c19f

UnknownScript_0x5c19f: ; 0x5c19f
	jumpstd $0027
	end
; 0x5c1a3

UnknownScript_0x5c1a3: ; 0x5c1a3
	jumpstd $0028
	end
; 0x5c1a7

UnknownScript_0x5c1a7: ; 0x5c1a7
	jumpstd $002a
	end
; 0x5c1ab

UnknownScript_0x5c1ab: ; 0x5c1ab
	jumpstd $002b
	end
; 0x5c1af

TrainerLassKrise: ; 0x5c1af
	; bit/flag number
	dw $518

	; trainer group && trainer id
	db LASS, KRISE

	; text when seen
	dw LassKriseSeenText

	; text when trainer beaten
	dw LassKriseBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw LassKriseScript
; 0x5c1bb

LassKriseScript: ; 0x5c1bb
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5c71d
	closetext
	loadmovesprites
	end
; 0x5c1c3

MapNationalParkSignpost0Script: ; 0x5c1c3
	jumptext UnknownText_0x5c750
; 0x5c1c6

MapNationalParkSignpost1Script: ; 0x5c1c6
	jumptext UnknownText_0x5c771
; 0x5c1c9

MapNationalParkSignpost3Script: ; 0x5c1c9
	jumptext UnknownText_0x5c7c6
; 0x5c1cc

ItemFragment_0x5c1cc: ; 0x5c1cc
	db PARLYZ_HEAL, 1
; 0x5c1ce

ItemFragment_0x5c1ce: ; 0x5c1ce
	db TM_28, 1
; 0x5c1d0

MapNationalParkSignpostItem2: ; 0x5c1d0
	dw $0084
	db FULL_HEAL
	
; 0x5c1d3

UnknownText_0x5c1d3: ; 0x5c1d3
	db $0, "Look! Check out my", $4f
	db "bag!", $51
	db "I printed out my", $4f
	db "favorites from my", $51
	db "#DEX and stuck", $4f
	db "them on my bag.", $57
; 0x5c22e

UnknownText_0x5c22e: ; 0x5c22e
	db $0, "This is MAIL I got", $4f
	db "from my daughter.", $55
	db "It cheers me up.", $57
; 0x5c265

UnknownText_0x5c265: ; 0x5c265
	db $0, "Pay attention,", $4f
	db "please!", $51
	db "…Oops, I have to", $4f
	db "quit thinking like", $51
	db "a teacher all the", $4f
	db "time.", $51
	db "You must be a", $4f
	db "#MON trainer.", $51
	db "Since you're work-", $4f
	db "ing so hard, I", $51
	db "want you to have", $4f
	db "this.", $57
; 0x5c30d

UnknownText_0x5c30d: ; 0x5c30d
	db $0, "Let a #MON hold", $4f
	db "that QUICK CLAW.", $51
	db "Sometimes it will", $4f
	db "strike first", $55
	db "during battle.", $57
; 0x5c35d

UnknownText_0x5c35d: ; 0x5c35d
	db $0, "I'm playing with", $4f
	db "stickers I printed", $55
	db "from my #DEX.", $57
; 0x5c38f

UnknownText_0x5c38f: ; 0x5c38f
	db $0, "I get the other", $4f
	db "guy's #DEX", $55
	db "sticker if I win.", $57
; 0x5c3bc

UnknownText_0x5c3bc: ; 0x5c3bc
	db $0, "I take walks in", $4f
	db "the PARK, but I", $51
	db "never go into the", $4f
	db "grass.", $51
	db "Trainers always", $4f
	db "want to battle…", $57
; 0x5c416

UnknownText_0x5c416: ; 0x5c416
	db $0, "PERSIAN: Fufushaa!", $57
; 0x5c42a

UnknownText_0x5c42a: ; 0x5c42a
	db $0, "I'm printing out", $4f
	db "my #DEX.", $51
	db "You can also print", $4f
	db "out stuff like", $51
	db "MAIL and your PC", $4f
	db "BOXES.", $57
; 0x5c47e

SchoolboyJack1SeenText: ; 0x5c47e
	db $0, "The world of", $4f
	db "#MON is deep.", $51
	db "There are still", $4f
	db "lots of things we", $55
	db "don't know.", $51
	db "But I know more", $4f
	db "than you do!", $57
; 0x5c4e4

SchoolboyJack1BeatenText: ; 0x5c4e4
	db $0, "Wha-wha-what?", $57
; 0x5c4f3

UnknownText_0x5c4f3: ; 0x5c4f3
	db $0, "There is a lot", $4f
	db "to learn.", $51
	db "For example…", $51
	db "There are 50 kinds", $4f
	db "of TMs.", $51
	db "Traded #MON", $4f
	db "level up faster.", $57
; 0x5c552

PokefanfBeverly1SeenText: ; 0x5c552
	db $0, "My #MON are", $4f
	db "simply darling.", $51
	db "Let me tell you", $4f
	db "how proud my", $55
	db "darlings make me.", $57
; 0x5c59e

PokefanfBeverly1BeatenText: ; 0x5c59e
	db $0, "I can beat you in", $4f
	db "pride, but…", $57
; 0x5c5bd

UnknownText_0x5c5bd: ; 0x5c5bd
	db $0, "I must say, your", $4f
	db "#MON are quite", $55
	db "cute, too.", $57
; 0x5c5e9

PokefanmWilliamSeenText: ; 0x5c5e9
	db $0, "We adore our #-", $4f
	db "MON, even if they", $55
	db "dislike us.", $51
	db "That's what being", $4f
	db "a FAN is about.", $57
; 0x5c639

PokefanmWilliamBeatenText: ; 0x5c639
	db $0, "M-my #MON!", $57
; 0x5c645

UnknownText_0x5c645: ; 0x5c645
	db $0, "I lost the battle,", $4f
	db "but my #MON win", $51
	db "the prize for", $4f
	db "being most lovely.", $57
; 0x5c68a

UnknownText_0x5c68a: ; 0x5c68a
	db $0, "My friend keeps a", $4f
	db "MARILL!", $51
	db "I find them very", $4f
	db "endearing.", $51
	db "Oh, I wish for a", $4f
	db "MARILL of my own…", $57
; 0x5c6e4

LassKriseSeenText: ; 0x5c6e4
	db $0, "Hello? Why are you", $4f
	db "staring at me?", $51
	db "Oh, a battle?", $57
; 0x5c715

LassKriseBeatenText: ; 0x5c715
	db $0, "…Hmmm…", $57
; 0x5c71d

UnknownText_0x5c71d: ; 0x5c71d
	db $0, "I thought you were", $4f
	db "staring at me", $55
	db "because I'm cute!", $57
; 0x5c750

UnknownText_0x5c750: ; 0x5c750
	db $0, "RELAXATION SQUARE", $4f
	db "NATIONAL PARK", $57
; 0x5c771

UnknownText_0x5c771: ; 0x5c771
	db $0, "What is this", $4f
	db "notice?", $51
	db "Please battle only", $4f
	db "in the grass.", $51
	db "NATIONAL PARK", $4f
	db "WARDEN'S OFFICE", $57
; 0x5c7c6

UnknownText_0x5c7c6: ; 0x5c7c6
	db $0, "TRAINER TIPS", $51
	db "Print out MAIL by", $4f
	db "opening it then", $55
	db "pressing START.", $57
; 0x5c806

NationalPark_MapEventHeader: ; 0x5c806
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $12, $21, 1, GROUP_ROUTE_36_NATIONAL_PARK_GATE, MAP_ROUTE_36_NATIONAL_PARK_GATE
	warp_def $13, $21, 2, GROUP_ROUTE_36_NATIONAL_PARK_GATE, MAP_ROUTE_36_NATIONAL_PARK_GATE
	warp_def $2f, $a, 1, GROUP_ROUTE_35_NATIONAL_PARK_GATE, MAP_ROUTE_35_NATIONAL_PARK_GATE
	warp_def $2f, $b, 2, GROUP_ROUTE_35_NATIONAL_PARK_GATE, MAP_ROUTE_35_NATIONAL_PARK_GATE

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 44, 14, $0, MapNationalParkSignpost0Script
	signpost 31, 27, $0, MapNationalParkSignpost1Script
	signpost 47, 6, $7, MapNationalParkSignpostItem2
	signpost 4, 12, $0, MapNationalParkSignpost3Script

	; people-events
	db 14
	person_event $28, 28, 19, $5, $1, 255, 255, $a0, 0, UnknownScript_0x5c002, $ffff
	person_event $2e, 8, 18, $6, $0, 255, 255, $0, 0, UnknownScript_0x5c005, $ffff
	person_event $29, 44, 31, $6, $0, 255, 255, $a0, 0, UnknownScript_0x5c008, $ffff
	person_event $27, 45, 15, $8, $0, 255, 255, $0, 0, UnknownScript_0x5c023, $ffff
	person_event $27, 45, 14, $6, $0, 255, 255, $80, 0, UnknownScript_0x5c026, $ffff
	person_event $29, 45, 21, $2, $21, 255, 255, $0, 0, UnknownScript_0x5c029, $ffff
	person_event $82, 44, 30, $16, $0, 255, 255, $0, 0, UnknownScript_0x5c02c, $ffff
	person_event $27, 27, 31, $a, $0, 255, 255, $92, 3, TrainerSchoolboyJack1, $ffff
	person_event $2e, 33, 22, $a, $0, 255, 255, $82, 2, TrainerPokefanfBeverly1, $ffff
	person_event $2d, 13, 20, $a, $0, 255, 255, $82, 2, TrainerPokefanmWilliam, $ffff
	person_event $28, 18, 12, $a, $0, 255, 255, $92, 3, TrainerLassKrise, $ffff
	person_event $54, 16, 39, $1, $0, 255, 255, $1, 0, ItemFragment_0x5c1cc, $0658
	person_event $3, 10, 30, $6, $0, 255, 255, $0, 0, UnknownScript_0x5c037, $ffff
	person_event $54, 47, 5, $1, $0, 255, 255, $1, 0, ItemFragment_0x5c1ce, $0659
; 0x5c8ea

NationalParkBugContest_MapScriptHeader: ; 0x5c8ea
	; trigger count
	db 0

	; callback count
	db 0
; 0x5c8ec

UnknownScript_0x5c8ec: ; 0x5c8ec
	faceplayer
	loadfont
	2writetext UnknownText_0x5c94c
	closetext
	loadmovesprites
	end
; 0x5c8f4

UnknownScript_0x5c8f4: ; 0x5c8f4
	faceplayer
	loadfont
	2writetext UnknownText_0x5c973
	closetext
	loadmovesprites
	end
; 0x5c8fc

UnknownScript_0x5c8fc: ; 0x5c8fc
	faceplayer
	loadfont
	2writetext UnknownText_0x5c9a3
	closetext
	loadmovesprites
	end
; 0x5c904

UnknownScript_0x5c904: ; 0x5c904
	faceplayer
	loadfont
	2writetext UnknownText_0x5c9cc
	closetext
	loadmovesprites
	end
; 0x5c90c

UnknownScript_0x5c90c: ; 0x5c90c
	faceplayer
	loadfont
	2writetext UnknownText_0x5ca15
	closetext
	loadmovesprites
	end
; 0x5c914

UnknownScript_0x5c914: ; 0x5c914
	faceplayer
	loadfont
	2writetext UnknownText_0x5ca52
	closetext
	loadmovesprites
	end
; 0x5c91c

UnknownScript_0x5c91c: ; 0x5c91c
	faceplayer
	loadfont
	2writetext UnknownText_0x5ca8f
	closetext
	loadmovesprites
	end
; 0x5c924

UnknownScript_0x5c924: ; 0x5c924
	faceplayer
	loadfont
	2writetext UnknownText_0x5cac8
	closetext
	loadmovesprites
	end
; 0x5c92c

UnknownScript_0x5c92c: ; 0x5c92c
	faceplayer
	loadfont
	2writetext UnknownText_0x5cb25
	closetext
	loadmovesprites
	end
; 0x5c934

UnknownScript_0x5c934: ; 0x5c934
	faceplayer
	loadfont
	2writetext UnknownText_0x5cb64
	closetext
	loadmovesprites
	end
; 0x5c93c

MapNationalParkBugContestSignpost0Script: ; 0x5c93c
	jumptext UnknownText_0x5cba7
; 0x5c93f

MapNationalParkBugContestSignpost1Script: ; 0x5c93f
	jumptext UnknownText_0x5cbc8
; 0x5c942

MapNationalParkBugContestSignpost3Script: ; 0x5c942
	jumptext UnknownText_0x5cc1d
; 0x5c945

ItemFragment_0x5c945: ; 0x5c945
	db PARLYZ_HEAL, 1
; 0x5c947

ItemFragment_0x5c947: ; 0x5c947
	db TM_28, 1
; 0x5c949

MapNationalParkBugContestSignpostItem2: ; 0x5c949
	dw $0084
	db FULL_HEAL
	
; 0x5c94c

UnknownText_0x5c94c: ; 0x5c94c
	db $0, "DON: I'm going to", $4f
	db "win! Don't bother", $55
	db "me.", $57
; 0x5c973

UnknownText_0x5c973: ; 0x5c973
	db $0, "ED: My PARASECT", $4f
	db "puts #MON to", $55
	db "sleep with SPORE.", $57
; 0x5c9a3

UnknownText_0x5c9a3: ; 0x5c9a3
	db $0, "NICK: I'm raising", $4f
	db "fast #MON for", $55
	db "battles.", $57
; 0x5c9cc

UnknownText_0x5c9cc: ; 0x5c9cc
	db $0, "WILLIAM: I'm not", $4f
	db "concerned about", $55
	db "winning.", $51
	db "I'm just looking", $4f
	db "for rare #MON.", $57
; 0x5ca15

UnknownText_0x5ca15: ; 0x5ca15
	db $0, "BENNY: Ssh! You'll", $4f
	db "scare off SCYTHER.", $51
	db "I'll talk to you", $4f
	db "later.", $57
; 0x5ca52

UnknownText_0x5ca52: ; 0x5ca52
	db $0, "BARRY: You should", $4f
	db "weaken bug #MON", $51
	db "first, then throw", $4f
	db "a BALL.", $57
; 0x5ca8f

UnknownText_0x5ca8f: ; 0x5ca8f
	db $0, "CINDY: I love bug", $4f
	db "#MON.", $51
	db "I guess you must", $4f
	db "like them too.", $57
; 0x5cac8

UnknownText_0x5cac8: ; 0x5cac8
	db $0, "JOSH: I've been", $4f
	db "collecting bug", $51
	db "#MON since I", $4f
	db "was just a baby.", $51
	db "There's no way I'm", $4f
	db "going to lose!", $57
; 0x5cb25

UnknownText_0x5cb25: ; 0x5cb25
	db $0, "SAMUEL: If you've", $4f
	db "got the time to", $51
	db "chat, go find some", $4f
	db "bug #MON.", $57
; 0x5cb64

UnknownText_0x5cb64: ; 0x5cb64
	db $0, "KIPP: I've studied", $4f
	db "about bug #MON", $55
	db "a lot.", $51
	db "I'm going to win", $4f
	db "for sure.", $57
; 0x5cba7

UnknownText_0x5cba7: ; 0x5cba7
	db $0, "RELAXATION SQUARE", $4f
	db "NATIONAL PARK", $57
; 0x5cbc8

UnknownText_0x5cbc8: ; 0x5cbc8
	db $0, "What is this", $4f
	db "notice?", $51
	db "Please battle only", $4f
	db "in the grass.", $51
	db "NATIONAL PARK", $4f
	db "WARDEN'S OFFICE", $57
; 0x5cc1d

UnknownText_0x5cc1d: ; 0x5cc1d
	db $0, "TRAINER TIPS", $51
	db "Print out MAIL by", $4f
	db "opening it then", $55
	db "pressing START.", $57
; 0x5cc5d

NationalParkBugContest_MapEventHeader: ; 0x5cc5d
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $12, $21, 1, GROUP_ROUTE_36_NATIONAL_PARK_GATE, MAP_ROUTE_36_NATIONAL_PARK_GATE
	warp_def $13, $21, 1, GROUP_ROUTE_36_NATIONAL_PARK_GATE, MAP_ROUTE_36_NATIONAL_PARK_GATE
	warp_def $2f, $a, 1, GROUP_ROUTE_35_NATIONAL_PARK_GATE, MAP_ROUTE_35_NATIONAL_PARK_GATE
	warp_def $2f, $b, 1, GROUP_ROUTE_35_NATIONAL_PARK_GATE, MAP_ROUTE_35_NATIONAL_PARK_GATE

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 44, 14, $0, MapNationalParkBugContestSignpost0Script
	signpost 31, 27, $0, MapNationalParkBugContestSignpost1Script
	signpost 47, 6, $7, MapNationalParkBugContestSignpostItem2
	signpost 4, 12, $0, MapNationalParkBugContestSignpost3Script

	; people-events
	db 12
	person_event $27, 33, 23, $2, $22, 255, 255, $80, 0, UnknownScript_0x5c8ec, $0716
	person_event $27, 26, 32, $2, $22, 255, 255, $a0, 0, UnknownScript_0x5c8f4, $0717
	person_event $2c, 22, 13, $7, $0, 255, 255, $90, 0, UnknownScript_0x5c8fc, $0718
	person_event $2d, 17, 11, $4, $1, 255, 255, $b0, 0, UnknownScript_0x5c904, $0719
	person_event $27, 13, 27, $3, $0, 255, 255, $80, 0, UnknownScript_0x5c90c, $071a
	person_event $27, 17, 31, $2, $33, 255, 255, $a0, 0, UnknownScript_0x5c914, $071b
	person_event $28, 27, 11, $5, $2, 255, 255, $90, 0, UnknownScript_0x5c91c, $071c
	person_event $27, 31, 15, $2, $11, 255, 255, $80, 0, UnknownScript_0x5c924, $071d
	person_event $27, 12, 20, $2, $11, 255, 255, $a0, 0, UnknownScript_0x5c92c, $071e
	person_event $27, 38, 21, $2, $33, 255, 255, $90, 0, UnknownScript_0x5c934, $071f
	person_event $54, 16, 39, $1, $0, 255, 255, $1, 0, ItemFragment_0x5c945, $0658
	person_event $54, 47, 5, $1, $0, 255, 255, $1, 0, ItemFragment_0x5c947, $0659
; 0x5cd27

RadioTower1F_MapScriptHeader: ; 0x5cd27
	; trigger count
	db 0

	; callback count
	db 0
; 0x5cd29

UnknownScript_0x5cd29: ; 0x5cd29
	faceplayer
	loadfont
	checkbit2 $0013
	iftrue UnknownScript_0x5cd37
	2writetext UnknownText_0x5ce77
	closetext
	loadmovesprites
	end
; 0x5cd37

UnknownScript_0x5cd37: ; 0x5cd37
	2writetext UnknownText_0x5ce81
	closetext
	loadmovesprites
	end
; 0x5cd3d

UnknownScript_0x5cd3d: ; 0x5cd3d
	faceplayer
	loadfont
	2writetext UnknownText_0x5ceba
	keeptextopen
	special $0053
	iffalse UnknownScript_0x5cd4c
	special $0054
UnknownScript_0x5cd4c: ; 0x5cd4c
	special $0055
	checkbit2 $004e
	iftrue UnknownScript_0x5cd84
	2writetext UnknownText_0x5cf3a
	keeptextopen
	loadmovesprites
	applymovement $6, MovementData_0x5ce71
	loadfont
	2writetext UnknownText_0x5cf5a
	keeptextopen
	waitbutton
	2writetext UnknownText_0x5cf79
	playsound $0009
	waitbutton
	keeptextopen
	special $0052
	loadmovesprites
	applymovement $6, MovementData_0x5ce74
	loadfont
	if_equal $1, UnknownScript_0x5cd8a
	if_equal $2, UnknownScript_0x5cd9f
	if_equal $3, UnknownScript_0x5cdb4
	2jump UnknownScript_0x5cdc9
; 0x5cd84

UnknownScript_0x5cd84: ; 0x5cd84
	2writetext UnknownText_0x5cf7e
	closetext
	loadmovesprites
	end
; 0x5cd8a

UnknownScript_0x5cd8a: ; 0x5cd8a
	2writetext UnknownText_0x5cfb5
	playsound $0099
	waitbutton
	keeptextopen
	giveitem MASTER_BALL, $1
	iffalse UnknownScript_0x5cdcf
	itemnotify
	setbit2 $004e
	2jump UnknownScript_0x5cd84
; 0x5cd9f

UnknownScript_0x5cd9f: ; 0x5cd9f
	2writetext UnknownText_0x5d023
	playsound $0098
	waitbutton
	keeptextopen
	giveitem EXP_SHARE, $1
	iffalse UnknownScript_0x5cdcf
	itemnotify
	setbit2 $004e
	2jump UnknownScript_0x5cd84
; 0x5cdb4

UnknownScript_0x5cdb4: ; 0x5cdb4
	2writetext UnknownText_0x5d076
	playsound $0094
	waitbutton
	keeptextopen
	giveitem PP_UP, $1
	iffalse UnknownScript_0x5cdcf
	itemnotify
	setbit2 $004e
	2jump UnknownScript_0x5cd84
; 0x5cdc9

UnknownScript_0x5cdc9: ; 0x5cdc9
	2writetext UnknownText_0x5d0c0
	closetext
	loadmovesprites
	end
; 0x5cdcf

UnknownScript_0x5cdcf: ; 0x5cdcf
	2writetext UnknownText_0x5d0e6
	closetext
	loadmovesprites
	end
; 0x5cdd5

UnknownScript_0x5cdd5: ; 0x5cdd5
	faceplayer
	loadfont
	checkbit2 $0000
	iftrue UnknownScript_0x5ce2d
	2writetext UnknownText_0x5d12d
	yesorno
	iffalse UnknownScript_0x5ce4b
	2writetext UnknownText_0x5d1f2
	yesorno
	iffalse UnknownScript_0x5ce42
	playsound $0027
	waitbutton
	2writetext UnknownText_0x5d231
	yesorno
	iffalse UnknownScript_0x5ce42
	playsound $0027
	waitbutton
	2writetext UnknownText_0x5d282
	yesorno
	iftrue UnknownScript_0x5ce42
	playsound $0027
	waitbutton
	2writetext UnknownText_0x5d2bc
	yesorno
	iffalse UnknownScript_0x5ce42
	playsound $0027
	waitbutton
	2writetext UnknownText_0x5d30e
	yesorno
	iftrue UnknownScript_0x5ce42
	playsound $0027
	waitbutton
	2writetext UnknownText_0x5d37b
	keeptextopen
	stringtotext RadioCardText, $1
	2call UnknownScript_0x5ce3e
	2writetext UnknownText_0x5d3c0
	keeptextopen
	setbit2 $0000
UnknownScript_0x5ce2d: ; 0x5ce2d
	2writetext UnknownText_0x5d3e5
	closetext
	loadmovesprites
	end
; 0x5ce33

RadioCardText: ; 0x5ce33
	db "RADIO CARD@"
; 0x5ce3d

UnknownScript_0x5ce3e: ; 0x5ce3e
	jumpstd $002f
	end
; 0x5ce42

UnknownScript_0x5ce42: ; 0x5ce42
	playsound $0019
	2writetext UnknownText_0x5d409
	closetext
	loadmovesprites
	end
; 0x5ce4b

UnknownScript_0x5ce4b: ; 0x5ce4b
	2writetext UnknownText_0x5d443
	closetext
	loadmovesprites
	end
; 0x5ce51

UnknownScript_0x5ce51: ; 0x5ce51
	jumptextfaceplayer UnknownText_0x5d476
; 0x5ce54

UnknownScript_0x5ce54: ; 0x5ce54
	jumptextfaceplayer UnknownText_0x5d4ac
; 0x5ce57

TrainerGruntM3: ; 0x5ce57
	; bit/flag number
	dw $4f3

	; trainer group && trainer id
	db GRUNTM, 3

	; text when seen
	dw GruntM3SeenText

	; text when trainer beaten
	dw GruntM3BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM3Script
; 0x5ce63

GruntM3Script: ; 0x5ce63
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5d5a2
	closetext
	loadmovesprites
	end
; 0x5ce6b

MapRadioTower1FSignpost0Script: ; 0x5ce6b
	jumptext UnknownText_0x5d5e7
; 0x5ce6e

MapRadioTower1FSignpost1Script: ; 0x5ce6e
	jumptext UnknownText_0x5d631
; 0x5ce71

MovementData_0x5ce71: ; 0x5ce71
	step_right
	turn_head_up
	step_end
; 0x5ce74

MovementData_0x5ce74: ; 0x5ce74
	step_left
	turn_head_up
	step_end
; 0x5ce77

UnknownText_0x5ce77: ; 0x5ce77
	db $0, "Welcome!", $57
; 0x5ce81

UnknownText_0x5ce81: ; 0x5ce81
	db $0, "Hello. I'm sorry,", $4f
	db "but we're not", $55
	db "offering any tours", $55
	db "today.", $57
; 0x5ceba

UnknownText_0x5ceba: ; 0x5ceba
	db $0, "Hi, are you here", $4f
	db "for the LUCKY NUM-", $55
	db "BER SHOW?", $51
	db "Want me to check", $4f
	db "the ID numbers of", $55
	db "your #MON?", $51
	db "If you get lucky,", $4f
	db "you win a prize.", $57
; 0x5cf3a

UnknownText_0x5cf3a: ; 0x5cf3a
	db $0, "This week's ID", $4f
	db "number is @"
	text_from_ram $d099
	db $0, ".", $57
; 0x5cf5a

UnknownText_0x5cf5a: ; 0x5cf5a
	db $0, "Let's see if you", $4f
	db "have a match.", $57
; 0x5cf79

UnknownText_0x5cf79: ; 0x5cf79
	db $0, $56, $4f
	db $56, $57
; 0x5cf7e

UnknownText_0x5cf7e: ; 0x5cf7e
	db $0, "Please come back", $4f
	db "next week for the", $55
	db "next LUCKY NUMBER.", $57
; 0x5cfb5

UnknownText_0x5cfb5: ; 0x5cfb5
	db $0, "Wow! You have a", $4f
	db "perfect match of", $55
	db "all five numbers!", $51
	db "We have a grand", $4f
	db "prize winner!", $51
	db "You have won a", $4f
	db "MASTER BALL!", $57
; 0x5d023

UnknownText_0x5d023: ; 0x5d023
	db $0, "Hey! You've", $4f
	db "matched the last", $55
	db "three numbers!", $51
	db "You've won second", $4f
	db "prize, an EXP.", $55
	db "SHARE!", $57
; 0x5d076

UnknownText_0x5d076: ; 0x5d076
	db $0, "Ooh, you've", $4f
	db "matched the last", $55
	db "two numbers.", $51
	db "You've won third", $4f
	db "prize, a PP UP.", $57
; 0x5d0c0

UnknownText_0x5d0c0: ; 0x5d0c0
	db $0, "Nope, none of your", $4f
	db "ID numbers match.", $57
; 0x5d0e6

UnknownText_0x5d0e6: ; 0x5d0e6
	db $0, "You've got no room", $4f
	db "for your prize.", $51
	db "Make room and come", $4f
	db "back right away.", $57
; 0x5d12d

UnknownText_0x5d12d: ; 0x5d12d
	db $0, "We have a special", $4f
	db "quiz campaign on", $55
	db "right now.", $51
	db "Answer five ques-", $4f
	db "tions correctly to", $55
	db "win a RADIO CARD.", $51
	db "Slide it into your", $4f
	db "#GEAR to play", $51
	db "the radio anytime,", $4f
	db "anywhere.", $51
	db "Would you like to", $4f
	db "take the quiz?", $57
; 0x5d1f2

UnknownText_0x5d1f2: ; 0x5d1f2
	db $0, "Question 1:", $51
	db "Is there a #MON", $4f
	db "that appears only", $55
	db "in the morning?", $57
; 0x5d231

UnknownText_0x5d231: ; 0x5d231
	db $0, "Correct!", $4f
	db "Question 2:", $51
	db "Is this statement", $4f
	db "correct?", $51
	db "You can't buy a", $4f
	db "BERRY at a MART.", $57
; 0x5d282

UnknownText_0x5d282: ; 0x5d282
	db $0, "Bull's-eye!", $4f
	db "Question 3:", $51
	db "Does HM01 contain", $4f
	db "the move FLASH?", $57
; 0x5d2bc

UnknownText_0x5d2bc: ; 0x5d2bc
	db $0, "So far so good!", $4f
	db "Question 4:", $51
	db "Is FALKNER the", $4f
	db "VIOLET GYM LEADER", $51
	db "who uses bird", $4f
	db "#MON?", $57
; 0x5d30e

UnknownText_0x5d30e: ; 0x5d30e
	db $0, "Wow! Right again!", $4f
	db "Here's the final", $55
	db "question:", $51
	db "Do GOLDENROD GAME", $4f
	db "CORNER's slots", $51
	db "have CHARMANDER", $4f
	db "on their reels?", $57
; 0x5d37b

UnknownText_0x5d37b: ; 0x5d37b
	db $0, "Bingo! You got it!", $4f
	db "Congratulations!", $51
	db "Here's your prize,", $4f
	db "a RADIO CARD!", $57
; 0x5d3c0

UnknownText_0x5d3c0: ; 0x5d3c0
	db $0, $52, "'s #GEAR", $4f
	db "can now double as", $55
	db "a radio!", $57
; 0x5d3e5

UnknownText_0x5d3e5: ; 0x5d3e5
	db $0, "Please tune in to", $4f
	db "our radio shows.", $57
; 0x5d409

UnknownText_0x5d409: ; 0x5d409
	db $0, "Oh, dear.", $4f
	db "Sorry, but you", $51
	db "got it wrong.", $4f
	db "Please try again!", $57
; 0x5d443

UnknownText_0x5d443: ; 0x5d443
	db $0, "Oh. I see. Please", $4f
	db "see me if you", $55
	db "change your mind.", $57
; 0x5d476

UnknownText_0x5d476: ; 0x5d476
	db $0, "BEN is a fabulous", $4f
	db "DJ.", $51
	db "His sweet voice", $4f
	db "makes me melt!", $57
; 0x5d4ac

UnknownText_0x5d4ac: ; 0x5d4ac
	db $0, "I love MARY, from", $4f
	db "#MON TALK.", $51
	db "I only know what", $4f
	db "she sounds like,", $55
	db "though.", $57
; 0x5d4f4

GruntM3SeenText: ; 0x5d4f4
	db $0, "We've finally", $4f
	db "taken over the", $55
	db "RADIO TOWER!", $51
	db "Now everyone will", $4f
	db "get to experience", $51
	db "the true terror of", $4f
	db "TEAM ROCKET!", $51
	db "We'll show you", $4f
	db "how scary we are!", $57
; 0x5d582

GruntM3BeatenText: ; 0x5d582
	db $0, "Too strong! We", $4f
	db "must watch you…", $57
; 0x5d5a2

UnknownText_0x5d5a2: ; 0x5d5a2
	db $0, "You're too strong.", $51
	db "Our plan could be", $4f
	db "ruined. I must", $55
	db "warn the others…", $57
; 0x5d5e7

UnknownText_0x5d5e7: ; 0x5d5e7
	db $0, "1F RECEPTION", $4f
	db "2F SALES", $51
	db "3F PERSONNEL", $4f
	db "4F PRODUCTION", $51
	db "5F DIRECTOR'S", $4f
	db "   OFFICE", $57
; 0x5d631

UnknownText_0x5d631: ; 0x5d631
	db $0, "LUCKY CHANNEL!", $51
	db "Win with #MON", $4f
	db "ID numbers!", $51
	db "Trade your #MON", $4f
	db "to collect differ-", $55
	db "ent ID numbers!", $57
; 0x5d68e

RadioTower1F_MapEventHeader: ; 0x5d68e
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $2, 11, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $3, 11, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $0, $f, 2, GROUP_RADIO_TOWER_2F, MAP_RADIO_TOWER_2F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 3, $0, MapRadioTower1FSignpost0Script
	signpost 0, 13, $0, MapRadioTower1FSignpost1Script

	; people-events
	db 6
	person_event $42, 10, 9, $8, $0, 255, 255, $80, 0, UnknownScript_0x5cd29, $ffff
	person_event $28, 8, 20, $8, $0, 255, 255, $80, 0, UnknownScript_0x5ce51, $06cf
	person_event $27, 8, 19, $9, $0, 255, 255, $90, 0, UnknownScript_0x5ce54, $06cf
	person_event $35, 5, 18, $6, $0, 255, 255, $2, 3, TrainerGruntM3, $06ce
	person_event $40, 10, 12, $7, $0, 255, 255, $90, 0, UnknownScript_0x5cd3d, $06cf
	person_event $24, 10, 16, $7, $0, 255, 255, $a0, 0, UnknownScript_0x5cdd5, $06cf
; 0x5d6fb

RadioTower2F_MapScriptHeader: ; 0x5d6fb
	; trigger count
	db 0

	; callback count
	db 0
; 0x5d6fd

UnknownScript_0x5d6fd: ; 0x5d6fd
	end
; 0x5d6fe

UnknownScript_0x5d6fe: ; 0x5d6fe
	jumptextfaceplayer UnknownText_0x5d924
; 0x5d701

UnknownScript_0x5d701: ; 0x5d701
	faceplayer
	loadfont
	checkbit2 $0013
	iftrue UnknownScript_0x5d70f
	2writetext UnknownText_0x5d956
	closetext
	loadmovesprites
	end
; 0x5d70f

UnknownScript_0x5d70f: ; 0x5d70f
	2writetext UnknownText_0x5d983
	closetext
	loadmovesprites
	end
; 0x5d715

UnknownScript_0x5d715: ; 0x5d715
	loadfont
	2writetext UnknownText_0x5d9b6
	cry JIGGLYPUFF
	closetext
	loadmovesprites
	end
; 0x5d71f

UnknownScript_0x5d71f: ; 0x5d71f
	jumptextfaceplayer UnknownText_0x5d9cb
; 0x5d722

UnknownScript_0x5d722: ; 0x5d722
	jumptextfaceplayer UnknownText_0x5da44
; 0x5d725

TrainerGruntM4: ; 0x5d725
	; bit/flag number
	dw $4f4

	; trainer group && trainer id
	db GRUNTM, 4

	; text when seen
	dw GruntM4SeenText

	; text when trainer beaten
	dw GruntM4BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM4Script
; 0x5d731

GruntM4Script: ; 0x5d731
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5db07
	closetext
	loadmovesprites
	end
; 0x5d739

TrainerGruntM5: ; 0x5d739
	; bit/flag number
	dw $4f5

	; trainer group && trainer id
	db GRUNTM, 5

	; text when seen
	dw GruntM5SeenText

	; text when trainer beaten
	dw GruntM5BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM5Script
; 0x5d745

GruntM5Script: ; 0x5d745
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5db99
	closetext
	loadmovesprites
	end
; 0x5d74d

TrainerGruntM6: ; 0x5d74d
	; bit/flag number
	dw $4f6

	; trainer group && trainer id
	db GRUNTM, 6

	; text when seen
	dw GruntM6SeenText

	; text when trainer beaten
	dw GruntM6BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM6Script
; 0x5d759

GruntM6Script: ; 0x5d759
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5dc00
	closetext
	loadmovesprites
	end
; 0x5d761

TrainerGruntF2: ; 0x5d761
	; bit/flag number
	dw $511

	; trainer group && trainer id
	db GRUNTF, 2

	; text when seen
	dw GruntF2SeenText

	; text when trainer beaten
	dw GruntF2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntF2Script
; 0x5d76d

GruntF2Script: ; 0x5d76d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5dcd0
	closetext
	loadmovesprites
	end
; 0x5d775

UnknownScript_0x5d775: ; 0x5d775
	faceplayer
	loadfont
	checkbit2 $0013
	iftrue UnknownScript_0x5d865
	checkbit1 $033d
	iffalse UnknownScript_0x5d800
	checkbit2 $0060
	iftrue UnknownScript_0x5d82f
	checkcode $a
	if_greater_than $12, UnknownScript_0x5d893
	checkbit2 $005f
	iffalse UnknownScript_0x5d80a
	checkitem BLUE_CARD
	iffalse UnknownScript_0x5d86b
	checkcode $18
	if_equal $1e, UnknownScript_0x5d87f
	playmusic $0060
	2writetext UnknownText_0x5de35
	special $00a3
	iffalse UnknownScript_0x5d81e
	2writetext UnknownText_0x5de84
	closetext
	loadmovesprites
	spriteface $b, $3
	checkcode $9
	if_not_equal $3, UnknownScript_0x5d7be
	applymovement $0, MovementData_0x5d921
UnknownScript_0x5d7be: ; 0x5d7be
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x5dedd
	closetext
	loadmovesprites
	spriteface $b, $0
	refreshscreen $0
	special $0092
	loadmovesprites
	iffalse UnknownScript_0x5d845
	loadfont
	2writetext UnknownText_0x5dfc1
	closetext
	loadmovesprites
	checkcode $18
	addvar $1
	writevarcode $18
	waitbutton
	playsound $0022
	setbit2 $0060
	pause 20
	spriteface $b, $3
	loadfont
	2writetext UnknownText_0x5e054
	closetext
	loadmovesprites
	special $006a
	pause 20
	special $003d
	checkcode $18
	if_equal $1e, UnknownScript_0x5d8a4
	end
; 0x5d800

UnknownScript_0x5d800: ; 0x5d800
	2writetext UnknownText_0x5dcf4
	keeptextopen
	setbit1 $033d
	verbosegiveitem BLUE_CARD, 1
UnknownScript_0x5d80a: ; 0x5d80a
	2writetext UnknownText_0x5de10
	closetext
	loadmovesprites
	checkcellnum $25
	iftrue UnknownScript_0x5d81a
	checkbit1 $033c
	iftrue UnknownScript_0x5d8cc
UnknownScript_0x5d81a: ; 0x5d81a
	spriteface $b, $3
	end
; 0x5d81e

UnknownScript_0x5d81e: ; 0x5d81e
	2writetext UnknownText_0x5df29
	closetext
	loadmovesprites
	spriteface $b, $3
	special $006a
	pause 20
	special $003d
	end
; 0x5d82f

UnknownScript_0x5d82f: ; 0x5d82f
	2writetext UnknownText_0x5df6c
	closetext
	loadmovesprites
	checkcellnum $25
	iftrue UnknownScript_0x5d83f
	checkbit1 $033c
	iftrue UnknownScript_0x5d8cc
UnknownScript_0x5d83f: ; 0x5d83f
	spriteface $b, $3
	pause 10
	end
; 0x5d845

UnknownScript_0x5d845: ; 0x5d845
	setbit2 $0060
	loadfont
	2writetext UnknownText_0x5e01c
	closetext
	loadmovesprites
	spriteface $b, $3
	pause 20
	loadfont
	2writetext UnknownText_0x5e054
	closetext
	loadmovesprites
	spriteface $b, $3
	special $006a
	pause 20
	special $003d
	end
; 0x5d865

UnknownScript_0x5d865: ; 0x5d865
	2writetext UnknownText_0x5e0c2
	closetext
	loadmovesprites
	end
; 0x5d86b

UnknownScript_0x5d86b: ; 0x5d86b
	2writetext UnknownText_0x5e192
	closetext
	loadmovesprites
	checkcellnum $25
	iftrue UnknownScript_0x5d87b
	checkbit1 $029e
	iftrue UnknownScript_0x5d8cc
UnknownScript_0x5d87b: ; 0x5d87b
	spriteface $b, $3
	end
; 0x5d87f

UnknownScript_0x5d87f: ; 0x5d87f
	2writetext UnknownText_0x5e0f1
	closetext
	loadmovesprites
	checkcellnum $25
	iftrue UnknownScript_0x5d88f
	checkbit1 $029e
	iftrue UnknownScript_0x5d8cc
UnknownScript_0x5d88f: ; 0x5d88f
	spriteface $b, $3
	end
; 0x5d893

UnknownScript_0x5d893: ; 0x5d893
	2writetext UnknownText_0x5e131
	closetext
	loadmovesprites
	checkcellnum $25
	iftrue UnknownScript_0x5d8a3
	checkbit1 $033c
	iftrue UnknownScript_0x5d8cc
UnknownScript_0x5d8a3: ; 0x5d8a3
	end
; 0x5d8a4

UnknownScript_0x5d8a4: ; 0x5d8a4
	checkcellnum $25
	iftrue UnknownScript_0x5d8fe
	pause 20
	spriteface $b, $0
	pause 15
	spriteface $0, $1
	pause 15
	checkbit1 $029e
	iftrue UnknownScript_0x5d8cc
	showemote $0, $b, 15
	setbit1 $029e
	setbit1 $033c
	loadfont
	2writetext UnknownText_0x5e1ee
	2jump UnknownScript_0x5d8d0
; 0x5d8cc

UnknownScript_0x5d8cc: ; 0x5d8cc
	loadfont
	2writetext UnknownText_0x5e2bf
UnknownScript_0x5d8d0: ; 0x5d8d0
	askforphonenumber $25
	if_equal $1, UnknownScript_0x5d8f6
	if_equal $2, UnknownScript_0x5d8ed
	2writetext UnknownText_0x5e2f3
	playsound $0093
	waitbutton
	keeptextopen
	2writetext UnknownText_0x5e310
	closetext
	loadmovesprites
	spriteface $b, $3
	addcellnum $25
	end
; 0x5d8ed

UnknownScript_0x5d8ed: ; 0x5d8ed
	2writetext UnknownText_0x5e33c
	closetext
	loadmovesprites
	spriteface $b, $3
	end
; 0x5d8f6

UnknownScript_0x5d8f6: ; 0x5d8f6
	2writetext UnknownText_0x5e35e
	closetext
	loadmovesprites
	spriteface $b, $3
UnknownScript_0x5d8fe: ; 0x5d8fe
	end
; 0x5d8ff

UnknownScript_0x5d8ff: ; 0x5d8ff
	faceplayer
	loadfont
	checkitem BLUE_CARD
	iffalse UnknownScript_0x5d90f
	2writetext UnknownText_0x5e392
	keeptextopen
	special $0093
	loadmovesprites
	end
; 0x5d90f

UnknownScript_0x5d90f: ; 0x5d90f
	2writetext UnknownText_0x5e3d8
	keeptextopen
	loadmovesprites
	end
; 0x5d915

MapRadioTower2FSignpost0Script: ; 0x5d915
	jumptext UnknownText_0x5e426
; 0x5d918

MapRadioTower2FSignpost1Script: ; 0x5d918
	jumptext UnknownText_0x5e430
; 0x5d91b

MapRadioTower2FSignpost5Script: ; 0x5d91b
	jumptext UnknownText_0x5e463
; 0x5d91e

MapRadioTower2FSignpost4Script: ; 0x5d91e
	jumpstd $0003
; 0x5d921

MovementData_0x5d921: ; 0x5d921
	slow_step_down
	slow_step_right
	step_end
; 0x5d924

UnknownText_0x5d924: ; 0x5d924
	db $0, "You can listen to", $4f
	db "the radio any-", $55
	db "where. Tune in!", $57
; 0x5d956

UnknownText_0x5d956: ; 0x5d956
	db $0, "Lullabies on the", $4f
	db "radio may make", $55
	db "#MON sleep.", $57
; 0x5d983

UnknownText_0x5d983: ; 0x5d983
	db $0, "Why would they", $4f
	db "want to take over", $55
	db "the RADIO TOWER?", $57
; 0x5d9b6

UnknownText_0x5d9b6: ; 0x5d9b6
	db $0, "JIGGLYPUFF:", $4f
	db "Jiggly…", $57
; 0x5d9cb

UnknownText_0x5d9cb: ; 0x5d9cb
	db $0, "Sorry. Authorized", $4f
	db "personnel only", $55
	db "beyond this point.", $51
	db "It wasn't that way", $4f
	db "before.", $51
	db "There's something", $4f
	db "wrong with the", $55
	db "DIRECTOR…", $57
; 0x5da44

UnknownText_0x5da44: ; 0x5da44
	db $0, "Feel free to look", $4f
	db "around anywhere.", $51
	db "The DIRECTOR is", $4f
	db "nice again, just", $55
	db "as he was before.", $57
; 0x5da9b

GruntM4SeenText: ; 0x5da9b
	db $0, "Three years ago,", $4f
	db "TEAM ROCKET was", $55
	db "forced to disband.", $51
	db "But we're making a", $4f
	db "comeback here!", $57
; 0x5daf1

GruntM4BeatenText: ; 0x5daf1
	db $0, "Gwah! Don't get", $4f
	db "cute!", $57
; 0x5db07

UnknownText_0x5db07: ; 0x5db07
	db $0, "We won't let you", $4f
	db "ruin our plans", $55
	db "for our comeback!", $57
; 0x5db39

GruntM5SeenText: ; 0x5db39
	db $0, "We're TEAM ROCKET,", $4f
	db "the exploiters of", $55
	db "#MON!", $51
	db "We love being", $4f
	db "evil! Scared?", $57
; 0x5db80

GruntM5BeatenText: ; 0x5db80
	db $0, "You think you're a", $4f
	db "hero?", $57
; 0x5db99

UnknownText_0x5db99: ; 0x5db99
	db $0, "We're not always", $4f
	db "evil. We just do", $55
	db "whatever we like.", $57
; 0x5dbcd

GruntM6SeenText: ; 0x5dbcd
	db $0, "Hey, hey! Keep out", $4f
	db "of our way!", $57
; 0x5dbed

GruntM6BeatenText: ; 0x5dbed
	db $0, "Arggh. I give up.", $57
; 0x5dc00

UnknownText_0x5dc00: ; 0x5dc00
	db $0, "Our EXECUTIVES are", $4f
	db "trying to take", $55
	db "this place over.", $51
	db "They have some big", $4f
	db "plan. I wonder", $55
	db "what that is?", $57
; 0x5dc64

GruntF2SeenText: ; 0x5dc64
	db $0, "Hahaha!", $51
	db "How boring.", $4f
	db "It was far too", $51
	db "easy to take over", $4f
	db "this place!", $51
	db "Come on, keep me", $4f
	db "amused!", $57
; 0x5dcbf

GruntF2BeatenText: ; 0x5dcbf
	db $0, "Wh-who are you?", $57
; 0x5dcd0

UnknownText_0x5dcd0: ; 0x5dcd0
	db $0, "You beat me, and", $4f
	db "I won't forget it!", $57
; 0x5dcf4

UnknownText_0x5dcf4: ; 0x5dcf4
	db $0, "BUENA: Hi! I'm", $4f
	db "BUENA!", $51
	db "Do you know about", $4f
	db "a radio program", $55
	db "called PASSWORD?", $51
	db "If you can tell me", $4f
	db "the password from", $51
	db "the program, you", $4f
	db "will earn points.", $51
	db "Save up those", $4f
	db "points and trade", $51
	db "them to that sweet", $4f
	db "young lady over", $51
	db "there for some", $4f
	db "choice prizes!", $51
	db "Here you go!", $51
	db "It's your very own", $4f
	db "point card!", $57
; 0x5de10

UnknownText_0x5de10: ; 0x5de10
	db $0, "BUENA: Tune in to", $4f
	db "my PASSWORD SHOW!", $57
; 0x5de35

UnknownText_0x5de35: ; 0x5de35
	db $0, "BUENA: Hi!", $4f
	db "Did you tune in to", $55
	db "my radio show?", $51
	db "Do you remember", $4f
	db "today's password?", $57
; 0x5de84

UnknownText_0x5de84: ; 0x5de84
	db $0, "BUENA: Oh, wow!", $4f
	db "Thank you!", $51
	db "What was your name", $4f
	db "again?", $51
	db "…", $14, ", OK!", $51
	db "Come on, ", $14, ".", $4f
	db "Join the show.", $57
; 0x5dedd

UnknownText_0x5dedd: ; 0x5dedd
	db $0, "BUENA: Everyone", $4f
	db "ready?", $51
	db "I want to hear you", $4f
	db "shout out today's", $51
	db "password for", $4f
	db $14, "!", $57
; 0x5df29

UnknownText_0x5df29: ; 0x5df29
	db $0, "BUENA: Come back", $4f
	db "after you listen", $51
	db "to my show, OK?", $4f
	db "Catch ya later!", $57
; 0x5df6c

UnknownText_0x5df6c: ; 0x5df6c
	db $0, "BUENA: Sorry…", $51
	db "You get just one", $4f
	db "chance each day.", $51
	db "Come back tomorrow", $4f
	db "for another try!", $57
; 0x5dfc1

UnknownText_0x5dfc1: ; 0x5dfc1
	db $0, "BUENA: YIPPEE!", $4f
	db "That's right!", $51
	db "You did tune in!", $4f
	db "I'm so happy!", $51
	db "You earned one", $4f
	db "point! Congrats!", $57
; 0x5e01c

UnknownText_0x5e01c: ; 0x5e01c
	db $0, "BUENA: Aww…", $4f
	db "That's not it…", $51
	db "Did you forget the", $4f
	db "password?", $57
; 0x5e054

UnknownText_0x5e054: ; 0x5e054
	db $0, "BUENA: Yup! Our", $4f
	db "contestant was", $51
	db $14, ".", $4f
	db "Thanks for coming!", $51
	db "I hope all you", $4f
	db "listeners will", $51
	db "come too!", $4f
	db "I'll be waiting!", $57
; 0x5e0c2

UnknownText_0x5e0c2: ; 0x5e0c2
	db $0, "BUENA: Huh?", $4f
	db "Today's password?", $51
	db "HELP, of course!", $57
; 0x5e0f1

UnknownText_0x5e0f1: ; 0x5e0f1
	db $0, "BUENA: Your BLUE", $4f
	db "CARD's full.", $51
	db "Trade it in for a", $4f
	db "fabulous prize!", $57
; 0x5e131

UnknownText_0x5e131: ; 0x5e131
	db $0, "BUENA: Tune in to", $4f
	db "PASSWORD every", $51
	db "night from six to", $4f
	db "midnight!", $51
	db "Tune in, then drop", $4f
	db "in for a visit!", $57
; 0x5e192

UnknownText_0x5e192: ; 0x5e192
	db $0, "BUENA: Oh? You", $4f
	db "forgot to bring", $55
	db "your BLUE CARD?", $51
	db "I can't give you", $4f
	db "points if you", $55
	db "don't have it.", $57
; 0x5e1ee

UnknownText_0x5e1ee: ; 0x5e1ee
	db $0, "BUENA: Oh! Your", $4f
	db "BLUE CARD reached", $51
	db "30 points today!", $4f
	db "That's so wild!", $51
	db "Hmm… There isn't a", $4f
	db "prize for hitting", $55
	db "30 points, but…", $51
	db "You came by so", $4f
	db "often, ", $14, ".", $51
	db "I'll make you a", $4f
	db "special deal!", $51
	db "How would you like", $4f
	db "my phone number?", $57
; 0x5e2bf

UnknownText_0x5e2bf: ; 0x5e2bf
	db $0, "BUENA: ", $14, ",", $4f
	db "do you want to", $51
	db "register my phone", $4f
	db "number?", $57
; 0x5e2f3

UnknownText_0x5e2f3: ; 0x5e2f3
	db $0, $52, " registered", $4f
	db "BUENA's number.", $57
; 0x5e310

UnknownText_0x5e310: ; 0x5e310
	db $0, "BUENA: I look", $4f
	db "forward to hearing", $55
	db "from you!", $57
; 0x5e33c

UnknownText_0x5e33c: ; 0x5e33c
	db $0, "BUENA: Aww… It's a", $4f
	db "special prize…", $57
; 0x5e35e

UnknownText_0x5e35e: ; 0x5e35e
	db $0, "BUENA: ", $14, ",", $4f
	db "your phone list", $51
	db "has no room left", $4f
	db "for me…", $57
; 0x5e392

UnknownText_0x5e392: ; 0x5e392
	db $0, "You can cash in", $4f
	db "your saved points", $51
	db "for a lovely prize", $4f
	db "of your choice!", $57
; 0x5e3d8

UnknownText_0x5e3d8: ; 0x5e3d8
	db $0, "You can't trade in", $4f
	db "points without", $55
	db "your BLUE CARD.", $51
	db "Don't forget your", $4f
	db "BLUE CARD!", $57
; 0x5e426

UnknownText_0x5e426: ; 0x5e426
	db $0, "2F SALES", $57
; 0x5e430

UnknownText_0x5e430: ; 0x5e430
	db $0, "PROF.OAK'S #MON", $4f
	db "TALK", $51
	db "The Hottest Show", $4f
	db "on the Air!", $57
; 0x5e463

UnknownText_0x5e463: ; 0x5e463
	db $0, "Anywhere, Anytime", $4f
	db "#MON Radio", $57
; 0x5e481

RadioTower2F_MapEventHeader: ; 0x5e481
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $0, $0, 1, GROUP_RADIO_TOWER_3F, MAP_RADIO_TOWER_3F
	warp_def $0, $f, 3, GROUP_RADIO_TOWER_1F, MAP_RADIO_TOWER_1F

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 0, 3, $0, MapRadioTower2FSignpost0Script
	signpost 0, 5, $0, MapRadioTower2FSignpost1Script
	signpost 1, 9, $0, MapRadioTower2FSignpost4Script
	signpost 1, 10, $0, MapRadioTower2FSignpost4Script
	signpost 1, 11, $0, MapRadioTower2FSignpost4Script
	signpost 0, 13, $0, MapRadioTower2FSignpost5Script

	; people-events
	db 11
	person_event $2b, 10, 10, $8, $0, 255, 255, $a0, 0, UnknownScript_0x5d6fe, $06cf
	person_event $29, 6, 21, $5, $1, 255, 255, $80, 0, UnknownScript_0x5d701, $ffff
	person_event $35, 8, 5, $7, $0, 255, 255, $2, 3, TrainerGruntM4, $06ce
	person_event $35, 8, 12, $6, $0, 255, 255, $2, 3, TrainerGruntM5, $06ce
	person_event $35, 5, 8, $6, $0, 255, 255, $2, 2, TrainerGruntM6, $06ce
	person_event $36, 9, 14, $7, $0, 255, 255, $82, 3, TrainerGruntF2, $06ce
	person_event $41, 5, 4, $6, $0, 255, 255, $0, 0, UnknownScript_0x5d71f, $06d1
	person_event $41, 5, 5, $6, $0, 255, 255, $0, 0, UnknownScript_0x5d722, $06d0
	person_event $94, 5, 16, $16, $0, 255, 255, $0, 0, UnknownScript_0x5d715, $ffff
	person_event $2a, 9, 18, $9, $0, 255, 255, $80, 0, UnknownScript_0x5d775, $ffff
	person_event $42, 11, 16, $9, $0, 255, 255, $a0, 0, UnknownScript_0x5d8ff, $06cf
; 0x5e53e

RadioTower3F_MapScriptHeader: ; 0x5e53e
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x5e543
; 0x5e543

UnknownScript_0x5e543: ; 0x5e543
	checkbit1 $0025
	iftrue UnknownScript_0x5e54a
	return
; 0x5e54a

UnknownScript_0x5e54a: ; 0x5e54a
	changeblock $e, $2, $2a
	changeblock $e, $4, $1
	return
; 0x5e553

UnknownScript_0x5e553: ; 0x5e553
	jumptextfaceplayer UnknownText_0x5e621
; 0x5e556

UnknownScript_0x5e556: ; 0x5e556
	faceplayer
	loadfont
	checkbit1 $0021
	iftrue UnknownScript_0x5e564
	2writetext UnknownText_0x5e682
	closetext
	loadmovesprites
	end
; 0x5e564

UnknownScript_0x5e564: ; 0x5e564
	2writetext UnknownText_0x5e6eb
	closetext
	loadmovesprites
	end
; 0x5e56a

UnknownScript_0x5e56a: ; 0x5e56a
	faceplayer
	loadfont
	checkbit1 $0047
	iftrue UnknownScript_0x5e59d
	checkbit1 $0021
	iftrue UnknownScript_0x5e58a
	checkbit1 $0025
	iftrue UnknownScript_0x5e584
	2writetext UnknownText_0x5e754
	closetext
	loadmovesprites
	end
; 0x5e584

UnknownScript_0x5e584: ; 0x5e584
	2writetext UnknownText_0x5e7cb
	closetext
	loadmovesprites
	end
; 0x5e58a

UnknownScript_0x5e58a: ; 0x5e58a
	2writetext UnknownText_0x5e7e2
	keeptextopen
	verbosegiveitem TM_11, 1
	iffalse UnknownScript_0x5e5a1
	2writetext UnknownText_0x5e821
	closetext
	loadmovesprites
	setbit1 $0047
	end
; 0x5e59d

UnknownScript_0x5e59d: ; 0x5e59d
	2writetext UnknownText_0x5e85c
	closetext
UnknownScript_0x5e5a1: ; 0x5e5a1
	loadmovesprites
	end
; 0x5e5a3

TrainerGruntM7: ; 0x5e5a3
	; bit/flag number
	dw $4f7

	; trainer group && trainer id
	db GRUNTM, 7

	; text when seen
	dw GruntM7SeenText

	; text when trainer beaten
	dw GruntM7BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM7Script
; 0x5e5af

GruntM7Script: ; 0x5e5af
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5e8d0
	closetext
	loadmovesprites
	end
; 0x5e5b7

TrainerGruntM8: ; 0x5e5b7
	; bit/flag number
	dw $4f8

	; trainer group && trainer id
	db GRUNTM, 8

	; text when seen
	dw GruntM8SeenText

	; text when trainer beaten
	dw GruntM8BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM8Script
; 0x5e5c3

GruntM8Script: ; 0x5e5c3
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5e944
	closetext
	loadmovesprites
	end
; 0x5e5cb

TrainerGruntM9: ; 0x5e5cb
	; bit/flag number
	dw $4f9

	; trainer group && trainer id
	db GRUNTM, 9

	; text when seen
	dw GruntM9SeenText

	; text when trainer beaten
	dw GruntM9BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM9Script
; 0x5e5d7

GruntM9Script: ; 0x5e5d7
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5e9d0
	closetext
	loadmovesprites
	end
; 0x5e5df

TrainerScientistMarc: ; 0x5e5df
	; bit/flag number
	dw $4a2

	; trainer group && trainer id
	db SCIENTIST, MARC

	; text when seen
	dw ScientistMarcSeenText

	; text when trainer beaten
	dw ScientistMarcBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw ScientistMarcScript
; 0x5e5eb

ScientistMarcScript: ; 0x5e5eb
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5ea61
	closetext
	loadmovesprites
	end
; 0x5e5f3

MapRadioTower3FSignpost2Script: ; 0x5e5f3
	loadfont
	2writetext UnknownText_0x5eaa4
	closetext
	checkbit1 $0025
	iftrue UnknownScript_0x5e603
	checkitem CARD_KEY
	iftrue UnknownScript_0x5e605
UnknownScript_0x5e603: ; 0x5e603
	loadmovesprites
	end
; 0x5e605

UnknownScript_0x5e605: ; 0x5e605
	2writetext UnknownText_0x5eabc
	closetext
	setbit1 $0025
	playsound $001f
	changeblock $e, $2, $2a
	changeblock $e, $4, $1
	reloadmappart
	loadmovesprites
	waitbutton
	end
; 0x5e61b

MapRadioTower3FSignpost0Script: ; 0x5e61b
	jumptext UnknownText_0x5ead6
; 0x5e61e

MapRadioTower3FSignpost1Script: ; 0x5e61e
	jumptext UnknownText_0x5eae4
; 0x5e621

UnknownText_0x5e621: ; 0x5e621
	db $0, "We have recordings", $4f
	db "of the cries of", $51
	db "all #MON that", $4f
	db "have been found.", $51
	db "We must have about", $4f
	db "200 kinds.", $57
; 0x5e682

UnknownText_0x5e682: ; 0x5e682
	db $0, "To trainers, #-", $4f
	db "MON are their", $55
	db "beloved partners.", $51
	db "It's terrible how", $4f
	db "TEAM ROCKET is", $51
	db "trying to control", $4f
	db "#MON.", $57
; 0x5e6eb

UnknownText_0x5e6eb: ; 0x5e6eb
	db $0, "We run 24 hours a", $4f
	db "day to broadcast", $51
	db "entertaining pro-", $4f
	db "grams.", $51
	db "I'll do my best to", $4f
	db "run around the", $55
	db "clock too!", $57
; 0x5e754

UnknownText_0x5e754: ; 0x5e754
	db $0, "The TEAM ROCKET", $4f
	db "boss has locked", $55
	db "himself in.", $51
	db "But the DIRECTOR", $4f
	db "can open it.", $51
	db "He's up on the", $4f
	db "fifth floor.", $51
	db "Please save him!", $57
; 0x5e7cb

UnknownText_0x5e7cb: ; 0x5e7cb
	db $0, "Is the DIRECTOR", $4f
	db "safe?", $57
; 0x5e7e2

UnknownText_0x5e7e2: ; 0x5e7e2
	db $0, "Thank you!", $4f
	db "You're my hero!", $51
	db "This is a token of", $4f
	db "my appreciation.", $57
; 0x5e821

UnknownText_0x5e821: ; 0x5e821
	db $0, "It's SUNNY DAY.", $4f
	db "It powers up fire-", $55
	db "type moves for a", $55
	db "while.", $57
; 0x5e85c

UnknownText_0x5e85c: ; 0x5e85c
	db $0, "You were simply", $4f
	db "marvelous!", $57
; 0x5e878

GruntM7SeenText: ; 0x5e878
	db $0, "I've been given", $4f
	db "strict orders.", $51
	db "I'm to crush any-", $4f
	db "one who challenges", $55
	db "TEAM ROCKET!", $57
; 0x5e8c8

GruntM7BeatenText: ; 0x5e8c8
	db $0, "What?!", $57
; 0x5e8d0

UnknownText_0x5e8d0: ; 0x5e8d0
	db $0, "I failed in my", $4f
	db "duties…", $51
	db "I'll be docked pay", $4f
	db "for this…", $57
; 0x5e904

GruntM8SeenText: ; 0x5e904
	db $0, "It feels great", $4f
	db "ordering #MON", $55
	db "to commit crimes.", $57
; 0x5e934

GruntM8BeatenText: ; 0x5e934
	db $0, "You're kidding!", $57
; 0x5e944

UnknownText_0x5e944: ; 0x5e944
	db $0, "I feel lousy over", $4f
	db "losing!", $51
	db "Darn it! I hate", $4f
	db "useless #MON!", $57
; 0x5e97d

GruntM9SeenText: ; 0x5e97d
	db $0, "Why did the shut-", $4f
	db "ter open? Did you", $51
	db "have something to", $4f
	db "do with this?", $57
; 0x5e9c2

GruntM9BeatenText: ; 0x5e9c2
	db $0, "I'm done for!", $57
; 0x5e9d0

UnknownText_0x5e9d0: ; 0x5e9d0
	db $0, "What?! You made it", $4f
	db "past our men in", $55
	db "the UNDERGROUND?", $51
	db "How could you?", $57
; 0x5ea14

ScientistMarcSeenText: ; 0x5ea14
	db $0, "An unknown child", $4f
	db "wandering here?", $51
	db "Who are you?", $57
; 0x5ea43

ScientistMarcBeatenText: ; 0x5ea43
	db $0, "Tch! I took you", $4f
	db "too lightly!", $57
; 0x5ea61

UnknownText_0x5ea61: ; 0x5ea61
	db $0, "Bwahahaha…", $51
	db "I can transmit as", $4f
	db "strong a signal as", $55
	db "I need from here.", $57
; 0x5eaa4

UnknownText_0x5eaa4: ; 0x5eaa4
	db $0, "It's the CARD KEY", $4f
	db "slot.", $57
; 0x5eabc

UnknownText_0x5eabc: ; 0x5eabc
	db $0, $52, " inserted", $4f
	db "the CARD KEY.", $57
; 0x5ead6

UnknownText_0x5ead6: ; 0x5ead6
	db $0, "3F PERSONNEL", $57
; 0x5eae4

UnknownText_0x5eae4: ; 0x5eae4
	db $0, "#MON MUSIC with", $4f
	db "Host DJ BEN", $57
; 0x5eb01

RadioTower3F_MapEventHeader: ; 0x5eb01
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $0, 1, GROUP_RADIO_TOWER_2F, MAP_RADIO_TOWER_2F
	warp_def $0, $7, 2, GROUP_RADIO_TOWER_4F, MAP_RADIO_TOWER_4F
	warp_def $0, $11, 4, GROUP_RADIO_TOWER_4F, MAP_RADIO_TOWER_4F

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 0, 3, $0, MapRadioTower3FSignpost0Script
	signpost 0, 9, $0, MapRadioTower3FSignpost1Script
	signpost 2, 14, $1, MapRadioTower3FSignpost2Script

	; people-events
	db 7
	person_event $2b, 8, 11, $7, $0, 255, 255, $90, 0, UnknownScript_0x5e553, $06d0
	person_event $48, 8, 7, $a, $0, 255, 255, $80, 0, UnknownScript_0x5e556, $ffff
	person_event $24, 7, 15, $2, $11, 255, 255, $a0, 0, UnknownScript_0x5e56a, $ffff
	person_event $35, 5, 9, $9, $0, 255, 255, $2, 2, TrainerGruntM7, $06ce
	person_event $35, 6, 10, $6, $0, 255, 255, $2, 3, TrainerGruntM8, $06ce
	person_event $35, 10, 20, $7, $0, 255, 255, $2, 3, TrainerGruntM9, $06ce
	person_event $3c, 10, 13, $7, $0, 255, 255, $92, 5, TrainerScientistMarc, $06ce
; 0x5eb80

RadioTower4F_MapScriptHeader: ; 0x5eb80
	; trigger count
	db 0

	; callback count
	db 0
; 0x5eb82

UnknownScript_0x5eb82: ; 0x5eb82
	jumptextfaceplayer UnknownText_0x5ec12
; 0x5eb85

UnknownScript_0x5eb85: ; 0x5eb85
	faceplayer
	loadfont
	checkbit1 $0048
	iftrue UnknownScript_0x5ebac
	checkbit1 $0021
	iftrue UnknownScript_0x5eb99
	2writetext UnknownText_0x5ec68
	closetext
	loadmovesprites
	end
; 0x5eb99

UnknownScript_0x5eb99: ; 0x5eb99
	2writetext UnknownText_0x5ecab
	keeptextopen
	verbosegiveitem PINK_BOW, 1
	iffalse UnknownScript_0x5ebb0
	2writetext UnknownText_0x5ecef
	closetext
	loadmovesprites
	setbit1 $0048
	end
; 0x5ebac

UnknownScript_0x5ebac: ; 0x5ebac
	2writetext UnknownText_0x5ed2c
	closetext
UnknownScript_0x5ebb0: ; 0x5ebb0
	loadmovesprites
	end
; 0x5ebb2

UnknownScript_0x5ebb2: ; 0x5ebb2
	loadfont
	2writetext UnknownText_0x5ed66
	cry MEOWTH
	closetext
	loadmovesprites
	end
; 0x5ebbc

TrainerGruntM10: ; 0x5ebbc
	; bit/flag number
	dw $4fa

	; trainer group && trainer id
	db GRUNTM, 10

	; text when seen
	dw GruntM10SeenText

	; text when trainer beaten
	dw GruntM10BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM10Script
; 0x5ebc8

GruntM10Script: ; 0x5ebc8
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5ede2
	closetext
	loadmovesprites
	end
; 0x5ebd0

TrainerExecutivem2: ; 0x5ebd0
	; bit/flag number
	dw $572

	; trainer group && trainer id
	db EXECUTIVEM, 2

	; text when seen
	dw Executivem2SeenText

	; text when trainer beaten
	dw Executivem2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Executivem2Script
; 0x5ebdc

Executivem2Script: ; 0x5ebdc
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5ee69
	closetext
	loadmovesprites
	end
; 0x5ebe4

TrainerGruntF4: ; 0x5ebe4
	; bit/flag number
	dw $513

	; trainer group && trainer id
	db GRUNTF, 4

	; text when seen
	dw GruntF4SeenText

	; text when trainer beaten
	dw GruntF4BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntF4Script
; 0x5ebf0

GruntF4Script: ; 0x5ebf0
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5ef31
	closetext
	loadmovesprites
	end
; 0x5ebf8

TrainerScientistRich: ; 0x5ebf8
	; bit/flag number
	dw $4a3

	; trainer group && trainer id
	db SCIENTIST, RICH

	; text when seen
	dw ScientistRichSeenText

	; text when trainer beaten
	dw ScientistRichBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw ScientistRichScript
; 0x5ec04

ScientistRichScript: ; 0x5ec04
	talkaftercancel
	loadfont
	2writetext UnknownText_0x5efcb
	closetext
	loadmovesprites
	end
; 0x5ec0c

MapRadioTower4FSignpost0Script: ; 0x5ec0c
	jumptext UnknownText_0x5effe
; 0x5ec0f

MapRadioTower4FSignpost1Script: ; 0x5ec0f
	jumptext UnknownText_0x5f00d
; 0x5ec12

UnknownText_0x5ec12: ; 0x5ec12
	db $0, "I listened to the", $4f
	db "radio while I was", $55
	db "at the RUINS.", $51
	db "I heard a strange", $4f
	db "broadcast there.", $57
; 0x5ec68

UnknownText_0x5ec68: ; 0x5ec68
	db $0, "MARY: Why? Why do", $4f
	db "I have to suffer", $55
	db "through this?", $51
	db "MEOWTH, help me!", $57
; 0x5ecab

UnknownText_0x5ecab: ; 0x5ecab
	db $0, "MARY: Oh! You're", $4f
	db "my little savior!", $51
	db "Will you take this", $4f
	db "as my thanks?", $57
; 0x5ecef

UnknownText_0x5ecef: ; 0x5ecef
	db $0, "MARY: It's just", $4f
	db "right for #MON", $51
	db "that know normal-", $4f
	db "type moves.", $57
; 0x5ed2c

UnknownText_0x5ed2c: ; 0x5ed2c
	db $0, "MARY: Please tune", $4f
	db "into me on PROF.", $51
	db "OAK'S #MON TALK", $4f
	db "show.", $57
; 0x5ed66

UnknownText_0x5ed66: ; 0x5ed66
	db $0, "MEOWTH: Meowth…", $57
; 0x5ed77

GruntM10SeenText: ; 0x5ed77
	db $0, "You plan to rescue", $4f
	db "the DIRECTOR?", $51
	db "That won't be pos-", $4f
	db "sible because I'm", $55
	db "going to beat you!", $57
; 0x5edcf

GruntM10BeatenText: ; 0x5edcf
	db $0, "No! Unbelievable!", $57
; 0x5ede2

UnknownText_0x5ede2: ; 0x5ede2
	db $0, "I don't believe", $4f
	db "it! I was beaten!", $57
; 0x5ee04

Executivem2SeenText: ; 0x5ee04
	db $0, "Stop! I'm known as", $4f
	db "the TEAM ROCKET", $55
	db "fortress!", $51
	db "You're not taking", $4f
	db "another step!", $57
; 0x5ee50

Executivem2BeatenText: ; 0x5ee50
	db $0, "The fortress came", $4f
	db "down!", $57
; 0x5ee69

UnknownText_0x5ee69: ; 0x5ee69
	db $0, "You've earned my", $4f
	db "respect, so here's", $55
	db "some advice.", $51
	db "It's not too late.", $4f
	db "You can still turn", $55
	db "back.", $57
; 0x5eec4

GruntF4SeenText: ; 0x5eec4
	db $0, "Don't I think", $4f
	db "#MON are cute?", $51
	db "I'll think my", $4f
	db "#MON are cute--", $51
	db "after they beat", $4f
	db "yours!", $57
; 0x5ef15

GruntF4BeatenText: ; 0x5ef15
	db $0, "Oh, no! They're so", $4f
	db "useless!", $57
; 0x5ef31

UnknownText_0x5ef31: ; 0x5ef31
	db $0, "I love my", $4f
	db "beautiful self!", $51
	db "Who cares about", $4f
	db "#MON?", $57
; 0x5ef62

ScientistRichSeenText: ; 0x5ef62
	db $0, "Most excellent.", $51
	db "This RADIO TOWER", $4f
	db "will fulfill our", $55
	db "grand design.", $57
; 0x5efa3

ScientistRichBeatenText: ; 0x5efa3
	db $0, "Hmmm…", $51
	db "All grand plans", $4f
	db "come with snags.", $57
; 0x5efcb

UnknownText_0x5efcb: ; 0x5efcb
	db $0, "Do you honestly", $4f
	db "believe you can", $55
	db "stop TEAM ROCKET?", $57
; 0x5effe

UnknownText_0x5effe: ; 0x5effe
	db $0, "4F PRODUCTION", $57
; 0x5f00d

UnknownText_0x5f00d: ; 0x5f00d
	db $0, "4F STUDIO 2", $57
; 0x5f01a

RadioTower4F_MapEventHeader: ; 0x5f01a
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $0, 1, GROUP_RADIO_TOWER_5F, MAP_RADIO_TOWER_5F
	warp_def $0, $9, 2, GROUP_RADIO_TOWER_3F, MAP_RADIO_TOWER_3F
	warp_def $0, $c, 2, GROUP_RADIO_TOWER_5F, MAP_RADIO_TOWER_5F
	warp_def $0, $11, 3, GROUP_RADIO_TOWER_3F, MAP_RADIO_TOWER_3F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 7, $0, MapRadioTower4FSignpost0Script
	signpost 0, 15, $0, MapRadioTower4FSignpost1Script

	; people-events
	db 7
	person_event $3a, 8, 10, $7, $0, 255, 255, $80, 0, UnknownScript_0x5eb82, $06d0
	person_event $29, 10, 18, $3, $0, 255, 255, $a0, 0, UnknownScript_0x5eb85, $ffff
	person_event $82, 11, 16, $16, $0, 255, 255, $80, 0, UnknownScript_0x5ebb2, $ffff
	person_event $35, 10, 9, $1f, $0, 255, 255, $2, 3, TrainerGruntM10, $06ce
	person_event $35, 5, 18, $8, $2, 255, 255, $2, 2, TrainerExecutivem2, $06ce
	person_event $36, 8, 16, $9, $0, 255, 255, $82, 1, TrainerGruntF4, $06ce
	person_event $3c, 6, 8, $8, $0, 255, 255, $92, 4, TrainerScientistRich, $06ce
; 0x5f099

SECTION "bank18",DATA,BANK[$18]

RadioTower5F_MapScriptHeader: ; 0x60000
	; trigger count
	db 3

	; triggers
	dw UnknownScript_0x6000e, $0000
	dw UnknownScript_0x6000f, $0000
	dw UnknownScript_0x60010, $0000

	; callback count
	db 0
; 0x6000e

UnknownScript_0x6000e: ; 0x6000e
	end
; 0x6000f

UnknownScript_0x6000f: ; 0x6000f
	end
; 0x60010

UnknownScript_0x60010: ; 0x60010
	end
; 0x60011

UnknownScript_0x60011: ; 0x60011
	spriteface $2, $1
	showemote $0, $2, 15
	loadfont
	2writetext UnknownText_0x60128
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x60109
	playmusic $0039
	loadfont
	2writetext UnknownText_0x60147
	closetext
	loadmovesprites
	winlosstext UnknownText_0x60223, $0000
	setlasttalked $2
	loadtrainer EXECUTIVEM, 3
	startbattle
	returnafterbattle
	loadfont
	2writetext UnknownText_0x60246
	keeptextopen
	verbosegiveitem BASEMENT_KEY, 1
	loadmovesprites
	dotrigger $1
	setbit1 $0573
	end
; 0x60046

UnknownScript_0x60046: ; 0x60046
	faceplayer
	loadfont
	checkbit1 $0021
	iftrue UnknownScript_0x60054
	2writetext UnknownText_0x60246
	closetext
	loadmovesprites
	end
; 0x60054

UnknownScript_0x60054: ; 0x60054
	2writetext UnknownText_0x60824
	closetext
	loadmovesprites
	end
; 0x6005a

TrainerExecutivef1: ; 0x6005a
	; bit/flag number
	dw $56f

	; trainer group && trainer id
	db EXECUTIVEF, 1

	; text when seen
	dw Executivef1SeenText

	; text when trainer beaten
	dw Executivef1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Executivef1Script
; 0x60066

Executivef1Script: ; 0x60066
	talkaftercancel
	loadfont
	2writetext UnknownText_0x60358
	closetext
	loadmovesprites
	end
; 0x6006e

UnknownScript_0x6006e: ; 0x6006e
	applymovement $0, MovementData_0x60125
	playmusic $0039
	spriteface $3, $3
	loadfont
	2writetext UnknownText_0x603d1
	closetext
	loadmovesprites
	winlosstext UnknownText_0x604f3, $0000
	setlasttalked $3
	loadtrainer EXECUTIVEM, 1
	startbattle
	returnafterbattle
	loadfont
	2writetext UnknownText_0x6050e
	closetext
	loadmovesprites
	special $0030
	special $0033
	disappear $3
	disappear $4
	pause 15
	special $0032
	setbit1 $0571
	setbit1 $0021
	clearbit2 $0013
	setbit1 $06cc
	setbit1 $06cd
	setbit1 $06ce
	clearbit1 $0736
	clearbit2 $0017
	clearbit1 $06cf
	clearbit1 $06d0
	setbit1 $06e3
	clearbit1 $06e4
	special $003c
	disappear $2
	moveperson $2, $c, $0
	appear $2
	applymovement $2, MovementData_0x6010f
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x605b2
	keeptextopen
	verbosegiveitem CLEAR_BELL, 1
	2writetext UnknownText_0x6062c
	closetext
	loadmovesprites
	dotrigger $2
	domaptrigger GROUP_ECRUTEAK_HOUSE, MAP_ECRUTEAK_HOUSE, $0
	setbit1 $0078
	setbit1 $0761
	2jump UnknownScript_0x600f1
; 0x600f1

UnknownScript_0x600f1: ; 0x600f1
	applymovement $2, MovementData_0x6011a
	playsound $0023
	disappear $2
	end
; 0x600fb

UnknownScript_0x600fb: ; 0x600fb
	jumptextfaceplayer UnknownText_0x608be
; 0x600fe

ItemFragment_0x600fe: ; 0x600fe
	db ULTRA_BALL, 1
; 0x60100

MapRadioTower5FSignpost0Script: ; 0x60100
	jumptext UnknownText_0x608e0
; 0x60103

MapRadioTower5FSignpost2Script: ; 0x60103
	jumptext UnknownText_0x608f9
; 0x60106

MapRadioTower5FSignpost4Script: ; 0x60106
	jumpstd $0003
; 0x60109

MovementData_0x60109: ; 0x60109
	step_left
	step_left
	step_left
	step_up
	step_up
	step_end
; 0x6010f

MovementData_0x6010f: ; 0x6010f
	step_down
	step_down
	step_right
	step_right
	step_right
	step_right
	step_down
	step_down
	step_down
	step_left
	step_end
; 0x6011a

MovementData_0x6011a: ; 0x6011a
	step_right
	step_up
	step_up
	step_up
	step_left
	step_left
	step_left
	step_left
	step_up
	step_up
	step_end
; 0x60125

MovementData_0x60125: ; 0x60125
	step_left
	step_left
	step_end
; 0x60128

UnknownText_0x60128: ; 0x60128
	db $0, "Y-you! You came to", $4f
	db "rescue me?", $57
; 0x60147

UnknownText_0x60147: ; 0x60147
	db $0, "Is that what you", $4f
	db "were expecting?", $51
	db "Wrong!", $4f
	db "I'm an imposter!", $51
	db "I pretended to be", $4f
	db "the real thing to", $51
	db "prepare for our", $4f
	db "takeover.", $51
	db "Do you want to", $4f
	db "know where we hid", $55
	db "the real DIRECTOR?", $51
	db "Sure, I'll tell", $4f
	db "you. But only if", $55
	db "you can beat me!", $57
; 0x60223

UnknownText_0x60223: ; 0x60223
	db $0, "OK, OK. I'll tell", $4f
	db "you where he is.", $57
; 0x60246

UnknownText_0x60246: ; 0x60246
	db $0, "We stashed the", $4f
	db "real DIRECTOR in", $51
	db "the UNDERGROUND", $4f
	db "WAREHOUSE.", $51
	db "It's at the far", $4f
	db "end of the UNDER-", $55
	db "GROUND.", $51
	db "But I doubt you'll", $4f
	db "get that far.", $57
; 0x602cb

Executivef1SeenText: ; 0x602cb
	db $0, "Remember me from", $4f
	db "the HIDEOUT in", $55
	db "MAHOGANY TOWN?", $51
	db "I lost then, but I", $4f
	db "won't this time.", $57
; 0x6031e

Executivef1BeatenText: ; 0x6031e
	db $0, "This can't be", $4f
	db "happening!", $51
	db "I fought hard, but", $4f
	db "I still lost…", $57
; 0x60358

UnknownText_0x60358: ; 0x60358
	db $0, $52, ", isn't it?", $51
	db "A brat like you", $4f
	db "won't appreciate", $51
	db "the magnificence", $4f
	db "of TEAM ROCKET.", $51
	db "That's too bad.", $4f
	db "I really admire", $55
	db "your power.", $57
; 0x603d1

UnknownText_0x603d1: ; 0x603d1
	db $0, "Oh? You managed to", $4f
	db "get this far?", $51
	db "You must be quite", $4f
	db "the trainer.", $51
	db "We intend to take", $4f
	db "over this RADIO", $51
	db "STATION and an-", $4f
	db "nounce our come-", $55
	db "back.", $51
	db "That should bring", $4f
	db "our boss GIOVANNI", $51
	db "back from his solo", $4f
	db "training.", $51
	db "We are going to", $4f
	db "regain our former", $55
	db "glory.", $51
	db "I won't allow you", $4f
	db "to interfere with", $55
	db "our plans.", $57
; 0x604f3

UnknownText_0x604f3: ; 0x604f3
	db $0, "No! Forgive me,", $4f
	db "GIOVANNI!", $57
; 0x6050e

UnknownText_0x6050e: ; 0x6050e
	db $0, "How could this be?", $51
	db "Our dreams have", $4f
	db "come to naught.", $51
	db "I wasn't up to the", $4f
	db "task after all.", $51
	db "Like GIOVANNI did", $4f
	db "before me, I will", $51
	db "disband TEAM", $4f
	db "ROCKET here today.", $51
	db "Farewell.", $57
; 0x605b2

UnknownText_0x605b2: ; 0x605b2
	db $0, "DIRECTOR: ", $14, ",", $4f
	db "thank you!", $51
	db "Your courageous", $4f
	db "actions have saved", $51
	db "#MON nation-", $4f
	db "wide.", $51
	db "I know it's not", $4f
	db "much, but please", $55
	db "take this.", $57
; 0x6062c

UnknownText_0x6062c: ; 0x6062c
	db $0, "There used to be a", $4f
	db "tower right here", $55
	db "in GOLDENROD CITY.", $51
	db "But it was old and", $4f
	db "creaky.", $51
	db "So we replaced it", $4f
	db "with our RADIO", $55
	db "TOWER.", $51
	db "We dug up that", $4f
	db "bell during", $55
	db "construction.", $51
	db "I heard that all", $4f
	db "sorts of #MON", $51
	db "lived in GOLDENROD", $4f
	db "in the past.", $51
	db "Perhaps…", $51
	db "That bell has some", $4f
	db "connection to the", $51
	db "TIN TOWER in", $4f
	db "ECRUTEAK CITY…", $51
	db "Ah!", $51
	db "That reminds me…", $51
	db "I overheard TEAM", $4f
	db "ROCKET whispering.", $51
	db "Apparently, some-", $4f
	db "thing is going on", $55
	db "at the TIN TOWER.", $51
	db "I have no idea", $4f
	db "what is happening,", $51
	db "but you might look", $4f
	db "into it.", $51
	db "OK, I better go to", $4f
	db "my OFFICE.", $57
; 0x60824

UnknownText_0x60824: ; 0x60824
	db $0, "DIRECTOR: Hello,", $4f
	db $14, "!", $51
	db "You know, I love", $4f
	db "#MON.", $51
	db "I built this RADIO", $4f
	db "TOWER so I could", $51
	db "express my love", $4f
	db "of #MON.", $51
	db "It would be nice", $4f
	db "if people enjoyed", $55
	db "our programs.", $57
; 0x608be

UnknownText_0x608be: ; 0x608be
	db $0, "BEN: Do you listen", $4f
	db "to our music?", $57
; 0x608e0

UnknownText_0x608e0: ; 0x608e0
	db $0, "5F DIRECTOR'S", $4f
	db "   OFFICE", $57
; 0x608f9

UnknownText_0x608f9: ; 0x608f9
	db $0, "5F STUDIO 1", $57
; 0x60906

RadioTower5F_MapEventHeader: ; 0x60906
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $0, $0, 1, GROUP_RADIO_TOWER_4F, MAP_RADIO_TOWER_4F
	warp_def $0, $c, 3, GROUP_RADIO_TOWER_4F, MAP_RADIO_TOWER_4F

	; xy triggers
	db 2
	xy_trigger 0, $3, $0, $0, UnknownScript_0x60011, $0, $0
	xy_trigger 1, $5, $10, $0, UnknownScript_0x6006e, $0, $0

	; signposts
	db 5
	signpost 0, 3, $0, MapRadioTower5FSignpost0Script
	signpost 0, 11, $0, MapRadioTower5FSignpost2Script
	signpost 0, 15, $0, MapRadioTower5FSignpost2Script
	signpost 1, 16, $0, MapRadioTower5FSignpost4Script
	signpost 1, 17, $0, MapRadioTower5FSignpost4Script

	; people-events
	db 5
	person_event $40, 10, 7, $3, $0, 255, 255, $0, 0, UnknownScript_0x60046, $ffff
	person_event $35, 9, 17, $8, $0, 255, 255, $0, 0, ObjectEvent, $06ce
	person_event $36, 6, 21, $8, $0, 255, 255, $82, 1, TrainerExecutivef1, $06ce
	person_event $2c, 9, 17, $8, $0, 255, 255, $80, 0, UnknownScript_0x600fb, $06d0
	person_event $54, 9, 12, $1, $0, 255, 255, $1, 0, ItemFragment_0x600fe, $07cd
; 0x60980

OlivineLighthouse5F_MapScriptHeader: ; 0x60980
	; trigger count
	db 0

	; callback count
	db 0
; 0x60982

TrainerBird_keeperDenis: ; 0x60982
	; bit/flag number
	dw $400

	; trainer group && trainer id
	db BIRD_KEEPER, DENIS

	; text when seen
	dw Bird_keeperDenisSeenText

	; text when trainer beaten
	dw Bird_keeperDenisBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperDenisScript
; 0x6098e

Bird_keeperDenisScript: ; 0x6098e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x60ac3
	closetext
	loadmovesprites
	end
; 0x60996

TrainerSailorErnest: ; 0x60996
	; bit/flag number
	dw $579

	; trainer group && trainer id
	db SAILOR, ERNEST

	; text when seen
	dw SailorErnestSeenText

	; text when trainer beaten
	dw SailorErnestBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SailorErnestScript
; 0x609a2

SailorErnestScript: ; 0x609a2
	talkaftercancel
	loadfont
	2writetext UnknownText_0x60a1f
	closetext
	loadmovesprites
	end
; 0x609aa

ItemFragment_0x609aa: ; 0x609aa
	db RARE_CANDY, 1
; 0x609ac

ItemFragment_0x609ac: ; 0x609ac
	db SUPER_REPEL, 1
; 0x609ae

ItemFragment_0x609ae: ; 0x609ae
	db TM_34, 1
; 0x609b0

MapOlivineLighthouse5FSignpostItem0: ; 0x609b0
	dw $0085
	db HYPER_POTION
	
; 0x609b3

SailorErnestSeenText: ; 0x609b3
	db $0, "I wanted to battle", $4f
	db "JASMINE, but she's", $51
	db "not up to it now.", $4f
	db "So, how about you?", $57
; 0x609fe

SailorErnestBeatenText: ; 0x609fe
	db $0, "Whoa, whoa. You're", $4f
	db "overwhelming!", $57
; 0x60a1f

UnknownText_0x60a1f: ; 0x60a1f
	db $0, "A GYM LEADER isn't", $4f
	db "just about being", $51
	db "strong. A LEADER", $4f
	db "also needs to be", $55
	db "compassionate.", $57
; 0x60a74

Bird_keeperDenisSeenText: ; 0x60a74
	db $0, "We're pretty high", $4f
	db "up here. My bird", $51
	db "#MON are in", $4f
	db "prime form.", $57
; 0x60aaf

Bird_keeperDenisBeatenText: ; 0x60aaf
	db $0, "Oops…They crashed…", $57
; 0x60ac3

UnknownText_0x60ac3: ; 0x60ac3
	db $0, "My #MON learned", $4f
	db "how to use FLY in", $55
	db "CIANWOOD.", $51
	db "Well, since I'm a", $4f
	db "loser, I'll FLY", $55
	db "across the sea…", $57
; 0x60b20

OlivineLighthouse5F_MapEventHeader: ; 0x60b20
	; filler
	db 0, 0

	; warps
	db 7
	warp_def $f, $9, 1, GROUP_OLIVINE_LIGHTHOUSE_6F, MAP_OLIVINE_LIGHTHOUSE_6F
	warp_def $5, $3, 2, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F
	warp_def $7, $9, 3, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F
	warp_def $7, $10, 9, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F
	warp_def $7, $11, 10, GROUP_OLIVINE_LIGHTHOUSE_4F, MAP_OLIVINE_LIGHTHOUSE_4F
	warp_def $5, $10, 2, GROUP_OLIVINE_LIGHTHOUSE_6F, MAP_OLIVINE_LIGHTHOUSE_6F
	warp_def $5, $11, 3, GROUP_OLIVINE_LIGHTHOUSE_6F, MAP_OLIVINE_LIGHTHOUSE_6F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 13, 3, $7, MapOlivineLighthouse5FSignpostItem0

	; people-events
	db 5
	person_event $49, 15, 12, $a, $0, 255, 255, $92, 3, TrainerSailorErnest, $ffff
	person_event $27, 7, 12, $8, $0, 255, 255, $92, 4, TrainerBird_keeperDenis, $ffff
	person_event $54, 16, 19, $1, $0, 255, 255, $1, 0, ItemFragment_0x609aa, $0665
	person_event $54, 19, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x609ac, $0666
	person_event $54, 17, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x609ae, $0667
; 0x60b8f

OlivineLighthouse6F_MapScriptHeader: ; 0x60b8f
	; trigger count
	db 0

	; callback count
	db 0
; 0x60b91

UnknownScript_0x60b91: ; 0x60b91
	faceplayer
	loadfont
	checkitem SECRETPOTION
	iftrue UnknownScript_0x60bab
	checkbit1 $0037
	iftrue UnknownScript_0x60ba5
	2writetext UnknownText_0x60c81
	keeptextopen
	setbit1 $0037
UnknownScript_0x60ba5: ; 0x60ba5
	2writetext UnknownText_0x60d64
	closetext
	loadmovesprites
	end
; 0x60bab

UnknownScript_0x60bab: ; 0x60bab
	2writetext UnknownText_0x60d99
	yesorno
	iffalse UnknownScript_0x60c25
	2writetext UnknownText_0x60dc3
	keeptextopen
	takeitem SECRETPOTION, 1
	2writetext UnknownText_0x60dea
	closetext
	loadmovesprites
	spriteface $2, $3
	pause 15
	spriteface $3, $2
	loadfont
	playmusic $000d
	2writetext UnknownText_0x60e44
	pause 60
	keeptextopen
	loadmovesprites
	special $003d
	cry AMPHAROS
	special $002e
	pause 10
	special $0031
	loadfont
	2writetext UnknownText_0x60f3d
	closetext
	loadmovesprites
	spriteface $3, $3
	pause 10
	spriteface $3, $2
	pause 10
	spriteface $3, $3
	pause 10
	spriteface $3, $2
	pause 10
	faceplayer
	loadfont
	2writetext UnknownText_0x60e6c
	closetext
	loadmovesprites
	setbit1 $0020
	clearbit1 $06d3
	checkcode $9
	if_equal $0, UnknownScript_0x60c17
	if_equal $3, UnknownScript_0x60c1e
	applymovement $2, MovementData_0x60c68
	disappear $2
	end
; 0x60c17

UnknownScript_0x60c17: ; 0x60c17
	applymovement $2, MovementData_0x60c70
	disappear $2
	end
; 0x60c1e

UnknownScript_0x60c1e: ; 0x60c1e
	applymovement $2, MovementData_0x60c79
	disappear $2
	end
; 0x60c25

UnknownScript_0x60c25: ; 0x60c25
	2writetext UnknownText_0x60edf
	closetext
	loadmovesprites
	spriteface $2, $3
	pause 15
	spriteface $3, $2
	loadfont
	2writetext UnknownText_0x60ef1
	closetext
	loadmovesprites
	end
; 0x60c39

UnknownScript_0x60c39: ; 0x60c39
	end
; 0x60c3a

UnknownScript_0x60c3a: ; 0x60c3a
	faceplayer
	loadfont
	checkbit1 $0020
	iftrue UnknownScript_0x60c51
	2writetext UnknownText_0x60f03
	writebyte AMPHAROS
	special $005f
	keeptextopen
	2writetext UnknownText_0x60f19
	closetext
	loadmovesprites
	end
; 0x60c51

UnknownScript_0x60c51: ; 0x60c51
	2writetext UnknownText_0x60f3d
	cry AMPHAROS
	closetext
	loadmovesprites
	special $002e
	special $0031
	special $002e
	special $0031
	end
; 0x60c66

ItemFragment_0x60c66: ; 0x60c66
	db SUPER_POTION, 1
; 0x60c68

MovementData_0x60c68: ; 0x60c68
	slow_step_up
	slow_step_up
	slow_step_right
	slow_step_up
	slow_step_up
	accelerate_last
	accelerate_last
	step_end
; 0x60c70

MovementData_0x60c70: ; 0x60c70
	slow_step_down
	slow_step_right
	slow_step_right
	slow_step_right
	slow_step_up
	slow_step_right
	slow_step_right
	slow_step_right
	step_end
; 0x60c79

MovementData_0x60c79: ; 0x60c79
	slow_step_up
	slow_step_up
	slow_step_right
	slow_step_up
	slow_step_up
	slow_step_up
	accelerate_last
	step_end
; 0x60c81

UnknownText_0x60c81: ; 0x60c81
	db $0, "JASMINE: … This", $4f
	db "#MON always", $51
	db "kept the sea lit", $4f
	db "at night.", $51
	db "…But it suddenly", $4f
	db "got sick… It's", $55
	db "gasping for air…", $51
	db "…I understand", $4f
	db "that there is a", $51
	db "wonderful PHARMACY", $4f
	db "in CIANWOOD…", $51
	db "But that's across", $4f
	db "the sea…", $51
	db "And I can't leave", $4f
	db "AMPHY unattended…", $57
; 0x60d64

UnknownText_0x60d64: ; 0x60d64
	db $0, "…May I ask you to", $4f
	db "get some medicine", $55
	db "for me? Please?", $57
; 0x60d99

UnknownText_0x60d99: ; 0x60d99
	db $0, "JASMINE: …Will", $4f
	db "that medicine cure", $55
	db "AMPHY?", $57
; 0x60dc3

UnknownText_0x60dc3: ; 0x60dc3
	db $0, $52, " handed the", $4f
	db "SECRETPOTION to", $55
	db "JASMINE.", $57
; 0x60dea

UnknownText_0x60dea: ; 0x60dea
	db $0, "JASMINE: …Um,", $4f
	db "please don't be", $55
	db "offended…", $51
	db "…AMPHY will not", $4f
	db "take anything from", $55
	db "anyone but me…", $57
; 0x60e44

UnknownText_0x60e44: ; 0x60e44
	db $0, "JASMINE: …", $51
	db "AMPHY, how are you", $4f
	db "feeling?", $57
; 0x60e6c

UnknownText_0x60e6c: ; 0x60e6c
	db $0, "JASMINE: …Oh, I'm", $4f
	db "so relieved…", $51
	db "This is just so", $4f
	db "wonderful…", $51
	db "Thank you so very,", $4f
	db "very much.", $51
	db "…I will return to", $4f
	db "the GYM…", $57
; 0x60edf

UnknownText_0x60edf: ; 0x60edf
	db $0, "JASMINE: …I see…", $57
; 0x60ef1

UnknownText_0x60ef1: ; 0x60ef1
	db $0, "…AMPHY, hang on!", $57
; 0x60f03

UnknownText_0x60f03: ; 0x60f03
	db $0, "AMPHY: …", $4f
	db "…Pa… paloo…", $57
; 0x60f19

UnknownText_0x60f19: ; 0x60f19
	db $0, "Its breathing is", $4f
	db "terribly labored…", $57
; 0x60f3d

UnknownText_0x60f3d: ; 0x60f3d
	db $0, "AMPHY: Palu!", $4f
	db "Palulu!", $57
; 0x60f53

OlivineLighthouse6F_MapEventHeader: ; 0x60f53
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $f, $9, 1, GROUP_OLIVINE_LIGHTHOUSE_5F, MAP_OLIVINE_LIGHTHOUSE_5F
	warp_def $5, $10, 6, GROUP_OLIVINE_LIGHTHOUSE_5F, MAP_OLIVINE_LIGHTHOUSE_5F
	warp_def $5, $11, 7, GROUP_OLIVINE_LIGHTHOUSE_5F, MAP_OLIVINE_LIGHTHOUSE_5F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $17, 12, 12, $6, $0, 255, 255, $80, 0, UnknownScript_0x60b91, $06d2
	person_event $4c, 12, 13, $6, $0, 255, 255, $b0, 0, UnknownScript_0x60c3a, $ffff
	person_event $54, 8, 7, $1, $0, 255, 255, $1, 0, ItemFragment_0x60c66, $0668
; 0x60f8f

GoldenrodPokeCenter1F_MapScriptHeader: ; 0x60f8f
	; trigger count
	db 0

	; callback count
	db 0
; 0x60f91

UnknownScript_0x60f91: ; 0x60f91
	jumpstd $0000
; 0x60f94

UnknownScript_0x60f94: ; 0x60f94
	writebyte $b
	special $0086
	if_equal $b, UnknownScript_0x60f9e
	end
; 0x60f9e

UnknownScript_0x60f9e: ; 0x60f9e
	checkbit1 $0340
	iftrue UnknownScript_0x60fd8
	playsound $0023
	moveperson $3, $0, $7
	disappear $3
	appear $3
	playmusic $0011
	applymovement $3, MovementData_0x6105a
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x622f0
	closetext
	verbosegiveitem GS_BALL, 1
	setbit1 $0340
	setbit1 $00be
	2writetext UnknownText_0x62359
	closetext
	loadmovesprites
	applymovement $3, MovementData_0x61060
	special $003d
	disappear $3
	playsound $0023
UnknownScript_0x60fd8: ; 0x60fd8
	end
; 0x60fd9

UnknownScript_0x60fd9: ; 0x60fd9
	writebyte $b
	special $0086
	if_equal $b, UnknownScript_0x60fe3
	end
; 0x60fe3

UnknownScript_0x60fe3: ; 0x60fe3
	checkbit1 $0340
	iftrue UnknownScript_0x6101d
	playsound $0023
	moveperson $3, $0, $7
	disappear $3
	appear $3
	playmusic $0011
	applymovement $3, MovementData_0x61065
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x622f0
	closetext
	verbosegiveitem GS_BALL, 1
	setbit1 $0340
	setbit1 $00be
	2writetext UnknownText_0x62359
	closetext
	loadmovesprites
	applymovement $3, MovementData_0x6106c
	special $003d
	disappear $3
	playsound $0023
UnknownScript_0x6101d: ; 0x6101d
	end
; 0x6101e

UnknownScript_0x6101e: ; 0x6101e
	jumptextfaceplayer UnknownText_0x62105
; 0x61021

UnknownScript_0x61021: ; 0x61021
	jumptextfaceplayer UnknownText_0x62260
; 0x61024

UnknownScript_0x61024: ; 0x61024
	faceplayer
	loadfont
	2writetext UnknownText_0x623fb
	closetext
	2writetext UnknownText_0x6248c
	yesorno
	iffalse UnknownScript_0x6104b
	takeitem EON_MAIL, 1
	iffalse UnknownScript_0x6104b
	2writetext UnknownText_0x62549
	closetext
	2writetext UnknownText_0x624a4
	closetext
	verbosegiveitem REVIVE, 1
	iffalse UnknownScript_0x61051
	2writetext UnknownText_0x624e9
	closetext
	loadmovesprites
	end
; 0x6104b

UnknownScript_0x6104b: ; 0x6104b
	2writetext UnknownText_0x62509
	closetext
	loadmovesprites
	end
; 0x61051

UnknownScript_0x61051: ; 0x61051
	giveitem EON_MAIL, $1
	2writetext UnknownText_0x6252a
	closetext
	loadmovesprites
	end
; 0x6105a

MovementData_0x6105a: ; 0x6105a
	step_up
	step_right
	step_right
	step_right
	turn_head_down
	step_end
; 0x61060

MovementData_0x61060: ; 0x61060
	step_left
	step_left
	step_left
	step_down
	step_end
; 0x61065

MovementData_0x61065: ; 0x61065
	step_up
	step_right
	step_right
	step_right
	step_right
	turn_head_down
	step_end
; 0x6106c

MovementData_0x6106c: ; 0x6106c
	step_left
	step_left
	step_left
	step_left
	step_down
	step_end
; 0x61072

; unused
UnknownText_0x61072: ; 0x61072
	db $0, "Hello! Welcome to", $4f
	db "#COM CENTER", $55
	db "TRADE CORNER.", $51
	db "You can trade", $4f
	db "#MON with other", $55
	db "people far away.", $57
; 0x610ce

UnknownText_0x610ce: ; 0x610ce
	db $0, "To make a trade,", $4f
	db "we must hold your", $55
	db "#MON.", $51
	db "Would you like to", $4f
	db "trade?", $57
; 0x61111

UnknownText_0x61111: ; 0x61111
	db $0, "What kind of", $4f
	db "#MON do you", $55
	db "want in return?", $57
; 0x6113b

UnknownText_0x6113b: ; 0x6113b
	db $0, "Fine. We will try", $4f
	db "to trade your", $51
	db "@"
	text_from_ram $d099
	db $0, " for", $4f
	db "@"
	text_from_ram $d0ac
	db $0, ".", $51
	db "We'll have to hold", $4f
	db "your #MON", $55
	db "during the trade.", $51
	db "Please wait while", $4f
	db "we prepare the", $55
	db "room for it.", $57
; 0x611c9

UnknownText_0x611c9: ; 0x611c9
	db $0, "Fine. We will try", $4f
	db "to trade your", $51
	db "@"
	text_from_ram $d099
	db $0, " for a", $4f
	db "#MON that you", $55
	db "have never seen.", $51
	db "We'll have to hold", $4f
	db "your #MON", $55
	db "during the trade.", $51
	db "Please wait while", $4f
	db "we prepare the", $55
	db "room for it.", $57
; 0x61271

UnknownText_0x61271: ; 0x61271
	db $0, "Your trade #MON", $4f
	db "has been received.", $51
	db "It will take time", $4f
	db "to find a trade", $51
	db "partner. Please", $4f
	db "come back later.", $57
; 0x612d8

UnknownText_0x612d8: ; 0x612d8
	db $0, "Oh? You have only", $4f
	db "one #MON in", $55
	db "your party. ", $51
	db "Please come back", $4f
	db "once you've in-", $55
	db "creased the size", $55
	db "of your party.", $57
; 0x61344

UnknownText_0x61344: ; 0x61344
	db $0, "We hope to see you", $4f
	db "again.", $57
; 0x6135f

UnknownText_0x6135f: ; 0x6135f
	db $0, "Communication", $4f
	db "error…", $57
; 0x61375

UnknownText_0x61375: ; 0x61375
	db $0, "If we accept that", $4f
	db "#MON, what will", $55
	db "you battle with?", $57
; 0x613a9

UnknownText_0x613a9: ; 0x613a9
	db $0, "Sorry. We can't", $4f
	db "accept an EGG.", $57
; 0x613c8

UnknownText_0x613c8: ; 0x613c8
	db $0, "Sorry, but your", $4f
	db "#MON appears to", $51
	db "be abnormal. We", $4f
	db "can't accept it.", $57
; 0x61409

UnknownText_0x61409: ; 0x61409
	db $0, "Oh? Aren't we", $4f
	db "already holding a", $55
	db "#MON of yours?", $57
; 0x61438

UnknownText_0x61438: ; 0x61438
	db $0, "We'll check the", $4f
	db "rooms.", $51
	db "Please wait.", $57
; 0x6145c

UnknownText_0x6145c: ; 0x6145c
	db $0, "Thank you for your", $4f
	db "patience.", $51
	db "A trade partner", $4f
	db "has been found.", $57
; 0x6149a

UnknownText_0x6149a: ; 0x6149a
	db $0, "It's your new", $4f
	db "partner.", $51
	db "Please take care", $4f
	db "of it with love.", $51
	db "We hope to see you", $4f
	db "again.", $57
; 0x614ed

UnknownText_0x614ed: ; 0x614ed
	db $0, "Uh-oh. Your party", $4f
	db "is already full.", $51
	db "Please come back", $4f
	db "when you have room", $55
	db "in your party.", $57
; 0x61544

UnknownText_0x61544: ; 0x61544
	db $0, "It's unfortunate,", $4f
	db "but no one has", $51
	db "come forward as a", $4f
	db "trade partner.", $51
	db "Would you like", $4f
	db "your #MON back?", $57
; 0x615a5

UnknownText_0x615a5: ; 0x615a5
	db $0, "We have returned", $4f
	db "your #MON.", $57
; 0x615c2

UnknownText_0x615c2: ; 0x615c2
	db $0, "It's unfortunate,", $4f
	db "but no one has", $51
	db "come forward as a", $4f
	db "trade partner.", $51
	db "We've held your", $4f
	db "#MON for a long", $51
	db "time. As a result,", $4f
	db "it is very lonely.", $51
	db "Sorry, but we must", $4f
	db "return it to you.", $57
; 0x6166e

UnknownText_0x6166e: ; 0x6166e
	db $0, "We hope to see you", $4f
	db "again.", $57
; 0x61689

UnknownText_0x61689: ; 0x61689
	db $0, "Fine. We will", $4f
	db "continue to hold", $55
	db "your #MON.", $57
; 0x616b4

UnknownText_0x616b4: ; 0x616b4
	db $0, "Oh? You left your", $4f
	db "#MON with us", $55
	db "only recently.", $51
	db "Please come back", $4f
	db "later.", $57
; 0x616fb

UnknownText_0x616fb: ; 0x616fb
	db $0, "We'll SAVE before", $4f
	db "connecting to the", $55
	db "CENTER.", $57
; 0x61727

UnknownText_0x61727: ; 0x61727
	db $0, "Which #MON do", $4f
	db "you want to trade?", $57
; 0x61749

UnknownText_0x61749: ; 0x61749
	db $0, "Sorry, but we must", $4f
	db "cancel the trade.", $57
; 0x6176f

UnknownText_0x6176f: ; 0x6176f
	db $0, "Oh!", $51
	db "I see you have an", $4f
	db "EGG TICKET!", $51
	db "It's a coupon that", $4f
	db "special people can", $51
	db "redeem for a", $4f
	db "special #MON!", $57
; 0x617d2

UnknownText_0x617d2: ; 0x617d2
	db $0, "Let me give you a", $4f
	db "quick briefing.", $51
	db "Trades held at the", $4f
	db "TRADE CORNER are", $51
	db "between two", $4f
	db "trainers who don't", $51
	db "know each other's", $4f
	db "identity.", $51
	db "As a result, it", $4f
	db "may take time.", $51
	db "However, an ODD", $4f
	db "EGG is available", $55
	db "just for you.", $51
	db "It will be sent to", $4f
	db "you right away.", $51
	db "Please choose one", $4f
	db "of the rooms in", $51
	db "the CENTER.", $4f
	db "An ODD EGG will be", $51
	db "sent from the", $4f
	db "chosen room.", $57
; 0x6191f

UnknownText_0x6191f: ; 0x6191f
	db $0, "Please wait a", $4f
	db "moment.", $57
; 0x61936

UnknownText_0x61936: ; 0x61936
	db $0, "Thank you for", $4f
	db "waiting.", $51
	db "We received your", $4f
	db "ODD EGG.", $51
	db "Here it is!", $51
	db "Please raise it", $4f
	db "with loving care.", $57
; 0x61996

UnknownText_0x61996: ; 0x61996
	db $0, "I'm awfully sorry.", $51
	db "The EGG TICKET", $4f
	db "exchange service", $55
	db "isn't running now.", $57
; 0x619db

UnknownText_0x619db: ; 0x619db
	db $0, "It's a #MON", $4f
	db "NEWS MACHINE.", $57
; 0x619f5

UnknownText_0x619f5: ; 0x619f5
	db $0, "What would you", $4f
	db "like to do?", $57
; 0x61a11

UnknownText_0x61a11: ; 0x61a11
	db $0, "#MON NEWS is", $4f
	db "news compiled from", $51
	db "the SAVE files of", $4f
	db "#MON trainers.", $51
	db "When reading the", $4f
	db "NEWS, your SAVE", $51
	db "file may be sent", $4f
	db "out.", $51
	db "The SAVE file data", $4f
	db "will contain your", $51
	db "adventure log and", $4f
	db "mobile profile.", $51
	db "Your phone number", $4f
	db "will not be sent.", $51
	db "The contents of", $4f
	db "the NEWS will vary", $51
	db "depending on the", $4f
	db "SAVE files sent by", $51
	db "you and the other", $4f
	db "#MON trainers.", $51
	db "You might even be", $4f
	db "in the NEWS!", $57
; 0x61b7c

UnknownText_0x61b7c: ; 0x61b7c
	db $0, "Would you like to", $4f
	db "get the NEWS?", $57
; 0x61b9d

UnknownText_0x61b9d: ; 0x61b9d
	db $0, "Reading the latest", $4f
	db "NEWS… Please wait.", $57
; 0x61bc4

UnknownText_0x61bc4: ; 0x61bc4
	db $0, "There is no old", $4f
	db "NEWS…", $57
; 0x61bdb

UnknownText_0x61bdb: ; 0x61bdb
	db $0, "The NEWS data is", $4f
	db "corrupted.", $51
	db "Please download", $4f
	db "the NEWS again.", $57
; 0x61c18

UnknownText_0x61c18: ; 0x61c18
	db $0, "We're making", $4f
	db "preparations.", $51
	db "Please come back", $4f
	db "later.", $57
; 0x61c4b

UnknownText_0x61c4b: ; 0x61c4b
	db $0, "We will SAVE your", $4f
	db "progress before", $51
	db "starting the NEWS", $4f
	db "MACHINE.", $57
; 0x61c89

UnknownText_0x61c89: ; 0x61c89
	db $0, "Whoa, this #MON", $4f
	db "CENTER is huge.", $51
	db "They just built", $4f
	db "this place. They", $51
	db "installed lots of", $4f
	db "new machines too.", $57
; 0x61cef

UnknownText_0x61cef: ; 0x61cef
	db $0, "I thought up a fun", $4f
	db "new thing for the", $55
	db "TRADE CORNER!", $51
	db "I make a PIDGEY", $4f
	db "hold MAIL, then", $51
	db "put it up for", $4f
	db "trade for another", $55
	db "one!", $51
	db "If everyone did", $4f
	db "that, MAIL could", $51
	db "be traded with all", $4f
	db "sorts of people!", $51
	db "I call it PIDGEY", $4f
	db "MAIL!", $51
	db "If it becomes", $4f
	db "popular, I might", $51
	db "make lots of new", $4f
	db "friends!", $57
; 0x61dfd

UnknownText_0x61dfd: ; 0x61dfd
	db $0, "They said you can", $4f
	db "trade #MON with", $51
	db "total strangers up", $4f
	db "here.", $51
	db "But they're still", $4f
	db "adjusting things.", $57
; 0x61e5c

UnknownText_0x61e5c: ; 0x61e5c
	db $0, "Some girl I don't", $4f
	db "know sent me her", $51
	db "HOPPIP.", $4f
	db "You should trade", $51
	db "for a #MON that", $4f
	db "you want.", $57
; 0x61eb2

UnknownText_0x61eb2: ; 0x61eb2
	db $0, "I received a", $4f
	db "female HOPPIP, but", $55
	db "its named STANLEY!", $51
	db "That's my dad's", $4f
	db "name!", $57
; 0x61efa

UnknownText_0x61efa: ; 0x61efa
	db $0, "What is the NEWS", $4f
	db "MACHINE?", $51
	db "Does it get news", $4f
	db "from a wider area", $55
	db "than the radio?", $57
; 0x61f48

UnknownText_0x61f48: ; 0x61f48
	db $0, "The #COM CENTER", $4f
	db "will link with all", $51
	db "#MON CENTERS in", $4f
	db "a wireless net.", $51
	db "That must mean", $4f
	db "I'll be able to", $51
	db "link with all", $4f
	db "sorts of people.", $57
; 0x61fc9

UnknownText_0x61fc9: ; 0x61fc9
	db $0, "The machines here", $4f
	db "can't be used yet.", $51
	db "Still, it's nice", $4f
	db "coming to a trendy", $51
	db "place before other", $4f
	db "people.", $57
; 0x6202c

UnknownText_0x6202c: ; 0x6202c
	db $0, "My friend was in", $4f
	db "the NEWS a while", $51
	db "back. I was really", $4f
	db "surprised!", $57
; 0x6206d

UnknownText_0x6206d: ; 0x6206d
	db $0, "I get anxious if I", $4f
	db "don't check out", $55
	db "the latest NEWS!", $57
; 0x620a1

UnknownText_0x620a1: ; 0x620a1
	db $0, "If I get in the", $4f
	db "NEWS and become", $51
	db "famous, I bet I'll", $4f
	db "be adored.", $51
	db "I wonder how I", $4f
	db "could get in the", $55
	db "NEWS?", $57
; 0x62105

UnknownText_0x62105: ; 0x62105
	db $0, "The COLOSSEUM", $4f
	db "upstairs is for", $55
	db "link battles.", $51
	db "Battle records are", $4f
	db "posted on the", $51
	db "wall, so I can't", $4f
	db "afford to lose.", $57
; 0x62173

UnknownText_0x62173: ; 0x62173
	db $0, "I came over here", $4f
	db "when I got word", $51
	db "that GOLDENROD's", $4f
	db "#MON CENTER has", $51
	db "new machines that", $4f
	db "no one's ever seen", $55
	db "before.", $51
	db "But it looks like", $4f
	db "they're still busy", $51
	db "with all their", $4f
	db "preparations…", $57
; 0x62222

UnknownText_0x62222: ; 0x62222
	db $0, "Just seeing all", $4f
	db "these new things", $51
	db "here makes me feel", $4f
	db "younger!", $57
; 0x62260

UnknownText_0x62260: ; 0x62260
	db $0, "A higher level", $4f
	db "#MON doesn't", $55
	db "always win.", $51
	db "After all, it may", $4f
	db "have a type dis-", $55
	db "advantage.", $51
	db "I don't think", $4f
	db "there is a single", $51
	db "#MON that is", $4f
	db "the toughest.", $57
; 0x622f0

UnknownText_0x622f0: ; 0x622f0
	db $0, $52, ", isn't it?", $51
	db "Congratulations!", $51
	db "As a special deal,", $4f
	db "a GS BALL has been", $55
	db "sent just for you!", $51
	db "Please accept it!", $57
; 0x62359

UnknownText_0x62359: ; 0x62359
	db $0, "Please do come", $4f
	db "again!", $57
; 0x62370

UnknownText_0x62370: ; 0x62370
	db $0, "#COM CENTER", $4f
	db "1F INFORMATION", $51
	db "Left:", $4f
	db "ADMINISTRATION", $51
	db "Center:", $4f
	db "TRADE CORNER", $51
	db "Right:", $4f
	db "#MON NEWS", $57
; 0x623c7

UnknownText_0x623c7: ; 0x623c7
	db $0, "It's a #MON", $4f
	db "NEWS MACHINE!", $51
	db "It's not in", $4f
	db "operation yet…", $57
; 0x623fb

UnknownText_0x623fb: ; 0x623fb
	db $0, "Oh my, your pack", $4f
	db "looks so heavy!", $51
	db "Oh! Do you happen", $4f
	db "to have something", $55
	db "named EON MAIL?", $51
	db "My daughter is", $4f
	db "after one.", $51
	db "You can part with", $4f
	db "one, can't you?", $57
; 0x6248c

UnknownText_0x6248c: ; 0x6248c
	db $0, "Give away an EON", $4f
	db "MAIL?", $57
; 0x624a4

UnknownText_0x624a4: ; 0x624a4
	db $0, "Oh, that's great!", $4f
	db "Thank you, honey!", $51
	db "Here, this is for", $4f
	db "you in return!", $57
; 0x624e9

UnknownText_0x624e9: ; 0x624e9
	db $0, "My daughter will", $4f
	db "be delighted!", $57
; 0x62509

UnknownText_0x62509: ; 0x62509
	db $0, "Oh? You don't have", $4f
	db "one? Too bad.", $57
; 0x6252a

UnknownText_0x6252a: ; 0x6252a
	db $0, "Oh… Well, another", $4f
	db "time, then.", $57
; 0x62549

UnknownText_0x62549: ; 0x62549
	db $0, $52, " gave away", $4f
	db "the EON MAIL.", $57
; 0x62564

GoldenrodPokeCenter1F_MapEventHeader: ; 0x62564
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $7, $3, 15, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $4, 15, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $6, $0, 1, GROUP_GOLDENROD_POKECOM_CENTER_2F_MOBILE, MAP_GOLDENROD_POKECOM_CENTER_2F_MOBILE
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 2
	xy_trigger 0, $7, $3, $0, UnknownScript_0x60f94, $0, $0
	xy_trigger 0, $7, $4, $0, UnknownScript_0x60fd9, $0, $0

	; signposts
	db 0

	; people-events
	db 5
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x60f91, $ffff
	person_event $38, 12, 20, $6, $0, 255, 255, $90, 0, ObjectEvent, $ffff
	person_event $3, 5, 10, $6, $0, 255, 255, $a0, 0, UnknownScript_0x6101e, $ffff
	person_event $28, 8, 5, $5, $1, 255, 255, $0, 0, UnknownScript_0x61021, $ffff
	person_event $2e, 9, 11, $6, $0, 255, 255, $b0, 0, UnknownScript_0x61024, $ffff
; 0x625cf

GoldenrodPokeComCenter2FMobile_MapScriptHeader: ; 0x625cf
	; trigger count
	db 0

	; callback count
	db 0
; 0x625d1

UnknownScript_0x625d1: ; 0x625d1
	jumptextfaceplayer UnknownText_0x62674
; 0x625d4

UnknownScript_0x625d4: ; 0x625d4
	jumptextfaceplayer UnknownText_0x626f9
; 0x625d7

UnknownScript_0x625d7: ; 0x625d7
	jumptextfaceplayer UnknownText_0x62795
; 0x625da

MapGoldenrodPokeComCenter2FMobileSignpost0Script: ; 0x625da
	loadfont
	2writetext UnknownText_0x627ee
	closetext
UnknownScript_0x625df: ; 0x625df
	reloadmappart
	loadmenudata $6602
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x625f0
	if_equal $2, UnknownScript_0x625f8
	2jump UnknownScript_0x62600
; 0x625f0

UnknownScript_0x625f0: ; 0x625f0
	loadfont
	2writetext UnknownText_0x62828
	closetext
	2jump UnknownScript_0x625df
; 0x625f8

UnknownScript_0x625f8: ; 0x625f8
	loadfont
	2writetext UnknownText_0x628f4
	closetext
	2jump UnknownScript_0x625df
; 0x62600

UnknownScript_0x62600: ; 0x62600
	loadmovesprites
	end
; 0x62602

INCBIN "baserom.gbc",$62602,$62624 - $62602

MapGoldenrodPokeComCenter2FMobileSignpost1Script: ; 0x62624
	loadfont
	2writetext UnknownText_0x62989
	closetext
UnknownScript_0x62629: ; 0x62629
	reloadmappart
	loadmenudata $664c
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x6263a
	if_equal $2, UnknownScript_0x62642
	2jump UnknownScript_0x6264a
; 0x6263a

UnknownScript_0x6263a: ; 0x6263a
	loadfont
	2writetext UnknownText_0x629ae
	closetext
	2jump UnknownScript_0x62629
; 0x62642

UnknownScript_0x62642: ; 0x62642
	loadfont
	2writetext UnknownText_0x62a5a
	closetext
	2jump UnknownScript_0x62629
; 0x6264a

UnknownScript_0x6264a: ; 0x6264a
	loadmovesprites
	end
; 0x6264c

; menu data
INCBIN "baserom.gbc",$6264c,$25

MapGoldenrodPokeComCenter2FMobileSignpost2Script: ; 0x62671
	jumptext UnknownText_0x62b26
; 0x62674

UnknownText_0x62674: ; 0x62674
	db $0, "#COM CENTER and", $4f
	db "MOBILE CENTER were", $51
	db "built to satisfy", $4f
	db "demands for trades", $51
	db "and battles with", $4f
	db "trainers far away", $51
	db "and with total", $4f
	db "strangers.", $57
; 0x626f9

UnknownText_0x626f9: ; 0x626f9
	db $0, "When you linked", $4f
	db "with someone by", $51
	db "mobile phone for", $4f
	db "the first time,", $51
	db "weren't you", $4f
	db "impressed?", $51
	db "When my first try", $4f
	db "worked, I was so", $51
	db "impressed that I", $4f
	db "got the shakes!", $57
; 0x62795

UnknownText_0x62795: ; 0x62795
	db $0, "They were able to", $4f
	db "build this huge", $51
	db "facility thanks to", $4f
	db "advances in wire-", $55
	db "less technology.", $57
; 0x627ee

UnknownText_0x627ee: ; 0x627ee
	db $0, "It's a notice", $4f
	db "about where MOBILE", $51
	db "ADAPTERS are to be", $4f
	db "used…", $57
; 0x62828

UnknownText_0x62828: ; 0x62828
	db $0, "There's a #COM", $4f
	db "CLUB upstairs in", $51
	db "any #MON", $4f
	db "CENTER.", $51
	db "There, you can", $4f
	db "battle or trade", $51
	db "with a friend far", $4f
	db "away by using a", $55
	db "MOBILE ADAPTER.", $51
	db "To link up, your", $4f
	db "friend must have", $51
	db "the same kind of", $4f
	db "MOBILE ADAPTER as", $55
	db "you.", $57
; 0x628f4

UnknownText_0x628f4: ; 0x628f4
	db $0, "To use the TRADE", $4f
	db "CORNER or read the", $51
	db "#MON NEWS, you", $4f
	db "need to phone the", $55
	db "MOBILE CENTER.", $51
	db "You must register", $4f
	db "at the MOBILE", $51
	db "CENTER before", $4f
	db "connecting there.", $57
; 0x62989

UnknownText_0x62989: ; 0x62989
	db $0, "It's a notice", $4f
	db "about using the", $55
	db "phone…", $57
; 0x629ae

UnknownText_0x629ae: ; 0x629ae
	db $0, "Please ensure that", $4f
	db "your phone and", $51
	db "MOBILE ADAPTER are", $4f
	db "properly linked.", $51
	db "Please make sure", $4f
	db "the wireless phone", $55
	db "signal is strong.", $51
	db "Don't touch or", $4f
	db "hang up the phone", $55
	db "while linking.", $57
; 0x62a5a

UnknownText_0x62a5a: ; 0x62a5a
	db $0, "If the server is", $4f
	db "busy, it may not", $51
	db "be possible to log", $4f
	db "on.", $51
	db "If so, please call", $4f
	db "back later.", $51
	db "If you are unable", $4f
	db "to log on or don't", $51
	db "understand the", $4f
	db "error messages,", $51
	db "call a support", $4f
	db "center or read the", $55
	db "instructions.", $57
; 0x62b26

UnknownText_0x62b26: ; 0x62b26
	db $0, "The ADMINISTRATION", $4f
	db "OFFICE received an", $55
	db "e-mail. It says…", $51
	db $56, " ", $56, " ", $56, $51
	db "To the #COM", $4f
	db "CENTER staff…", $51
	db "Wireless communi-", $4f
	db "cation has enabled", $51
	db "#MON trainers", $4f
	db "to interact across", $51
	db "the nation. Let's", $4f
	db "keep working for", $51
	db "the day when all", $4f
	db "the trainers in", $51
	db "the world can link", $4f
	db "without barriers!", $51
	db $56, " ", $56, " ", $56, $57
; 0x62c32

GoldenrodPokeComCenter2FMobile_MapEventHeader: ; 0x62c32
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $1f, $0, 3, GROUP_GOLDENROD_POKECENTER_1F, MAP_GOLDENROD_POKECENTER_1F
	warp_def $1f, $1, 3, GROUP_GOLDENROD_POKECENTER_1F, MAP_GOLDENROD_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 26, 6, $1, MapGoldenrodPokeComCenter2FMobileSignpost0Script
	signpost 28, 6, $1, MapGoldenrodPokeComCenter2FMobileSignpost1Script
	signpost 26, 3, $1, MapGoldenrodPokeComCenter2FMobileSignpost2Script

	; people-events
	db 3
	person_event $3c, 32, 8, $4, $10, 255, 255, $80, 0, UnknownScript_0x625d1, $ffff
	person_event $3c, 31, 11, $7, $0, 255, 255, $90, 0, UnknownScript_0x625d4, $ffff
	person_event $3c, 33, 11, $7, $0, 255, 255, $a0, 0, UnknownScript_0x625d7, $ffff
; 0x62c78

IlexForestAzaleaGate_MapScriptHeader: ; 0x62c78
	; trigger count
	db 0

	; callback count
	db 0
; 0x62c7a

UnknownScript_0x62c7a: ; 0x62c7a
	jumptextfaceplayer UnknownText_0x62c80
; 0x62c7d

UnknownScript_0x62c7d: ; 0x62c7d
	jumptextfaceplayer UnknownText_0x62cb0
; 0x62c80

UnknownText_0x62c80: ; 0x62c80
	db $0, "ILEX FOREST is", $4f
	db "big. Be careful!", $55
	db "Don't get lost.", $57
; 0x62cb0

UnknownText_0x62cb0: ; 0x62cb0
	db $0, "The FOREST is", $4f
	db "watched over by", $55
	db "its protector.", $51
	db "Stay out of", $4f
	db "mischief!", $57
; 0x62cf4

IlexForestAzaleaGate_MapEventHeader: ; 0x62cf4
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 2, GROUP_ILEX_FOREST, MAP_ILEX_FOREST
	warp_def $5, $0, 3, GROUP_ILEX_FOREST, MAP_ILEX_FOREST
	warp_def $4, $9, 7, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN
	warp_def $5, $9, 8, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $43, 6, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x62c7a, $ffff
	person_event $30, 7, 5, $6, $0, 255, 255, $b0, 0, UnknownScript_0x62c7d, $ffff
; 0x62d28

Route34IlexForestGate_MapScriptHeader: ; 0x62d28
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x62d2d
; 0x62d2d

UnknownScript_0x62d2d: ; 0x62d2d
	checkbit1 $00c0
	iffalse UnknownScript_0x62d38
	disappear $2
	appear $5
	return
; 0x62d38

UnknownScript_0x62d38: ; 0x62d38
	disappear $5
	appear $2
	return
; 0x62d3d

UnknownScript_0x62d3d: ; 0x62d3d
	checkbit1 $00c0
	iffalse UnknownScript_0x62d62
	showemote $0, $5, 20
	spriteface $5, $2
	spriteface $0, $3
	follow $0, $5
	applymovement $0, MovementData_0x62d97
	stopfollow
	spriteface $0, $0
	loadfont
	2writetext UnknownText_0x62e41
	closetext
	loadmovesprites
	applymovement $5, MovementData_0x62d9a
UnknownScript_0x62d62: ; 0x62d62
	end
; 0x62d63

UnknownScript_0x62d63: ; 0x62d63
	faceplayer
	loadfont
	checkbit1 $00c0
	iftrue UnknownScript_0x62d84
	checkbit1 $007a
	iftrue UnknownScript_0x62d7e
	2writetext UnknownText_0x62d9d
	keeptextopen
	verbosegiveitem TM_12, 1
	iffalse UnknownScript_0x62d82
	setbit1 $007a
UnknownScript_0x62d7e: ; 0x62d7e
	2writetext UnknownText_0x62df6
	closetext
UnknownScript_0x62d82: ; 0x62d82
	loadmovesprites
	end
; 0x62d84

UnknownScript_0x62d84: ; 0x62d84
	2writetext UnknownText_0x62e41
	keeptextopen
	loadmovesprites
	end
; 0x62d8a

UnknownScript_0x62d8a: ; 0x62d8a
	loadfont
	2writetext UnknownText_0x62e83
	cry BUTTERFREE
	closetext
	loadmovesprites
	end
; 0x62d94

UnknownScript_0x62d94: ; 0x62d94
	jumptextfaceplayer UnknownText_0x62e97
; 0x62d97

MovementData_0x62d97: ; 0x62d97
	step_up
	step_up
	step_end
; 0x62d9a

MovementData_0x62d9a: ; 0x62d9a
	step_down
	step_right
	step_end
; 0x62d9d

UnknownText_0x62d9d: ; 0x62d9d
	db $0, "Oh, honey. You're", $4f
	db "making a #DEX?", $51
	db "It must be hard if", $4f
	db "#MON won't", $51
	db "appear. Try using", $4f
	db "this TM.", $57
; 0x62df6

UnknownText_0x62df6: ; 0x62df6
	db $0, "It's SWEET SCENT.", $51
	db "Use it wherever", $4f
	db "#MON appear.", $51
	db "#MON will be", $4f
	db "enticed by it.", $57
; 0x62e41

UnknownText_0x62e41: ; 0x62e41
	db $0, "Something's wrong", $4f
	db "in ILEX FOREST…", $51
	db "You should stay", $4f
	db "away right now.", $57
; 0x62e83

UnknownText_0x62e83: ; 0x62e83
	db $0, "BUTTERFREE: Freeh!", $57
; 0x62e97

UnknownText_0x62e97: ; 0x62e97
	db $0, "Did you see the", $4f
	db "shrine honoring", $55
	db "the protector?", $51
	db "It watches over", $4f
	db "the FOREST from", $55
	db "across time.", $51
	db "I think that it", $4f
	db "must be a grass-", $55
	db "type #MON.", $57
; 0x62f20

Route34IlexForestGate_MapEventHeader: ; 0x62f20
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 1, GROUP_ROUTE_34, MAP_ROUTE_34
	warp_def $0, $5, 2, GROUP_ROUTE_34, MAP_ROUTE_34
	warp_def $7, $4, 1, GROUP_ILEX_FOREST, MAP_ILEX_FOREST
	warp_def $7, $5, 1, GROUP_ILEX_FOREST, MAP_ILEX_FOREST

	; xy triggers
	db 1
	xy_trigger 0, $7, $4, $0, UnknownScript_0x62d3d, $0, $0

	; signposts
	db 0

	; people-events
	db 4
	person_event $29, 7, 13, $8, $0, 255, 255, $90, 0, UnknownScript_0x62d63, $06ea
	person_event $8b, 8, 13, $16, $0, 255, 255, $80, 0, UnknownScript_0x62d8a, $ffff
	person_event $28, 8, 7, $4, $10, 255, 255, $a0, 0, UnknownScript_0x62d94, $06eb
	person_event $29, 11, 9, $7, $0, 255, 255, $90, 0, UnknownScript_0x62d63, $06ec
; 0x62f76

DayCare_MapScriptHeader: ; 0x62f76
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x62f7b
; 0x62f7b

UnknownScript_0x62f7b: ; 0x62f7b
	checkbit2 $0005
	iftrue UnknownScript_0x62f88
	clearbit1 $06e5
	setbit1 $06e6
	return
; 0x62f88

UnknownScript_0x62f88: ; 0x62f88
	setbit1 $06e5
	clearbit1 $06e6
	return
; 0x62f8f

UnknownScript_0x62f8f: ; 0x62f8f
	faceplayer
	loadfont
	checkbit1 $033e
	iftrue UnknownScript_0x62fbd
	2writetext UnknownText_0x630ce
	keeptextopen
	loadmovesprites
	checkcode $1
	if_equal $6, UnknownScript_0x62fb6
	special $007d
	loadfont
	2writetext UnknownText_0x631ae
	playsound $0091
	waitbutton
	2writetext UnknownText_0x631c3
	closetext
	loadmovesprites
	setbit1 $033e
	end
; 0x62fb6

UnknownScript_0x62fb6: ; 0x62fb6
	loadfont
	2writetext UnknownText_0x63237
	closetext
	loadmovesprites
	end
; 0x62fbd

UnknownScript_0x62fbd: ; 0x62fbd
	special $001e
	closetext
	loadmovesprites
	end
; 0x62fc3

UnknownScript_0x62fc3: ; 0x62fc3
	faceplayer
	loadfont
	checkbit2 $0005
	iftrue UnknownScript_0x62fd1
	special $001f
	closetext
	loadmovesprites
	end
; 0x62fd1

UnknownScript_0x62fd1: ; 0x62fd1
	2writetext UnknownText_0x62fda
	closetext
	loadmovesprites
	end
; 0x62fd7

MapDayCareSignpost1Script: ; 0x62fd7
	jumpstd $0001
; 0x62fda

UnknownText_0x62fda: ; 0x62fda
	db $0, "Gramps was looking", $4f
	db "for you.", $57
; 0x62ff7

UnknownText_0x62ff7: ; 0x62ff7
	db $0, "I'm the DAY-CARE", $4f
	db "MAN.", $51
	db "There's something", $4f
	db "new in GOLDENROD", $51
	db "called the TRADE", $4f
	db "CORNER.", $51
	db "I was given an EGG", $4f
	db "TICKET that can be", $51
	db "traded in for a", $4f
	db "ODD EGG.", $51
	db "But since we run a", $4f
	db "DAY-CARE, we don't", $51
	db "need it. You may", $4f
	db "as well have it.", $57
; 0x630ce

UnknownText_0x630ce: ; 0x630ce
	db $0, "I'm the DAY-CARE", $4f
	db "MAN.", $51
	db "Do you know about", $4f
	db "EGGS?", $51
	db "I was raising", $4f
	db "#MON with my", $55
	db "wife, you see.", $51
	db "We were shocked to", $4f
	db "find an EGG!", $51
	db "How incredible is", $4f
	db "that?", $51
	db "Well, wouldn't you", $4f
	db "like this EGG?", $51
	db "Then fine, this is", $4f
	db "yours to keep!", $57
; 0x631a1

UnknownText_0x631a1: ; 0x631a1
	db $0, "Come again.", $57
; 0x631ae

UnknownText_0x631ae: ; 0x631ae
	db $0, $52, " received", $4f
	db "ODD EGG!", $57
; 0x631c3

UnknownText_0x631c3: ; 0x631c3
	db $0, "I found that when", $4f
	db "I was caring for", $51
	db "someone's #MON", $4f
	db "before.", $51
	db "But the trainer", $4f
	db "didn't want the", $51
	db "EGG, so I'd kept", $4f
	db "it around.", $57
; 0x63237

UnknownText_0x63237: ; 0x63237
	db $0, "You've no room for", $4f
	db "this.", $57
; 0x63250

DayCare_MapEventHeader: ; 0x63250
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $5, $0, 3, GROUP_ROUTE_34, MAP_ROUTE_34
	warp_def $6, $0, 4, GROUP_ROUTE_34, MAP_ROUTE_34
	warp_def $7, $2, 5, GROUP_ROUTE_34, MAP_ROUTE_34
	warp_def $7, $3, 5, GROUP_ROUTE_34, MAP_ROUTE_34

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapDayCareSignpost1Script
	signpost 1, 1, $0, MapDayCareSignpost1Script

	; people-events
	db 2
	person_event $2f, 7, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x62f8f, $06e5
	person_event $30, 7, 9, $8, $0, 255, 255, $80, 0, UnknownScript_0x62fc3, $ffff
; 0x6328e

SECTION "bank19",DATA,BANK[$19]

INCBIN "baserom.gbc",$64000,$4000

SECTION "bank1A",DATA,BANK[$1A]

Route11_MapScriptHeader: ; 0x68000
	; trigger count
	db 0

	; callback count
	db 0
; 0x68002

TrainerYoungsterOwen: ; 0x68002
	; bit/flag number
	dw $5b3

	; trainer group && trainer id
	db YOUNGSTER, OWEN

	; text when seen
	dw YoungsterOwenSeenText

	; text when trainer beaten
	dw YoungsterOwenBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterOwenScript
; 0x6800e

YoungsterOwenScript: ; 0x6800e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x680b2
	closetext
	loadmovesprites
	end
; 0x68016

TrainerYoungsterJason: ; 0x68016
	; bit/flag number
	dw $5b4

	; trainer group && trainer id
	db YOUNGSTER, JASON

	; text when seen
	dw YoungsterJasonSeenText

	; text when trainer beaten
	dw YoungsterJasonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterJasonScript
; 0x68022

YoungsterJasonScript: ; 0x68022
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6814a
	closetext
	loadmovesprites
	end
; 0x6802a

TrainerPsychicHerman: ; 0x6802a
	; bit/flag number
	dw $43c

	; trainer group && trainer id
	db PSYCHIC_T, HERMAN

	; text when seen
	dw PsychicHermanSeenText

	; text when trainer beaten
	dw PsychicHermanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicHermanScript
; 0x68036

PsychicHermanScript: ; 0x68036
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6817b
	closetext
	loadmovesprites
	end
; 0x6803e

TrainerPsychicFidel: ; 0x6803e
	; bit/flag number
	dw $43d

	; trainer group && trainer id
	db PSYCHIC_T, FIDEL

	; text when seen
	dw PsychicFidelSeenText

	; text when trainer beaten
	dw PsychicFidelBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicFidelScript
; 0x6804a

PsychicFidelScript: ; 0x6804a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x681ec
	closetext
	loadmovesprites
	end
; 0x68052

MapRoute11Signpost0Script: ; 0x68052
	jumptext UnknownText_0x68238
; 0x68055

UnknownScript_0x68055: ; 0x68055
	fruittree $18
; 0x68057

MapRoute11SignpostItem1: ; 0x68057
	dw $00f5
	db REVIVE
	
; 0x6805a

YoungsterOwenSeenText: ; 0x6805a
	db $0, "There's no cheat-", $4f
	db "ing in #MON.", $51
	db "Let's keep it fair", $4f
	db "and square!", $57
; 0x68097

YoungsterOwenBeatenText: ; 0x68097
	db $0, "Huh? How did this", $4f
	db "happen?", $57
; 0x680b2

UnknownText_0x680b2: ; 0x680b2
	db $0, "I fought fair and", $4f
	db "square with honor.", $51
	db "I don't regret", $4f
	db "this at all.", $57
; 0x680f3

YoungsterJasonSeenText: ; 0x680f3
	db $0, "It itches and", $4f
	db "tickles a bit when", $51
	db "I wear shorts in", $4f
	db "the grass.", $57
; 0x68131

YoungsterJasonBeatenText: ; 0x68131
	db $0, "Aiyaaah!", $4f
	db "I got stomped!", $57
; 0x6814a

UnknownText_0x6814a: ; 0x6814a
	db $0, "I'm going to catch", $4f
	db "more #MON in", $55
	db "the grass.", $57
; 0x68175

PsychicHermanSeenText: ; 0x68175
	db $0, "…", $57
; 0x68178

PsychicHermanBeatenText: ; 0x68178
	db $0, "…", $57
; 0x6817b

UnknownText_0x6817b: ; 0x6817b
	db $0, "…", $51
	db "I lost while I had", $4f
	db "my eyes closed…", $57
; 0x681a1

PsychicFidelSeenText: ; 0x681a1
	db $0, "I can see it…", $51
	db "Everything to see", $4f
	db "about you…", $57
; 0x681cd

PsychicFidelBeatenText: ; 0x681cd
	db $0, "I couldn't foresee", $4f
	db "your power…", $57
; 0x681ec

UnknownText_0x681ec: ; 0x681ec
	db $0, "Strength in con-", $4f
	db "viction…", $51
	db "You're strong be-", $4f
	db "cause you believe", $55
	db "in your #MON.", $57
; 0x68238

UnknownText_0x68238: ; 0x68238
	db $0, "ROUTE 11", $57
; 0x68242

Route11_MapEventHeader: ; 0x68242
	; filler
	db 0, 0

	; warps
	db 0

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 7, 3, $0, MapRoute11Signpost0Script
	signpost 5, 32, $7, MapRoute11SignpostItem1

	; people-events
	db 5
	person_event $27, 18, 26, $a, $0, 255, 255, $92, 3, TrainerYoungsterOwen, $ffff
	person_event $27, 8, 24, $6, $0, 255, 255, $92, 3, TrainerYoungsterJason, $ffff
	person_event $27, 11, 32, $6, $0, 255, 255, $92, 1, TrainerPsychicHerman, $ffff
	person_event $27, 10, 12, $a, $0, 255, 255, $92, 3, TrainerPsychicFidel, $ffff
	person_event $5d, 6, 36, $1, $0, 255, 255, $0, 0, UnknownScript_0x68055, $ffff
; 0x68293

VioletMart_MapScriptHeader: ; 0x68293
	; trigger count
	db 0

	; callback count
	db 0
; 0x68295

UnknownScript_0x68295: ; 0x68295
	loadfont
	pokemart $0, $0002
	loadmovesprites
	end
; 0x6829c

UnknownScript_0x6829c: ; 0x6829c
	jumptextfaceplayer UnknownText_0x682a2
; 0x6829f

UnknownScript_0x6829f: ; 0x6829f
	jumptextfaceplayer UnknownText_0x68323
; 0x682a2

UnknownText_0x682a2: ; 0x682a2
	db $0, "When you first", $4f
	db "catch a #MON,", $55
	db "it may be weak.", $51
	db "But it will even-", $4f
	db "tually grow to be", $55
	db "strong.", $51
	db "It's important to", $4f
	db "treat #MON with", $55
	db "love.", $57
; 0x68323

UnknownText_0x68323: ; 0x68323
	db $0, "#MON can hold", $4f
	db "items like POTION", $55
	db "and ANTIDOTE.", $51
	db "But they don't", $4f
	db "appear to know how", $51
	db "to use manmade", $4f
	db "items.", $57
; 0x68389

VioletMart_MapEventHeader: ; 0x68389
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $7, $3, 1, GROUP_VIOLET_CITY, MAP_VIOLET_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x68295, $ffff
	person_event $30, 10, 11, $5, $1, 255, 255, $0, 0, UnknownScript_0x6829c, $ffff
	person_event $23, 6, 9, $3, $0, 255, 255, $80, 0, UnknownScript_0x6829f, $ffff
; 0x683c0

VioletGym_MapScriptHeader: ; 0x683c0
	; trigger count
	db 0

	; callback count
	db 0
; 0x683c2

UnknownScript_0x683c2: ; 0x683c2
	faceplayer
	loadfont
	checkbit1 $04bd
	iftrue UnknownScript_0x683ec
	2writetext UnknownText_0x68473
	closetext
	loadmovesprites
	winlosstext UnknownText_0x6854a, $0000
	loadtrainer FALKNER, 1
	startbattle
	returnafterbattle
	setbit1 $04bd
	loadfont
	2writetext UnknownText_0x685af
	playsound $009c
	waitbutton
	setbit2 $001b
	checkcode $7
	2call UnknownScript_0x68418
UnknownScript_0x683ec: ; 0x683ec
	checkbit1 $0008
	iftrue UnknownScript_0x68412
	setbit1 $03fb
	setbit1 $03fc
	domaptrigger GROUP_ELMS_LAB, MAP_ELMS_LAB, $2
	specialphonecall $3
	2writetext UnknownText_0x685c8
	keeptextopen
	verbosegiveitem TM_31, 1
	iffalse UnknownScript_0x68416
	setbit1 $0008
	2writetext UnknownText_0x68648
	closetext
	loadmovesprites
	end
; 0x68412

UnknownScript_0x68412: ; 0x68412
	2writetext UnknownText_0x68735
	closetext
UnknownScript_0x68416: ; 0x68416
	loadmovesprites
	end
; 0x68418

UnknownScript_0x68418: ; 0x68418
	if_equal $7, UnknownScript_0x68424
	if_equal $6, UnknownScript_0x68421
	end
; 0x68421

UnknownScript_0x68421: ; 0x68421
	jumpstd $0012
; 0x68424

UnknownScript_0x68424: ; 0x68424
	jumpstd $0013
; 0x68427

TrainerBird_keeperRod: ; 0x68427
	; bit/flag number
	dw $3fb

	; trainer group && trainer id
	db BIRD_KEEPER, ROD

	; text when seen
	dw Bird_keeperRodSeenText

	; text when trainer beaten
	dw Bird_keeperRodBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperRodScript
; 0x68433

Bird_keeperRodScript: ; 0x68433
	talkaftercancel
	loadfont
	2writetext UnknownText_0x68837
	closetext
	loadmovesprites
	end
; 0x6843b

TrainerBird_keeperAbe: ; 0x6843b
	; bit/flag number
	dw $3fc

	; trainer group && trainer id
	db BIRD_KEEPER, ABE

	; text when seen
	dw Bird_keeperAbeSeenText

	; text when trainer beaten
	dw Bird_keeperAbeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperAbeScript
; 0x68447

Bird_keeperAbeScript: ; 0x68447
	talkaftercancel
	loadfont
	2writetext UnknownText_0x688c7
	closetext
	loadmovesprites
	end
; 0x6844f

VioletGymGuyScript: ; 0x6844f
	faceplayer
	loadfont
	checkbit1 $04bd
	iftrue .VioletGymGuyWinScript
	2writetext VioletGymGuyText
	closetext
	loadmovesprites
	end

.VioletGymGuyWinScript
	2writetext VioletGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x68463

MapVioletGymSignpost1Script: ; 0x68463
	checkbit2 $001b
	iftrue UnknownScript_0x6846c
	jumpstd $002d
; 0x6846c

UnknownScript_0x6846c: ; 0x6846c
	trainertotext FALKNER, 1, $1
	jumpstd $002e
; 0x68473

UnknownText_0x68473: ; 0x68473
	db $0, "I'm FALKNER, the", $4f
	db "VIOLET #MON GYM", $55
	db "leader!", $51
	db "People say you can", $4f
	db "clip flying-type", $51
	db "#MON's wings", $4f
	db "with a jolt of", $55
	db "electricity…", $51
	db "I won't allow such", $4f
	db "insults to bird", $55
	db "#MON!", $51
	db "I'll show you the", $4f
	db "real power of the", $51
	db "magnificent bird", $4f
	db "#MON!", $57
; 0x6854a

UnknownText_0x6854a: ; 0x6854a
	db $0, "…Darn! My dad's", $4f
	db "cherished bird", $55
	db "#MON…", $51
	db "All right.", $4f
	db "Take this.", $51
	db "It's the official", $4f
	db "#MON LEAGUE", $55
	db "ZEPHYRBADGE.", $57
; 0x685af

UnknownText_0x685af: ; 0x685af
	db $0, $52, " received", $4f
	db "ZEPHYRBADGE.", $57
; 0x685c8

UnknownText_0x685c8: ; 0x685c8
	db $0, "ZEPHYRBADGE", $4f
	db "raises the attack", $55
	db "power of #MON.", $51
	db "It also enables", $4f
	db "#MON to use", $51
	db "FLASH, if they", $4f
	db "have it, anytime.", $51
	db "Here--take this", $4f
	db "too.", $57
; 0x68648

UnknownText_0x68648: ; 0x68648
	db $0, "By using a TM, a", $4f
	db "#MON will", $51
	db "instantly learn a", $4f
	db "new move.", $51
	db "Think before you", $4f
	db "act--a TM can be", $55
	db "used only once.", $51
	db "TM31 contains", $4f
	db "MUD-SLAP.", $51
	db "It reduces the", $4f
	db "enemy's accuracy", $51
	db "while it causes", $4f
	db "damage.", $51
	db "In other words, it", $4f
	db "is both defensive", $55
	db "and offensive.", $57
; 0x68735

UnknownText_0x68735: ; 0x68735
	db $0, "There are #MON", $4f
	db "GYMS in cities and", $55
	db "towns ahead.", $51
	db "You should test", $4f
	db "your skills at", $55
	db "these GYMS.", $51
	db "I'm going to train", $4f
	db "harder to become", $51
	db "the greatest bird", $4f
	db "master!", $57
; 0x687cd

Bird_keeperRodSeenText: ; 0x687cd
	db $0, "The keyword is", $4f
	db "guts!", $51
	db "Those here are", $4f
	db "training night and", $51
	db "day to become bird", $4f
	db "#MON masters.", $51
	db "Come on!", $57
; 0x6882f

Bird_keeperRodBeatenText: ; 0x6882f
	db $0, "Gaaah!", $57
; 0x68837

UnknownText_0x68837: ; 0x68837
	db $0, "FALKNER's skills", $4f
	db "are for real!", $51
	db "Don't get cocky", $4f
	db "just because you", $55
	db "beat me!", $57
; 0x6887f

Bird_keeperAbeSeenText: ; 0x6887f
	db $0, "Let me see if you", $4f
	db "are good enough to", $55
	db "face FALKNER!", $57
; 0x688b3

Bird_keeperAbeBeatenText: ; 0x688b3
	db $0, "This can't be", $4f
	db "true!", $57
; 0x688c7

UnknownText_0x688c7: ; 0x688c7
	db $0, "This is pathetic,", $4f
	db "losing to some", $55
	db "rookie trainer…", $57
; 0x688f9

VioletGymGuyText: ; 0x688f9
	db $0, "Hey! I'm no train-", $4f
	db "er but I can give", $55
	db "some advice!", $51
	db "Believe me!", $4f
	db "If you believe, a", $51
	db "championship dream", $4f
	db "can come true.", $51
	db "You believe?", $4f
	db "Then listen.", $51
	db "The grass-type is", $4f
	db "weak against the", $51
	db "flying-type. Keep", $4f
	db "this in mind.", $57
; 0x689c8

VioletGymGuyWinText: ; 0x689c8
	db $0, "Nice battle! Keep", $4f
	db "it up, and you'll", $51
	db "be the CHAMP in no", $4f
	db "time at all!", $57
; 0x68a0c

VioletGym_MapEventHeader: ; 0x68a0c
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $f, $4, 2, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $f, $5, 2, GROUP_VIOLET_CITY, MAP_VIOLET_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 13, 3, $0, MapVioletGymSignpost1Script
	signpost 13, 6, $0, MapVioletGymSignpost1Script

	; people-events
	db 4
	person_event $12, 5, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x683c2, $ffff
	person_event $27, 10, 11, $8, $2, 255, 255, $92, 3, TrainerBird_keeperRod, $ffff
	person_event $27, 14, 6, $9, $2, 255, 255, $92, 3, TrainerBird_keeperAbe, $ffff
	person_event $48, 17, 11, $6, $0, 255, 255, $80, 0, VioletGymGuyScript, $ffff
; 0x68a5a

EarlsPokemonAcademy_MapScriptHeader: ; 0x68a5a
	; trigger count
	db 0

	; callback count
	db 0
; 0x68a5c

UnknownScript_0x68a5c: ; 0x68a5c
	applymovement $2, MovementData_0x68b2d
	faceplayer
	loadfont
	2writetext UnknownText_0x68b3b
	yesorno
	iffalse UnknownScript_0x68a70
	2writetext UnknownText_0x68bbd
	yesorno
	iffalse UnknownScript_0x68a7d
UnknownScript_0x68a70: ; 0x68a70
	2writetext UnknownText_0x68c51
	yesorno
	iffalse UnknownScript_0x68a7d
	2writetext UnknownText_0x68c7b
	closetext
	loadmovesprites
	end
; 0x68a7d

UnknownScript_0x68a7d: ; 0x68a7d
	2writetext UnknownText_0x68d31
	closetext
	loadmovesprites
	end
; 0x68a83

UnknownScript_0x68a83: ; 0x68a83
	jumptextfaceplayer UnknownText_0x68d80
; 0x68a86

UnknownScript_0x68a86: ; 0x68a86
	faceplayer
	loadfont
	2writetext UnknownText_0x68dda
	closetext
	loadmovesprites
	spriteface $4, $0
	end
; 0x68a91

UnknownScript_0x68a91: ; 0x68a91
	faceplayer
	loadfont
	2writetext UnknownText_0x68e07
	closetext
	loadmovesprites
	spriteface $5, $0
	end
; 0x68a9c

UnknownScript_0x68a9c: ; 0x68a9c
	jumptextfaceplayer UnknownText_0x68e39
; 0x68a9f

MapEarlsPokemonAcademySignpost3Script: ; 0x68a9f
	loadfont
	2writetext UnknownText_0x68eb2
UnknownScript_0x68aa3: ; 0x68aa3
	loadmenudata $4ae1
	interpretmenu
	writebackup
	if_equal $1, UnknownScript_0x68abe
	if_equal $2, UnknownScript_0x68ac5
	if_equal $3, UnknownScript_0x68acc
	if_equal $4, UnknownScript_0x68ad3
	if_equal $5, UnknownScript_0x68ada
	loadmovesprites
	end
; 0x68abe

UnknownScript_0x68abe: ; 0x68abe
	2writetext UnknownText_0x68efe
	closetext
	2jump UnknownScript_0x68aa3
; 0x68ac5

UnknownScript_0x68ac5: ; 0x68ac5
	2writetext UnknownText_0x68f80
	closetext
	2jump UnknownScript_0x68aa3
; 0x68acc

UnknownScript_0x68acc: ; 0x68acc
	2writetext UnknownText_0x68fe2
	closetext
	2jump UnknownScript_0x68aa3
; 0x68ad3

UnknownScript_0x68ad3: ; 0x68ad3
	2writetext UnknownText_0x69055
	closetext
	2jump UnknownScript_0x68aa3
; 0x68ada

UnknownScript_0x68ada: ; 0x68ada
	2writetext UnknownText_0x690cb
	closetext
	2jump UnknownScript_0x68aa3
; 0x68ae1

; menu data
INCBIN "baserom.gbc",$68ae1,$2a

UnknownScript_0x68b0b: ; 0x68b0b
	loadfont
	2writetext UnknownText_0x69136
	yesorno
	iffalse UnknownScript_0x68b25
	2writetext UnknownText_0x69197
	yesorno
	iffalse UnknownScript_0x68b25
	2writetext UnknownText_0x69207
	yesorno
	iffalse UnknownScript_0x68b25
	2writetext UnknownText_0x69287
	closetext
UnknownScript_0x68b25: ; 0x68b25
	loadmovesprites
	end
; 0x68b27

UnknownScript_0x68b27: ; 0x68b27
	jumptext UnknownText_0x69344
; 0x68b2a

MapEarlsPokemonAcademySignpost1Script: ; 0x68b2a
	jumpstd $0001
; 0x68b2d

MovementData_0x68b2d: ; 0x68b2d
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	step_end
; 0x68b3b

UnknownText_0x68b3b: ; 0x68b3b
	db $0, "EARL, I am!", $51
	db "Wonderful are", $4f
	db "#MON, yes!", $51
	db "Teach you I will", $4f
	db "to be a better", $55
	db "trainer!", $51
	db "What you want to", $4f
	db "know? Want to be", $55
	db "a winner is you?", $57
; 0x68bbd

UnknownText_0x68bbd: ; 0x68bbd
	db $0, "Good! Teach you,", $4f
	db "I will!", $51
	db "In battle, #MON", $4f
	db "top on list jump", $55
	db "out first!", $51
	db "Change order in", $4f
	db "list, make battle", $55
	db "easy, maybe!", $51
	db "More from me you", $4f
	db "want to hear?", $57
; 0x68c51

UnknownText_0x68c51: ; 0x68c51
	db $0, "So, want to know", $4f
	db "how to raise", $55
	db "#MON well?", $57
; 0x68c7b

UnknownText_0x68c7b: ; 0x68c7b
	db $0, "Fine! Teach you,", $4f
	db "I will!", $51
	db "If #MON come", $4f
	db "out in battle even", $51
	db "briefly, some EXP.", $4f
	db "Points it gets.", $51
	db "At top of list put", $4f
	db "weak #MON.", $51
	db "Switch in battle", $4f
	db "quick!", $51
	db "This way, weak", $4f
	db "#MON strong", $55
	db "become!", $57
; 0x68d31

UnknownText_0x68d31: ; 0x68d31
	db $0, "Oh! Smart student", $4f
	db "you are! Nothing", $55
	db "more do I teach!", $51
	db "Good to #MON", $4f
	db "you must be!", $57
; 0x68d80

UnknownText_0x68d80: ; 0x68d80
	db $0, "I'm taking notes", $4f
	db "of the teacher's", $55
	db "lecture.", $51
	db "I'd better copy", $4f
	db "the stuff on the", $55
	db "blackboard too.", $57
; 0x68dda

UnknownText_0x68dda: ; 0x68dda
	db $0, "I traded my best", $4f
	db "#MON to the", $55
	db "guy beside me.", $57
; 0x68e07

UnknownText_0x68e07: ; 0x68e07
	db $0, "Huh? The #MON I", $4f
	db "just got is hold-", $55
	db "ing something!", $57
; 0x68e39

UnknownText_0x68e39: ; 0x68e39
	db $0, "A #MON holding", $4f
	db "a BERRY will heal", $55
	db "itself in battle.", $51
	db "Many other items", $4f
	db "can be held by", $55
	db "#MON…", $51
	db "It sure is tough", $4f
	db "taking notes…", $57
; 0x68eb2

UnknownText_0x68eb2: ; 0x68eb2
	db $0, "The blackboard", $4f
	db "describes #MON", $51
	db "status changes in", $4f
	db "battle.", $57
; 0x68eeb

UnknownText_0x68eeb: ; 0x68eeb
	db $0, "Read which topic?", $57
; 0x68efe

UnknownText_0x68efe: ; 0x68efe
	db $0, "If poisoned, a", $4f
	db "#MON steadily", $55
	db "loses HP.", $51
	db "Poison lingers", $4f
	db "after the battle,", $51
	db "and HP is lost as", $4f
	db "you walk.", $51
	db "To cure it, use an", $4f
	db "ANTIDOTE.", $57
; 0x68f80

UnknownText_0x68f80: ; 0x68f80
	db $0, "Paralysis reduces", $4f
	db "speed and may", $55
	db "prevent movement.", $51
	db "It remains after", $4f
	db "battle, so use", $55
	db "a PARLYZ HEAL.", $57
; 0x68fe2

UnknownText_0x68fe2: ; 0x68fe2
	db $0, "If asleep, your", $4f
	db "#MON can't make", $55
	db "a move.", $51
	db "A sleeping #MON", $4f
	db "doesn't wake up", $55
	db "after battle.", $51
	db "Wake it up with", $4f
	db "an AWAKENING.", $57
; 0x69055

UnknownText_0x69055: ; 0x69055
	db $0, "A burn steadily", $4f
	db "consumes HP.", $51
	db "It also reduces", $4f
	db "attack power.", $51
	db "A burn lingers", $4f
	db "after battle.", $51
	db "Use a BURN HEAL as", $4f
	db "the cure.", $57
; 0x690cb

UnknownText_0x690cb: ; 0x690cb
	db $0, "If your #MON is", $4f
	db "frozen, it can't", $55
	db "do a thing.", $51
	db "It remains frozen", $4f
	db "after battle.", $51
	db "Thaw it out with", $4f
	db "an ICE HEAL.", $57
; 0x69136

UnknownText_0x69136: ; 0x69136
	db $0, "It's this kid's", $4f
	db "notebook…", $51
	db "Catch #MON", $4f
	db "using # BALLS.", $51
	db "Up to six can be", $4f
	db "in your party.", $51
	db "Keep reading?", $57
; 0x69197

UnknownText_0x69197: ; 0x69197
	db $0, "Before throwing a", $4f
	db "# BALL, weaken", $55
	db "the target first.", $51
	db "A poisoned or", $4f
	db "burned #MON is", $55
	db "easier to catch.", $51
	db "Keep reading?", $57
; 0x69207

UnknownText_0x69207: ; 0x69207
	db $0, "Some moves may", $4f
	db "cause confusion.", $51
	db "Confusion may make", $4f
	db "a #MON attack", $55
	db "itself.", $51
	db "Leaving battle", $4f
	db "clears up any", $55
	db "confusion.", $51
	db "Keep reading?", $57
; 0x69287

UnknownText_0x69287: ; 0x69287
	db $0, "People who catch", $4f
	db "and use #MON", $51
	db "in battle are", $4f
	db "#MON trainers.", $51
	db "They are expected", $4f
	db "to visit #MON", $51
	db "GYMS and defeat", $4f
	db "other trainers.", $51
	db "The next page", $4f
	db "is… Blank!", $51
	db "Boy: E-he-he…", $51
	db "I haven't written", $4f
	db "anymore…", $57
; 0x69344

UnknownText_0x69344: ; 0x69344
	db $0, "This super machine", $4f
	db "prints data out as", $51
	db "stickers!", $57
; 0x69375

EarlsPokemonAcademy_MapEventHeader: ; 0x69375
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $f, $3, 3, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $f, $4, 3, GROUP_VIOLET_CITY, MAP_VIOLET_CITY

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 1, 0, $0, MapEarlsPokemonAcademySignpost1Script
	signpost 1, 1, $0, MapEarlsPokemonAcademySignpost1Script
	signpost 0, 3, $0, MapEarlsPokemonAcademySignpost3Script
	signpost 0, 4, $0, MapEarlsPokemonAcademySignpost3Script

	; people-events
	db 6
	person_event $3a, 6, 8, $6, $0, 255, 255, $a0, 0, UnknownScript_0x68a5c, $06cb
	person_event $27, 9, 6, $7, $0, 255, 255, $80, 0, UnknownScript_0x68a83, $ffff
	person_event $3, 15, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x68a86, $ffff
	person_event $3, 15, 8, $8, $0, 255, 255, $80, 0, UnknownScript_0x68a91, $ffff
	person_event $27, 11, 8, $7, $0, 255, 255, $0, 0, UnknownScript_0x68a9c, $ffff
	person_event $55, 8, 6, $1, $0, 255, 255, $0, 0, UnknownScript_0x68b0b, $ffff
; 0x693e7

VioletNicknameSpeechHouse_MapScriptHeader: ; 0x693e7
	; trigger count
	db 0

	; callback count
	db 0
; 0x693e9

UnknownScript_0x693e9: ; 0x693e9
	jumptextfaceplayer UnknownText_0x693fa
; 0x693ec

UnknownScript_0x693ec: ; 0x693ec
	jumptextfaceplayer UnknownText_0x6945e
; 0x693ef

UnknownScript_0x693ef: ; 0x693ef
	faceplayer
	loadfont
	2writetext UnknownText_0x6947c
	cry PIDGEY
	closetext
	loadmovesprites
	end
; 0x693fa

UnknownText_0x693fa: ; 0x693fa
	db $0, "She uses the names", $4f
	db "of her favorite", $55
	db "things to eat.", $51
	db "For the nicknames", $4f
	db "she gives to her", $55
	db "#MON, I mean.", $57
; 0x6945e

UnknownText_0x6945e: ; 0x6945e
	db $0, "I call my PIDGEY", $4f
	db "STRAWBERRY!", $57
; 0x6947c

UnknownText_0x6947c: ; 0x6947c
	db $0, "STRAWBERRY: Pijji!", $57
; 0x69490

VioletNicknameSpeechHouse_MapEventHeader: ; 0x69490
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $3, 4, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $7, $4, 4, GROUP_VIOLET_CITY, MAP_VIOLET_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $29, 7, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x693e9, $ffff
	person_event $28, 8, 10, $7, $0, 255, 255, $a0, 0, UnknownScript_0x693ec, $ffff
	person_event $4e, 6, 9, $5, $1, 255, 255, $b0, 0, UnknownScript_0x693ef, $ffff
; 0x694c7

VioletPokeCenter1F_MapScriptHeader: ; 0x694c7
	; trigger count
	db 0

	; callback count
	db 0
; 0x694c9

UnknownScript_0x694c9: ; 0x694c9
	jumpstd $0000
; 0x694cc

UnknownScript_0x694cc: ; 0x694cc
	faceplayer
	loadfont
	checkbit1 $002c
	iftrue UnknownScript_0x6953a
	2writetext UnknownText_0x69555
UnknownScript_0x694d7: ; 0x694d7
	yesorno
	iffalse UnknownScript_0x69531
	checkcode $1
	if_equal $6, UnknownScript_0x6952b
	giveegg TOGEPI, 5
	stringtotext $5523, $1
	2call UnknownScript_0x69527
	setbit1 $002d
	clearbit1 $0701
	clearbit1 $0054
	domaptrigger GROUP_ROUTE_32, MAP_ROUTE_32, $1
	2writetext UnknownText_0x695c5
	closetext
	loadmovesprites
	checkcode $9
	if_equal $1, UnknownScript_0x69511
	spriteface $0, $0
	applymovement $6, MovementData_0x69549
	playsound $0023
	disappear $6
	waitbutton
	end
; 0x69511

UnknownScript_0x69511: ; 0x69511
	applymovement $6, MovementData_0x6954e
	spriteface $0, $0
	applymovement $6, MovementData_0x69551
	playsound $0023
	disappear $6
	waitbutton
	end
; 0x69523

UnknownRawText_0x69523: ; 0x69523
	db "EGG@"
; 0x69527

UnknownScript_0x69527: ; 0x69527
	jumpstd $0030
	end
; 0x6952b

UnknownScript_0x6952b: ; 0x6952b
	2writetext UnknownText_0x69693
	closetext
	loadmovesprites
	end
; 0x69531

UnknownScript_0x69531: ; 0x69531
	2writetext UnknownText_0x696f2
	closetext
	loadmovesprites
	setbit1 $002c
	end
; 0x6953a

UnknownScript_0x6953a: ; 0x6953a
	2writetext UnknownText_0x69712
	2jump UnknownScript_0x694d7
; 0x69540

UnknownScript_0x69540: ; 0x69540
	jumptextfaceplayer UnknownText_0x69809
; 0x69543

UnknownScript_0x69543: ; 0x69543
	jumptextfaceplayer UnknownText_0x6983c
; 0x69546

UnknownScript_0x69546: ; 0x69546
	jumptextfaceplayer UnknownText_0x698b8
; 0x69549

MovementData_0x69549: ; 0x69549
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x6954e

MovementData_0x6954e: ; 0x6954e
	step_left
	step_down
	step_end
; 0x69551

MovementData_0x69551: ; 0x69551
	step_down
	step_down
	step_down
	step_end
; 0x69555

UnknownText_0x69555: ; 0x69555
	db $0, $14, ", long", $4f
	db "time, no see.", $51
	db "PROF.ELM asked me", $4f
	db "to find you.", $51
	db "He has another", $4f
	db "favor to ask.", $51
	db "Would you take the", $4f
	db "#MON EGG?", $57
; 0x695c5

UnknownText_0x695c5: ; 0x695c5
	db $0, "We discovered that", $4f
	db "a #MON will not", $51
	db "hatch until it", $4f
	db "grows in the EGG.", $51
	db "It also has to be", $4f
	db "with other active", $55
	db "#MON to hatch.", $51
	db $14, ", you're", $4f
	db "the only person", $55
	db "we can rely on.", $51
	db "Please call PROF.", $4f
	db "ELM when that EGG", $55
	db "hatches!", $57
; 0x69693

UnknownText_0x69693: ; 0x69693
	db $0, "Oh, no. You can't", $4f
	db "carry any more", $55
	db "#MON with you.", $51
	db "I'll wait here", $4f
	db "while you make", $55
	db "room for the EGG.", $57
; 0x696f2

UnknownText_0x696f2: ; 0x696f2
	db $0, "B-but… PROF.ELM", $4f
	db "asked for you…", $57
; 0x69712

UnknownText_0x69712: ; 0x69712
	db $0, $14, ", will you", $4f
	db "take the EGG?", $57
; 0x6972d

UnknownText_0x6972d: ; 0x6972d
	db $0, "I've been thinking", $4f
	db "it'd be great to", $51
	db "be able to link up", $4f
	db "and battle with my", $51
	db "friends who live", $4f
	db "far away.", $57
; 0x69791

UnknownText_0x69791: ; 0x69791
	db $0, "I just battled a", $4f
	db "friend in CIANWOOD", $55
	db "over a link.", $51
	db "If you connect a", $4f
	db "MOBILE ADAPTER,", $51
	db "you can link with", $4f
	db "a friend far away.", $57
; 0x69809

UnknownText_0x69809: ; 0x69809
	db $0, "A guy named BILL", $4f
	db "made the #MON", $55
	db "PC storage system.", $57
; 0x6983c

UnknownText_0x6983c: ; 0x6983c
	db $0, "It was around", $4f
	db "three years ago.", $51
	db "TEAM ROCKET was up", $4f
	db "to no good with", $55
	db "#MON.", $51
	db "But justice pre-", $4f
	db "vailed--a young", $55
	db "kid broke 'em up.", $57
; 0x698b8

UnknownText_0x698b8: ; 0x698b8
	db $0, "#MON are smart.", $4f
	db "They won't obey a", $51
	db "trainer they don't", $4f
	db "respect.", $51
	db "Without the right", $4f
	db "GYM BADGES, they", $51
	db "will just do as", $4f
	db "they please.", $57
; 0x69935

VioletPokeCenter1F_MapEventHeader: ; 0x69935
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 5, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $7, $4, 5, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 5
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x694c9, $ffff
	person_event $3, 10, 11, $6, $0, 255, 255, $a0, 0, UnknownScript_0x69540, $ffff
	person_event $40, 8, 5, $3, $0, 255, 255, $0, 0, UnknownScript_0x69543, $ffff
	person_event $27, 5, 12, $6, $0, 255, 255, $80, 0, UnknownScript_0x69546, $ffff
	person_event $3c, 7, 8, $6, $0, 255, 255, $90, 0, UnknownScript_0x694cc, $0700
; 0x6998b

VioletOnixTradeHouse_MapScriptHeader: ; 0x6998b
	; trigger count
	db 0

	; callback count
	db 0
; 0x6998d

UnknownScript_0x6998d: ; 0x6998d
	jumptextfaceplayer UnknownText_0x69997
; 0x69990

UnknownScript_0x69990: ; 0x69990
	faceplayer
	loadfont
	trade $1
	closetext
	loadmovesprites
	end
; 0x69997

UnknownText_0x69997: ; 0x69997
	db $0, "A #MON you get", $4f
	db "in a trade grows", $55
	db "quickly.", $51
	db "But if you don't", $4f
	db "have the right GYM", $51
	db "BADGE, they may", $4f
	db "disobey you.", $57
; 0x69a01

VioletOnixTradeHouse_MapEventHeader: ; 0x69a01
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $3, 6, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $7, $4, 6, GROUP_VIOLET_CITY, MAP_VIOLET_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $2d, 7, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x6998d, $ffff
	person_event $27, 9, 10, $4, $20, 255, 255, $80, 0, UnknownScript_0x69990, $ffff
; 0x69a2b

Route32RuinsofAlphGate_MapScriptHeader: ; 0x69a2b
	; trigger count
	db 0

	; callback count
	db 0
; 0x69a2d

UnknownScript_0x69a2d: ; 0x69a2d
	jumptextfaceplayer UnknownText_0x69a36
; 0x69a30

UnknownScript_0x69a30: ; 0x69a30
	jumptextfaceplayer UnknownText_0x69a81
; 0x69a33

UnknownScript_0x69a33: ; 0x69a33
	jumptextfaceplayer UnknownText_0x69abd
; 0x69a36

UnknownText_0x69a36: ; 0x69a36
	db $0, "RUINS OF ALPH", $51
	db "A Look-and-Touch", $4f
	db "Tourist Site", $51
	db "Try the sliding", $4f
	db "stone panels!", $57
; 0x69a81

UnknownText_0x69a81: ; 0x69a81
	db $0, "You're studying", $4f
	db "the RUINS?", $51
	db "I see a scientist", $4f
	db "in the making.", $57
; 0x69abd

UnknownText_0x69abd: ; 0x69abd
	db $0, "There are drawings", $4f
	db "on stone panels.", $51
	db "I tried moving", $4f
	db "them. I wonder", $55
	db "what they are.", $57
; 0x69b0f

Route32RuinsofAlphGate_MapEventHeader: ; 0x69b0f
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 10, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $5, $0, 11, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $4, $9, 2, GROUP_ROUTE_32, MAP_ROUTE_32
	warp_def $5, $9, 3, GROUP_ROUTE_32, MAP_ROUTE_32

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $43, 6, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x69a2d, $ffff
	person_event $2d, 6, 12, $4, $10, 255, 255, $b0, 0, UnknownScript_0x69a30, $ffff
	person_event $27, 10, 5, $7, $0, 255, 255, $a0, 0, UnknownScript_0x69a33, $ffff
; 0x69b50

Route32PokeCenter1F_MapScriptHeader: ; 0x69b50
	; trigger count
	db 0

	; callback count
	db 0
; 0x69b52

UnknownScript_0x69b52: ; 0x69b52
	jumpstd $0000
; 0x69b55

UnknownScript_0x69b55: ; 0x69b55
	faceplayer
	loadfont
	checkbit1 $0017
	iftrue UnknownScript_0x69b7a
	2writetext UnknownText_0x69b83
	yesorno
	iffalse UnknownScript_0x69b74
	2writetext UnknownText_0x69be8
	keeptextopen
	verbosegiveitem OLD_ROD, 1
	2writetext UnknownText_0x69c1b
	closetext
	loadmovesprites
	setbit1 $0017
	end
; 0x69b74

UnknownScript_0x69b74: ; 0x69b74
	2writetext UnknownText_0x69c6c
	closetext
	loadmovesprites
	end
; 0x69b7a

UnknownScript_0x69b7a: ; 0x69b7a
	2writetext UnknownText_0x69c8d
	closetext
	loadmovesprites
	end
; 0x69b80

UnknownScript_0x69b80: ; 0x69b80
	jumptextfaceplayer UnknownText_0x69cac
; 0x69b83

UnknownText_0x69b83: ; 0x69b83
	db $0, "This is a great", $4f
	db "fishing spot.", $51
	db "You saw people", $4f
	db "fishing? How", $55
	db "about you?", $51
	db "Would you like one", $4f
	db "of my RODS?", $57
; 0x69be8

UnknownText_0x69be8: ; 0x69be8
	db $0, "Heh, that's good", $4f
	db "to hear.", $51
	db "Now you're an", $4f
	db "angler too!", $57
; 0x69c1b

UnknownText_0x69c1b: ; 0x69c1b
	db $0, "Fishing is great!", $51
	db "If there's water,", $4f
	db "be it the sea or a", $51
	db "stream, try out", $4f
	db "your ROD.", $57
; 0x69c6c

UnknownText_0x69c6c: ; 0x69c6c
	db $0, "Oh. That's rather", $4f
	db "disappointing…", $57
; 0x69c8d

UnknownText_0x69c8d: ; 0x69c8d
	db $0, "Yo, kid. How are", $4f
	db "they biting?", $57
; 0x69cac

UnknownText_0x69cac: ; 0x69cac
	db $0, "What should I make", $4f
	db "my #MON hold?", $51
	db "Maybe an item that", $4f
	db "increases ATTACK", $55
	db "power…", $57
; 0x69cf9

Route32PokeCenter1F_MapEventHeader: ; 0x69cf9
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_ROUTE_32, MAP_ROUTE_32
	warp_def $7, $4, 1, GROUP_ROUTE_32, MAP_ROUTE_32
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x69b52, $ffff
	person_event $3b, 8, 5, $6, $0, 255, 255, $a0, 0, UnknownScript_0x69b55, $ffff
	person_event $24, 6, 10, $6, $0, 255, 255, $80, 0, UnknownScript_0x69b80, $ffff
; 0x69d35

Route35Goldenrodgate_MapScriptHeader: ; 0x69d35
	; trigger count
	db 0

	; callback count
	db 0
; 0x69d37

UnknownScript_0x69d37: ; 0x69d37
	faceplayer
	loadfont
	checkbit1 $0052
	iftrue UnknownScript_0x69d92
	checkbit1 $0051
	iftrue UnknownScript_0x69d85
	checkbit1 $0050
	iftrue UnknownScript_0x69d73
	2writetext UnknownText_0x69ddd
	yesorno
	iffalse UnknownScript_0x69d7f
	2writetext UnknownText_0x69e48
	keeptextopen
	waitbutton
	checkcode $1
	if_equal $6, UnknownScript_0x69d79
	2writetext UnknownText_0x69eb8
	playsound $0091
	waitbutton
	givepoke SPEAROW, 10, 0, 1, GiftSpearowName, GiftSpearowOTName
	givepokeitem GiftSpearowMail
	setbit1 $0050
UnknownScript_0x69d73: ; 0x69d73
	2writetext UnknownText_0x69ed6
	closetext
	loadmovesprites
	end
; 0x69d79

UnknownScript_0x69d79: ; 0x69d79
	2writetext UnknownText_0x69f56
	closetext
	loadmovesprites
	end
; 0x69d7f

UnknownScript_0x69d7f: ; 0x69d7f
	2writetext UnknownText_0x69f74
	closetext
	loadmovesprites
	end
; 0x69d85

UnknownScript_0x69d85: ; 0x69d85
	2writetext UnknownText_0x69f8b
	keeptextopen
	verbosegiveitem HP_UP, 1
	iffalse UnknownScript_0x69d96
	setbit1 $0052
UnknownScript_0x69d92: ; 0x69d92
	2writetext UnknownText_0x69fd9
	closetext
UnknownScript_0x69d96: ; 0x69d96
	loadmovesprites
	end

GiftSpearowMail: ; 0x69d98
	db FLOWER_MAIL
	db "DARK CAVE leads", $4E
	db "to another road@"
GiftSpearowName: ; 0x69db9
	db "KENYA@"
GiftSpearowOTName: ; 0x69dbf
	db "RANDY@"

	db 0 ; 0x69dc5 XXX is there a reason for this?

UnknownScript_0x69dc6: ; 0x69dc6
	faceplayer
	loadfont
	checkbit1 $002a
	iftrue UnknownScript_0x69dd4
	2writetext UnknownText_0x6a00a
	closetext
	loadmovesprites
	end
; 0x69dd4

UnknownScript_0x69dd4: ; 0x69dd4
	2writetext UnknownText_0x6a09a
	closetext
	loadmovesprites
	end
; 0x69dda

UnknownScript_0x69dda: ; 0x69dda
	jumptextfaceplayer UnknownText_0x6a0cb
; 0x69ddd

UnknownText_0x69ddd: ; 0x69ddd
	db $0, "Excuse me, kid!", $4f
	db "Can you do a guy", $55
	db "a favor?", $51
	db "Can you take this", $4f
	db "#MON with MAIL", $55
	db "to my friend?", $51
	db "He's on ROUTE 31.", $57
; 0x69e48

UnknownText_0x69e48: ; 0x69e48
	db $0, "You will? Perfect!", $4f
	db "Thanks, kid!", $51
	db "My pal's a chubby", $4f
	db "guy who snoozes", $55
	db "all the time.", $51
	db "You'll recognize", $4f
	db "him right away!", $57
; 0x69eb8

UnknownText_0x69eb8: ; 0x69eb8
	db $0, $52, " received a", $4f
	db "#MON with MAIL.", $57
; 0x69ed6

UnknownText_0x69ed6: ; 0x69ed6
	db $0, "You can read it,", $4f
	db "but don't lose it!", $55
	db "ROUTE 31!", $51
	db "Oh, yeah. There", $4f
	db "was a weird tree", $55
	db "blocking the road.", $51
	db "I wonder if it's", $4f
	db "been cleared?", $57
; 0x69f56

UnknownText_0x69f56: ; 0x69f56
	db $0, "You can't carry", $4f
	db "another #MON…", $57
; 0x69f74

UnknownText_0x69f74: ; 0x69f74
	db $0, "Oh… Never mind,", $4f
	db "then…", $57
; 0x69f8b

UnknownText_0x69f8b: ; 0x69f8b
	db $0, "Thanks, kid! You", $4f
	db "made the delivery", $55
	db "for me!", $51
	db "Here's something", $4f
	db "for your trouble!", $57
; 0x69fd9

UnknownText_0x69fd9: ; 0x69fd9
	db $0, "My pal was snooz-", $4f
	db "ing, right? Heh,", $55
	db "what'd I say?", $57
; 0x6a00a

UnknownText_0x6a00a: ; 0x6a00a
	db $0, "A strange tree is", $4f
	db "blocking the road.", $51
	db "It wriggles around", $4f
	db "if you talk to it.", $51
	db "I heard it became", $4f
	db "wild when someone", $51
	db "watered it with a", $4f
	db "SQUIRTBOTTLE.", $57
; 0x6a09a

UnknownText_0x6a09a: ; 0x6a09a
	db $0, "I like the #MON", $4f
	db "Lullaby they play", $55
	db "on the radio.", $57
; 0x6a0cb

UnknownText_0x6a0cb: ; 0x6a0cb
	db $0, "I wonder how many", $4f
	db "kinds of #MON", $51
	db "there are in the", $4f
	db "world.", $51
	db "Three years ago,", $4f
	db "PROF.OAK said that", $51
	db "there were 150", $4f
	db "different kinds.", $57
; 0x6a148

Route35Goldenrodgate_MapEventHeader: ; 0x6a148
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 1, GROUP_ROUTE_35, MAP_ROUTE_35
	warp_def $0, $5, 2, GROUP_ROUTE_35, MAP_ROUTE_35
	warp_def $7, $4, 12, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $7, $5, 12, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $43, 8, 4, $9, $0, 255, 255, $80, 0, UnknownScript_0x69d37, $ffff
	person_event $2e, 8, 10, $4, $10, 255, 255, $90, 0, UnknownScript_0x69dc6, $ffff
	person_event $3a, 6, 7, $3, $0, 255, 255, $a0, 0, UnknownScript_0x69dda, $ffff
; 0x6a189

Route35NationalParkgate_MapScriptHeader: ; 0x6a189
	; trigger count
	db 3

	; triggers
	dw UnknownScript_0x6a19d, $0000
	dw UnknownScript_0x6a19e, $0000
	dw UnknownScript_0x6a19f, $0000

	; callback count
	db 2

	; callbacks

	dbw 5, UnknownScript_0x6a1a3

	dbw 2, UnknownScript_0x6a1af
; 0x6a19d

UnknownScript_0x6a19d: ; 0x6a19d
	end
; 0x6a19e

UnknownScript_0x6a19e: ; 0x6a19e
	end
; 0x6a19f

UnknownScript_0x6a19f: ; 0x6a19f
	priorityjump UnknownScript_0x6a1d1
	end
; 0x6a1a3

UnknownScript_0x6a1a3: ; 0x6a1a3
	checkbit2 $0011
	iftrue UnknownScript_0x6a1ac
	dotrigger $0
	return
; 0x6a1ac

UnknownScript_0x6a1ac: ; 0x6a1ac
	dotrigger $2
	return
; 0x6a1af

UnknownScript_0x6a1af: ; 0x6a1af
	checkcode $b
	if_equal TUESDAY, UnknownScript_0x6a1ca
	if_equal THURSDAY, UnknownScript_0x6a1ca
	if_equal SATURDAY, UnknownScript_0x6a1ca
	checkbit2 $0011
	iftrue UnknownScript_0x6a1ac
	disappear $2
	appear $3
	appear $4
	return
; 0x6a1ca

UnknownScript_0x6a1ca: ; 0x6a1ca
	appear $2
	disappear $3
	disappear $4
	return
; 0x6a1d1

UnknownScript_0x6a1d1: ; 0x6a1d1
	applymovement $0, MovementData_0x6a2e2
	spriteface $2, $3
	loadfont
	checkcode $11
	addvar $1
	RAM2MEM $0
	2writetext UnknownText_0x6a79a
	yesorno
	iffalse UnknownScript_0x6a1ee
	2writetext UnknownText_0x6a7db
	closetext
	loadmovesprites
	jumpstd $0016
; 0x6a1ee

UnknownScript_0x6a1ee: ; 0x6a1ee
	2writetext UnknownText_0x6a823
	closetext
	loadmovesprites
	2call UnknownScript_0x6a261
	playsound $001f
	special $002e
	waitbutton
	warpfacing $1, GROUP_NATIONAL_PARK_BUG_CONTEST, MAP_NATIONAL_PARK_BUG_CONTEST, $a, $2f
	end
; 0x6a204

UnknownScript_0x6a204: ; 0x6a204
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x6a2c7
	if_equal MONDAY, UnknownScript_0x6a2c7
	if_equal WEDNESDAY, UnknownScript_0x6a2c7
	if_equal FRIDAY, UnknownScript_0x6a2c7
	faceplayer
	loadfont
	checkbit2 $0051
	iftrue UnknownScript_0x6a2c1
	2call UnknownScript_0x6a2de
	2writetext UnknownText_0x6a2eb
	yesorno
	iffalse UnknownScript_0x6a2a3
	checkcode $1
	if_less_than $1, UnknownScript_0x6a271
	special $0016
	clearbit1 $0308
UnknownScript_0x6a234: ; 0x6a234
	setbit2 $0011
	special $003c
	2writetext UnknownText_0x6a39d
	keeptextopen
	2writetext UnknownText_0x6a3c7
	playsound $0001
	waitbutton
	2writetext UnknownText_0x6a3e2
	closetext
	loadmovesprites
	special $0018
	2call UnknownScript_0x6a261
	playsound $001f
	special $002e
	waitbutton
	special $0047
	warpfacing $1, GROUP_NATIONAL_PARK_BUG_CONTEST, MAP_NATIONAL_PARK_BUG_CONTEST, $a, $2f
	end
; 0x6a261

UnknownScript_0x6a261: ; 0x6a261
	checkcode $9
	if_equal $2, UnknownScript_0x6a26c
	applymovement $0, MovementData_0x6a2e5
	end
; 0x6a26c

UnknownScript_0x6a26c: ; 0x6a26c
	applymovement $0, MovementData_0x6a2e9
	end
; 0x6a271

UnknownScript_0x6a271: ; 0x6a271
	checkcode $1
	if_greater_than $6, $627d
	checkcode $10
	if_equal $0, UnknownScript_0x6a2b5
	special $005a
	if_equal $1, UnknownScript_0x6a2bb
	2writetext UnknownText_0x6a4c6
	yesorno
	iffalse UnknownScript_0x6a2a9
	special $0016
	iftrue UnknownScript_0x6a2af
	setbit1 $0308
	2writetext UnknownText_0x6a537
	keeptextopen
	2writetext UnknownText_0x6a56b
	playsound $000c
	waitbutton
	keeptextopen
	2jump UnknownScript_0x6a234
; 0x6a2a3

UnknownScript_0x6a2a3: ; 0x6a2a3
	2writetext UnknownText_0x6a5dc
	closetext
	loadmovesprites
	end
; 0x6a2a9

UnknownScript_0x6a2a9: ; 0x6a2a9
	2writetext UnknownText_0x6a597
	closetext
	loadmovesprites
	end
; 0x6a2af

UnknownScript_0x6a2af: ; 0x6a2af
	2writetext UnknownText_0x6a608
	closetext
	loadmovesprites
	end
; 0x6a2b5

UnknownScript_0x6a2b5: ; 0x6a2b5
	2writetext UnknownText_0x6a67c
	closetext
	loadmovesprites
	end
; 0x6a2bb

UnknownScript_0x6a2bb: ; 0x6a2bb
	2writetext UnknownText_0x6a71f
	closetext
	loadmovesprites
	end
; 0x6a2c1

UnknownScript_0x6a2c1: ; 0x6a2c1
	2writetext UnknownText_0x6a84f
	closetext
	loadmovesprites
	end
; 0x6a2c7

UnknownScript_0x6a2c7: ; 0x6a2c7
	jumptextfaceplayer UnknownText_0x6a894
; 0x6a2ca

UnknownScript_0x6a2ca: ; 0x6a2ca
	faceplayer
	loadfont
	checkbit2 $0051
	iftrue UnknownScript_0x6a2c1
	2writetext UnknownText_0x6a894
	closetext
	loadmovesprites
	end
; 0x6a2d8

UnknownScript_0x6a2d8: ; 0x6a2d8
	jumptextfaceplayer UnknownText_0x6a8d8
; 0x6a2db

MapRoute36NationalParkgateSignpost0Script: ; 0x6a2db
	jumptext UnknownText_0x6a90e
; 0x6a2de

UnknownScript_0x6a2de: ; 0x6a2de
	jumpstd $0015
	end
; 0x6a2e2

MovementData_0x6a2e2: ; 0x6a2e2
	step_down
	turn_head_left
	step_end
; 0x6a2e5

MovementData_0x6a2e5: ; 0x6a2e5
	step_right
	step_up
	step_up
	step_end
; 0x6a2e9

MovementData_0x6a2e9: ; 0x6a2e9
	step_up
	step_end
; 0x6a2eb

UnknownText_0x6a2eb: ; 0x6a2eb
	db $0, "Today's @"
	text_from_ram $d099
	db $0, ".", $4f
	db "That means the", $51
	db "Bug-Catching Con-", $4f
	db "test is on today.", $51
	db "The rules are sim-", $4f
	db "ple.", $51
	db "Using one of your", $4f
	db "#MON, catch a", $51
	db "bug #MON to be", $4f
	db "judged.", $51
	db "Would you like to", $4f
	db "give it a try?", $57
; 0x6a39d

UnknownText_0x6a39d: ; 0x6a39d
	db $0, "Here are the PARK", $4f
	db "BALLS for the", $55
	db "Contest.", $57
; 0x6a3c7

UnknownText_0x6a3c7: ; 0x6a3c7
	db $0, $52, " received", $4f
	db "20 PARK BALLS.", $57
; 0x6a3e2

UnknownText_0x6a3e2: ; 0x6a3e2
	db $0, "The person who", $4f
	db "gets the strong-", $55
	db "est bug #MON", $55
	db "is the winner.", $51
	db "You have 20", $4f
	db "minutes.", $51
	db "If you run out of", $4f
	db "PARK BALLS, you're", $55
	db "done.", $51
	db "You can keep the", $4f
	db "last #MON you", $55
	db "catch as your own.", $51
	db "Go out and catch", $4f
	db "the strongest bug", $51
	db "#MON you can", $4f
	db "find!", $57
; 0x6a4c6

UnknownText_0x6a4c6: ; 0x6a4c6
	db $0, "Uh-oh…", $51
	db "You have more than", $4f
	db "one #MON.", $51
	db "You'll have to use", $4f
	db "@"
	text_from_ram $d099
	db $0, ", the", $51
	db "first #MON in", $4f
	db "your party.", $51
	db "Is that OK with", $4f
	db "you?", $57
; 0x6a537

UnknownText_0x6a537: ; 0x6a537
	db $0, "Fine, we'll hold", $4f
	db "your other #MON", $55
	db "while you compete.", $57
; 0x6a56b

UnknownText_0x6a56b: ; 0x6a56b
	db $0, $52, "'s #MON", $4f
	db "were left with the", $55
	db "CONTEST HELPER.", $57
; 0x6a597

UnknownText_0x6a597: ; 0x6a597
	db $0, "Please choose the", $4f
	db "#MON to be used", $51
	db "in the Contest,", $4f
	db "then come see me.", $57
; 0x6a5dc

UnknownText_0x6a5dc: ; 0x6a5dc
	db $0, "OK. We hope you'll", $4f
	db "take part in the", $55
	db "future.", $57
; 0x6a608

UnknownText_0x6a608: ; 0x6a608
	db $0, "Uh-oh…", $4f
	db "The first #MON", $51
	db "in your party", $4f
	db "can't battle.", $51
	db "Please switch it", $4f
	db "with the #MON", $51
	db "you want to use,", $4f
	db "then come see me.", $57
; 0x6a67c

UnknownText_0x6a67c: ; 0x6a67c
	db $0, "Uh-oh…", $4f
	db "Both your party", $51
	db "and your PC BOX", $4f
	db "are full.", $51
	db "You have no room", $4f
	db "to put the bug", $55
	db "#MON you catch.", $51
	db "Please make room", $4f
	db "in your party or", $51
	db "your PC BOX, then", $4f
	db "come see me.", $57
; 0x6a71f

UnknownText_0x6a71f: ; 0x6a71f
	db $0, "Uh-oh…", $4f
	db "You have an EGG as", $51
	db "the first #MON", $4f
	db "in your party.", $51
	db "Please switch it", $4f
	db "with the #MON", $51
	db "you want to use,", $4f
	db "then come see me.", $57
; 0x6a79a

UnknownText_0x6a79a: ; 0x6a79a
	db $0, "You still have @"
	text_from_ram $d099
	db $0, $4f
	db "minute(s) left.", $51
	db "Do you want to", $4f
	db "finish now?", $57
; 0x6a7db

UnknownText_0x6a7db: ; 0x6a7db
	db $0, "OK. Please wait at", $4f
	db "the North Gate for", $51
	db "the announcement", $4f
	db "of the winners.", $57
; 0x6a823

UnknownText_0x6a823: ; 0x6a823
	db $0, "OK. Please get", $4f
	db "back outside and", $55
	db "finish up.", $57
; 0x6a84f

UnknownText_0x6a84f: ; 0x6a84f
	db $0, "Today's Contest is", $4f
	db "over. We hope you", $51
	db "will participate", $4f
	db "in the future.", $57
; 0x6a894

UnknownText_0x6a894: ; 0x6a894
	db $0, "We hold Contests", $4f
	db "regularly in the", $51
	db "PARK. You should", $4f
	db "give it a shot.", $57
; 0x6a8d8

UnknownText_0x6a8d8: ; 0x6a8d8
	db $0, "When is the next", $4f
	db "Bug-Catching Con-", $55
	db "test going to be?", $57
; 0x6a90e

UnknownText_0x6a90e: ; 0x6a90e
	db $0, "The Bug-Catching", $4f
	db "Contest is held on", $51
	db "Tuesday, Thursday", $4f
	db "and Saturday.", $51
	db "Not only do you", $4f
	db "earn a prize just", $51
	db "for participating,", $4f
	db "you also get to", $51
	db "keep the bug", $4f
	db "#MON you may", $51
	db "have at the end of", $4f
	db "the contest.", $57
; 0x6a9d2

Route35NationalParkgate_MapEventHeader: ; 0x6a9d2
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $3, 3, GROUP_NATIONAL_PARK, MAP_NATIONAL_PARK
	warp_def $0, $4, 4, GROUP_NATIONAL_PARK, MAP_NATIONAL_PARK
	warp_def $7, $3, 3, GROUP_ROUTE_35, MAP_ROUTE_35
	warp_def $7, $4, 3, GROUP_ROUTE_35, MAP_ROUTE_35

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 0, 5, $0, MapRoute36NationalParkgateSignpost0Script

	; people-events
	db 3
	person_event $43, 5, 6, $6, $0, 255, 255, $a0, 0, UnknownScript_0x6a204, $0745
	person_event $27, 9, 10, $2, $11, 255, 255, $80, 0, UnknownScript_0x6a2d8, $0734
	person_event $43, 7, 4, $9, $0, 255, 255, $a0, 0, UnknownScript_0x6a2ca, $0746
; 0x6aa18

Route36RuinsofAlphgate_MapScriptHeader: ; 0x6aa18
	; trigger count
	db 0

	; callback count
	db 0
; 0x6aa1a

UnknownScript_0x6aa1a: ; 0x6aa1a
	jumptextfaceplayer UnknownText_0x6aa20
; 0x6aa1d

UnknownScript_0x6aa1d: ; 0x6aa1d
	jumptextfaceplayer UnknownText_0x6aa5b
; 0x6aa20

UnknownText_0x6aa20: ; 0x6aa20
	db $0, "Don't you wonder", $4f
	db "who'd make some-", $55
	db "thing like this?", $55
	db "And why?", $57
; 0x6aa5b

UnknownText_0x6aa5b: ; 0x6aa5b
	db $0, "Did you see that", $4f
	db "strange tree in", $55
	db "the road?", $51
	db "That may explain", $4f
	db "why fewer people", $51
	db "are visiting the", $4f
	db "RUINS OF ALPH.", $57
; 0x6aac9

Route36RuinsofAlphgate_MapEventHeader: ; 0x6aac9
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 3, GROUP_ROUTE_36, MAP_ROUTE_36
	warp_def $0, $5, 4, GROUP_ROUTE_36, MAP_ROUTE_36
	warp_def $7, $4, 9, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE
	warp_def $7, $5, 9, GROUP_RUINS_OF_ALPH_OUTSIDE, MAP_RUINS_OF_ALPH_OUTSIDE

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $43, 8, 4, $9, $0, 255, 255, $80, 0, UnknownScript_0x6aa1a, $ffff
	person_event $2f, 9, 11, $2, $21, 255, 255, $b0, 0, UnknownScript_0x6aa1d, $ffff
; 0x6aafd

Route36NationalParkgate_MapScriptHeader: ; 0x6aafd
	; trigger count
	db 3

	; triggers
	dw UnknownScript_0x6ab11, $0000
	dw UnknownScript_0x6ab12, $0000
	dw UnknownScript_0x6ab13, $0000

	; callback count
	db 2

	; callbacks

	dbw 5, UnknownScript_0x6ab17

	dbw 2, UnknownScript_0x6ab23
; 0x6ab11

UnknownScript_0x6ab11: ; 0x6ab11
	end
; 0x6ab12

UnknownScript_0x6ab12: ; 0x6ab12
	end
; 0x6ab13

UnknownScript_0x6ab13: ; 0x6ab13
	priorityjump UnknownScript_0x6ab47
	end
; 0x6ab17

UnknownScript_0x6ab17: ; 0x6ab17
	checkbit2 $0011
	iftrue UnknownScript_0x6ab20
	dotrigger $0
	return
; 0x6ab20

UnknownScript_0x6ab20: ; 0x6ab20
	dotrigger $2
	return
; 0x6ab23

UnknownScript_0x6ab23: ; 0x6ab23
	checkbit1 $02d2
	iftrue UnknownScript_0x6ab46
	checkcode $b
	if_equal TUESDAY, UnknownScript_0x6ab42
	if_equal THURSDAY, UnknownScript_0x6ab42
	if_equal SATURDAY, UnknownScript_0x6ab42
	checkbit2 $0011
	iftrue UnknownScript_0x6ab42
	disappear $2
	appear $d
	return
; 0x6ab42

UnknownScript_0x6ab42: ; 0x6ab42
	appear $2
	disappear $d
UnknownScript_0x6ab46: ; 0x6ab46
	return
; 0x6ab47

UnknownScript_0x6ab47: ; 0x6ab47
	spriteface $0, $1
	loadfont
	checkcode $11
	addvar $1
	RAM2MEM $0
	2writetext UnknownText_0x6b284
	yesorno
	iffalse UnknownScript_0x6ab76
	2writetext UnknownText_0x6b2c5
	closetext
	loadmovesprites
	special $0030
	special $0033
	2call UnknownScript_0x6ab8c
	disappear $2
	appear $d
	applymovement $0, MovementData_0x6add1
	pause 15
	special $0032
	jumpstd $0017
; 0x6ab76

UnknownScript_0x6ab76: ; 0x6ab76
	2writetext UnknownText_0x6b300
	closetext
	loadmovesprites
	spriteface $0, $2
	playsound $0023
	special $002e
	waitbutton
	warpfacing $2, GROUP_NATIONAL_PARK_BUG_CONTEST, MAP_NATIONAL_PARK_BUG_CONTEST, $21, $12
	end
; 0x6ab8c

UnknownScript_0x6ab8c: ; 0x6ab8c
	checkbit1 $0716
	iftrue UnknownScript_0x6ab94
	appear $3
UnknownScript_0x6ab94: ; 0x6ab94
	checkbit1 $0717
	iftrue UnknownScript_0x6ab9c
	appear $4
UnknownScript_0x6ab9c: ; 0x6ab9c
	checkbit1 $0718
	iftrue UnknownScript_0x6aba4
	appear $5
UnknownScript_0x6aba4: ; 0x6aba4
	checkbit1 $0719
	iftrue UnknownScript_0x6abac
	appear $6
UnknownScript_0x6abac: ; 0x6abac
	checkbit1 $071a
	iftrue UnknownScript_0x6abb4
	appear $7
UnknownScript_0x6abb4: ; 0x6abb4
	checkbit1 $071b
	iftrue UnknownScript_0x6abbc
	appear $8
UnknownScript_0x6abbc: ; 0x6abbc
	checkbit1 $071c
	iftrue UnknownScript_0x6abc4
	appear $9
UnknownScript_0x6abc4: ; 0x6abc4
	checkbit1 $071d
	iftrue UnknownScript_0x6abcc
	appear $a
UnknownScript_0x6abcc: ; 0x6abcc
	checkbit1 $071e
	iftrue UnknownScript_0x6abd4
	appear $b
UnknownScript_0x6abd4: ; 0x6abd4
	checkbit1 $071f
	iftrue UnknownScript_0x6abdc
	appear $c
UnknownScript_0x6abdc: ; 0x6abdc
	special $0037
	end
; 0x6abe0

UnknownScript_0x6abe0: ; 0x6abe0
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x6acf1
	if_equal MONDAY, UnknownScript_0x6acf1
	if_equal WEDNESDAY, UnknownScript_0x6acf1
	if_equal FRIDAY, UnknownScript_0x6acf1
	faceplayer
	loadfont
	checkbit2 $0051
	iftrue UnknownScript_0x6ac91
	2call UnknownScript_0x6ad02
	2writetext UnknownText_0x6add5
	yesorno
	iffalse UnknownScript_0x6ac73
	checkcode $1
	if_less_than $1, UnknownScript_0x6ac41
	special $0016
	clearbit1 $0308
UnknownScript_0x6ac10: ; 0x6ac10
	setbit2 $0011
	special $003c
	2writetext UnknownText_0x6ae87
	keeptextopen
	waitbutton
	2writetext UnknownText_0x6aeb1
	playsound $0001
	waitbutton
	2writetext UnknownText_0x6aecc
	closetext
	loadmovesprites
	setbit2 $0011
	special $0018
	spriteface $0, $2
	playsound $0023
	special $002e
	waitbutton
	special $0047
	warpfacing $2, GROUP_NATIONAL_PARK_BUG_CONTEST, MAP_NATIONAL_PARK_BUG_CONTEST, $21, $12
	end
; 0x6ac41

UnknownScript_0x6ac41: ; 0x6ac41
	checkcode $1
	if_greater_than $6, UnknownScript_0x6ac4d
	checkcode $10
	if_equal $0, UnknownScript_0x6ac85
UnknownScript_0x6ac4d: ; 0x6ac4d
	special $005a
	if_equal $1, UnknownScript_0x6ac8b
	2writetext UnknownText_0x6afb0
	yesorno
	iffalse UnknownScript_0x6ac79
	special $0016
	iftrue UnknownScript_0x6ac7f
	setbit1 $0308
	2writetext UnknownText_0x6b021
	keeptextopen
	2writetext UnknownText_0x6b055
	playsound $000c
	waitbutton
	keeptextopen
	2jump UnknownScript_0x6ac10
; 0x6ac73

UnknownScript_0x6ac73: ; 0x6ac73
	2writetext UnknownText_0x6b0c6
	closetext
	loadmovesprites
	end
; 0x6ac79

UnknownScript_0x6ac79: ; 0x6ac79
	2writetext UnknownText_0x6b081
	closetext
	loadmovesprites
	end
; 0x6ac7f

UnknownScript_0x6ac7f: ; 0x6ac7f
	2writetext UnknownText_0x6b0f2
	closetext
	loadmovesprites
	end
; 0x6ac85

UnknownScript_0x6ac85: ; 0x6ac85
	2writetext UnknownText_0x6b166
	closetext
	loadmovesprites
	end
; 0x6ac8b

UnknownScript_0x6ac8b: ; 0x6ac8b
	2writetext UnknownText_0x6b209
	closetext
	loadmovesprites
	end
; 0x6ac91

UnknownScript_0x6ac91: ; 0x6ac91
	checkbit1 $0313
	iftrue UnknownScript_0x6acaf
	checkbit1 $0314
	iftrue UnknownScript_0x6acbe
	checkbit1 $0315
	iftrue UnknownScript_0x6accd
	checkbit1 $0316
	iftrue UnknownScript_0x6acdc
	2writetext UnknownText_0x6b32b
	closetext
	loadmovesprites
	end
; 0x6acaf

UnknownScript_0x6acaf: ; 0x6acaf
	2writetext UnknownText_0x6b97f
	keeptextopen
	verbosegiveitem SUN_STONE, 1
	iffalse UnknownScript_0x6aceb
	clearbit1 $0313
	loadmovesprites
	end
; 0x6acbe

UnknownScript_0x6acbe: ; 0x6acbe
	2writetext UnknownText_0x6b97f
	keeptextopen
	verbosegiveitem EVERSTONE, 1
	iffalse UnknownScript_0x6aceb
	clearbit1 $0314
	loadmovesprites
	end
; 0x6accd

UnknownScript_0x6accd: ; 0x6accd
	2writetext UnknownText_0x6b97f
	keeptextopen
	verbosegiveitem GOLD_BERRY, 1
	iffalse UnknownScript_0x6aceb
	clearbit1 $0315
	loadmovesprites
	end
; 0x6acdc

UnknownScript_0x6acdc: ; 0x6acdc
	2writetext UnknownText_0x6b97f
	keeptextopen
	verbosegiveitem BERRY, 1
	iffalse UnknownScript_0x6aceb
	clearbit1 $0316
	loadmovesprites
	end
; 0x6aceb

UnknownScript_0x6aceb: ; 0x6aceb
	2writetext UnknownText_0x6b910
	closetext
	loadmovesprites
	end
; 0x6acf1

UnknownScript_0x6acf1: ; 0x6acf1
	jumptextfaceplayer UnknownText_0x6b370
; 0x6acf4

UnknownScript_0x6acf4: ; 0x6acf4
	faceplayer
	loadfont
	checkbit2 $0051
	iftrue UnknownScript_0x6ac91
	2writetext UnknownText_0x6b370
	closetext
	loadmovesprites
	end
; 0x6ad02

UnknownScript_0x6ad02: ; 0x6ad02
	jumpstd $0015
	end
; 0x6ad06

UnknownScript_0x6ad06: ; 0x6ad06
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6ad14
	2writetext UnknownText_0x6b399
	closetext
	loadmovesprites
	end
; 0x6ad14

UnknownScript_0x6ad14: ; 0x6ad14
	2writetext UnknownText_0x6b3c4
	closetext
	loadmovesprites
	end
; 0x6ad1a

UnknownScript_0x6ad1a: ; 0x6ad1a
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6ad28
	2writetext UnknownText_0x6b40f
	closetext
	loadmovesprites
	end
; 0x6ad28

UnknownScript_0x6ad28: ; 0x6ad28
	2writetext UnknownText_0x6b440
	closetext
	loadmovesprites
	end
; 0x6ad2e

UnknownScript_0x6ad2e: ; 0x6ad2e
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6ad3c
	2writetext UnknownText_0x6b462
	closetext
	loadmovesprites
	end
; 0x6ad3c

UnknownScript_0x6ad3c: ; 0x6ad3c
	2writetext UnknownText_0x6b496
	closetext
	loadmovesprites
	end
; 0x6ad42

UnknownScript_0x6ad42: ; 0x6ad42
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6ad50
	2writetext UnknownText_0x6b4da
	closetext
	loadmovesprites
	end
; 0x6ad50

UnknownScript_0x6ad50: ; 0x6ad50
	2writetext UnknownText_0x6b50a
	closetext
	loadmovesprites
	end
; 0x6ad56

UnknownScript_0x6ad56: ; 0x6ad56
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6ad64
	2writetext UnknownText_0x6b54e
	closetext
	loadmovesprites
	end
; 0x6ad64

UnknownScript_0x6ad64: ; 0x6ad64
	2writetext UnknownText_0x6b57c
	closetext
	loadmovesprites
	end
; 0x6ad6a

UnknownScript_0x6ad6a: ; 0x6ad6a
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6ad78
	2writetext UnknownText_0x6b5b0
	closetext
	loadmovesprites
	end
; 0x6ad78

UnknownScript_0x6ad78: ; 0x6ad78
	2writetext UnknownText_0x6b5dd
	closetext
	loadmovesprites
	end
; 0x6ad7e

UnknownScript_0x6ad7e: ; 0x6ad7e
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6ad8c
	2writetext UnknownText_0x6b64b
	closetext
	loadmovesprites
	end
; 0x6ad8c

UnknownScript_0x6ad8c: ; 0x6ad8c
	2writetext UnknownText_0x6b698
	closetext
	loadmovesprites
	end
; 0x6ad92

UnknownScript_0x6ad92: ; 0x6ad92
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6ada0
	2writetext UnknownText_0x6b6b8
	closetext
	loadmovesprites
	end
; 0x6ada0

UnknownScript_0x6ada0: ; 0x6ada0
	2writetext UnknownText_0x6b6e9
	closetext
	loadmovesprites
	end
; 0x6ada6

UnknownScript_0x6ada6: ; 0x6ada6
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6adb4
	2writetext UnknownText_0x6b71b
	closetext
	loadmovesprites
	end
; 0x6adb4

UnknownScript_0x6adb4: ; 0x6adb4
	2writetext UnknownText_0x6b740
	closetext
	loadmovesprites
	end
; 0x6adba

UnknownScript_0x6adba: ; 0x6adba
	faceplayer
	loadfont
	checkbit1 $0000
	iffalse UnknownScript_0x6adc8
	2writetext UnknownText_0x6b76f
	closetext
	loadmovesprites
	end
; 0x6adc8

UnknownScript_0x6adc8: ; 0x6adc8
	2writetext UnknownText_0x6b7af
	closetext
	loadmovesprites
	end
; 0x6adce

UnknownScript_0x6adce: ; 0x6adce
	jumptext UnknownText_0x6b84c
; 0x6add1

MovementData_0x6add1: ; 0x6add1
	big_step_down
	big_step_right
	turn_head_up
	step_end
; 0x6add5

UnknownText_0x6add5: ; 0x6add5
	db $0, "Today's @"
	text_from_ram $d099
	db $0, ".", $4f
	db "That means the", $51
	db "Bug-Catching Con-", $4f
	db "test is on today.", $51
	db "The rules are sim-", $4f
	db "ple.", $51
	db "Using one of your", $4f
	db "#MON, catch a", $51
	db "bug #MON to be", $4f
	db "judged.", $51
	db "Would you like to", $4f
	db "give it a try?", $57
; 0x6ae87

UnknownText_0x6ae87: ; 0x6ae87
	db $0, "Here are the PARK", $4f
	db "BALLS for the", $55
	db "Contest.", $57
; 0x6aeb1

UnknownText_0x6aeb1: ; 0x6aeb1
	db $0, $52, " received", $4f
	db "20 PARK BALLS.", $57
; 0x6aecc

UnknownText_0x6aecc: ; 0x6aecc
	db $0, "The person who", $4f
	db "gets the strong-", $55
	db "est bug #MON", $55
	db "is the winner.", $51
	db "You have 20", $4f
	db "minutes.", $51
	db "If you run out of", $4f
	db "PARK BALLS, you're", $55
	db "done.", $51
	db "You can keep the", $4f
	db "last #MON you", $55
	db "catch as your own.", $51
	db "Go out and catch", $4f
	db "the strongest bug", $51
	db "#MON you can", $4f
	db "find!", $57
; 0x6afb0

UnknownText_0x6afb0: ; 0x6afb0
	db $0, "Uh-oh…", $51
	db "You have more than", $4f
	db "one #MON.", $51
	db "You'll have to use", $4f
	db "@"
	text_from_ram $d099
	db $0, ", the", $51
	db "first #MON in", $4f
	db "your party.", $51
	db "Is that OK with", $4f
	db "you?", $57
; 0x6b021

UnknownText_0x6b021: ; 0x6b021
	db $0, "Fine, we'll hold", $4f
	db "your other #MON", $55
	db "while you compete.", $57
; 0x6b055

UnknownText_0x6b055: ; 0x6b055
	db $0, $52, "'s #MON", $4f
	db "were left with the", $55
	db "CONTEST HELPER.", $57
; 0x6b081

UnknownText_0x6b081: ; 0x6b081
	db $0, "Please choose the", $4f
	db "#MON to be used", $51
	db "in the Contest,", $4f
	db "then come see me.", $57
; 0x6b0c6

UnknownText_0x6b0c6: ; 0x6b0c6
	db $0, "OK. We hope you'll", $4f
	db "take part in the", $55
	db "future.", $57
; 0x6b0f2

UnknownText_0x6b0f2: ; 0x6b0f2
	db $0, "Uh-oh…", $4f
	db "The first #MON", $51
	db "in your party", $4f
	db "can't battle.", $51
	db "Please switch it", $4f
	db "with the #MON", $51
	db "you want to use,", $4f
	db "then come see me.", $57
; 0x6b166

UnknownText_0x6b166: ; 0x6b166
	db $0, "Uh-oh…", $4f
	db "Both your party", $51
	db "and your PC BOX", $4f
	db "are full.", $51
	db "You have no room", $4f
	db "to put the bug", $55
	db "#MON you catch.", $51
	db "Please make room", $4f
	db "in your party or", $51
	db "your PC BOX, then", $4f
	db "come see me.", $57
; 0x6b209

UnknownText_0x6b209: ; 0x6b209
	db $0, "Uh-oh…", $4f
	db "You have an EGG as", $51
	db "the first #MON", $4f
	db "in your party.", $51
	db "Please switch it", $4f
	db "with the #MON", $51
	db "you want to use,", $4f
	db "then come see me.", $57
; 0x6b284

UnknownText_0x6b284: ; 0x6b284
	db $0, "You still have @"
	text_from_ram $d099
	db $0, $4f
	db "minute(s) left.", $51
	db "Do you want to", $4f
	db "finish now?", $57
; 0x6b2c5

UnknownText_0x6b2c5: ; 0x6b2c5
	db $0, "OK. Please wait", $4f
	db "here for the", $51
	db "announcement of", $4f
	db "the winners.", $57
; 0x6b300

UnknownText_0x6b300: ; 0x6b300
	db $0, "OK. Please go back", $4f
	db "outside and finish", $55
	db "up.", $57
; 0x6b32b

UnknownText_0x6b32b: ; 0x6b32b
	db $0, "Today's Contest is", $4f
	db "over. We hope you", $51
	db "will participate", $4f
	db "in the future.", $57
; 0x6b370

UnknownText_0x6b370: ; 0x6b370
	db $0, "Some #MON can", $4f
	db "only be seen in", $55
	db "the PARK.", $57
; 0x6b399

UnknownText_0x6b399: ; 0x6b399
	db $0, "DON: Wow, you beat", $4f
	db "me. You're pretty", $55
	db "good.", $57
; 0x6b3c4

UnknownText_0x6b3c4: ; 0x6b3c4
	db $0, "DON: Luck plays a", $4f
	db "big part in this.", $51
	db "You never know", $4f
	db "what #MON will", $55
	db "appear.", $57
; 0x6b40f

UnknownText_0x6b40f: ; 0x6b40f
	db $0, "ED: I envy you.", $4f
	db "I just couldn't", $55
	db "do it this time.", $57
; 0x6b440

UnknownText_0x6b440: ; 0x6b440
	db $0, "ED: Maybe you win", $4f
	db "with big #MON?", $57
; 0x6b462

UnknownText_0x6b462: ; 0x6b462
	db $0, "NICK: Well done!", $4f
	db "I'm going to raise", $55
	db "my #MON better.", $57
; 0x6b496

UnknownText_0x6b496: ; 0x6b496
	db $0, "NICK: Maybe you", $4f
	db "get a higher score", $51
	db "for a #MON of", $4f
	db "an unusual color.", $57
; 0x6b4da

UnknownText_0x6b4da: ; 0x6b4da
	db $0, "WILLIAM: You're", $4f
	db "the winner? What", $55
	db "did you catch?", $57
; 0x6b50a

UnknownText_0x6b50a: ; 0x6b50a
	db $0, "WILLIAM: Well, I'm", $4f
	db "satisfied because", $51
	db "I caught a #MON", $4f
	db "that I wanted.", $57
; 0x6b54e

UnknownText_0x6b54e: ; 0x6b54e
	db $0, "BENNY: Congrats!", $4f
	db "You have earned my", $55
	db "respect!", $57
; 0x6b57c

UnknownText_0x6b57c: ; 0x6b57c
	db $0, "BENNY: I caught a", $4f
	db "SCYTHER before,", $55
	db "but I didn't win.", $57
; 0x6b5b0

UnknownText_0x6b5b0: ; 0x6b5b0
	db $0, "BARRY: That #-", $4f
	db "MON you caught…", $55
	db "it's awesome!", $57
; 0x6b5dd

UnknownText_0x6b5dd: ; 0x6b5dd
	db $0, "BARRY: It's easier", $4f
	db "to win if you get", $51
	db "a high-level bug", $4f
	db "#MON.", $51
	db "But I think they", $4f
	db "also consider some", $55
	db "other points.", $57
; 0x6b64b

UnknownText_0x6b64b: ; 0x6b64b
	db $0, "CINDY: You won?", $4f
	db "That's great!", $51
	db "Do you feel like", $4f
	db "looking for bug", $55
	db "#MON with me?", $57
; 0x6b698

UnknownText_0x6b698: ; 0x6b698
	db $0, "CINDY: I really", $4f
	db "love bug #MON!", $57
; 0x6b6b8

UnknownText_0x6b6b8: ; 0x6b6b8
	db $0, "JOSH: I… I can't", $4f
	db "believe I lost at", $55
	db "bug-catching…", $57
; 0x6b6e9

UnknownText_0x6b6e9: ; 0x6b6e9
	db $0, "JOSH: I heard that", $4f
	db "somebody won with", $55
	db "a CATERPIE!", $57
; 0x6b71b

UnknownText_0x6b71b: ; 0x6b71b
	db $0, "SAMUEL: Next time,", $4f
	db "I'm going to win.", $57
; 0x6b740

UnknownText_0x6b740: ; 0x6b740
	db $0, "SAMUEL: Darn.", $4f
	db "I thought I would", $55
	db "score higher…", $57
; 0x6b76f

UnknownText_0x6b76f: ; 0x6b76f
	db $0, "KIPP: Could you", $4f
	db "give me some tips?", $51
	db "I want to study", $4f
	db "your style.", $57
; 0x6b7af

UnknownText_0x6b7af: ; 0x6b7af
	db $0, "KIPP: I study a", $4f
	db "lot, but that's", $51
	db "not good enough to", $4f
	db "win.", $57
; 0x6b7e7

; This text is unused and unreferenced in the final game.
; The tree Pokémon is Sudowoodo.
; The Silph Scope 2 was later reworked into the Squirtbottle.

UnusedSudowoodoText: ; 0x6b7e7
	db 0, "I hear there's a", $4f
	db "#MON that looks", $55
	db "just like a tree.", $51
	db "You can reveal its", $4f
	db "identity using a", $55
	db "SILPHSCOPE 2.", $57

UnknownText_0x6b84c: ; 0x6b84c
	db $0, "The Bug-Catching", $4f
	db "Contest is held on", $51
	db "Tuesday, Thursday", $4f
	db "and Saturday.", $51
	db "Not only do you", $4f
	db "earn a prize just", $51
	db "for participating,", $4f
	db "you also get to", $51
	db "keep the bug", $4f
	db "#MON you may", $51
	db "have at the end of", $4f
	db "the contest.", $57
; 0x6b910

UnknownText_0x6b910: ; 0x6b910
	db $0, "Uh-oh… Your PACK", $4f
	db "is full.", $51
	db "We'll hold on to", $4f
	db "your prize, but", $55
	db "only for today.", $51
	db "Please make room,", $4f
	db "then come see me.", $57
; 0x6b97f

UnknownText_0x6b97f: ; 0x6b97f
	db $0, $52, "?", $51
	db "Here's the prize", $4f
	db "we were holding", $55
	db "for you.", $57
; 0x6b9ac

Route36NationalParkgate_MapEventHeader: ; 0x6b9ac
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 1, GROUP_NATIONAL_PARK, MAP_NATIONAL_PARK
	warp_def $5, $0, 2, GROUP_NATIONAL_PARK, MAP_NATIONAL_PARK
	warp_def $4, $9, 1, GROUP_ROUTE_36, MAP_ROUTE_36
	warp_def $5, $9, 2, GROUP_ROUTE_36, MAP_ROUTE_36

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 0, 6, $0, MapRoute36NationalParkgateSignpost0Script

	; people-events
	db 12
	person_event $43, 7, 4, $6, $0, 255, 255, $a0, 0, UnknownScript_0x6abe0, $0747
	person_event $27, 9, 6, $7, $0, 255, 255, $80, 0, UnknownScript_0x6ad06, $0720
	person_event $27, 9, 8, $7, $0, 255, 255, $a0, 0, UnknownScript_0x6ad1a, $0721
	person_event $2c, 10, 6, $7, $0, 255, 255, $90, 0, UnknownScript_0x6ad2e, $0722
	person_event $2d, 9, 10, $7, $0, 255, 255, $b0, 0, UnknownScript_0x6ad42, $0723
	person_event $27, 11, 6, $7, $0, 255, 255, $80, 0, UnknownScript_0x6ad56, $0724
	person_event $27, 10, 9, $7, $0, 255, 255, $a0, 0, UnknownScript_0x6ad6a, $0725
	person_event $28, 10, 7, $7, $0, 255, 255, $90, 0, UnknownScript_0x6ad7e, $0726
	person_event $27, 11, 8, $7, $0, 255, 255, $80, 0, UnknownScript_0x6ad92, $0727
	person_event $27, 11, 10, $7, $0, 255, 255, $a0, 0, UnknownScript_0x6ada6, $0728
	person_event $27, 10, 10, $7, $0, 255, 255, $90, 0, UnknownScript_0x6adba, $0729
	person_event $43, 6, 7, $6, $0, 255, 255, $a0, 0, UnknownScript_0x6acf4, $0748
; 0x6ba67

SECTION "bank1B",DATA,BANK[$1B]

Route8_MapScriptHeader: ; 0x6c000
	; trigger count
	db 0

	; callback count
	db 0
; 0x6c002

TrainerBikerDwayne: ; 0x6c002
	; bit/flag number
	dw $433

	; trainer group && trainer id
	db BIKER, DWAYNE

	; text when seen
	dw BikerDwayneSeenText

	; text when trainer beaten
	dw BikerDwayneBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BikerDwayneScript
; 0x6c00e

BikerDwayneScript: ; 0x6c00e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6c0c8
	closetext
	loadmovesprites
	end
; 0x6c016

TrainerBikerHarris: ; 0x6c016
	; bit/flag number
	dw $434

	; trainer group && trainer id
	db BIKER, HARRIS

	; text when seen
	dw BikerHarrisSeenText

	; text when trainer beaten
	dw BikerHarrisBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BikerHarrisScript
; 0x6c022

BikerHarrisScript: ; 0x6c022
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6c143
	closetext
	loadmovesprites
	end
; 0x6c02a

TrainerBikerZeke: ; 0x6c02a
	; bit/flag number
	dw $435

	; trainer group && trainer id
	db BIKER, ZEKE

	; text when seen
	dw BikerZekeSeenText

	; text when trainer beaten
	dw BikerZekeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BikerZekeScript
; 0x6c036

BikerZekeScript: ; 0x6c036
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6c1a3
	closetext
	loadmovesprites
	end
; 0x6c03e

TrainerSupernerdSam: ; 0x6c03e
	; bit/flag number
	dw $586

	; trainer group && trainer id
	db SUPER_NERD, SAM

	; text when seen
	dw SupernerdSamSeenText

	; text when trainer beaten
	dw SupernerdSamBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SupernerdSamScript
; 0x6c04a

SupernerdSamScript: ; 0x6c04a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6c219
	closetext
	loadmovesprites
	end
; 0x6c052

TrainerSupernerdTom: ; 0x6c052
	; bit/flag number
	dw $587

	; trainer group && trainer id
	db SUPER_NERD, TOM

	; text when seen
	dw SupernerdTomSeenText

	; text when trainer beaten
	dw SupernerdTomBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SupernerdTomScript
; 0x6c05e

SupernerdTomScript: ; 0x6c05e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6c27e
	closetext
	loadmovesprites
	end
; 0x6c066

MapRoute8Signpost1Script: ; 0x6c066
	jumptext UnknownText_0x6c2aa
; 0x6c069

MapRoute8Signpost0Script: ; 0x6c069
	jumptext UnknownText_0x6c2b7
; 0x6c06c

UnknownScript_0x6c06c: ; 0x6c06c
	fruittree $1b
; 0x6c06e

BikerDwayneSeenText: ; 0x6c06e
	db $0, "We're the KANTO", $4f
	db "#MON FEDERATION", $55
	db "trainer group.", $51
	db "We'll drive you", $4f
	db "under our wheels!", $57
; 0x6c0be

BikerDwayneBeatenText: ; 0x6c0be
	db $0, "S-sorry!", $57
; 0x6c0c8

UnknownText_0x6c0c8: ; 0x6c0c8
	db $0, "The KANTO #MON", $4f
	db "FEDERATION will", $55
	db "never fall!", $57
; 0x6c0f4

BikerHarrisSeenText: ; 0x6c0f4
	db $0, "The cops shut down", $4f
	db "our UNDERGROUND", $51
	db "PATH! That really", $4f
	db "fries me!", $57
; 0x6c134

BikerHarrisBeatenText: ; 0x6c134
	db $0, "F-forgive me!", $57
; 0x6c143

UnknownText_0x6c143: ; 0x6c143
	db $0, "Wiped out by some", $4f
	db "punk from JOHTO…", $57
; 0x6c167

BikerZekeSeenText: ; 0x6c167
	db $0, "We're the KANTO", $4f
	db "#MON FEDERA-", $55
	db "TION!", $55
	db "Right on!", $57
; 0x6c194

BikerZekeBeatenText: ; 0x6c194
	db $0, "Yikes! Sorry!", $57
; 0x6c1a3

UnknownText_0x6c1a3: ; 0x6c1a3
	db $0, "We'll try not to", $4f
	db "disturb anyone", $55
	db "from now on…", $57
; 0x6c1d0

SupernerdSamSeenText: ; 0x6c1d0
	db $0, "How does the MAG-", $4f
	db "NET TRAIN work?", $57
; 0x6c1f3

SupernerdSamBeatenText: ; 0x6c1f3
	db $0, "I just want to see", $4f
	db "the MAGNET TRAIN…", $57
; 0x6c219

UnknownText_0x6c219: ; 0x6c219
	db $0, "The power of mag-", $4f
	db "nets is awesome!", $57
; 0x6c23d

SupernerdTomSeenText: ; 0x6c23d
	db $0, "Hm… You've got", $4f
	db "many GYM BADGES.", $57
; 0x6c25d

SupernerdTomBeatenText: ; 0x6c25d
	db $0, "Just as I thought…", $4f
	db "You're tough!", $57
; 0x6c27e

UnknownText_0x6c27e: ; 0x6c27e
	db $0, "GYM BADGES give", $4f
	db "you advantages in", $55
	db "battles.", $57
; 0x6c2aa

UnknownText_0x6c2aa: ; 0x6c2aa
	db $0, "It's locked…", $57
; 0x6c2b7

UnknownText_0x6c2b7: ; 0x6c2b7
	db $0, "The flyer's torn.", $51
	db "It's impossible to", $4f
	db "read…", $57
; 0x6c2e1

Route8_MapEventHeader: ; 0x6c2e1
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $4, $4, 3, GROUP_ROUTE_8_SAFFRON_GATE, MAP_ROUTE_8_SAFFRON_GATE
	warp_def $5, $4, 4, GROUP_ROUTE_8_SAFFRON_GATE, MAP_ROUTE_8_SAFFRON_GATE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 7, 11, $0, MapRoute8Signpost0Script
	signpost 5, 10, $0, MapRoute8Signpost1Script

	; people-events
	db 6
	person_event $4a, 12, 14, $8, $0, 255, 255, $82, 5, TrainerBikerDwayne, $ffff
	person_event $4a, 13, 14, $8, $0, 255, 255, $a2, 5, TrainerBikerHarris, $ffff
	person_event $4a, 14, 14, $8, $0, 255, 255, $92, 5, TrainerBikerZeke, $ffff
	person_event $2b, 6, 27, $6, $0, 255, 255, $b2, 3, TrainerSupernerdSam, $ffff
	person_event $2b, 16, 35, $a, $0, 255, 255, $b2, 4, TrainerSupernerdTom, $ffff
	person_event $5d, 9, 37, $1, $0, 255, 255, $0, 0, UnknownScript_0x6c06c, $ffff
; 0x6c349

MahoganyMart1F_MapScriptHeader: ; 0x6c349
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x6c356, $0000
	dw UnknownScript_0x6c357, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x6c35b
; 0x6c356

UnknownScript_0x6c356: ; 0x6c356
	end
; 0x6c357

UnknownScript_0x6c357: ; 0x6c357
	priorityjump UnknownScript_0x6c38f
	end
; 0x6c35b

UnknownScript_0x6c35b: ; 0x6c35b
	checkbit1 $02e2
	iftrue UnknownScript_0x6c362
	return
; 0x6c362

UnknownScript_0x6c362: ; 0x6c362
	changeblock $6, $2, $1e
	return
; 0x6c367

UnknownScript_0x6c367: ; 0x6c367
	faceplayer
	loadfont
	checkbit1 $0060
	iftrue UnknownScript_0x6c375
	pokemart $0, $000f
	loadmovesprites
	end
; 0x6c375

UnknownScript_0x6c375: ; 0x6c375
	2writetext UnknownText_0x6c46b
	closetext
	loadmovesprites
	end
; 0x6c37b

UnknownScript_0x6c37b: ; 0x6c37b
	faceplayer
	loadfont
	checkbit1 $0060
	iftrue UnknownScript_0x6c389
	2writetext UnknownText_0x6c494
	closetext
	loadmovesprites
	end
; 0x6c389

UnknownScript_0x6c389: ; 0x6c389
	2writetext UnknownText_0x6c501
	closetext
	loadmovesprites
	end
; 0x6c38f

UnknownScript_0x6c38f: ; 0x6c38f
	pause 15
	loadfont
	2writetext UnknownText_0x6c52a
	pause 15
	loadmovesprites
	playsound $0041
	applymovement $5, MovementData_0x6c3f6
	applymovement $3, MovementData_0x6c3fb
	pause 15
	disappear $5
	pause 15
	applymovement $4, MovementData_0x6c407
	loadfont
	2writetext UnknownText_0x6c549
	closetext
	loadmovesprites
	follow $4, $0
	applymovement $4, MovementData_0x6c40a
	applymovement $2, MovementData_0x6c403
	applymovement $4, MovementData_0x6c40e
	stopfollow
	loadfont
	2writetext UnknownText_0x6c59e
	closetext
	showemote $0, $2, 10
	playsound $002a
	changeblock $6, $2, $1e
	reloadmappart
	loadmovesprites
	setbit1 $02e2
	spriteface $4, $2
	loadfont
	2writetext UnknownText_0x6c5ba
	closetext
	loadmovesprites
	applymovement $4, MovementData_0x6c412
	playsound $0023
	disappear $4
	dotrigger $0
	waitbutton
	end
; 0x6c3ee

UnknownScript_0x6c3ee: ; 0x6c3ee
	faceplayer
	loadfont
	pokemart $0, $0010
	loadmovesprites
	end
; 0x6c3f6

MovementData_0x6c3f6: ; 0x6c3f6
	fix_facing
	big_step_left
	big_step_right
	remove_fixed_facing
	step_end
; 0x6c3fb

MovementData_0x6c3fb: ; 0x6c3fb
	fix_facing
	big_step_left
	remove_fixed_facing
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	step_end
; 0x6c403

MovementData_0x6c403: ; 0x6c403
	fix_facing
	big_step_left
	remove_fixed_facing
	step_end
; 0x6c407

MovementData_0x6c407: ; 0x6c407
	slow_step_left
	turn_head_down
	step_end
; 0x6c40a

MovementData_0x6c40a: ; 0x6c40a
	slow_step_right
	slow_step_up
	slow_step_up
	step_end
; 0x6c40e

MovementData_0x6c40e: ; 0x6c40e
	slow_step_up
	slow_step_right
	slow_step_right
	step_end
; 0x6c412

MovementData_0x6c412: ; 0x6c412
	slow_step_right
	step_end
; 0x6c414

UnknownText_0x6c414: ; 0x6c414
	db $0, "Hello, kiddo!", $51
	db "How would you like", $4f
	db "some RAGECANDYBAR?", $51
	db "It's the thing to", $4f
	db "eat in MAHOGANY!", $57
; 0x6c46b

UnknownText_0x6c46b: ; 0x6c46b
	db $0, "Arrgh… You found", $4f
	db "the secret stair-", $55
	db "way…", $57
; 0x6c494

UnknownText_0x6c494: ; 0x6c494
	db $0, "Heheh! The experi-", $4f
	db "ment worked like a", $55
	db "charm.", $51
	db "MAGIKARP are just", $4f
	db "worthless, but", $51
	db "GYARADOS are big", $4f
	db "moneymakers.", $57
; 0x6c501

UnknownText_0x6c501: ; 0x6c501
	db $0, "Urrgh…", $51
	db "That guy's dragon", $4f
	db "#MON are tough…", $57
; 0x6c52a

UnknownText_0x6c52a: ; 0x6c52a
	db $0, "LANCE: DRAGONITE,", $4f
	db "HYPER BEAM.", $57
; 0x6c549

UnknownText_0x6c549: ; 0x6c549
	db $0, "What took you,", $4f
	db $14, "?", $51
	db "Just as I thought,", $4f
	db "that strange radio", $51
	db "signal is coming", $4f
	db "from here.", $57
; 0x6c59e

UnknownText_0x6c59e: ; 0x6c59e
	db $0, "The stairs are", $4f
	db "right here.", $57
; 0x6c5ba

UnknownText_0x6c5ba: ; 0x6c5ba
	db $0, "LANCE: ", $14, ", we", $4f
	db "should split up to", $51
	db "check this place.", $4f
	db "I'll go first.", $57
; 0x6c5fb

MahoganyMart1F_MapEventHeader: ; 0x6c5fb
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN
	warp_def $7, $4, 1, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN
	warp_def $3, $7, 1, GROUP_TEAM_ROCKET_BASE_B1F, MAP_TEAM_ROCKET_BASE_B1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 5
	person_event $4b, 7, 8, $6, $0, 255, 255, $0, 0, UnknownScript_0x6c367, $06da
	person_event $41, 10, 5, $3, $0, 255, 255, $0, 0, UnknownScript_0x6c37b, $06da
	person_event $1e, 10, 8, $8, $0, 255, 255, $0, 0, ObjectEvent, $06d5
	person_event $4f, 10, 7, $8, $0, 255, 255, $0, 0, ObjectEvent, $06d5
	person_event $30, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x6c3ee, $0736
; 0x6c651

TeamRocketBaseB1F_MapScriptHeader: ; 0x6c651
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x6c65a, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x6c65b
; 0x6c65a

UnknownScript_0x6c65a: ; 0x6c65a
	end
; 0x6c65b

UnknownScript_0x6c65b: ; 0x6c65b
	disappear $2
	return
; 0x6c65e

SecurityCamera1a: ; 0x6c65e
	checkbit1 $02e4
	iftrue NoSecurityCamera
	2call PlaySecurityCameraSounds
	checkbit1 $06da
	iftrue NoSecurityCamera
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $13, $2
	appear $2
	spriteface $0, $2
	applymovement $2, SecurityCameraMovement1
	2call TrainerCameraGrunt1
	if_equal $1, NoSecurityCamera
	2call PlaySecurityCameraSounds
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $13, $2
	appear $2
	applymovement $2, SecurityCameraMovement1
	2call TrainerCameraGrunt2
	if_equal $1, NoSecurityCamera
	setbit1 $02e4
	end
; 0x6c6a7

SecurityCamera1b: ; 0x6c6a7
	checkbit1 $02e4
	iftrue NoSecurityCamera
	2call PlaySecurityCameraSounds
	checkbit1 $06da
	iftrue NoSecurityCamera
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $13, $3
	appear $2
	spriteface $0, $2
	applymovement $2, SecurityCameraMovement1
	2call TrainerCameraGrunt1
	if_equal $1, NoSecurityCamera
	2call PlaySecurityCameraSounds
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $13, $3
	appear $2
	applymovement $2, SecurityCameraMovement1
	2call TrainerCameraGrunt2
	if_equal $1, NoSecurityCamera
	setbit1 $02e4
	end
; 0x6c6f0

SecurityCamera2a: ; 0x6c6f0
	checkbit1 $02e5
	iftrue NoSecurityCamera
	2call PlaySecurityCameraSounds
	checkbit1 $06da
	iftrue NoSecurityCamera
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $4, $7
	appear $2
	spriteface $0, $2
	applymovement $2, SecurityCameraMovement2
	2call TrainerCameraGrunt1
	if_equal $1, NoSecurityCamera
	2call PlaySecurityCameraSounds
	showemote $0, $0, 15
	playmusic $0039
	spriteface $0, $3
	moveperson $2, $c, $5
	appear $2
	applymovement $2, SecurityCameraMovement3
	2call TrainerCameraGrunt2
	if_equal $1, NoSecurityCamera
	setbit1 $02e5
	end
; 0x6c73c

SecurityCamera2b: ; 0x6c73c
	checkbit1 $02e5
	iftrue NoSecurityCamera
	2call PlaySecurityCameraSounds
	checkbit1 $06da
	iftrue NoSecurityCamera
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $4, $8
	appear $2
	spriteface $0, $2
	applymovement $2, SecurityCameraMovement4
	2call TrainerCameraGrunt1
	if_equal $1, NoSecurityCamera
	2call PlaySecurityCameraSounds
	showemote $0, $0, 15
	playmusic $0039
	spriteface $0, $3
	moveperson $2, $c, $5
	appear $2
	applymovement $2, SecurityCameraMovement5
	2call TrainerCameraGrunt2
	if_equal $1, NoSecurityCamera
	setbit1 $02e5
	end
; 0x6c788

SecurityCamera3a: ; 0x6c788
	checkbit1 $02e6
	iftrue NoSecurityCamera
	2call PlaySecurityCameraSounds
	checkbit1 $06da
	iftrue NoSecurityCamera
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $13, $6
	appear $2
	spriteface $0, $2
	applymovement $2, SecurityCameraMovement1
	2call TrainerCameraGrunt1
	if_equal $1, NoSecurityCamera
	2call PlaySecurityCameraSounds
	showemote $0, $0, 15
	playmusic $0039
	spriteface $0, $3
	moveperson $2, $19, $b
	appear $2
	applymovement $2, SecurityCameraMovement6
	2call TrainerCameraGrunt2
	if_equal $1, NoSecurityCamera
	setbit1 $02e6
	end
; 0x6c7d4

SecurityCamera3b: ; 0x6c7d4
	checkbit1 $02e6
	iftrue NoSecurityCamera
	2call PlaySecurityCameraSounds
	checkbit1 $06da
	iftrue NoSecurityCamera
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $13, $7
	appear $2
	spriteface $0, $2
	applymovement $2, SecurityCameraMovement1
	2call TrainerCameraGrunt1
	if_equal $1, NoSecurityCamera
	2call PlaySecurityCameraSounds
	showemote $0, $0, 15
	playmusic $0039
	spriteface $0, $3
	moveperson $2, $19, $c
	appear $2
	applymovement $2, SecurityCameraMovement7
	2call TrainerCameraGrunt2
	if_equal $1, NoSecurityCamera
	setbit1 $02e6
	end
; 0x6c820

SecurityCamera4: ; 0x6c820
	checkbit1 $02e7
	iftrue NoSecurityCamera
	2call PlaySecurityCameraSounds
	checkbit1 $06da
	iftrue NoSecurityCamera
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $11, $10
	appear $2
	spriteface $0, $2
	applymovement $2, SecurityCameraMovement1
	2call TrainerCameraGrunt1
	if_equal $1, NoSecurityCamera
	2call PlaySecurityCameraSounds
	showemote $0, $0, 15
	playmusic $0039
	spriteface $0, $3
	moveperson $2, $19, $b
	appear $2
	applymovement $2, SecurityCameraMovement8
	2call TrainerCameraGrunt2
	if_equal $1, NoSecurityCamera
	setbit1 $02e7
	end
; 0x6c86c

SecurityCamera5: ; 0x6c86c
	checkbit1 $02e8
	iftrue NoSecurityCamera
	2call PlaySecurityCameraSounds
	checkbit1 $06da
	iftrue NoSecurityCamera
	showemote $0, $0, 15
	playmusic $0039
	moveperson $2, $3, $10
	appear $2
	spriteface $0, $2
	applymovement $2, SecurityCameraMovement1
	2call TrainerCameraGrunt1
	if_equal $1, NoSecurityCamera
	2call PlaySecurityCameraSounds
	showemote $0, $0, 15
	playmusic $0039
	spriteface $0, $3
	moveperson $2, $e, $10
	appear $2
	applymovement $2, SecurityCameraMovement9
	2call TrainerCameraGrunt2
	if_equal $1, NoSecurityCamera
	setbit1 $02e8
	end
; 0x6c8b8

NoSecurityCamera: ; 0x6c8b8
	end
; 0x6c8b9

TrainerCameraGrunt1: ; 0x6c8b9
	loadfont
	2writetext CameraGrunt1SeenText
	closetext
	loadmovesprites
	winlosstext CameraGrunt1BeatenText, $0000
	setlasttalked $2
	loadtrainer GRUNTM, 20
	startbattle
	disappear $2
	returnafterbattle
	end
; 0x6c8ce

TrainerCameraGrunt2: ; 0x6c8ce
	loadfont
	2writetext CameraGrunt2SeenText
	closetext
	loadmovesprites
	winlosstext CameraGrunt2BeatenText, $0000
	setlasttalked $2
	loadtrainer GRUNTM, 21
	startbattle
	disappear $2
	returnafterbattle
	end
; 0x6c8e3

PlaySecurityCameraSounds: ; 0x6c8e3
	playsound $0030
	pause 10
	playsound $0030
	pause 10
	playsound $0030
	pause 10
	playsound $0030
	pause 10
	playsound $0030
	pause 10
	playsound $0030
	end
; 0x6c900

ExplodingTrap1: ; 0x6c900
	checkbit1 $02e9
	iftrue NoExplodingTrap
	2call KoffingExplodingTrap
	returnafterbattle
	setbit1 $02e9
	end

ExplodingTrap2: ; 0x6c90e
	checkbit1 $02ea
	iftrue NoExplodingTrap
	2call VoltorbExplodingTrap
	returnafterbattle
	setbit1 $02ea
	end

ExplodingTrap3: ; 0x6c91c
	checkbit1 $02eb
	iftrue NoExplodingTrap
	2call GeodudeExplodingTrap
	returnafterbattle
	setbit1 $02eb
	end

ExplodingTrap4: ; 0x6c92a
	checkbit1 $02ec
	iftrue NoExplodingTrap
	2call VoltorbExplodingTrap
	returnafterbattle
	setbit1 $02ec
	end

ExplodingTrap5: ; 0x6c938
	checkbit1 $02ed
	iftrue NoExplodingTrap
	2call GeodudeExplodingTrap
	returnafterbattle
	setbit1 $02ed
	end

ExplodingTrap6: ; 0x6c946
	checkbit1 $02ee
	iftrue NoExplodingTrap
	2call KoffingExplodingTrap
	returnafterbattle
	setbit1 $02ee
	end

ExplodingTrap7: ; 0x6c954
	checkbit1 $02ef
	iftrue NoExplodingTrap
	2call VoltorbExplodingTrap
	returnafterbattle
	setbit1 $02ef
	end

ExplodingTrap8: ; 0x6c962
	checkbit1 $02f0
	iftrue NoExplodingTrap
	2call KoffingExplodingTrap
	returnafterbattle
	setbit1 $02f0
	end

ExplodingTrap9: ; 0x6c970
	checkbit1 $02f1
	iftrue NoExplodingTrap
	2call KoffingExplodingTrap
	returnafterbattle
	setbit1 $02f1
	end

ExplodingTrap10: ; 0x6c97e
	checkbit1 $02f2
	iftrue NoExplodingTrap
	2call VoltorbExplodingTrap
	returnafterbattle
	setbit1 $02f2
	end

ExplodingTrap11: ; 0x6c98c
	checkbit1 $02f3
	iftrue NoExplodingTrap
	2call GeodudeExplodingTrap
	returnafterbattle
	setbit1 $02f3
	end

ExplodingTrap12: ; 0x6c99a
	checkbit1 $02f4
	iftrue NoExplodingTrap
	2call GeodudeExplodingTrap
	returnafterbattle
	setbit1 $02f4
	end

ExplodingTrap13: ; 0x6c9a8
	checkbit1 $02f5
	iftrue NoExplodingTrap
	2call GeodudeExplodingTrap
	returnafterbattle
	setbit1 $02f5
	end

ExplodingTrap14: ; 0x6c9b6
	checkbit1 $02f6
	iftrue NoExplodingTrap
	2call KoffingExplodingTrap
	returnafterbattle
	setbit1 $02f6
	end

ExplodingTrap15: ; 0x6c9c4
	checkbit1 $02f7
	iftrue NoExplodingTrap
	2call VoltorbExplodingTrap
	returnafterbattle
	setbit1 $02f7
	end

ExplodingTrap16: ; 0x6c9d2
	checkbit1 $02f8
	iftrue NoExplodingTrap
	2call KoffingExplodingTrap
	returnafterbattle
	setbit1 $02f8
	end

ExplodingTrap17: ; 0x6c9e0
	checkbit1 $02f9
	iftrue NoExplodingTrap
	2call VoltorbExplodingTrap
	returnafterbattle
	setbit1 $02f9
	end

ExplodingTrap18: ; 0x6c9ee
	checkbit1 $02fa
	iftrue NoExplodingTrap
	2call GeodudeExplodingTrap
	returnafterbattle
	setbit1 $02fa
	end

ExplodingTrap19: ; 0x6c9fc
	checkbit1 $02fb
	iftrue NoExplodingTrap
	2call GeodudeExplodingTrap
	returnafterbattle
	setbit1 $02fb
	end

ExplodingTrap20: ; 0x6ca0a
	checkbit1 $02fc
	iftrue NoExplodingTrap
	2call VoltorbExplodingTrap
	returnafterbattle
	setbit1 $02fc
	end

ExplodingTrap21: ; 0x6ca18
	checkbit1 $02fd
	iftrue NoExplodingTrap
	2call KoffingExplodingTrap
	returnafterbattle
	setbit1 $02fd
	end

ExplodingTrap22: ; 0x6ca26
	checkbit1 $02fe
	iftrue NoExplodingTrap
	2call VoltorbExplodingTrap
	returnafterbattle
	setbit1 $02fe
	end

VoltorbExplodingTrap: ; 0x6ca34
	special $002e
	cry VOLTORB
	special $0031
	setlasttalked $ff
	writecode $3, $9
	loadpokedata VOLTORB, 23
	startbattle
	end

GeodudeExplodingTrap: ; 0x6ca47
	special $002e
	cry GEODUDE
	special $0031
	setlasttalked $ff
	writecode $3, $9
	loadpokedata GEODUDE, 21
	startbattle
	end

KoffingExplodingTrap: ; 0x6ca5a
	special $002e
	cry KOFFING
	special $0031
	setlasttalked $ff
	writecode $3, $9
	loadpokedata KOFFING, 21
	startbattle
	end

NoExplodingTrap: ; 0x6ca6d
	end
; 0x6ca6e

TrainerScientistJed: ; 0x6ca6e
	; bit/flag number
	dw $4a1

	; trainer group && trainer id
	db SCIENTIST, JED

	; text when seen
	dw ScientistJedSeenText

	; text when trainer beaten
	dw ScientistJedBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw ScientistJedScript
; 0x6ca7a

ScientistJedScript: ; 0x6ca7a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6cc16
	closetext
	loadmovesprites
	end
; 0x6ca82

TrainerGruntM16: ; 0x6ca82
	; bit/flag number
	dw $500

	; trainer group && trainer id
	db GRUNTM, 16

	; text when seen
	dw GruntM16SeenText

	; text when trainer beaten
	dw GruntM16BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM16Script
; 0x6ca8e

GruntM16Script: ; 0x6ca8e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6cd1b
	closetext
	loadmovesprites
	end
; 0x6ca96

MapTeamRocketBaseB1FSignpost5Script: ; 0x6ca96
	jumptext SecurityCameraText
; 0x6ca99

MapTeamRocketBaseB1FSignpost7Script: ; 0x6ca99
	jumpstd $0004
; 0x6ca9c

MapTeamRocketBaseB1FSignpost0Script: ; 0x6ca9c
	loadfont
	checkbit1 $02e3
	iftrue UnknownScript_0x6cabe
	2writetext UnknownText_0x6cdad
	playsound $0021
	closetext
	loadmovesprites
	setbit1 $02e3
	setbit1 $02e4
	setbit1 $02e5
	setbit1 $02e6
	setbit1 $02e7
	setbit1 $02e8
	end
; 0x6cabe

UnknownScript_0x6cabe: ; 0x6cabe
	2writetext UnknownText_0x6cdd0
	closetext
	loadmovesprites
	end
; 0x6cac4

ItemFragment_0x6cac4: ; 0x6cac4
	db HYPER_POTION, 1
; 0x6cac6

ItemFragment_0x6cac6: ; 0x6cac6
	db NUGGET, 1
; 0x6cac8

ItemFragment_0x6cac8: ; 0x6cac8
	db GUARD_SPEC, 1
; 0x6caca

MapTeamRocketBaseB1FSignpostItem8: ; 0x6caca
	dw $0086
	db REVIVE
	
; 0x6cacd

SecurityCameraMovement1: ; 0x6cacd
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	step_end
; 0x6cad2

SecurityCameraMovement2: ; 0x6cad2
	big_step_up
	big_step_right
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	turn_head_right
	step_end
; 0x6cada

SecurityCameraMovement3: ; 0x6cada
	big_step_left
	big_step_left
	big_step_left
	big_step_up
	big_step_up
	big_step_up
	big_step_left
	big_step_left
	step_end
; 0x6cae3

SecurityCameraMovement4: ; 0x6cae3
; he jumps over a trap
	jump_step_up
	big_step_right
	big_step_up
	big_step_up
	big_step_up
	turn_head_right
	step_end
; 0x6caea

SecurityCameraMovement5: ; 0x6caea
	big_step_left
	big_step_left
	big_step_left
	big_step_up
	big_step_up
	big_step_left
	big_step_left
	step_end
; 0x6caf2

SecurityCameraMovement6: ; 0x6caf2
	big_step_up
	big_step_up
	big_step_right
	big_step_up
	big_step_up
	big_step_up
	big_step_left
	step_end
; 0x6cafa

SecurityCameraMovement7: ; 0x6cafa
	big_step_up
	big_step_up
	big_step_up
	big_step_right
	big_step_up
	big_step_up
	big_step_left
	step_end
; 0x6cb02

SecurityCameraMovement8: ; 0x6cb02
	big_step_down
	big_step_down
	big_step_right
	big_step_down
	big_step_down
	big_step_down
	big_step_left
	big_step_left
	big_step_left
	step_end
; 0x6cb0c

SecurityCameraMovement9: ; 0x6cb0c
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	step_end
; 0x6cb12

CameraGrunt1SeenText: ; 0x6cb12
	db $0, "Hey!", $4f
	db "Intruder alert!", $57
; 0x6cb28

CameraGrunt1BeatenText: ; 0x6cb28
	db $0, "Dang… I failed…", $57
; 0x6cb39

CameraGrunt2SeenText: ; 0x6cb39
	db $0, "It's my turn!", $4f
	db "There's no escape!", $57
; 0x6cb59

CameraGrunt2BeatenText: ; 0x6cb59
	db $0, "Surveillance cams", $4f
	db "are in the #MON", $55
	db "statues.", $51
	db "We'll keep appear-", $4f
	db "ing until you trip", $55
	db "a secret switch.", $57
; 0x6cbbb

ScientistJedSeenText: ; 0x6cbbb
	db $0, "This was once a", $4f
	db "ninja hideout.", $51
	db "There are traps to", $4f
	db "confound intruders", $55
	db "like you.", $57
; 0x6cc0b

ScientistJedBeatenText: ; 0x6cc0b
	db $0, "I get it…", $57
; 0x6cc16

UnknownText_0x6cc16: ; 0x6cc16
	db $0, "All right. I'll", $4f
	db "divulge a secret", $55
	db "about our hideout.", $51
	db "That thing on the", $4f
	db "floor up ahead is", $55
	db "a warp panel.", $51
	db "If you step on it,", $4f
	db "you'll be warped", $51
	db "back to the en-", $4f
	db "trance.", $57
; 0x6ccb7

GruntM16SeenText: ; 0x6ccb7
	db $0, "Heheh. Feeling", $4f
	db "lucky, punk?", $51
	db "Go ahead, take", $4f
	db "another step.", $51
	db "We've got traps", $4f
	db "set in the floor!", $57
; 0x6cd12

GruntM16BeatenText: ; 0x6cd12
	db $0, "Kaboom!", $57
; 0x6cd1b

UnknownText_0x6cd1b: ; 0x6cd1b
	db $0, "I don't even know", $4f
	db "where the traps", $55
	db "are planted.", $51
	db "You'll just have", $4f
	db "to collect your", $55
	db "courage and walk.", $57
; 0x6cd7c

SecurityCameraText: ; 0x6cd7c
	db $0, "It's a PERSIAN", $4f
	db "statue…", $51
	db "Its eyes are oddly", $4f
	db "shiny.", $57
; 0x6cdad

UnknownText_0x6cdad: ; 0x6cdad
	db $0, "A secret switch!", $4f
	db "Better press it.", $57
; 0x6cdd0

UnknownText_0x6cdd0: ; 0x6cdd0
	db $0, "The switch is", $4f
	db "turned off.", $57
; 0x6cdeb

TeamRocketBaseB1F_MapEventHeader: ; 0x6cdeb
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $2, $1b, 3, GROUP_MAHOGANY_MART_1F, MAP_MAHOGANY_MART_1F
	warp_def $e, $3, 1, GROUP_TEAM_ROCKET_BASE_B2F, MAP_TEAM_ROCKET_BASE_B2F
	warp_def $f, $5, 4, GROUP_TEAM_ROCKET_BASE_B1F, MAP_TEAM_ROCKET_BASE_B1F
	warp_def $2, $19, 3, GROUP_TEAM_ROCKET_BASE_B1F, MAP_TEAM_ROCKET_BASE_B1F

	; xy triggers
	db 30
	; There are five security cameras in the base.
	; Walking in front of one triggers two Rocket Grunts.
	xy_trigger 0, $2, $18, $0, SecurityCamera1a, $0, $0
	xy_trigger 0, $3, $18, $0, SecurityCamera1b, $0, $0
	xy_trigger 0, $2, $6, $0, SecurityCamera2a, $0, $0
	xy_trigger 0, $3, $6, $0, SecurityCamera2b, $0, $0
	xy_trigger 0, $6, $18, $0, SecurityCamera3a, $0, $0
	xy_trigger 0, $7, $18, $0, SecurityCamera3b, $0, $0
	xy_trigger 0, $10, $16, $0, SecurityCamera4, $0, $0
	xy_trigger 0, $10, $8, $0, SecurityCamera5, $0, $0
	; There are spots on the floor that trigger a Pokémon battle.
	; Each Pokémon (Voltorb, Koffing, Geodude) knows Selfdestruct.
	xy_trigger 0, $7, $2, $0, ExplodingTrap1, $0, $0
	xy_trigger 0, $7, $3, $0, ExplodingTrap2, $0, $0
	xy_trigger 0, $7, $4, $0, ExplodingTrap3, $0, $0
	xy_trigger 0, $8, $1, $0, ExplodingTrap4, $0, $0
	xy_trigger 0, $8, $3, $0, ExplodingTrap5, $0, $0
	xy_trigger 0, $8, $5, $0, ExplodingTrap6, $0, $0
	xy_trigger 0, $9, $3, $0, ExplodingTrap7, $0, $0
	xy_trigger 0, $9, $4, $0, ExplodingTrap8, $0, $0
	xy_trigger 0, $a, $1, $0, ExplodingTrap9, $0, $0
	xy_trigger 0, $a, $2, $0, ExplodingTrap10, $0, $0
	xy_trigger 0, $a, $3, $0, ExplodingTrap11, $0, $0
	xy_trigger 0, $a, $5, $0, ExplodingTrap12, $0, $0
	xy_trigger 0, $b, $2, $0, ExplodingTrap13, $0, $0
	xy_trigger 0, $b, $4, $0, ExplodingTrap14, $0, $0
	xy_trigger 0, $c, $1, $0, ExplodingTrap15, $0, $0
	xy_trigger 0, $c, $2, $0, ExplodingTrap16, $0, $0
	xy_trigger 0, $c, $4, $0, ExplodingTrap17, $0, $0
	xy_trigger 0, $c, $5, $0, ExplodingTrap18, $0, $0
	xy_trigger 0, $d, $1, $0, ExplodingTrap19, $0, $0
	xy_trigger 0, $d, $3, $0, ExplodingTrap20, $0, $0
	xy_trigger 0, $d, $4, $0, ExplodingTrap21, $0, $0
	xy_trigger 0, $d, $5, $0, ExplodingTrap22, $0, $0

	; signposts
	db 9
	signpost 11, 19, $0, MapTeamRocketBaseB1FSignpost0Script
	signpost 1, 24, $1, MapTeamRocketBaseB1FSignpost5Script
	signpost 1, 6, $1, MapTeamRocketBaseB1FSignpost5Script
	signpost 15, 8, $1, MapTeamRocketBaseB1FSignpost5Script
	signpost 15, 22, $1, MapTeamRocketBaseB1FSignpost5Script
	signpost 5, 24, $1, MapTeamRocketBaseB1FSignpost5Script
	signpost 11, 20, $0, MapTeamRocketBaseB1FSignpost7Script
	signpost 11, 21, $0, MapTeamRocketBaseB1FSignpost7Script
	signpost 11, 3, $7, MapTeamRocketBaseB1FSignpostItem8

	; people-events
	db 6
	person_event $35, 4, 4, $6, $0, 255, 255, $0, 0, ObjectEvent, $06d9
	person_event $35, 8, 6, $9, $0, 255, 255, $2, 3, TrainerGruntM16, $06da
	person_event $3c, 16, 22, $8, $0, 255, 255, $92, 3, TrainerScientistJed, $06da
	person_event $54, 10, 31, $1, $0, 255, 255, $1, 0, ItemFragment_0x6cac4, $0669
	person_event $54, 19, 18, $1, $0, 255, 255, $1, 0, ItemFragment_0x6cac6, $066a
	person_event $54, 16, 25, $1, $0, 255, 255, $1, 0, ItemFragment_0x6cac8, $066b
; 0x6cf70

TeamRocketBaseB2F_MapScriptHeader: ; 0x6cf70
	; trigger count
	db 4

	; triggers
	dw UnknownScript_0x6cf85, $0000
	dw UnknownScript_0x6cf86, $0000
	dw UnknownScript_0x6cf87, $0000
	dw UnknownScript_0x6cf88, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x6cf89
; 0x6cf85

UnknownScript_0x6cf85: ; 0x6cf85
	end
; 0x6cf86

UnknownScript_0x6cf86: ; 0x6cf86
	end
; 0x6cf87

UnknownScript_0x6cf87: ; 0x6cf87
	end
; 0x6cf88

UnknownScript_0x6cf88: ; 0x6cf88
	end
; 0x6cf89

UnknownScript_0x6cf89: ; 0x6cf89
	checkbit1 $0300
	iftrue UnknownScript_0x6cf90
	return
; 0x6cf90

UnknownScript_0x6cf90: ; 0x6cf90
	changeblock $e, $c, $7
	return
; 0x6cf95

UnknownScript_0x6cf95: ; 0x6cf95
	moveperson $4, $9, $d
	2jump UnknownScript_0x6cfac
; 0x6cf9c

UnknownScript_0x6cf9c: ; 0x6cf9c
	moveperson $3, $15, $10
	moveperson $2, $15, $10
	moveperson $5, $a, $d
	moveperson $4, $a, $d
UnknownScript_0x6cfac: ; 0x6cfac
	appear $3
	appear $2
	loadfont
	2writetext UnknownText_0x6d2ad
	closetext
	loadmovesprites
	spriteface $0, $0
	showemote $0, $0, 15
	applymovement $0, MovementData_0x6d21f
	playmusic $0039
	applymovement $3, MovementData_0x6d224
	spriteface $0, $1
	applymovement $2, MovementData_0x6d22f
	loadfont
	2writetext UnknownText_0x6d2c3
	closetext
	loadmovesprites
	cry DRAGONITE
	spriteface $3, $2
	spriteface $0, $2
	appear $5
	applymovement $5, MovementData_0x6d236
	applymovement $3, MovementData_0x6d23b
	applymovement $2, MovementData_0x6d24c
	appear $4
	applymovement $4, MovementData_0x6d244
	loadfont
	2writetext UnknownText_0x6d38c
	closetext
	loadmovesprites
	spriteface $0, $3
	applymovement $3, MovementData_0x6d241
	loadfont
	2writetext UnknownText_0x6d3bd
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x6d24a
	applymovement $3, MovementData_0x6d248
	winlosstext UnknownText_0x6d45c, $0000
	setlasttalked $3
	loadtrainer EXECUTIVEF, 2
	startbattle
	disappear $5
	setbit1 $06dd
	setbit1 $06de
	setbit1 $06d6
	returnafterbattle
	setbit1 $0570
	loadfont
	2writetext UnknownText_0x6d4c6
	closetext
	loadmovesprites
	special $0030
	special $0033
	disappear $2
	disappear $3
	disappear $c
	disappear $d
	disappear $e
	pause 15
	special $0032
	dotrigger $2
	clearbit1 $06d6
	spriteface $4, $0
	loadfont
	2writetext UnknownText_0x6d5d8
	closetext
	loadmovesprites
	applymovement $4, MovementData_0x6d250
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x6d64e
	closetext
	loadmovesprites
	follow $4, $0
	applymovement $4, MovementData_0x6d254
	stopfollow
	applymovement $4, MovementData_0x6d258
	loadfont
	2writetext UnknownText_0x6d6cf
	closetext
	loadmovesprites
	applymovement $4, MovementData_0x6d267
	disappear $4
; 0x6d075

UnknownScript_0x6d075: ; 0x6d075
	applymovement $0, MovementData_0x6d271
	end
; 0x6d07a

UnknownScript_0x6d07a: ; 0x6d07a
	loadfont
	2writetext UnknownText_0x6d7ea
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x6d278
	end
; 0x6d085

UnknownScript_0x6d085: ; 0x6d085
	spriteface $0, $1
	2jump UnknownScript_0x6d091
; 0x6d08b

UnknownScript_0x6d08b: ; 0x6d08b
	spriteface $0, $3
	spriteface $4, $2
UnknownScript_0x6d091: ; 0x6d091
	loadfont
	2writetext UnknownText_0x6da97
	closetext
	loadmovesprites
	special $002e
	special $009d
	playsound $0005
	special $001b
	special $0031
	loadfont
	2writetext UnknownText_0x6daf7
	closetext
	loadmovesprites
	dotrigger $1
	setbit1 $004c
	checkcode $9
	if_equal $3, UnknownScript_0x6d0be
	applymovement $4, MovementData_0x6d212
	disappear $4
	end
; 0x6d0be

UnknownScript_0x6d0be: ; 0x6d0be
	applymovement $4, MovementData_0x6d219
	disappear $4
	end
; 0x6d0c5

TrainerGruntM17: ; 0x6d0c5
	; bit/flag number
	dw $501

	; trainer group && trainer id
	db GRUNTM, 17

	; text when seen
	dw GruntM17SeenText

	; text when trainer beaten
	dw GruntM17BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM17Script
; 0x6d0d1

GruntM17Script: ; 0x6d0d1
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6db88
	closetext
	loadmovesprites
	end
; 0x6d0d9

TrainerGruntM18: ; 0x6d0d9
	; bit/flag number
	dw $502

	; trainer group && trainer id
	db GRUNTM, 18

	; text when seen
	dw GruntM18SeenText

	; text when trainer beaten
	dw GruntM18BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM18Script
; 0x6d0e5

GruntM18Script: ; 0x6d0e5
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6dc1a
	closetext
	loadmovesprites
	end
; 0x6d0ed

TrainerGruntM19: ; 0x6d0ed
	; bit/flag number
	dw $503

	; trainer group && trainer id
	db GRUNTM, 19

	; text when seen
	dw GruntM19SeenText

	; text when trainer beaten
	dw GruntM19BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM19Script
; 0x6d0f9

GruntM19Script: ; 0x6d0f9
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6dcd1
	closetext
	loadmovesprites
	end
; 0x6d101

UnknownScript_0x6d101: ; 0x6d101
	cry ELECTRODE
	loadpokedata ELECTRODE, 23
	startbattle
	iftrue UnknownScript_0x6d182
	disappear $6
	disappear $9
	checkbit1 $06e0
	iffalse UnknownScript_0x6d182
	checkbit1 $06e1
	iffalse UnknownScript_0x6d182
	checkbit1 $06e2
	iffalse UnknownScript_0x6d182
	returnafterbattle
	special $003c
	applymovement $0, MovementData_0x6d28c
	2jump UnknownScript_0x6d184
; 0x6d12c

UnknownScript_0x6d12c: ; 0x6d12c
	cry ELECTRODE
	loadpokedata ELECTRODE, 23
	startbattle
	iftrue UnknownScript_0x6d182
	disappear $7
	disappear $a
	checkbit1 $06e0
	iffalse UnknownScript_0x6d182
	checkbit1 $06e1
	iffalse UnknownScript_0x6d182
	checkbit1 $06e2
	iffalse UnknownScript_0x6d182
	returnafterbattle
	special $003c
	applymovement $0, MovementData_0x6d299
	2jump UnknownScript_0x6d184
; 0x6d157

UnknownScript_0x6d157: ; 0x6d157
	cry ELECTRODE
	loadpokedata ELECTRODE, 23
	startbattle
	iftrue UnknownScript_0x6d182
	disappear $8
	disappear $b
	checkbit1 $06e0
	iffalse UnknownScript_0x6d182
	checkbit1 $06e1
	iffalse UnknownScript_0x6d182
	checkbit1 $06e2
	iffalse UnknownScript_0x6d182
	returnafterbattle
	special $003c
	applymovement $0, MovementData_0x6d2a4
	2jump UnknownScript_0x6d184
; 0x6d182

UnknownScript_0x6d182: ; 0x6d182
	returnafterbattle
	end
; 0x6d184

UnknownScript_0x6d184: ; 0x6d184
	moveperson $4, $12, $6
	appear $4
	applymovement $4, MovementData_0x6d27a
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x6d809
	keeptextopen
	verbosegiveitem HM_06, 1
	setbit1 $0015
	2writetext UnknownText_0x6d8f8
	closetext
	loadmovesprites
	spriteface $4, $0
	loadfont
	2writetext UnknownText_0x6d994
	closetext
	loadmovesprites
	spriteface $0, $0
	applymovement $4, MovementData_0x6d283
	disappear $4
	setbit1 $0022
	clearbit2 $000e
	setbit1 $06dc
	setbit1 $0757
	dotrigger $3
	clearbit1 $0735
	setbit1 $02e3
	setbit1 $02e4
	setbit1 $02e5
	setbit1 $02e6
	setbit1 $02e7
	setbit1 $02e8
	end
; 0x6d1d7

MapTeamRocketBaseB2FSignpostPtr1: ; 0x6d1d7
	dw $0300
	dw MapTeamRocketBaseB2FSignpost1Script
	
; 0x6d1db

MapTeamRocketBaseB2FSignpost1Script: ; 0x6d1db
	loadfont
	checkbit1 $02ff
	iftrue UnknownScript_0x6d1e8
	2writetext UnknownText_0x6dd39
	closetext
	loadmovesprites
	end
; 0x6d1e8

UnknownScript_0x6d1e8: ; 0x6d1e8
	2writetext UnknownText_0x6dd6b
	closetext
	playsound $001f
	changeblock $e, $c, $7
	reloadmappart
	loadmovesprites
	setbit1 $0300
	waitbutton
	end
; 0x6d1fa

MapTeamRocketBaseB2FSignpost21Script: ; 0x6d1fa
	loadfont
	checkbit1 $0022
	iftrue UnknownScript_0x6d207
	2writetext UnknownText_0x6dda7
	closetext
	loadmovesprites
	end
; 0x6d207

UnknownScript_0x6d207: ; 0x6d207
	2writetext UnknownText_0x6de03
	closetext
	loadmovesprites
	end
; 0x6d20d

ItemFragment_0x6d20d: ; 0x6d20d
	db TM_46, 1
; 0x6d20f

MapTeamRocketBaseB2FSignpostItem22: ; 0x6d20f
	dw $0087
	db FULL_HEAL
	
; 0x6d212

MovementData_0x6d212: ; 0x6d212
	step_right
	step_right
	step_right
	step_right
	step_right
	step_right
	step_end
; 0x6d219

MovementData_0x6d219: ; 0x6d219
	step_right
	step_right
	step_right
	step_right
	step_right
	step_end
; 0x6d21f

MovementData_0x6d21f: ; 0x6d21f
	step_down
	step_down
	step_down
	turn_head_right
	step_end
; 0x6d224

MovementData_0x6d224: ; 0x6d224
	big_step_left
	big_step_left
	big_step_up
	big_step_up
	big_step_up
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	turn_head_down
	step_end
; 0x6d22f

MovementData_0x6d22f: ; 0x6d22f
	big_step_left
	big_step_left
	big_step_up
	big_step_up
	big_step_left
	big_step_left
	step_end
; 0x6d236

MovementData_0x6d236: ; 0x6d236
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	step_end
; 0x6d23b

MovementData_0x6d23b: ; 0x6d23b
	fix_facing
	db $39 ; movement
	jump_step_right
	db $38 ; movement
	remove_fixed_facing
	step_end
; 0x6d241

MovementData_0x6d241: ; 0x6d241
	slow_step_down
	turn_head_left
	step_end
; 0x6d244

MovementData_0x6d244: ; 0x6d244
	step_right
	step_right
	step_right
	step_end
; 0x6d248

MovementData_0x6d248: ; 0x6d248
	big_step_left
	step_end
; 0x6d24a

MovementData_0x6d24a: ; 0x6d24a
	big_step_left
	step_end
; 0x6d24c

MovementData_0x6d24c: ; 0x6d24c
	big_step_left
	big_step_up
	turn_head_left
	step_end
; 0x6d250

MovementData_0x6d250: ; 0x6d250
	step_right
	step_right
	turn_head_down
	step_end
; 0x6d254

MovementData_0x6d254: ; 0x6d254
	step_up
	step_up
	step_up
	step_end
; 0x6d258

MovementData_0x6d258: ; 0x6d258
	accelerate_last
	step_left
	step_left
	turn_head_up
	accelerate_last
	step_right
	step_right
	step_right
	step_right
	turn_head_up
	accelerate_last
	step_left
	step_left
	turn_head_down
	step_end
; 0x6d267

MovementData_0x6d267: ; 0x6d267
	step_right
	step_right
	step_right
	step_right
	step_up
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x6d271

MovementData_0x6d271: ; 0x6d271
	step_up
	step_left
	step_left
	step_left
	step_left
	turn_head_up
	step_end
; 0x6d278

MovementData_0x6d278: ; 0x6d278
	step_left
	step_end
; 0x6d27a

MovementData_0x6d27a: ; 0x6d27a
	step_down
	step_down
	step_down
	step_down
	step_down
	step_left
	step_left
	step_left
	step_end
; 0x6d283

MovementData_0x6d283: ; 0x6d283
	step_down
	step_down
	step_left
	step_left
	step_left
	step_left
	step_left
	step_left
	step_end
; 0x6d28c

MovementData_0x6d28c: ; 0x6d28c
	step_right
	step_right
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_right
	step_right
	step_right
	step_right
	step_end
; 0x6d299

MovementData_0x6d299: ; 0x6d299
	step_right
	step_right
	step_down
	step_down
	step_down
	step_down
	step_right
	step_right
	step_right
	step_right
	step_end
; 0x6d2a4

MovementData_0x6d2a4: ; 0x6d2a4
	step_right
	step_right
	step_down
	step_down
	step_right
	step_right
	step_right
	step_right
	step_end
; 0x6d2ad

UnknownText_0x6d2ad: ; 0x6d2ad
	db $0, "Hold it right", $4f
	db "there!", $57
; 0x6d2c3

UnknownText_0x6d2c3: ; 0x6d2c3
	db $0, "We can't have a", $4f
	db "brat like you on", $55
	db "the loose.", $51
	db "It's harmful to", $4f
	db "TEAM ROCKET's", $55
	db "pride, you see.", $51
	db "However strong you", $4f
	db "may be, you can't", $51
	db "take both of us at", $4f
	db "the same time.", $51
	db "Sorry, baby. Now", $4f
	db "get ready to be", $55
	db "thrashed.", $57
; 0x6d38c

UnknownText_0x6d38c: ; 0x6d38c
	db $0, "Hey! Don't be so", $4f
	db "selfish. Spread", $55
	db "the fun around.", $57
; 0x6d3bd

UnknownText_0x6d3bd: ; 0x6d3bd
	db $0, "What? You had an", $4f
	db "accomplice?", $51
	db "Where is your", $4f
	db "sense of honor?", $51
	db "As the interim", $4f
	db "boss in place of", $51
	db "GIOVANNI, I'll", $4f
	db "show you how wrong", $51
	db "it is to meddle", $4f
	db "with TEAM ROCKET!", $57
; 0x6d45c

UnknownText_0x6d45c: ; 0x6d45c
	db $0, "Tch, you really", $4f
	db "are strong.", $51
	db "It's too bad.", $51
	db "If you were to", $4f
	db "join TEAM ROCKET,", $51
	db "you could become", $4f
	db "an EXECUTIVE.", $57
; 0x6d4c6

UnknownText_0x6d4c6: ; 0x6d4c6
	db $0, "…This hideout is", $4f
	db "done for…", $51
	db "But that's fine.", $4f
	db "The broadcast ex-", $55
	db "periment was a", $55
	db "total success.", $51
	db "It doesn't matter", $4f
	db "what happens to", $55
	db "this hideout now.", $51
	db "We have much big-", $4f
	db "ger plans.", $51
	db "You'll come to", $4f
	db "appreciate TEAM", $51
	db "ROCKET's true", $4f
	db "power soon enough.", $51
	db "Enjoy yourself", $4f
	db "while you can…", $51
	db "Fufufufu…", $57
; 0x6d5d8

UnknownText_0x6d5d8: ; 0x6d5d8
	db $0, "LANCE: That did", $4f
	db "it. We defeated", $51
	db "all the ROCKETS", $4f
	db "here.", $51
	db "But I'm concerned", $4f
	db "about the young", $51
	db "guy I battled in", $4f
	db "the process…", $57
; 0x6d64e

UnknownText_0x6d64e: ; 0x6d64e
	db $0, "Sorry, ", $14, ".", $4f
	db "I saw how well you", $51
	db "were doing, so I", $4f
	db "just hung back.", $51
	db "Now all there is", $4f
	db "left to do is to", $51
	db "turn off that odd", $4f
	db "radio signal.", $57
; 0x6d6cf

UnknownText_0x6d6cf: ; 0x6d6cf
	db $0, "It's this machine", $4f
	db "that's causing all", $55
	db "the problems.", $51
	db "I don't see a", $4f
	db "switch on it…", $51
	db "We have no choice.", $4f
	db "We have to make", $51
	db "all the ELECTRODE", $4f
	db "faint.", $51
	db "That should stop", $4f
	db "this machine from", $51
	db "transmitting that", $4f
	db "strange signal.", $51
	db "It's no fault of", $4f
	db "the #MON, so it", $51
	db "makes me feel", $4f
	db "guilty.", $51
	db $14, ", let's", $4f
	db "split the job.", $57
; 0x6d7ea

UnknownText_0x6d7ea: ; 0x6d7ea
	db $0, "LANCE: Leave this", $4f
	db "side to me.", $57
; 0x6d809

UnknownText_0x6d809: ; 0x6d809
	db $0, "LANCE: That odd", $4f
	db "signal has finally", $55
	db "stopped.", $51
	db "The LAKE should be", $4f
	db "back to normal.", $51
	db "You're the hero!", $4f
	db "Let me thank you", $51
	db "on behalf of all", $4f
	db "the #MON.", $51
	db "Oh, yes. You", $4f
	db "should take this.", $51
	db "I found it here,", $4f
	db "but I don't have", $55
	db "any need for it.", $57
; 0x6d8e6

UnknownText_0x6d8e6: ; 0x6d8e6
	db $0, $52, " received", $4f
	db "HM06.", $57
; 0x6d8f8

UnknownText_0x6d8f8: ; 0x6d8f8
	db $0, "That's WHIRLPOOL.", $4f
	db "Teach it to a", $51
	db "#MON to get", $4f
	db "across wild water.", $51
	db "But keep this in", $4f
	db "mind.", $51
	db "You can use that", $4f
	db "out of battle only", $51
	db "with the BADGE", $4f
	db "from MAHOGANY GYM.", $57
; 0x6d994

UnknownText_0x6d994: ; 0x6d994
	db $0, $14, "…", $51
	db "The journey to be-", $4f
	db "coming the #MON", $51
	db "MASTER is long and", $4f
	db "difficult.", $51
	db "Knowing that, will", $4f
	db "you keep going?", $51
	db "…", $51
	db "I see. No, you're", $4f
	db "right.", $51
	db "If you would give", $4f
	db "up that easily,", $51
	db "you would have", $4f
	db "never chased that", $51
	db "dream in the first", $4f
	db "place.", $51
	db "I look forward to", $4f
	db "seeing you again!", $57
; 0x6da97

UnknownText_0x6da97: ; 0x6da97
	db $0, "LANCE: Are you all", $4f
	db "right?", $51
	db "Your #MON are", $4f
	db "hurt and tired.", $51
	db "Here, give them", $4f
	db "some of my medi-", $55
	db "cine.", $57
; 0x6daf7

UnknownText_0x6daf7: ; 0x6daf7
	db $0, "LANCE: ", $14, ",", $4f
	db "let's give it our", $55
	db "best for #MON.", $57
; 0x6db22

GruntM17SeenText: ; 0x6db22
	db $0, "The door won't", $4f
	db "open?", $51
	db "Well, duh.", $4f
	db "It has to have a", $51
	db "password that only", $4f
	db "TEAM ROCKET knows.", $57
; 0x6db79

GruntM17BeatenText: ; 0x6db79
	db $0, "What? I lost?", $57
; 0x6db88

UnknownText_0x6db88: ; 0x6db88
	db $0, "Heh, I'm just a", $4f
	db "GRUNT.", $51
	db "I don't know the", $4f
	db "password. Too bad", $55
	db "for you.", $57
; 0x6dbca

GruntM18SeenText: ; 0x6dbca
	db $0, "Oh, a kid? I don't", $4f
	db "really like this,", $51
	db "but eliminate you", $4f
	db "I must.", $57
; 0x6dc09

GruntM18BeatenText: ; 0x6dc09
	db $0, "I knew I'd lose…", $57
; 0x6dc1a

UnknownText_0x6dc1a: ; 0x6dc1a
	db $0, "I got wiped out on", $4f
	db "the last mission", $55
	db "by a kid too.", $51
	db "When we were ab-", $4f
	db "ducting #MON,", $51
	db "this kid with long", $4f
	db "red hair and mean-", $51
	db "looking eyes just", $4f
	db "creamed me…", $57
; 0x6dcb0

GruntM19SeenText: ; 0x6dcb0
	db $0, "You rotten little", $4f
	db "pest!", $57
; 0x6dcc9

GruntM19BeatenText: ; 0x6dcc9
	db $0, "Grrrr…", $57
; 0x6dcd1

UnknownText_0x6dcd1: ; 0x6dcd1
	db $0, "Heh, only the boss", $4f
	db "knows the password", $55
	db "for that door.", $51
	db "Where's the boss?", $4f
	db "Who knows? Go look", $55
	db "for yourself.", $57
; 0x6dd39

UnknownText_0x6dd39: ; 0x6dd39
	db $0, "The door's closed…", $51
	db "It needs a pass-", $4f
	db "word to open.", $57
; 0x6dd6b

UnknownText_0x6dd6b: ; 0x6dd6b
	db $0, "The door's closed…", $51
	db $52, " entered", $4f
	db "the password.", $51
	db "The door opened!", $57
; 0x6dda7

UnknownText_0x6dda7: ; 0x6dda7
	db $0, "It's the radio", $4f
	db "transmitter that's", $51
	db "sending the", $4f
	db "sinister signal.", $51
	db "It's working at", $4f
	db "full capacity.", $57
; 0x6de03

UnknownText_0x6de03: ; 0x6de03
	db $0, "The radio trans-", $4f
	db "mitter has finally", $51
	db "stopped its evil", $4f
	db "broadcast.", $57
; 0x6de44

TeamRocketBaseB2F_MapEventHeader: ; 0x6de44
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $e, $3, 2, GROUP_TEAM_ROCKET_BASE_B1F, MAP_TEAM_ROCKET_BASE_B1F
	warp_def $2, $3, 1, GROUP_TEAM_ROCKET_BASE_B3F, MAP_TEAM_ROCKET_BASE_B3F
	warp_def $2, $1b, 2, GROUP_TEAM_ROCKET_BASE_B3F, MAP_TEAM_ROCKET_BASE_B3F
	warp_def $6, $3, 3, GROUP_TEAM_ROCKET_BASE_B3F, MAP_TEAM_ROCKET_BASE_B3F
	warp_def $e, $1b, 4, GROUP_TEAM_ROCKET_BASE_B3F, MAP_TEAM_ROCKET_BASE_B3F

	; xy triggers
	db 9
	xy_trigger 0, $e, $5, $0, UnknownScript_0x6d085, $0, $0
	xy_trigger 0, $d, $4, $0, UnknownScript_0x6d08b, $0, $0
	xy_trigger 1, $b, $e, $0, UnknownScript_0x6cf95, $0, $0
	xy_trigger 1, $b, $f, $0, UnknownScript_0x6cf9c, $0, $0
	xy_trigger 2, $c, $e, $0, UnknownScript_0x6d075, $0, $0
	xy_trigger 2, $c, $f, $0, UnknownScript_0x6d075, $0, $0
	xy_trigger 2, $3, $c, $0, UnknownScript_0x6d07a, $0, $0
	xy_trigger 2, $a, $c, $0, UnknownScript_0x6d07a, $0, $0
	xy_trigger 2, $b, $c, $0, UnknownScript_0x6d07a, $0, $0

	; signposts
	db 23
	signpost 12, 14, $6, MapTeamRocketBaseB2FSignpostPtr1
	signpost 12, 15, $6, MapTeamRocketBaseB2FSignpostPtr1
	signpost 9, 17, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 9, 16, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 9, 15, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 9, 14, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 9, 13, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 9, 12, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 8, 12, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 7, 12, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 6, 12, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 5, 12, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 4, 12, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 4, 13, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 4, 14, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 4, 15, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 4, 16, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 4, 17, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 5, 17, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 6, 17, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 7, 17, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 8, 17, $0, MapTeamRocketBaseB2FSignpost21Script
	signpost 7, 26, $7, MapTeamRocketBaseB2FSignpostItem22

	; people-events
	db 14
	person_event $35, 20, 24, $7, $0, 255, 255, $0, 0, ObjectEvent, $06de
	person_event $36, 20, 24, $7, $0, 255, 255, $80, 0, ObjectEvent, $06dd
	person_event $1e, 17, 9, $6, $0, 255, 255, $0, 0, ObjectEvent, $06d6
	person_event $4f, 17, 13, $9, $0, 255, 255, $0, 0, ObjectEvent, $06df
	person_event $9b, 9, 11, $16, $0, 255, 255, $0, 0, UnknownScript_0x6d101, $06e0
	person_event $9b, 11, 11, $16, $0, 255, 255, $0, 0, UnknownScript_0x6d12c, $06e1
	person_event $9b, 13, 11, $16, $0, 255, 255, $0, 0, UnknownScript_0x6d157, $06e2
	person_event $9b, 9, 26, $16, $0, 255, 255, $0, 0, ObjectEvent, $06e0
	person_event $9b, 11, 26, $16, $0, 255, 255, $0, 0, ObjectEvent, $06e1
	person_event $9b, 13, 26, $16, $0, 255, 255, $0, 0, ObjectEvent, $06e2
	person_event $35, 17, 29, $6, $0, 255, 255, $2, 3, TrainerGruntM17, $06da
	person_event $35, 5, 8, $a, $0, 255, 255, $2, 1, TrainerGruntM18, $06da
	person_event $35, 18, 25, $8, $0, 255, 255, $2, 4, TrainerGruntM19, $06da
	person_event $54, 14, 7, $1, $0, 255, 255, $1, 0, ItemFragment_0x6d20d, $066c
; 0x6dfd4

TeamRocketBaseB3F_MapScriptHeader: ; 0x6dfd4
	; trigger count
	db 4

	; triggers
	dw UnknownScript_0x6dfe9, $0000
	dw UnknownScript_0x6dfed, $0000
	dw UnknownScript_0x6dfee, $0000
	dw UnknownScript_0x6dfef, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x6dff0
; 0x6dfe9

UnknownScript_0x6dfe9: ; 0x6dfe9
	priorityjump UnknownScript_0x6dffc
	end
; 0x6dfed

UnknownScript_0x6dfed: ; 0x6dfed
	end
; 0x6dfee

UnknownScript_0x6dfee: ; 0x6dfee
	end
; 0x6dfef

UnknownScript_0x6dfef: ; 0x6dfef
	end
; 0x6dff0

UnknownScript_0x6dff0: ; 0x6dff0
	checkbit1 $0303
	iftrue UnknownScript_0x6dff7
	return
; 0x6dff7

UnknownScript_0x6dff7: ; 0x6dff7
	changeblock $a, $8, $7
	return
; 0x6dffc

UnknownScript_0x6dffc: ; 0x6dffc
	spriteface $0, $2
	pause 5
	spriteface $4, $3
	pause 20
	applymovement $2, MovementData_0x6e12a
	loadfont
	2writetext UnknownText_0x6e179
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x6e12c
	disappear $2
	dotrigger $1
	end
; 0x6e019

UnknownScript_0x6e019: ; 0x6e019
	spriteface $0, $2
	showemote $0, $0, 15
	special $006a
	appear $a
	applymovement $a, MovementData_0x6e164
	spriteface $0, $2
	playmusic $001f
	loadfont
	2writetext UnknownText_0x6e267
	closetext
	loadmovesprites
	playsound $0041
	applymovement $0, MovementData_0x6e175
	applymovement $a, MovementData_0x6e16d
	disappear $a
	dotrigger $2
	special $003d
	end
; 0x6e048

UnknownScript_0x6e048: ; 0x6e048
	jumptextfaceplayer UnknownText_0x6e235
; 0x6e04b

UnknownScript_0x6e04b: ; 0x6e04b
	applymovement $0, MovementData_0x6e133
	2jump UnknownScript_0x6e056
; 0x6e052

UnknownScript_0x6e052: ; 0x6e052
	applymovement $0, MovementData_0x6e13a
UnknownScript_0x6e056: ; 0x6e056
	pause 30
	showemote $0, $3, 15
	playmusic $0039
	spriteface $3, $0
	loadfont
	2writetext UnknownText_0x6e400
	closetext
	loadmovesprites
	applymovement $3, MovementData_0x6e142
	winlosstext UnknownText_0x6e511, $0000
	setlasttalked $3
	loadtrainer EXECUTIVEM, 4
	startbattle
	returnafterbattle
	setbit1 $0574
	loadfont
	2writetext UnknownText_0x6e548
	closetext
	loadmovesprites
	applymovement $3, MovementData_0x6e144
	playsound $0041
	applymovement $3, MovementData_0x6e147
	disappear $3
	dotrigger $3
	end
; 0x6e091

UnknownScript_0x6e091: ; 0x6e091
	loadfont
	2writetext UnknownText_0x6e585
	closetext
	loadmovesprites
	setbit1 $02ff
	end
; 0x6e09b

TrainerGruntF5: ; 0x6e09b
	; bit/flag number
	dw $514

	; trainer group && trainer id
	db GRUNTF, 5

	; text when seen
	dw GruntF5SeenText

	; text when trainer beaten
	dw GruntF5BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntF5Script
; 0x6e0a7

GruntF5Script: ; 0x6e0a7
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6e611
	closetext
	loadmovesprites
	setbit1 $0301
	end
; 0x6e0b2

TrainerGruntM28: ; 0x6e0b2
	; bit/flag number
	dw $50c

	; trainer group && trainer id
	db GRUNTM, 28

	; text when seen
	dw GruntM28SeenText

	; text when trainer beaten
	dw GruntM28BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM28Script
; 0x6e0be

GruntM28Script: ; 0x6e0be
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6e737
	closetext
	loadmovesprites
	setbit1 $0302
	end
; 0x6e0c9

TrainerScientistRoss: ; 0x6e0c9
	; bit/flag number
	dw $49f

	; trainer group && trainer id
	db SCIENTIST, ROSS

	; text when seen
	dw ScientistRossSeenText

	; text when trainer beaten
	dw ScientistRossBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw ScientistRossScript
; 0x6e0d5

ScientistRossScript: ; 0x6e0d5
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6e822
	closetext
	loadmovesprites
	end
; 0x6e0dd

TrainerScientistMitch: ; 0x6e0dd
	; bit/flag number
	dw $4a0

	; trainer group && trainer id
	db SCIENTIST, MITCH

	; text when seen
	dw ScientistMitchSeenText

	; text when trainer beaten
	dw ScientistMitchBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw ScientistMitchScript
; 0x6e0e9

ScientistMitchScript: ; 0x6e0e9
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6e90a
	closetext
	loadmovesprites
	end
; 0x6e0f1

MapTeamRocketBaseB3FSignpostPtr1: ; 0x6e0f1
	dw $0303
	dw MapTeamRocketBaseB3FSignpost1Script
	
; 0x6e0f5

MapTeamRocketBaseB3FSignpost1Script: ; 0x6e0f5
	loadfont
	checkbit1 $0301
	iffalse UnknownScript_0x6e105
	checkbit1 $0302
	iffalse UnknownScript_0x6e105
	2jump UnknownScript_0x6e10b
; 0x6e105

UnknownScript_0x6e105: ; 0x6e105
	2writetext UnknownText_0x6e970
	closetext
	loadmovesprites
	end
; 0x6e10b

UnknownScript_0x6e10b: ; 0x6e10b
	2writetext UnknownText_0x6e9a3
	closetext
	playsound $001f
	changeblock $a, $8, $7
	reloadmappart
	loadmovesprites
	setbit1 $0303
	waitbutton
	end
; 0x6e11d

MapTeamRocketBaseB3FSignpost9Script: ; 0x6e11d
	jumpstd $0004
; 0x6e120

ItemFragment_0x6e120: ; 0x6e120
	db PROTEIN, 1
; 0x6e122

ItemFragment_0x6e122: ; 0x6e122
	db X_SPECIAL, 1
; 0x6e124

ItemFragment_0x6e124: ; 0x6e124
	db FULL_HEAL, 1
; 0x6e126

ItemFragment_0x6e126: ; 0x6e126
	db ICE_HEAL, 1
; 0x6e128

ItemFragment_0x6e128: ; 0x6e128
	db ULTRA_BALL, 1
; 0x6e12a

MovementData_0x6e12a: ; 0x6e12a
	step_right
	step_end
; 0x6e12c

MovementData_0x6e12c: ; 0x6e12c
	step_down
	step_left
	step_left
	step_left
	step_left
	step_left
	step_end
; 0x6e133

MovementData_0x6e133: ; 0x6e133
	step_up
	step_up
	step_up
	step_left
	step_left
	turn_head_up
	step_end
; 0x6e13a

MovementData_0x6e13a: ; 0x6e13a
	step_up
	step_up
	step_left
	step_up
	step_left
	step_left
	turn_head_up
	step_end
; 0x6e142

MovementData_0x6e142: ; 0x6e142
	step_down
	step_end
; 0x6e144

MovementData_0x6e144: ; 0x6e144
	big_step_right
	big_step_right
	step_end
; 0x6e147

MovementData_0x6e147: ; 0x6e147
	fix_facing
	fast_jump_step_left
	remove_fixed_facing
	accelerate_last
	accelerate_last
	slow_step_right
	big_step_down
	big_step_down
	big_step_down
	big_step_right
	big_step_down
	big_step_down
	big_step_down
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_left
	big_step_left
	step_end
; 0x6e164

MovementData_0x6e164: ; 0x6e164
	step_down
	step_down
	step_down
	step_down
	step_down
	step_right
	step_right
	step_right
	step_end
; 0x6e16d

MovementData_0x6e16d: ; 0x6e16d
	step_left
	step_left
	step_up
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x6e175

MovementData_0x6e175: ; 0x6e175
	fix_facing
	big_step_right
	remove_fixed_facing
	step_end
; 0x6e179

UnknownText_0x6e179: ; 0x6e179
	db $0, "LANCE: It takes", $4f
	db "two passwords to", $51
	db "get into the", $4f
	db "boss's quarters.", $51
	db "Those passwords", $4f
	db "are known only to", $55
	db "a few ROCKETS.", $51
	db "That ROCKET there", $4f
	db "very graciously", $55
	db "told me so.", $51
	db $14, ", let's go", $4f
	db "get the passwords.", $57
; 0x6e235

UnknownText_0x6e235: ; 0x6e235
	db $0, "Urrggh… The guy", $4f
	db "in the cape is", $55
	db "incredibly tough…", $57
; 0x6e267

UnknownText_0x6e267: ; 0x6e267
	db $0, "…", $51
	db "Didn't I tell you", $4f
	db "that I was going", $51
	db "to destroy TEAM", $4f
	db "ROCKET?", $51
	db "…Tell me, who was", $4f
	db "the guy in the", $51
	db "cape who used", $4f
	db "dragon #MON?", $51
	db "My #MON were no", $4f
	db "match at all.", $51
	db "I don't care that", $4f
	db "I lost. I can beat", $51
	db "him by getting", $4f
	db "stronger #MON.", $51
	db "It's what he said", $4f
	db "that bothers me…", $51
	db "He told me that", $4f
	db "I don't love and", $51
	db "trust my #MON", $4f
	db "enough.", $51
	db "I'm furious that I", $4f
	db "lost to a bleeding", $55
	db "heart like him.", $51
	db "…Humph! I don't", $4f
	db "have the time for", $55
	db "the likes of you!", $57
; 0x6e400

UnknownText_0x6e400: ; 0x6e400
	db $0, "What? Who are you?", $4f
	db "This is the office", $51
	db "of our leader,", $4f
	db "GIOVANNI.", $51
	db "Since disbanding", $4f
	db "TEAM ROCKET three", $51
	db "years ago, he has", $4f
	db "been in training.", $51
	db "But we're certain", $4f
	db "he will be back", $51
	db "some day to assume", $4f
	db "command again.", $51
	db "That's why we're", $4f
	db "standing guard.", $51
	db "I won't let any-", $4f
	db "one disturb this", $55
	db "place!", $57
; 0x6e511

UnknownText_0x6e511: ; 0x6e511
	db $0, "I… I couldn't do a", $4f
	db "thing…", $51
	db "GIOVANNI, please", $4f
	db "forgive me…", $57
; 0x6e548

UnknownText_0x6e548: ; 0x6e548
	db $0, "No, I can't let", $4f
	db "this affect me.", $51
	db "I have to inform", $4f
	db "the others…", $57
; 0x6e585

UnknownText_0x6e585: ; 0x6e585
	db $0, "MURKROW: The", $4f
	db "password is…", $51
	db "HAIL GIOVANNI.", $57
; 0x6e5af

GruntF5SeenText: ; 0x6e5af
	db $0, "Do I know the", $4f
	db "password?", $51
	db "Maybe.", $51
	db "But no weakling's", $4f
	db "going to get it!", $57
; 0x6e5f1

GruntF5BeatenText: ; 0x6e5f1
	db $0, "All right. Stop.", $4f
	db "I'll tell you.", $57
; 0x6e611

UnknownText_0x6e611: ; 0x6e611
	db $0, "The password to", $4f
	db "the boss's room is", $51
	db "SLOWPOKETAIL.", $51
	db "But it's useless", $4f
	db "unless you have", $55
	db "two passwords.", $57
; 0x6e671

GruntM28SeenText: ; 0x6e671
	db $0, "Hyuck-hyuck-hyuck!", $51
	db "You're challenging", $4f
	db "me to a battle?", $51
	db "Hah! You're nuts,", $4f
	db "but you have guts!", $51
	db "I like that!", $51
	db "If you can beat", $4f
	db "me, I'll tell you", $51
	db "a password to the", $4f
	db "boss's room!", $57
; 0x6e717

GruntM28BeatenText: ; 0x6e717
	db $0, "Hyuck-hyuck-hyuck!", $4f
	db "You're good!", $57
; 0x6e737

UnknownText_0x6e737: ; 0x6e737
	db $0, "Hyuck-hyuck-hyuck!", $51
	db "The password to", $4f
	db "the boss's room…", $51
	db "Uh…, I think it is", $4f
	db "RATICATE TAIL.", $57
; 0x6e78d

ScientistRossSeenText: ; 0x6e78d
	db $0, "I used to work for", $4f
	db "SILPH, but now I", $51
	db "run research for", $4f
	db "TEAM ROCKET.", $51
	db "A meddlesome child", $4f
	db "like you needs to", $55
	db "be punished.", $57
; 0x6e802

ScientistRossBeatenText: ; 0x6e802
	db $0, "A mere tactical", $4f
	db "error cost me…", $57
; 0x6e822

UnknownText_0x6e822: ; 0x6e822
	db $0, "A radio signal", $4f
	db "that drives #-", $55
	db "MON mad…", $51
	db "My experiment is a", $4f
	db "complete success.", $51
	db "My promotion is", $4f
	db "assured. This loss", $51
	db "means absolutely", $4f
	db "nothing.", $57
; 0x6e8ac

ScientistMitchSeenText: ; 0x6e8ac
	db $0, "I don't care that", $4f
	db "#MON are hurt", $55
	db "by our experiment.", $57
; 0x6e8df

ScientistMitchBeatenText: ; 0x6e8df
	db $0, "Thinking is my", $4f
	db "strong suit, not", $55
	db "battling.", $57
; 0x6e90a

UnknownText_0x6e90a: ; 0x6e90a
	db $0, "If we turn up the", $4f
	db "power of our radio", $51
	db "signal for broad-", $4f
	db "cast nationwide…", $51
	db "The very thought", $4f
	db "excites me!", $57
; 0x6e970

UnknownText_0x6e970: ; 0x6e970
	db $0, "The door's closed…", $51
	db "It needs two", $4f
	db "passwords to open.", $57
; 0x6e9a3

UnknownText_0x6e9a3: ; 0x6e9a3
	db $0, "The door's closed…", $51
	db $52, " entered", $4f
	db "the two passwords.", $51
	db "The door opened!", $57
; 0x6e9e4

TeamRocketBaseB3F_MapEventHeader: ; 0x6e9e4
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $2, $3, 2, GROUP_TEAM_ROCKET_BASE_B2F, MAP_TEAM_ROCKET_BASE_B2F
	warp_def $2, $1b, 3, GROUP_TEAM_ROCKET_BASE_B2F, MAP_TEAM_ROCKET_BASE_B2F
	warp_def $6, $3, 4, GROUP_TEAM_ROCKET_BASE_B2F, MAP_TEAM_ROCKET_BASE_B2F
	warp_def $e, $1b, 5, GROUP_TEAM_ROCKET_BASE_B2F, MAP_TEAM_ROCKET_BASE_B2F

	; xy triggers
	db 3
	xy_trigger 2, $8, $a, $0, UnknownScript_0x6e04b, $0, $0
	xy_trigger 2, $8, $b, $0, UnknownScript_0x6e052, $0, $0
	xy_trigger 1, $a, $8, $0, UnknownScript_0x6e019, $0, $0

	; signposts
	db 10
	signpost 9, 10, $6, MapTeamRocketBaseB3FSignpostPtr1
	signpost 9, 11, $6, MapTeamRocketBaseB3FSignpostPtr1
	signpost 1, 10, $0, MapTeamRocketBaseB3FSignpost9Script
	signpost 1, 11, $0, MapTeamRocketBaseB3FSignpost9Script
	signpost 1, 12, $0, MapTeamRocketBaseB3FSignpost9Script
	signpost 1, 13, $0, MapTeamRocketBaseB3FSignpost9Script
	signpost 13, 4, $0, MapTeamRocketBaseB3FSignpost9Script
	signpost 13, 5, $0, MapTeamRocketBaseB3FSignpost9Script
	signpost 13, 6, $0, MapTeamRocketBaseB3FSignpost9Script
	signpost 13, 7, $0, MapTeamRocketBaseB3FSignpost9Script

	; people-events
	db 14
	person_event $1e, 18, 29, $6, $0, 255, 255, $0, 0, UnknownScript_0x6dffc, $06d7
	person_event $35, 7, 12, $7, $0, 255, 255, $0, 0, ObjectEvent, $06db
	person_event $9e, 6, 11, $16, $0, 255, 255, $90, 0, UnknownScript_0x6e091, $06da
	person_event $36, 11, 25, $7, $0, 255, 255, $82, 0, TrainerGruntF5, $06da
	person_event $35, 18, 9, $a, $0, 255, 255, $2, 3, TrainerGruntM28, $06da
	person_event $3c, 15, 27, $7, $0, 255, 255, $92, 0, TrainerScientistRoss, $06da
	person_event $3c, 19, 15, $9, $0, 255, 255, $92, 3, TrainerScientistMitch, $06da
	person_event $35, 18, 28, $6, $0, 255, 255, $0, 0, UnknownScript_0x6e048, $06da
	person_event $4, 9, 8, $6, $0, 255, 255, $0, 0, ObjectEvent, $06c0
	person_event $54, 16, 5, $1, $0, 255, 255, $1, 0, ItemFragment_0x6e120, $066d
	person_event $54, 16, 7, $1, $0, 255, 255, $1, 0, ItemFragment_0x6e122, $066e
	person_event $54, 13, 32, $1, $0, 255, 255, $1, 0, ItemFragment_0x6e124, $066f
	person_event $54, 6, 21, $1, $0, 255, 255, $1, 0, ItemFragment_0x6e126, $0670
	person_event $54, 14, 18, $1, $0, 255, 255, $1, 0, ItemFragment_0x6e128, $0654
; 0x6eafe

IlexForest_MapScriptHeader: ; 0x6eafe
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x6eb03
; 0x6eb03

UnknownScript_0x6eb03: ; 0x6eb03
	checkbit1 $0010
	iftrue UnknownScript_0x6eb34
	copybytetovar FarfetchdPosition
	if_equal $1, UnknownScript_0x6eb35
	if_equal $2, UnknownScript_0x6eb3c
	if_equal $3, UnknownScript_0x6eb43
	if_equal $4, UnknownScript_0x6eb4a
	if_equal $5, UnknownScript_0x6eb51
	if_equal $6, UnknownScript_0x6eb58
	if_equal $7, UnknownScript_0x6eb5f
	if_equal $8, UnknownScript_0x6eb66
	if_equal $9, UnknownScript_0x6eb6d
	if_equal $a, UnknownScript_0x6eb74
UnknownScript_0x6eb34: ; 0x6eb34
	return
; 0x6eb35

UnknownScript_0x6eb35: ; 0x6eb35
	moveperson $2, $e, $1f
	appear $2
	return
; 0x6eb3c

UnknownScript_0x6eb3c: ; 0x6eb3c
	moveperson $2, $f, $19
	appear $2
	return
; 0x6eb43

UnknownScript_0x6eb43: ; 0x6eb43
	moveperson $2, $14, $18
	appear $2
	return
; 0x6eb4a

UnknownScript_0x6eb4a: ; 0x6eb4a
	moveperson $2, $1d, $16
	appear $2
	return
; 0x6eb51

UnknownScript_0x6eb51: ; 0x6eb51
	moveperson $2, $1c, $1f
	appear $2
	return
; 0x6eb58

UnknownScript_0x6eb58: ; 0x6eb58
	moveperson $2, $18, $23
	appear $2
	return
; 0x6eb5f

UnknownScript_0x6eb5f: ; 0x6eb5f
	moveperson $2, $16, $1f
	appear $2
	return
; 0x6eb66

UnknownScript_0x6eb66: ; 0x6eb66
	moveperson $2, $f, $1d
	appear $2
	return
; 0x6eb6d

UnknownScript_0x6eb6d: ; 0x6eb6d
	moveperson $2, $a, $23
	appear $2
	return
; 0x6eb74

UnknownScript_0x6eb74: ; 0x6eb74
	moveperson $2, $6, $1c
	appear $2
	return
; 0x6eb7b

UnknownScript_0x6eb7b: ; 0x6eb7b
	faceplayer
	loadfont
	checkbit1 $0029
	iftrue UnknownScript_0x6eb89
	2writetext UnknownText_0x6ef5c
	closetext
	loadmovesprites
	end
; 0x6eb89

UnknownScript_0x6eb89: ; 0x6eb89
	2writetext UnknownText_0x6f019
	closetext
	loadmovesprites
	end
; 0x6eb8f

UnknownScript_0x6eb8f: ; 0x6eb8f
	copybytetovar FarfetchdPosition
	if_equal $1, UnknownScript_0x6ebba
	if_equal $2, UnknownScript_0x6ebd9
	if_equal $3, UnknownScript_0x6ec02
	if_equal $4, UnknownScript_0x6ec2b
	if_equal $5, UnknownScript_0x6ec54
	if_equal $6, UnknownScript_0x6eca7
	if_equal $7, UnknownScript_0x6ecd0
	if_equal $8, UnknownScript_0x6ed0e
	if_equal $9, UnknownScript_0x6ed50
	if_equal $a, UnknownScript_0x6ed96
UnknownScript_0x6ebba: ; 0x6ebba
	faceplayer
	loadfont
	2writetext UnknownText_0x6f06f
	keeptextopen
	2writetext UnknownText_0x6f086
	cry FARFETCH_D
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x6ee8f
	moveperson $2, $f, $19
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $2
	end
; 0x6ebd9

UnknownScript_0x6ebd9: ; 0x6ebd9
	2call UnknownScript_0x6eda1
	if_equal $0, UnknownScript_0x6ebf1
	applymovement $2, MovementData_0x6ee95
	moveperson $2, $14, $18
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $3
	end
; 0x6ebf1

UnknownScript_0x6ebf1: ; 0x6ebf1
	applymovement $2, MovementData_0x6ee9e
	moveperson $2, $f, $1d
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $8
	end
; 0x6ec02

UnknownScript_0x6ec02: ; 0x6ec02
	2call UnknownScript_0x6eda1
	if_equal $2, UnknownScript_0x6ec1a
	applymovement $2, MovementData_0x6eea4
	moveperson $2, $1d, $16
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $4
	end
; 0x6ec1a

UnknownScript_0x6ec1a: ; 0x6ec1a
	applymovement $2, MovementData_0x6eeab
	moveperson $2, $f, $19
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $2
	end
; 0x6ec2b

UnknownScript_0x6ec2b: ; 0x6ec2b
	2call UnknownScript_0x6eda1
	if_equal $1, UnknownScript_0x6ec43
	applymovement $2, MovementData_0x6eeb1
	moveperson $2, $1c, $1f
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $5
	end
; 0x6ec43

UnknownScript_0x6ec43: ; 0x6ec43
	applymovement $2, MovementData_0x6eeb8
	moveperson $2, $14, $18
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $3
	end
; 0x6ec54

UnknownScript_0x6ec54: ; 0x6ec54
	2call UnknownScript_0x6eda1
	if_equal $1, UnknownScript_0x6ec85
	if_equal $2, UnknownScript_0x6ec74
	if_equal $3, UnknownScript_0x6ec96
	applymovement $2, MovementData_0x6eebd
	moveperson $2, $18, $23
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $6
	end
; 0x6ec74

UnknownScript_0x6ec74: ; 0x6ec74
	applymovement $2, MovementData_0x6eec7
	moveperson $2, $16, $1f
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $7
	end
; 0x6ec85

UnknownScript_0x6ec85: ; 0x6ec85
	applymovement $2, MovementData_0x6eecc
	moveperson $2, $1d, $16
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $4
	end
; 0x6ec96

UnknownScript_0x6ec96: ; 0x6ec96
	applymovement $2, MovementData_0x6eed2
	moveperson $2, $1d, $16
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $4
	end
; 0x6eca7

UnknownScript_0x6eca7: ; 0x6eca7
	2call UnknownScript_0x6eda1
	if_equal $3, UnknownScript_0x6ecbf
	applymovement $2, MovementData_0x6eee6
	moveperson $2, $16, $1f
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $7
	end
; 0x6ecbf

UnknownScript_0x6ecbf: ; 0x6ecbf
	applymovement $2, MovementData_0x6eeef
	moveperson $2, $1c, $1f
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $5
	end
; 0x6ecd0

UnknownScript_0x6ecd0: ; 0x6ecd0
	2call UnknownScript_0x6eda1
	if_equal $0, UnknownScript_0x6ecfd
	if_equal $2, UnknownScript_0x6ecec
	applymovement $2, MovementData_0x6eef8
	moveperson $2, $f, $1d
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $8
	end
; 0x6ecec

UnknownScript_0x6ecec: ; 0x6ecec
	applymovement $2, MovementData_0x6ef00
	moveperson $2, $18, $23
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $6
	end
; 0x6ecfd

UnknownScript_0x6ecfd: ; 0x6ecfd
	applymovement $2, MovementData_0x6ef09
	moveperson $2, $1c, $1f
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $5
	end
; 0x6ed0e

UnknownScript_0x6ed0e: ; 0x6ed0e
	2call UnknownScript_0x6eda1
	if_equal $1, UnknownScript_0x6ed3f
	if_equal $2, UnknownScript_0x6ed3f
	if_equal $3, UnknownScript_0x6ed2e
	applymovement $2, MovementData_0x6ef10
	moveperson $2, $a, $23
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $9
	end
; 0x6ed2e

UnknownScript_0x6ed2e: ; 0x6ed2e
	applymovement $2, MovementData_0x6ef18
	moveperson $2, $16, $1f
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $7
	end
; 0x6ed3f

UnknownScript_0x6ed3f: ; 0x6ed3f
	applymovement $2, MovementData_0x6ef1e
	moveperson $2, $f, $19
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $2
	end
; 0x6ed50

UnknownScript_0x6ed50: ; 0x6ed50
	2call UnknownScript_0x6eda1
	if_equal $0, UnknownScript_0x6ed85
	if_equal $3, UnknownScript_0x6ed74
	applymovement $2, MovementData_0x6ef23
	moveperson $2, $6, $1c
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $a
	appear $4
	setbit1 $06f7
	setbit1 $0029
	end
; 0x6ed74

UnknownScript_0x6ed74: ; 0x6ed74
	applymovement $2, MovementData_0x6ef33
	moveperson $2, $f, $1d
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $8
	end
; 0x6ed85

UnknownScript_0x6ed85: ; 0x6ed85
	applymovement $2, MovementData_0x6ef3d
	moveperson $2, $f, $1d
	disappear $2
	appear $2
	loadvar FarfetchdPosition, $8
	end
; 0x6ed96

UnknownScript_0x6ed96: ; 0x6ed96
	faceplayer
	loadfont
	2writetext UnknownText_0x6f086
	cry FARFETCH_D
	closetext
	loadmovesprites
	end
; 0x6eda1

UnknownScript_0x6eda1: ; 0x6eda1
	faceplayer
	loadfont
	2writetext UnknownText_0x6f086
	cry FARFETCH_D
	closetext
	loadmovesprites
	checkcode $9
	end
; 0x6edae

UnknownScript_0x6edae: ; 0x6edae
	faceplayer
	loadfont
	checkbit1 $0010
	iftrue UnknownScript_0x6edd8
	2writetext UnknownText_0x6f099
	keeptextopen
	verbosegiveitem HM_01, 1
	setbit1 $0010
	2writetext UnknownText_0x6f141
	closetext
	loadmovesprites
	setbit1 $06e9
	setbit1 $06f3
	setbit1 $06f4
	clearbit1 $06f5
	clearbit1 $06f6
	clearbit1 $06f7
	end
; 0x6edd8

UnknownScript_0x6edd8: ; 0x6edd8
	2writetext UnknownText_0x6f1c0
	closetext
	loadmovesprites
	end
; 0x6edde

UnknownScript_0x6edde: ; 0x6edde
	faceplayer
	loadfont
	checkbit1 $005f
	iftrue UnknownScript_0x6edf3
	2writetext UnknownText_0x6f21b
	keeptextopen
	verbosegiveitem TM_02, 1
	iffalse UnknownScript_0x6edf7
	setbit1 $005f
UnknownScript_0x6edf3: ; 0x6edf3
	2writetext UnknownText_0x6f26d
	closetext
UnknownScript_0x6edf7: ; 0x6edf7
	loadmovesprites
	end
; 0x6edf9

TrainerBug_catcherWayne: ; 0x6edf9
	; bit/flag number
	dw $5c0

	; trainer group && trainer id
	db BUG_CATCHER, WAYNE

	; text when seen
	dw Bug_catcherWayneSeenText

	; text when trainer beaten
	dw Bug_catcherWayneBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherWayneScript
; 0x6ee05

Bug_catcherWayneScript: ; 0x6ee05
	talkaftercancel
	loadfont
	2writetext UnknownText_0x6f571
	closetext
	loadmovesprites
	end
; 0x6ee0d

UnknownScript_0x6ee0d: ; 0x6ee0d
	jumptextfaceplayer UnknownText_0x6f2af
; 0x6ee10

ItemFragment_0x6ee10: ; 0x6ee10
	db REVIVE, 1
; 0x6ee12

ItemFragment_0x6ee12: ; 0x6ee12
	db X_ATTACK, 1
; 0x6ee14

ItemFragment_0x6ee14: ; 0x6ee14
	db ANTIDOTE, 1
; 0x6ee16

ItemFragment_0x6ee16: ; 0x6ee16
	db ETHER, 1
; 0x6ee18

MapIlexForestSignpostItem1: ; 0x6ee18
	dw $0088
	db ETHER
	
; 0x6ee1b

MapIlexForestSignpostItem2: ; 0x6ee1b
	dw $0089
	db SUPER_POTION
	
; 0x6ee1e

MapIlexForestSignpostItem3: ; 0x6ee1e
	dw $008a
	db FULL_HEAL
; 0x6ee21

UnknownScript_0x6ee21: ; 0x6ee21
	jumpstd $000e
; 0x6ee24

MapIlexForestSignpost0Script: ; 0x6ee24
	jumptext UnknownText_0x6f2de
; 0x6ee27

MapIlexForestSignpost4Script: ; 0x6ee27
	checkbit1 $00c0
	iftrue UnknownScript_0x6ee30
	2jump UnknownScript_0x6ee35
; 0x6ee30

UnknownScript_0x6ee30: ; 0x6ee30
	checkitem GS_BALL
	iftrue UnknownScript_0x6ee38
UnknownScript_0x6ee35: ; 0x6ee35
	jumptext UnknownText_0x6f358
; 0x6ee38

UnknownScript_0x6ee38: ; 0x6ee38
	loadfont
	2writetext UnknownText_0x6f394
	yesorno
	iftrue UnknownScript_0x6ee42
	loadmovesprites
	end
; 0x6ee42

UnknownScript_0x6ee42: ; 0x6ee42
	takeitem GS_BALL, 1
	clearbit1 $00c0
	setbit1 $07a4
	disappear $8
	clearbit1 $06eb
	2writetext UnknownText_0x6f43b
	closetext
	loadmovesprites
	pause 20
	showemote $0, $0, 20
	special $006a
	applymovement $0, MovementData_0x6ef58
	pause 30
	spriteface $0, $0
	pause 20
	clearbit2 $0064
	special $008f
	loadpokedata CELEBI, 30
	startbattle
	returnafterbattle
	pause 20
	special $0090
	iffalse UnknownScript_0x6ee8e
	appear $7
	applymovement $7, MovementData_0x6ef4e
	loadfont
	2writetext UnknownText_0x6f452
	closetext
	loadmovesprites
	applymovement $7, MovementData_0x6ef53
	disappear $7
UnknownScript_0x6ee8e: ; 0x6ee8e
	end
; 0x6ee8f

MovementData_0x6ee8f: ; 0x6ee8f
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	step_end
; 0x6ee95

MovementData_0x6ee95: ; 0x6ee95
	big_step_up
	big_step_up
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_down
	step_end
; 0x6ee9e

MovementData_0x6ee9e: ; 0x6ee9e
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	step_end
; 0x6eea4

MovementData_0x6eea4: ; 0x6eea4
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	step_end
; 0x6eeab

MovementData_0x6eeab: ; 0x6eeab
	big_step_up
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	step_end
; 0x6eeb1

MovementData_0x6eeb1: ; 0x6eeb1
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	step_end
; 0x6eeb8

MovementData_0x6eeb8: ; 0x6eeb8
	big_step_left
	jump_step_left
	big_step_left
	big_step_left
	step_end
; 0x6eebd

MovementData_0x6eebd: ; 0x6eebd
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	step_end
; 0x6eec7

MovementData_0x6eec7: ; 0x6eec7
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	step_end
; 0x6eecc

MovementData_0x6eecc: ; 0x6eecc
	big_step_up
	big_step_up
	big_step_up
	big_step_right
	big_step_up
	step_end
; 0x6eed2

MovementData_0x6eed2: ; 0x6eed2
	big_step_right
	turn_head_up
	db $3e ; movement
	turn_head_down
	db $3e ; movement
	turn_head_up
	db $3e ; movement
	big_step_down
	big_step_down
	fix_facing
	jump_step_up
	accelerate_last
	accelerate_last
	remove_fixed_facing
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	step_end
; 0x6eee6

MovementData_0x6eee6: ; 0x6eee6
	big_step_left
	big_step_left
	big_step_left
	big_step_up
	big_step_up
	big_step_right
	big_step_up
	big_step_up
	step_end
; 0x6eeef

MovementData_0x6eeef: ; 0x6eeef
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	step_end
; 0x6eef8

MovementData_0x6eef8: ; 0x6eef8
	big_step_up
	big_step_up
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	step_end
; 0x6ef00

MovementData_0x6ef00: ; 0x6ef00
	big_step_down
	big_step_down
	big_step_left
	big_step_down
	big_step_down
	big_step_right
	big_step_right
	big_step_right
	step_end
; 0x6ef09

MovementData_0x6ef09: ; 0x6ef09
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	step_end
; 0x6ef10

MovementData_0x6ef10: ; 0x6ef10
	big_step_down
	big_step_left
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	step_end
; 0x6ef18

MovementData_0x6ef18: ; 0x6ef18
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	step_end
; 0x6ef1e

MovementData_0x6ef1e: ; 0x6ef1e
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	step_end
; 0x6ef23

MovementData_0x6ef23: ; 0x6ef23
	big_step_left
	big_step_left
	fix_facing
	jump_step_right
	accelerate_last
	accelerate_last
	remove_fixed_facing
	big_step_left
	big_step_left
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	step_end
; 0x6ef33

MovementData_0x6ef33: ; 0x6ef33
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	step_end
; 0x6ef3d

MovementData_0x6ef3d: ; 0x6ef3d
	big_step_left
	big_step_left
	fix_facing
	jump_step_right
	accelerate_last
	accelerate_last
	remove_fixed_facing
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	step_end
; 0x6ef4e

MovementData_0x6ef4e: ; 0x6ef4e
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x6ef53

MovementData_0x6ef53: ; 0x6ef53
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x6ef58

MovementData_0x6ef58: ; 0x6ef58
	fix_facing
	slow_step_down
	remove_fixed_facing
	step_end
; 0x6ef5c

UnknownText_0x6ef5c: ; 0x6ef5c
	db $0, "Oh, man… My boss", $4f
	db "is going to be", $55
	db "steaming…", $51
	db "The FARFETCH'D", $4f
	db "that CUTS trees", $51
	db "for charcoal took", $4f
	db "off on me.", $51
	db "I can't go looking", $4f
	db "for it here in the", $55
	db "ILEX FOREST.", $51
	db "It's too big, dark", $4f
	db "and scary for me…", $57
; 0x6f019

UnknownText_0x6f019: ; 0x6f019
	db $0, "Wow! Thanks a", $4f
	db "whole bunch!", $51
	db "My boss's #MON", $4f
	db "won't obey me be-", $55
	db "cause I don't have", $55
	db "a BADGE.", $57
; 0x6f06f

UnknownText_0x6f06f: ; 0x6f06f
	db $0, "It's the missing", $4f
	db "#MON!", $57
; 0x6f086

UnknownText_0x6f086: ; 0x6f086
	db $0, "FARFETCH'D: Kwaa!", $57
; 0x6f099

UnknownText_0x6f099: ; 0x6f099
	db $0, "Ah! My FARFETCH'D!", $51
	db "You found it for", $4f
	db "us, kid?", $51
	db "Without it, we", $4f
	db "wouldn't be able", $51
	db "to CUT trees for", $4f
	db "charcoal.", $51
	db "Thanks, kid!", $51
	db "Now, how can I", $4f
	db "thank you…", $51
	db "I know! Here, take", $4f
	db "this.", $57
; 0x6f141

UnknownText_0x6f141: ; 0x6f141
	db $0, "That's the CUT HM.", $4f
	db "Teach that to a", $51
	db "#MON to clear", $4f
	db "small trees.", $51
	db "Of course, you", $4f
	db "have to have the", $51
	db "GYM BADGE from", $4f
	db "AZALEA to use it.", $57
; 0x6f1c0

UnknownText_0x6f1c0: ; 0x6f1c0
	db $0, "Do you want to", $4f
	db "apprentice as a", $51
	db "charcoal maker", $4f
	db "with me?", $51
	db "You'll be first-", $4f
	db "rate in ten years!", $57
; 0x6f21b

UnknownText_0x6f21b: ; 0x6f21b
	db $0, "What am I doing?", $51
	db "I'm shaking trees", $4f
	db "using HEADBUTT.", $51
	db "It's fun. Here,", $4f
	db "you try it too!", $57
; 0x6f26d

UnknownText_0x6f26d: ; 0x6f26d
	db $0, "Rattle trees with", $4f
	db "HEADBUTT. Some-", $55
	db "times, sleeping", $55
	db "#MON fall out.", $57
; 0x6f2af

UnknownText_0x6f2af: ; 0x6f2af
	db $0, "Did something", $4f
	db "happen to the", $55
	db "forest's guardian?", $57
; 0x6f2de

UnknownText_0x6f2de: ; 0x6f2de
	db $0, "ILEX FOREST is", $4f
	db "so overgrown with", $51
	db "trees that you", $4f
	db "can't see the sky.", $51
	db "Please watch out", $4f
	db "for items that may", $55
	db "have been dropped.", $57
; 0x6f358

UnknownText_0x6f358: ; 0x6f358
	db $0, "ILEX FOREST", $4f
	db "SHRINE…", $51
	db "It's in honor of", $4f
	db "the forest's", $55
	db "protector…", $57
; 0x6f394

UnknownText_0x6f394: ; 0x6f394
	db $0, "ILEX FOREST", $4f
	db "SHRINE…", $51
	db "It's in honor of", $4f
	db "the forest's", $55
	db "protector…", $51
	db "Oh? What is this?", $51
	db "It's a hole.", $4f
	db "It looks like the", $51
	db "GS BALL would fit", $4f
	db "inside it.", $51
	db "Want to put the GS", $4f
	db "BALL here?", $57
; 0x6f43b

UnknownText_0x6f43b: ; 0x6f43b
	db $0, $52, " put in the", $4f
	db "GS BALL.", $57
; 0x6f452

UnknownText_0x6f452: ; 0x6f452
	db $0, "Whew, wasn't that", $4f
	db "something!", $51
	db $52, ", that was", $4f
	db "fantastic. Thanks!", $51
	db "The legends about", $4f
	db "that SHRINE were", $55
	db "real after all.", $51
	db "I feel inspired by", $4f
	db "what I just saw.", $51
	db "It motivates me to", $4f
	db "make better BALLS!", $51
	db "I'm going!", $57
; 0x6f515

Bug_catcherWayneSeenText: ; 0x6f515
	db $0, "Don't sneak up on", $4f
	db "me like that!", $51
	db "You frightened a", $4f
	db "#MON away!", $57
; 0x6f551

Bug_catcherWayneBeatenText: ; 0x6f551
	db $0, "I hadn't seen that", $4f
	db "#MON before…", $57
; 0x6f571

UnknownText_0x6f571: ; 0x6f571
	db $0, "A #MON I've", $4f
	db "never seen before", $51
	db "fell out of the", $4f
	db "tree when I used", $55
	db "HEADBUTT.", $51
	db "I ought to use", $4f
	db "HEADBUTT in other", $55
	db "places too.", $57
; 0x6f5e7

IlexForest_MapEventHeader: ; 0x6f5e7
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $5, $1, 3, GROUP_ROUTE_34_ILEX_FOREST_GATE, MAP_ROUTE_34_ILEX_FOREST_GATE
	warp_def $2a, $3, 1, GROUP_ILEX_FOREST_AZALEA_GATE, MAP_ILEX_FOREST_AZALEA_GATE
	warp_def $2b, $3, 2, GROUP_ILEX_FOREST_AZALEA_GATE, MAP_ILEX_FOREST_AZALEA_GATE

	; xy triggers
	db 0

	; signposts
	db 5
	signpost 17, 3, $0, MapIlexForestSignpost0Script
	signpost 7, 11, $7, MapIlexForestSignpostItem1
	signpost 14, 22, $7, MapIlexForestSignpostItem2
	signpost 17, 1, $7, MapIlexForestSignpostItem3
	signpost 22, 8, $1, MapIlexForestSignpost4Script

	; people-events
	db 11
	person_event $4e, 35, 18, $3, $0, 255, 255, $b0, 0, UnknownScript_0x6eb8f, $06e9
	person_event $27, 32, 11, $6, $0, 255, 255, $a0, 0, UnknownScript_0x6eb7b, $06f3
	person_event $41, 32, 9, $9, $0, 255, 255, $0, 0, UnknownScript_0x6edae, $06f4
	person_event $2c, 18, 19, $9, $0, 255, 255, $0, 0, UnknownScript_0x6edde, $ffff
	person_event $54, 36, 24, $1, $0, 255, 255, $1, 0, ItemFragment_0x6ee10, $0671
	person_event $b, 33, 12, $7, $0, 255, 255, $0, 0, ObjectEvent, $07a5
	person_event $28, 28, 7, $9, $0, 255, 255, $a0, 0, UnknownScript_0x6ee0d, $06ed
	person_event $27, 5, 16, $7, $0, 255, 255, $a2, 0, TrainerBug_catcherWayne, $ffff
	person_event $54, 21, 13, $1, $0, 255, 255, $1, 0, ItemFragment_0x6ee12, $07b9
	person_event $54, 11, 21, $1, $0, 255, 255, $1, 0, ItemFragment_0x6ee14, $07ba
	person_event $54, 5, 31, $1, $0, 255, 255, $1, 0, ItemFragment_0x6ee16, $07bb
; 0x6f6a4

SECTION "bank1C",DATA,BANK[$1C]

LakeofRage_MapScriptHeader: ; 0x70000
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x70010, $0000
	dw UnknownScript_0x70011, $0000

	; callback count
	db 2

	; callbacks

	dbw 5, UnknownScript_0x70012

	dbw 2, UnknownScript_0x70016
; 0x70010

UnknownScript_0x70010: ; 0x70010
	end
; 0x70011

UnknownScript_0x70011: ; 0x70011
	end
; 0x70012

UnknownScript_0x70012: ; 0x70012
	setbit2 $004a
	return
; 0x70016

UnknownScript_0x70016: ; 0x70016
	checkcode $b
	if_equal WEDNESDAY, UnknownScript_0x7001f
	disappear $b
	return
; 0x7001f

UnknownScript_0x7001f: ; 0x7001f
	appear $b
	return
; 0x70022

UnknownScript_0x70022: ; 0x70022
	checkbit1 $0026
	iftrue UnknownScript_0x70057
	loadfont
	2writetext UnknownText_0x70157
	keeptextopen
	faceplayer
	2writetext UnknownText_0x701b4
	yesorno
	iffalse UnknownScript_0x7004e
UnknownScript_0x70035: ; 0x70035
	2writetext UnknownText_0x702c6
	closetext
	loadmovesprites
	playsound $0013
	applymovement $2, MovementData_0x70155
	disappear $2
	clearbit1 $06d5
	setbit1 $0060
	domaptrigger GROUP_MAHOGANY_MART_1F, MAP_MAHOGANY_MART_1F, $1
	end
; 0x7004e

UnknownScript_0x7004e: ; 0x7004e
	2writetext UnknownText_0x70371
	closetext
	loadmovesprites
	setbit1 $0026
	end
; 0x70057

UnknownScript_0x70057: ; 0x70057
	faceplayer
	loadfont
	2writetext UnknownText_0x703a5
	yesorno
	iffalse UnknownScript_0x7004e
	2jump UnknownScript_0x70035
; 0x70063

UnknownScript_0x70063: ; 0x70063
	loadfont
	2writetext UnknownText_0x703cb
	pause 15
	cry GYARADOS
	loadmovesprites
	loadpokedata GYARADOS, 30
	writecode $3, $7
	startbattle
	if_equal $1, UnknownScript_0x7007a
	disappear $a
UnknownScript_0x7007a: ; 0x7007a
	returnafterbattle
	loadfont
	giveitem RED_SCALE, $1
	waitbutton
	2writetext UnknownText_0x703df
	playsound $0001
	waitbutton
	itemnotify
	loadmovesprites
	dotrigger $0
	appear $2
	end
; 0x7008e

UnknownScript_0x7008e: ; 0x7008e
	faceplayer
	loadfont
	checkbit1 $0022
	iftrue UnknownScript_0x7009c
	2writetext UnknownText_0x703f8
	closetext
	loadmovesprites
	end
; 0x7009c

UnknownScript_0x7009c: ; 0x7009c
	2writetext UnknownText_0x70421
	closetext
	loadmovesprites
	end
; 0x700a2

UnknownScript_0x700a2: ; 0x700a2
	jumptextfaceplayer UnknownText_0x70444
; 0x700a5

UnknownScript_0x700a5: ; 0x700a5
	jumptextfaceplayer UnknownText_0x704bb
; 0x700a8

MapLakeofRageSignpost0Script: ; 0x700a8
	jumptext UnknownText_0x708d7
; 0x700ab

MapLakeofRageSignpost1Script: ; 0x700ab
	loadfont
	2writetext UnknownText_0x70903
	checkbit1 $0022
	iftrue UnknownScript_0x700b8
	closetext
	loadmovesprites
	end
; 0x700b8

UnknownScript_0x700b8: ; 0x700b8
	keeptextopen
	special $001a
	loadmovesprites
	end
; 0x700be

TrainerFisherAndre: ; 0x700be
	; bit/flag number
	dw $455

	; trainer group && trainer id
	db FISHER, ANDRE

	; text when seen
	dw FisherAndreSeenText

	; text when trainer beaten
	dw FisherAndreBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherAndreScript
; 0x700ca

FisherAndreScript: ; 0x700ca
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7058f
	closetext
	loadmovesprites
	end
; 0x700d2

TrainerFisherRaymond: ; 0x700d2
	; bit/flag number
	dw $456

	; trainer group && trainer id
	db FISHER, RAYMOND

	; text when seen
	dw FisherRaymondSeenText

	; text when trainer beaten
	dw FisherRaymondBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherRaymondScript
; 0x700de

FisherRaymondScript: ; 0x700de
	talkaftercancel
	loadfont
	2writetext UnknownText_0x70611
	closetext
	loadmovesprites
	end
; 0x700e6

TrainerCooltrainermAaron: ; 0x700e6
	; bit/flag number
	dw $549

	; trainer group && trainer id
	db COOLTRAINERM, AARON

	; text when seen
	dw CooltrainermAaronSeenText

	; text when trainer beaten
	dw CooltrainermAaronBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermAaronScript
; 0x700f2

CooltrainermAaronScript: ; 0x700f2
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7069c
	closetext
	loadmovesprites
	end
; 0x700fa

TrainerCooltrainerfLois: ; 0x700fa
	; bit/flag number
	dw $55c

	; trainer group && trainer id
	db COOLTRAINERF, LOIS

	; text when seen
	dw CooltrainerfLoisSeenText

	; text when trainer beaten
	dw CooltrainerfLoisBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfLoisScript
; 0x70106

CooltrainerfLoisScript: ; 0x70106
	talkaftercancel
	loadfont
	2writetext UnknownText_0x70752
	closetext
	loadmovesprites
	end
; 0x7010e

UnknownScript_0x7010e: ; 0x7010e
	faceplayer
	loadfont
	checkbit1 $006b
	iftrue UnknownScript_0x7013c
	checkcode $b
	if_not_equal WEDNESDAY, UnknownScript_0x70142
	checkbit1 $006a
	iftrue UnknownScript_0x70129
	2writetext UnknownText_0x70784
	keeptextopen
	setbit1 $006a
UnknownScript_0x70129: ; 0x70129
	2writetext UnknownText_0x707dd
	keeptextopen
	verbosegiveitem BLACKBELT, 1
	iffalse UnknownScript_0x70140
	setbit1 $006b
	2writetext UnknownText_0x7080b
	closetext
	loadmovesprites
	end
; 0x7013c

UnknownScript_0x7013c: ; 0x7013c
	2writetext UnknownText_0x70844
	closetext
UnknownScript_0x70140: ; 0x70140
	loadmovesprites
	end
; 0x70142

UnknownScript_0x70142: ; 0x70142
	2writetext UnknownText_0x708a9
	closetext
	loadmovesprites
	end
; 0x70148

ItemFragment_0x70148: ; 0x70148
	db ELIXER, 1
; 0x7014a

ItemFragment_0x7014a: ; 0x7014a
	db TM_43, 1
; 0x7014c

MapLakeofRageSignpostItem2: ; 0x7014c
	dw $00b5
	db FULL_RESTORE
	
; 0x7014f

MapLakeofRageSignpostItem3: ; 0x7014f
	dw $00b6
	db RARE_CANDY
	
; 0x70152

MapLakeofRageSignpostItem4: ; 0x70152
	dw $00b7
	db MAX_POTION
	
; 0x70155

MovementData_0x70155: ; 0x70155
	teleport_from
	step_end
; 0x70157

UnknownText_0x70157: ; 0x70157
	db $0, "This lake is full", $4f
	db "of GYARADOS but", $55
	db "nothing else…", $51
	db "So the MAGIKARP", $4f
	db "are being forced", $55
	db "to evolve…", $57
; 0x701b4

UnknownText_0x701b4: ; 0x701b4
	db $0, "Did you come here", $4f
	db "because of the", $55
	db "rumors?", $51
	db "You're ", $52, "?", $4f
	db "I'm LANCE, a", $55
	db "trainer like you.", $51
	db "I heard some ru-", $4f
	db "mors, so I came to", $55
	db "investigate…", $51
	db "I saw the way you", $4f
	db "battled earlier,", $55
	db $14, ".", $51
	db "I can tell that", $4f
	db "you're a trainer", $51
	db "with considerable", $4f
	db "skill.", $51
	db "If you don't mind,", $4f
	db "could you help me", $55
	db "investigate?", $57
; 0x702c6

UnknownText_0x702c6: ; 0x702c6
	db $0, "LANCE: Excellent!", $51
	db "It seems that the", $4f
	db "LAKE's MAGIKARP", $51
	db "are being forced", $4f
	db "to evolve.", $51
	db "A mysterious radio", $4f
	db "broadcast coming", $51
	db "from MAHOGANY is", $4f
	db "the cause.", $51
	db "I'll be waiting", $4f
	db "for you, ", $14, ".", $57
; 0x70371

UnknownText_0x70371: ; 0x70371
	db $0, "Oh… Well, if you", $4f
	db "change your mind,", $55
	db "please help me.", $57
; 0x703a5

UnknownText_0x703a5: ; 0x703a5
	db $0, "LANCE: Hm? Are you", $4f
	db "going to help me?", $57
; 0x703cb

UnknownText_0x703cb: ; 0x703cb
	db $0, "GYARADOS: Gyashaa!", $57
; 0x703df

UnknownText_0x703df: ; 0x703df
	db $0, $52, " obtained a", $4f
	db "RED SCALE.", $57
; 0x703f8

UnknownText_0x703f8: ; 0x703f8
	db $0, "The GYARADOS are", $4f
	db "angry!", $51
	db "It's a bad omen!", $57
; 0x70421

UnknownText_0x70421: ; 0x70421
	db $0, "Hahah! The MAGI-", $4f
	db "KARP are biting!", $57
; 0x70444

UnknownText_0x70444: ; 0x70444
	db $0, "I heard this lake", $4f
	db "was made by ram-", $55
	db "paging GYARADOS.", $51
	db "I wonder if there", $4f
	db "is any connection", $51
	db "to their mass out-", $4f
	db "break now?", $57
; 0x704bb

UnknownText_0x704bb: ; 0x704bb
	db $0, "Did my eyes de-", $4f
	db "ceive me? I saw a", $51
	db "red GYARADOS in", $4f
	db "the LAKE…", $51
	db "But I thought", $4f
	db "GYARADOS were", $55
	db "usually blue?", $57
; 0x70522

FisherAndreSeenText: ; 0x70522
	db $0, "Let me battle with", $4f
	db "the #MON I just", $55
	db "caught!", $57
; 0x7054e

FisherAndreBeatenText: ; 0x7054e
	db $0, "I might be an ex-", $4f
	db "pert angler, but", $51
	db "I stink as a #-", $4f
	db "MON trainer…", $57
; 0x7058f

UnknownText_0x7058f: ; 0x7058f
	db $0, "I won't lose as an", $4f
	db "angler! I catch", $55
	db "#MON all day.", $57
; 0x705c0

FisherRaymondSeenText: ; 0x705c0
	db $0, "No matter what I", $4f
	db "do, all I catch", $51
	db "are the same #-", $4f
	db "MON…", $57
; 0x705f7

FisherRaymondBeatenText: ; 0x705f7
	db $0, "My line's all", $4f
	db "tangled up…", $57
; 0x70611

UnknownText_0x70611: ; 0x70611
	db $0, "Why can't I catch", $4f
	db "any good #MON?", $57
; 0x70632

CooltrainermAaronSeenText: ; 0x70632
	db $0, "If a trainer spots", $4f
	db "another trainer,", $51
	db "he has to make a", $4f
	db "challenge.", $51
	db "That is our", $4f
	db "destiny.", $57
; 0x70688

CooltrainermAaronBeatenText: ; 0x70688
	db $0, "Whew…", $4f
	db "Good battle.", $57
; 0x7069c

UnknownText_0x7069c: ; 0x7069c
	db $0, "#MON and their", $4f
	db "trainer become", $51
	db "powerful through", $4f
	db "constant battling.", $57
; 0x706df

CooltrainerfLoisSeenText: ; 0x706df
	db $0, "What happened to", $4f
	db "the red GYARADOS?", $51
	db "It's gone?", $51
	db "Oh, darn. I came", $4f
	db "here for nothing?", $51
	db "I know--let's", $4f
	db "battle!", $57
; 0x70745

CooltrainerfLoisBeatenText: ; 0x70745
	db $0, "Good going!", $57
; 0x70752

UnknownText_0x70752: ; 0x70752
	db $0, "Come to think of", $4f
	db "it, I've seen a", $55
	db "pink BUTTERFREE.", $57
; 0x70784

UnknownText_0x70784: ; 0x70784
	db $0, "WESLEY: Well, how", $4f
	db "do you do?", $51
	db "Seeing as how it's", $4f
	db "Wednesday today,", $51
	db "I'm WESLEY of", $4f
	db "Wednesday.", $57
; 0x707dd

UnknownText_0x707dd: ; 0x707dd
	db $0, "Pleased to meet", $4f
	db "you. Please take a", $55
	db "souvenir.", $57
; 0x7080b

UnknownText_0x7080b: ; 0x7080b
	db $0, "WESLEY: BLACKBELT", $4f
	db "beefs up the power", $55
	db "of fighting moves.", $57
; 0x70844

UnknownText_0x70844: ; 0x70844
	db $0, "WESLEY: Since you", $4f
	db "found me, you must", $51
	db "have met my broth-", $4f
	db "ers and sisters.", $51
	db "Or did you just", $4f
	db "get lucky?", $57
; 0x708a9

UnknownText_0x708a9: ; 0x708a9
	db $0, "WESLEY: Today's", $4f
	db "not Wednesday.", $55
	db "That's too bad.", $57
; 0x708d7

UnknownText_0x708d7: ; 0x708d7
	db $0, "LAKE OF RAGE,", $4f
	db "also known as", $55
	db "GYARADOS LAKE.", $57
; 0x70903

UnknownText_0x70903: ; 0x70903
	db $0, "FISHING GURU'S", $4f
	db "HOUSE", $57
; 0x70919

LakeofRage_MapEventHeader: ; 0x70919
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $7, 1, GROUP_LAKE_OF_RAGE_HIDDEN_POWER_HOUSE, MAP_LAKE_OF_RAGE_HIDDEN_POWER_HOUSE
	warp_def $1f, $1b, 1, GROUP_LAKE_OF_RAGE_MAGIKARP_HOUSE, MAP_LAKE_OF_RAGE_MAGIKARP_HOUSE

	; xy triggers
	db 0

	; signposts
	db 5
	signpost 27, 21, $0, MapLakeofRageSignpost0Script
	signpost 31, 25, $0, MapLakeofRageSignpost1Script
	signpost 28, 11, $7, MapLakeofRageSignpostItem2
	signpost 4, 4, $7, MapLakeofRageSignpostItem3
	signpost 5, 35, $7, MapLakeofRageSignpostItem4

	; people-events
	db 12
	person_event $1e, 32, 25, $7, $0, 255, 255, $0, 0, UnknownScript_0x70022, $06d4
	person_event $2f, 30, 24, $7, $0, 255, 255, $0, 0, UnknownScript_0x7008e, $ffff
	person_event $2b, 17, 40, $8, $0, 255, 255, $0, 0, UnknownScript_0x700a2, $ffff
	person_event $24, 33, 29, $5, $1, 255, 255, $0, 0, UnknownScript_0x700a5, $ffff
	person_event $3a, 27, 34, $8, $0, 255, 255, $92, 1, TrainerFisherAndre, $0735
	person_event $3a, 30, 28, $7, $0, 255, 255, $92, 1, TrainerFisherRaymond, $0735
	person_event $23, 19, 8, $9, $0, 255, 255, $82, 1, TrainerCooltrainermAaron, $0735
	person_event $24, 11, 40, $8, $0, 255, 255, $82, 0, TrainerCooltrainerfLois, $0735
	person_event $a0, 26, 22, $16, $0, 255, 255, $80, 0, UnknownScript_0x70063, $0751
	person_event $2b, 8, 8, $6, $0, 255, 255, $0, 0, UnknownScript_0x7010e, $075c
	person_event $54, 14, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x70148, $0645
	person_event $54, 6, 39, $1, $0, 255, 255, $1, 0, ItemFragment_0x7014a, $0646
; 0x709de

CeladonDeptStore1F_MapScriptHeader: ; 0x709de
	; trigger count
	db 0

	; callback count
	db 0
; 0x709e0

UnknownScript_0x709e0: ; 0x709e0
	jumptextfaceplayer UnknownText_0x709ef
; 0x709e3

UnknownScript_0x709e3: ; 0x709e3
	jumptextfaceplayer UnknownText_0x70a35
; 0x709e6

UnknownScript_0x709e6: ; 0x709e6
	jumptextfaceplayer UnknownText_0x70aa9
; 0x709e9

MapCeladonDeptStore1FSignpost0Script: ; 0x709e9
	jumptext UnknownText_0x70aea
; 0x709ec

MapCeladonDeptStore6FSignpost1Script: ; 0x709ec
	jumpstd $0014
; 0x709ef

UnknownText_0x709ef: ; 0x709ef
	db $0, "Hello! Welcome to", $4f
	db "CELADON DEPT.", $55
	db "STORE!", $51
	db "The directory is", $4f
	db "on the wall.", $57
; 0x70a35

UnknownText_0x70a35: ; 0x70a35
	db $0, "This DEPT.STORE is", $4f
	db "part of the same", $51
	db "chain as the one", $4f
	db "in GOLDENROD CITY.", $51
	db "They were both", $4f
	db "renovated at the", $55
	db "same time.", $57
; 0x70aa9

UnknownText_0x70aa9: ; 0x70aa9
	db $0, "This is my first", $4f
	db "time here.", $51
	db "It's so big…", $51
	db "I'm afraid I'll", $4f
	db "get lost.", $57
; 0x70aea

UnknownText_0x70aea: ; 0x70aea
	db $0, "1F: SERVICE", $4f
	db "    COUNTER", $51
	db "2F: TRAINER'S", $4f
	db "    MARKET", $51
	db "3F: TM SHOP", $51
	db "4F: WISEMAN GIFTS", $51
	db "5F: DRUG STORE", $51
	db "6F: ROOFTOP", $4f
	db "    SQUARE", $57
; 0x70b60

CeladonDeptStore1F_MapEventHeader: ; 0x70b60
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $7, $7, 1, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $7, $8, 1, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $0, $f, 2, GROUP_CELADON_DEPT_STORE_2F, MAP_CELADON_DEPT_STORE_2F
	warp_def $0, $2, 1, GROUP_CELADON_DEPT_STORE_ELEVATOR, MAP_CELADON_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapCeladonDeptStore1FSignpost0Script
	signpost 0, 3, $0, MapCeladonDeptStore6FSignpost1Script

	; people-events
	db 3
	person_event $42, 5, 14, $6, $0, 255, 255, $80, 0, UnknownScript_0x709e0, $ffff
	person_event $40, 8, 15, $2, $11, 255, 255, $0, 0, UnknownScript_0x709e3, $ffff
	person_event $29, 7, 9, $5, $1, 255, 255, $a0, 0, UnknownScript_0x709e6, $ffff
; 0x70bab

CeladonDeptStore2F_MapScriptHeader: ; 0x70bab
	; trigger count
	db 0

	; callback count
	db 0
; 0x70bad

UnknownScript_0x70bad: ; 0x70bad
	faceplayer
	loadfont
	pokemart $0, $0017
	loadmovesprites
	end
; 0x70bb5

UnknownScript_0x70bb5: ; 0x70bb5
	faceplayer
	loadfont
	pokemart $0, $0018
	loadmovesprites
	end
; 0x70bbd

UnknownScript_0x70bbd: ; 0x70bbd
	jumptextfaceplayer UnknownText_0x70bc9
; 0x70bc0

UnknownScript_0x70bc0: ; 0x70bc0
	jumptextfaceplayer UnknownText_0x70c3e
; 0x70bc3

MapCeladonDeptStore2FSignpost0Script: ; 0x70bc3
	jumptext UnknownText_0x70c9c
; 0x70bc6

MapCeladonDeptStore2FSignpost1Script: ; 0x70bc6
	jumpstd $0014
; 0x70bc9

UnknownText_0x70bc9: ; 0x70bc9
	db $0, "I just recently", $4f
	db "became a trainer.", $51
	db "My son encouraged", $4f
	db "me to do it.", $51
	db "I'm impressed by", $4f
	db "the selection of", $55
	db "convenient items.", $57
; 0x70c3e

UnknownText_0x70c3e: ; 0x70c3e
	db $0, "My dad's having a", $4f
	db "hard time learning", $51
	db "the names of items", $4f
	db "and how they are", $51
	db "supposed to be", $4f
	db "used…", $57
; 0x70c9c

UnknownText_0x70c9c: ; 0x70c9c
	db $0, "Top Grade Items", $4f
	db "for Trainers!", $51
	db "2F: TRAINER'S", $4f
	db "    MARKET", $57
; 0x70cd4

CeladonDeptStore2F_MapEventHeader: ; 0x70cd4
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $c, 1, GROUP_CELADON_DEPT_STORE_3F, MAP_CELADON_DEPT_STORE_3F
	warp_def $0, $f, 3, GROUP_CELADON_DEPT_STORE_1F, MAP_CELADON_DEPT_STORE_1F
	warp_def $0, $2, 1, GROUP_CELADON_DEPT_STORE_ELEVATOR, MAP_CELADON_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapCeladonDeptStore2FSignpost0Script
	signpost 0, 3, $0, MapCeladonDeptStore2FSignpost1Script

	; people-events
	db 4
	person_event $39, 9, 17, $7, $0, 255, 255, $90, 0, UnknownScript_0x70bad, $ffff
	person_event $39, 9, 18, $7, $0, 255, 255, $90, 0, UnknownScript_0x70bb5, $ffff
	person_event $2d, 6, 9, $7, $0, 255, 255, $80, 0, UnknownScript_0x70bbd, $ffff
	person_event $27, 6, 10, $8, $0, 255, 255, $a0, 0, UnknownScript_0x70bc0, $ffff
; 0x70d27

CeladonDeptStore3F_MapScriptHeader: ; 0x70d27
	; trigger count
	db 0

	; callback count
	db 0
; 0x70d29

UnknownScript_0x70d29: ; 0x70d29
	faceplayer
	loadfont
	pokemart $0, $0019
	loadmovesprites
	end
; 0x70d31

UnknownScript_0x70d31: ; 0x70d31
	jumptextfaceplayer UnknownText_0x70d53
; 0x70d34

UnknownScript_0x70d34: ; 0x70d34
	faceplayer
	loadfont
	2writetext UnknownText_0x70d86
	closetext
	loadmovesprites
	spriteface $4, $0
	end
; 0x70d3f

UnknownScript_0x70d3f: ; 0x70d3f
	faceplayer
	loadfont
	2writetext UnknownText_0x70dc7
	closetext
	loadmovesprites
	spriteface $5, $0
	end
; 0x70d4a

UnknownScript_0x70d4a: ; 0x70d4a
	jumptextfaceplayer UnknownText_0x70e61
; 0x70d4d

MapCeladonDeptStore3FSignpost1Script: ; 0x70d4d
	jumpstd $0014
; 0x70d50

MapCeladonDeptStore3FSignpost0Script: ; 0x70d50
	jumptext UnknownText_0x70e85
; 0x70d53

UnknownText_0x70d53: ; 0x70d53
	db $0, "I can't decide", $4f
	db "which #MON I", $51
	db "should use this TM", $4f
	db "on…", $57
; 0x70d86

UnknownText_0x70d86: ; 0x70d86
	db $0, "Uh-oh! I traded my", $4f
	db "#MON without", $51
	db "removing the UP-", $4f
	db "GRADE from it.", $57
; 0x70dc7

UnknownText_0x70dc7: ; 0x70dc7
	db $0, "Yeah! I'm finally", $4f
	db "getting a PORYGON!", $51
	db "I'm no good at the", $4f
	db "slots, so I could", $51
	db "never get enough", $4f
	db "coins…", $51
	db "…Huh?", $51
	db "The traded PORYGON", $4f
	db "turned into a dif-", $55
	db "ferent #MON!", $57
; 0x70e61

UnknownText_0x70e61: ; 0x70e61
	db $0, "The TM SHOP sells", $4f
	db "some rare moves.", $57
; 0x70e85

UnknownText_0x70e85: ; 0x70e85
	db $0, "3F: TM SHOP", $51
	db "Make Your #MON", $4f
	db "Stronger!", $57
; 0x70eab

CeladonDeptStore3F_MapEventHeader: ; 0x70eab
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $c, 1, GROUP_CELADON_DEPT_STORE_2F, MAP_CELADON_DEPT_STORE_2F
	warp_def $0, $f, 2, GROUP_CELADON_DEPT_STORE_4F, MAP_CELADON_DEPT_STORE_4F
	warp_def $0, $2, 1, GROUP_CELADON_DEPT_STORE_ELEVATOR, MAP_CELADON_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapCeladonDeptStore3FSignpost0Script
	signpost 0, 3, $0, MapCeladonDeptStore3FSignpost1Script

	; people-events
	db 5
	person_event $39, 5, 11, $6, $0, 255, 255, $90, 0, UnknownScript_0x70d29, $ffff
	person_event $27, 8, 10, $4, $10, 255, 255, $a0, 0, UnknownScript_0x70d31, $ffff
	person_event $3, 5, 13, $6, $0, 255, 255, $80, 0, UnknownScript_0x70d34, $ffff
	person_event $3, 5, 14, $6, $0, 255, 255, $90, 0, UnknownScript_0x70d3f, $ffff
	person_event $2b, 8, 17, $2, $11, 255, 255, $80, 0, UnknownScript_0x70d4a, $ffff
; 0x70f0b

CeladonDeptStore4F_MapScriptHeader: ; 0x70f0b
	; trigger count
	db 0

	; callback count
	db 0
; 0x70f0d

UnknownScript_0x70f0d: ; 0x70f0d
	faceplayer
	loadfont
	pokemart $0, $001a
	loadmovesprites
	end
; 0x70f15

UnknownScript_0x70f15: ; 0x70f15
	jumptextfaceplayer UnknownText_0x70f21
; 0x70f18

UnknownScript_0x70f18: ; 0x70f18
	jumptextfaceplayer UnknownText_0x70f55
; 0x70f1b

MapCeladonDeptStore4FSignpost0Script: ; 0x70f1b
	jumptext UnknownText_0x70f8c
; 0x70f1e

MapCeladonDeptStore4FSignpost1Script: ; 0x70f1e
	jumpstd $0014
; 0x70f21

UnknownText_0x70f21: ; 0x70f21
	db $0, "I'm here to buy", $4f
	db "SURF MAIL to send", $55
	db "to my girlfriend.", $57
; 0x70f55

UnknownText_0x70f55: ; 0x70f55
	db $0, "This is the only", $4f
	db "place where you", $51
	db "can buy LOVELY", $4f
	db "MAIL.", $57
; 0x70f8c

UnknownText_0x70f8c: ; 0x70f8c
	db $0, "Express Yourself", $4f
	db "With Gifts!", $51
	db "4F: WISEMAN GIFTS", $57
; 0x70fbc

CeladonDeptStore4F_MapEventHeader: ; 0x70fbc
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $c, 1, GROUP_CELADON_DEPT_STORE_5F, MAP_CELADON_DEPT_STORE_5F
	warp_def $0, $f, 2, GROUP_CELADON_DEPT_STORE_3F, MAP_CELADON_DEPT_STORE_3F
	warp_def $0, $2, 1, GROUP_CELADON_DEPT_STORE_ELEVATOR, MAP_CELADON_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapCeladonDeptStore4FSignpost0Script
	signpost 0, 3, $0, MapCeladonDeptStore4FSignpost1Script

	; people-events
	db 3
	person_event $39, 9, 17, $7, $0, 255, 255, $90, 0, UnknownScript_0x70f0d, $ffff
	person_event $2b, 10, 11, $5, $1, 255, 255, $a0, 0, UnknownScript_0x70f15, $ffff
	person_event $27, 6, 12, $7, $0, 255, 255, $0, 0, UnknownScript_0x70f18, $ffff
; 0x71002

CeladonDeptStore5F_MapScriptHeader: ; 0x71002
	; trigger count
	db 0

	; callback count
	db 0
; 0x71004

UnknownScript_0x71004: ; 0x71004
	faceplayer
	loadfont
	pokemart $0, $001b
	loadmovesprites
	end
; 0x7100c

UnknownScript_0x7100c: ; 0x7100c
	faceplayer
	loadfont
	pokemart $0, $001c
	loadmovesprites
	end
; 0x71014

UnknownScript_0x71014: ; 0x71014
	jumptextfaceplayer UnknownText_0x71023
; 0x71017

UnknownScript_0x71017: ; 0x71017
	jumptextfaceplayer UnknownText_0x71072
; 0x7101a

UnknownScript_0x7101a: ; 0x7101a
	jumptextfaceplayer UnknownText_0x710b6
; 0x7101d

MapCeladonDeptStore5FSignpost0Script: ; 0x7101d
	jumptext UnknownText_0x71100
; 0x71020

MapCeladonDeptStore5FSignpost1Script: ; 0x71020
	jumpstd $0014
; 0x71023

UnknownText_0x71023: ; 0x71023
	db $0, "I want to buy some", $4f
	db "items that raise", $51
	db "#MON stats, but", $4f
	db "I don't have", $55
	db "enough money…", $57
; 0x71072

UnknownText_0x71072: ; 0x71072
	db $0, "I want PP UP, so I", $4f
	db "can raise the PP", $51
	db "of moves. But you", $4f
	db "can't buy it…", $57
; 0x710b6

UnknownText_0x710b6: ; 0x710b6
	db $0, "Using items on", $4f
	db "them makes #-", $55
	db "MON happy.", $51
	db "They hate certain", $4f
	db "items, though…", $57
; 0x71100

UnknownText_0x71100: ; 0x71100
	db $0, "5F: DRUG STORE", $57
; 0x71110

CeladonDeptStore5F_MapEventHeader: ; 0x71110
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $c, 1, GROUP_CELADON_DEPT_STORE_4F, MAP_CELADON_DEPT_STORE_4F
	warp_def $0, $f, 1, GROUP_CELADON_DEPT_STORE_6F, MAP_CELADON_DEPT_STORE_6F
	warp_def $0, $2, 1, GROUP_CELADON_DEPT_STORE_ELEVATOR, MAP_CELADON_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 14, $0, MapCeladonDeptStore5FSignpost0Script
	signpost 0, 3, $0, MapCeladonDeptStore5FSignpost1Script

	; people-events
	db 5
	person_event $39, 9, 11, $7, $0, 255, 255, $90, 0, UnknownScript_0x71004, $ffff
	person_event $39, 9, 12, $7, $0, 255, 255, $90, 0, UnknownScript_0x7100c, $ffff
	person_event $40, 9, 17, $2, $11, 255, 255, $80, 0, UnknownScript_0x71014, $ffff
	person_event $49, 8, 7, $2, $11, 255, 255, $90, 0, UnknownScript_0x71017, $ffff
	person_event $29, 11, 5, $9, $0, 255, 255, $a0, 0, UnknownScript_0x7101a, $ffff
; 0x71170

CeladonDeptStore6F_MapScriptHeader: ; 0x71170
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x71175
; 0x71175

UnknownScript_0x71175: ; 0x71175
	changeblock $c, $0, $3
	return
; 0x7117a

UnknownScript_0x7117a: ; 0x7117a
	jumptextfaceplayer UnknownText_0x712c7
; 0x7117d

UnknownScript_0x7117d: ; 0x7117d
	jumptextfaceplayer UnknownText_0x71310
; 0x71180

MapCeladonDeptStore6FSignpost5Script: ; 0x71180
	loadfont
	2writetext UnknownText_0x71250
UnknownScript_0x71184: ; 0x71184
	special $0051
	loadmenudata $5203
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x7119a
	if_equal $2, UnknownScript_0x711b4
	if_equal $3, UnknownScript_0x711ce
	loadmovesprites
	end
; 0x7119a

UnknownScript_0x7119a: ; 0x7119a
	checkmoney $0, 200
	if_equal $2, UnknownScript_0x711f5
	giveitem FRESH_WATER, $1
	iffalse UnknownScript_0x711fc
	takemoney $0, 200
	itemtotext FRESH_WATER, $0
	2jump UnknownScript_0x711e8
; 0x711b4

UnknownScript_0x711b4: ; 0x711b4
	checkmoney $0, 300
	if_equal $2, UnknownScript_0x711f5
	giveitem SODA_POP, $1
	iffalse UnknownScript_0x711fc
	takemoney $0, 300
	itemtotext SODA_POP, $0
	2jump UnknownScript_0x711e8
; 0x711ce

UnknownScript_0x711ce: ; 0x711ce
	checkmoney $0, 350
	if_equal $2, UnknownScript_0x711f5
	giveitem LEMONADE, $1
	iffalse UnknownScript_0x711fc
	takemoney $0, 350
	itemtotext LEMONADE, $0
	2jump UnknownScript_0x711e8
; 0x711e8

UnknownScript_0x711e8: ; 0x711e8
	pause 10
	playsound $001f
	2writetext UnknownText_0x71274
	keeptextopen
	itemnotify
	2jump UnknownScript_0x71184
; 0x711f5

UnknownScript_0x711f5: ; 0x711f5
	2writetext UnknownText_0x7128e
	closetext
	2jump UnknownScript_0x71184
; 0x711fc

UnknownScript_0x711fc: ; 0x711fc
	2writetext UnknownText_0x712a7
	closetext
	2jump UnknownScript_0x71184
; 0x71203

; menu data
INCBIN "baserom.gbc",$71203,$47

MapCeladonDeptStore6FSignpost0Script: ; 0x7124a
	jumptext UnknownText_0x7133e
; 0x7124d

UnknownScript_0x7124d: ; 0x7124d
	jumpstd $0014
; 0x71250

UnknownText_0x71250: ; 0x71250
	db $0, "A vending machine!", $4f
	db "Here's the menu.", $57
; 0x71274

UnknownText_0x71274: ; 0x71274
	db $0, "Clang!", $51
	db "@"
	text_from_ram $d099
	db $0, $4f
	db "popped out.", $57
; 0x7128e

UnknownText_0x7128e: ; 0x7128e
	db $0, "Oops, not enough", $4f
	db "money…", $57
; 0x712a7

UnknownText_0x712a7: ; 0x712a7
	db $0, "There's no more", $4f
	db "room for stuff…", $57
; 0x712c7

UnknownText_0x712c7: ; 0x712c7
	db $0, "A vending machine", $4f
	db "with a prize rou-", $55
	db "lette…", $51
	db "You never see", $4f
	db "those anymore.", $57
; 0x71310

UnknownText_0x71310: ; 0x71310
	db $0, "Aww! There's no", $4f
	db "games here!", $51
	db "I wanted to play…", $57
; 0x7133e

UnknownText_0x7133e: ; 0x7133e
	db $0, "6F: ROOFTOP SQUARE", $4f
	db "VENDING MACHINES", $57
; 0x71363

CeladonDeptStore6F_MapEventHeader: ; 0x71363
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $0, $f, 2, GROUP_CELADON_DEPT_STORE_5F, MAP_CELADON_DEPT_STORE_5F
	warp_def $0, $2, 1, GROUP_CELADON_DEPT_STORE_ELEVATOR, MAP_CELADON_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 0, 14, $0, MapCeladonDeptStore6FSignpost0Script
	signpost 0, 3, $0, MapCeladonDeptStore6FSignpost1Script
	signpost 1, 8, $1, MapCeladonDeptStore6FSignpost5Script
	signpost 1, 9, $1, MapCeladonDeptStore6FSignpost5Script
	signpost 1, 10, $1, MapCeladonDeptStore6FSignpost5Script
	signpost 1, 11, $1, MapCeladonDeptStore6FSignpost5Script

	; people-events
	db 2
	person_event $2b, 6, 13, $7, $0, 255, 255, $0, 0, UnknownScript_0x7117a, $ffff
	person_event $27, 9, 16, $2, $12, 255, 255, $80, 0, UnknownScript_0x7117d, $ffff
; 0x713ab

CeladonDeptStoreElevator_MapScriptHeader: ; 0x713ab
	; trigger count
	db 0

	; callback count
	db 0
; 0x713ad

MapCeladonDeptStoreElevatorSignpost0Script: ; 0x713ad
	loadfont
	elevator $53be
	loadmovesprites
	iffalse UnknownScript_0x713bd
	pause 5
	playsound $006e
	earthquake 60
	waitbutton
UnknownScript_0x713bd: ; 0x713bd
	end
; 0x713be

; elevator
UnknownText_0x713be: ; 0x713be
	text_waitbutton
	text_box $1504, 5, 5
	store_at $615
	text_waitbutton
	store_at $715
	text_dunno2
	store_at $815
	start_asm
; 0x713d0

INCBIN "baserom.gbc",$713d0,$713d8 - $713d0

CeladonDeptStoreElevator_MapEventHeader: ; 0x713d8
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $1, 255, GROUP_CELADON_DEPT_STORE_1F, MAP_CELADON_DEPT_STORE_1F
	warp_def $3, $2, 255, GROUP_CELADON_DEPT_STORE_1F, MAP_CELADON_DEPT_STORE_1F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 0, 3, $0, MapCeladonDeptStoreElevatorSignpost0Script

	; people-events
	db 0
; 0x713ed

CeladonMansion1F_MapScriptHeader: ; 0x713ed
	; trigger count
	db 0

	; callback count
	db 0
; 0x713ef

UnknownScript_0x713ef: ; 0x713ef
	jumptextfaceplayer UnknownText_0x71416
; 0x713f2

UnknownScript_0x713f2: ; 0x713f2
	loadfont
	2writetext UnknownText_0x71470
	cry MEOWTH
	closetext
	loadmovesprites
	end
; 0x713fc

UnknownScript_0x713fc: ; 0x713fc
	loadfont
	2writetext UnknownText_0x7147f
	cry CLEFAIRY
	closetext
	loadmovesprites
	end
; 0x71406

UnknownScript_0x71406: ; 0x71406
	loadfont
	2writetext UnknownText_0x71496
	cry NIDORAN_F
	closetext
	loadmovesprites
	end
; 0x71410

MapCeladonMansion1FSignpost0Script: ; 0x71410
	jumptext UnknownText_0x714ab
; 0x71413

MapCeladonMansion1FSignpost2Script: ; 0x71413
	jumpstd $0002
; 0x71416

UnknownText_0x71416: ; 0x71416
	db $0, "My dear #MON", $4f
	db "keep me company,", $51
	db "so I don't ever", $4f
	db "feel lonely.", $51
	db "MEOWTH even brings", $4f
	db "money home.", $57
; 0x71470

UnknownText_0x71470: ; 0x71470
	db $0, "MEOWTH: Meow!", $57
; 0x7147f

UnknownText_0x7147f: ; 0x7147f
	db $0, "CLEFAIRY: Clef", $4f
	db "cleff!", $57
; 0x71496

UnknownText_0x71496: ; 0x71496
	db $0, "NIDORAN: Kya", $4f
	db "kyaoo!", $57
; 0x714ab

UnknownText_0x714ab: ; 0x714ab
	db $0, "CELADON MANSION", $4f
	db "MANAGER'S SUITE", $57
; 0x714cc

CeladonMansion1F_MapEventHeader: ; 0x714cc
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $9, $6, 2, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $9, $7, 2, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $0, $3, 3, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $0, $0, 1, GROUP_CELADON_MANSION_2F, MAP_CELADON_MANSION_2F
	warp_def $0, $7, 4, GROUP_CELADON_MANSION_2F, MAP_CELADON_MANSION_2F

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 8, 5, $1, MapCeladonMansion1FSignpost0Script
	signpost 3, 0, $0, MapCeladonMansion1FSignpost2Script
	signpost 3, 2, $0, MapCeladonMansion1FSignpost2Script

	; people-events
	db 4
	person_event $30, 9, 5, $3, $0, 255, 255, $0, 0, UnknownScript_0x713ef, $ffff
	person_event $82, 10, 6, $16, $0, 255, 255, $0, 0, UnknownScript_0x713f2, $ffff
	person_event $8f, 8, 7, $16, $0, 255, 255, $0, 0, UnknownScript_0x713fc, $ffff
	person_event $82, 8, 8, $16, $2, 255, 255, $90, 0, UnknownScript_0x71406, $ffff
; 0x7152e

CeladonMansion2F_MapScriptHeader: ; 0x7152e
	; trigger count
	db 0

	; callback count
	db 0
; 0x71530

MapCeladonMansion2FSignpost0Script: ; 0x71530
	jumptext UnknownText_0x71539
; 0x71533

MapCeladonMansion2FSignpost1Script: ; 0x71533
	jumptext UnknownText_0x7162c
; 0x71536

MapCeladonMansion2FSignpost2Script: ; 0x71536
	jumpstd $0001
; 0x71539

UnknownText_0x71539: ; 0x71539
	db $0, $52, " turned on", $4f
	db "the PC.", $51
	db "…", $51
	db "Someone was in the", $4f
	db "middle of compos-", $55
	db "ing an e-mail.", $51
	db "…I hope you'll", $4f
	db "come visit KANTO.", $51
	db "I think you'll be", $4f
	db "surprised at how", $51
	db "much things have", $4f
	db "changed here.", $51
	db "You'll also see", $4f
	db "many #MON that", $51
	db "aren't native to", $4f
	db "JOHTO.", $51
	db "To the PRODUCER", $51
	db "…", $57
; 0x7162c

UnknownText_0x7162c: ; 0x7162c
	db $0, "GAME FREAK", $4f
	db "MEETING ROOM", $57
; 0x71645

CeladonMansion2F_MapEventHeader: ; 0x71645
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $0, 4, GROUP_CELADON_MANSION_1F, MAP_CELADON_MANSION_1F
	warp_def $0, $1, 2, GROUP_CELADON_MANSION_3F, MAP_CELADON_MANSION_3F
	warp_def $0, $6, 3, GROUP_CELADON_MANSION_3F, MAP_CELADON_MANSION_3F
	warp_def $0, $7, 5, GROUP_CELADON_MANSION_1F, MAP_CELADON_MANSION_1F

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 3, 0, $0, MapCeladonMansion2FSignpost0Script
	signpost 8, 5, $1, MapCeladonMansion2FSignpost1Script
	signpost 3, 2, $0, MapCeladonMansion2FSignpost2Script

	; people-events
	db 0
; 0x7166e

CeladonMansion3F_MapScriptHeader: ; 0x7166e
	; trigger count
	db 0

	; callback count
	db 0
; 0x71670

UnknownScript_0x71670: ; 0x71670
	faceplayer
	loadfont
	2writetext UnknownText_0x716ce
	checkcode $5
	if_less_than $f8, UnknownScript_0x7167e
	closetext
	loadmovesprites
	end
; 0x7167e

UnknownScript_0x7167e: ; 0x7167e
	keeptextopen
	2writetext UnknownText_0x71725
	playsound $00a3
	waitbutton
	2writetext UnknownText_0x71760
	keeptextopen
	special $006b
	2writetext UnknownText_0x71763
	closetext
	loadmovesprites
	setbit1 $00d6
	end
; 0x71696

UnknownScript_0x71696: ; 0x71696
	faceplayer
	loadfont
	checkbit1 $00d6
	iftrue UnknownScript_0x716a4
	2writetext UnknownText_0x717b4
	closetext
	loadmovesprites
	end
; 0x716a4

UnknownScript_0x716a4: ; 0x716a4
	2writetext UnknownText_0x717d8
	yesorno
	iffalse UnknownScript_0x716b0
	special $006c
	loadmovesprites
	end
; 0x716b0

UnknownScript_0x716b0: ; 0x716b0
	2writetext UnknownText_0x71830
	closetext
	loadmovesprites
	end
; 0x716b6

UnknownScript_0x716b6: ; 0x716b6
	2writetext UnknownText_0x71863
	closetext
	loadmovesprites
	end
; 0x716bc

UnknownScript_0x716bc: ; 0x716bc
	jumptextfaceplayer UnknownText_0x71895
; 0x716bf

UnknownScript_0x716bf: ; 0x716bf
	jumptextfaceplayer UnknownText_0x718ca
; 0x716c2

MapCeladonMansion3FSignpost0Script: ; 0x716c2
	jumptext UnknownText_0x7190b
; 0x716c5

MapCeladonMansion3FSignpost1Script: ; 0x716c5
	jumptext UnknownText_0x71928
; 0x716c8

MapCeladonMansion3FSignpost2Script: ; 0x716c8
	jumptext UnknownText_0x71952
; 0x716cb

MapCeladonMansion3FSignpost3Script: ; 0x716cb
	jumptext UnknownText_0x71996
; 0x716ce

UnknownText_0x716ce: ; 0x716ce
	db $0, "Is that right?", $51
	db "I'm the GAME", $4f
	db "DESIGNER!", $51
	db "Filling up your", $4f
	db "#DEX is tough,", $55
	db "but don't give up!", $57
; 0x71725

UnknownText_0x71725: ; 0x71725
	db $0, "Wow! Excellent!", $4f
	db "You completed your", $55
	db "#DEX!", $51
	db "Congratulations!", $57
; 0x71760

UnknownText_0x71760: ; 0x71760
	db $0, "…", $57
; 0x71763

UnknownText_0x71763: ; 0x71763
	db $0, "The GRAPHIC ARTIST", $4f
	db "will print out a", $55
	db "DIPLOMA for you.", $51
	db "You should go show", $4f
	db "it off.", $57
; 0x717b4

UnknownText_0x717b4: ; 0x717b4
	db $0, "I'm the GRAPHIC", $4f
	db "ARTIST.", $51
	db "I drew you!", $57
; 0x717d8

UnknownText_0x717d8: ; 0x717d8
	db $0, "I'm the GRAPHIC", $4f
	db "ARTIST.", $51
	db "Oh, you completed", $4f
	db "your #DEX?", $51
	db "Want me to print", $4f
	db "out your DIPLOMA?", $57
; 0x71830

UnknownText_0x71830: ; 0x71830
	db $0, "Give me a shout if", $4f
	db "you want your", $55
	db "DIPLOMA printed.", $57
; 0x71863

UnknownText_0x71863: ; 0x71863
	db $0, "Something's wrong.", $4f
	db "I'll have to can-", $55
	db "cel printing.", $57
; 0x71895

UnknownText_0x71895: ; 0x71895
	db $0, "Who, me? I'm the", $4f
	db "PROGRAMMER.", $51
	db "Play the slot", $4f
	db "machines!", $57
; 0x718ca

UnknownText_0x718ca: ; 0x718ca
	db $0, "Aren't the TWINS", $4f
	db "adorable?", $51
	db "JASMINE's pretty", $4f
	db "too.", $51
	db "Oh, I love them!", $57
; 0x7190b

UnknownText_0x7190b: ; 0x7190b
	db $0, "GAME FREAK", $4f
	db "DEVELOPMENT ROOM", $57
; 0x71928

UnknownText_0x71928: ; 0x71928
	db $0, "It's a detailed", $4f
	db "drawing of a", $55
	db "pretty girl.", $57
; 0x71952

UnknownText_0x71952: ; 0x71952
	db $0, "It's the game", $4f
	db "program. Messing", $51
	db "with it could put", $4f
	db "a bug in the game!", $57
; 0x71996

UnknownText_0x71996: ; 0x71996
	db $0, "It's crammed with", $4f
	db "reference materi-", $55
	db "als. There's even", $55
	db "a # DOLL.", $57
; 0x719d5

CeladonMansion3F_MapEventHeader: ; 0x719d5
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $0, 1, GROUP_CELADON_MANSION_ROOF, MAP_CELADON_MANSION_ROOF
	warp_def $0, $1, 2, GROUP_CELADON_MANSION_2F, MAP_CELADON_MANSION_2F
	warp_def $0, $6, 3, GROUP_CELADON_MANSION_2F, MAP_CELADON_MANSION_2F
	warp_def $0, $7, 2, GROUP_CELADON_MANSION_ROOF, MAP_CELADON_MANSION_ROOF

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 8, 5, $1, MapCeladonMansion3FSignpost0Script
	signpost 3, 4, $1, MapCeladonMansion3FSignpost1Script
	signpost 6, 1, $1, MapCeladonMansion3FSignpost2Script
	signpost 3, 1, $1, MapCeladonMansion3FSignpost3Script

	; people-events
	db 4
	person_event $23, 10, 7, $3, $0, 255, 255, $80, 0, UnknownScript_0x71670, $ffff
	person_event $48, 8, 7, $7, $0, 255, 255, $90, 0, UnknownScript_0x71696, $ffff
	person_event $2b, 11, 4, $7, $0, 255, 255, $90, 0, UnknownScript_0x716bc, $ffff
	person_event $3a, 8, 4, $7, $2, 255, 255, $80, 0, UnknownScript_0x716bf, $ffff
; 0x71a37

CeladonMansionRoof_MapScriptHeader: ; 0x71a37
	; trigger count
	db 0

	; callback count
	db 0
; 0x71a39

UnknownScript_0x71a39: ; 0x71a39
	jumptextfaceplayer UnknownText_0x71a3f
; 0x71a3c

MapCeladonMansionRoofSignpost0Script: ; 0x71a3c
	jumptext UnknownText_0x71aa1
; 0x71a3f

UnknownText_0x71a3f: ; 0x71a3f
	db $0, "High places--I do", $4f
	db "love them so!", $51
	db "I'd say the only", $4f
	db "thing that loves", $51
	db "heights as much as", $4f
	db "me is smoke!", $57
; 0x71aa1

UnknownText_0x71aa1: ; 0x71aa1
	db $0, "There's graffiti", $4f
	db "on the wall…", $51
	db $52, " added a", $4f
	db "moustache!", $57
; 0x71ad4

CeladonMansionRoof_MapEventHeader: ; 0x71ad4
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $1, $1, 1, GROUP_CELADON_MANSION_3F, MAP_CELADON_MANSION_3F
	warp_def $1, $6, 4, GROUP_CELADON_MANSION_3F, MAP_CELADON_MANSION_3F
	warp_def $5, $2, 1, GROUP_CELADON_MANSION_ROOF_HOUSE, MAP_CELADON_MANSION_ROOF_HOUSE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 1, 6, $4, MapCeladonMansionRoofSignpost0Script

	; people-events
	db 1
	person_event $3a, 9, 11, $4, $10, 255, 255, $90, 0, UnknownScript_0x71a39, $ffff
; 0x71afb

CeladonMansionRoofHouse_MapScriptHeader: ; 0x71afb
	; trigger count
	db 0

	; callback count
	db 0
; 0x71afd

UnknownScript_0x71afd: ; 0x71afd
	faceplayer
	loadfont
	checkbit1 $00da
	iftrue UnknownScript_0x71b21
	2writetext UnknownText_0x71b27
	keeptextopen
	checktime $4
	iftrue UnknownScript_0x71b14
	2writetext UnknownText_0x71b4a
	closetext
	loadmovesprites
	end
; 0x71b14

UnknownScript_0x71b14: ; 0x71b14
	2writetext UnknownText_0x71ba3
	keeptextopen
	verbosegiveitem TM_03, 1
	iffalse UnknownScript_0x71b25
	setbit1 $00da
UnknownScript_0x71b21: ; 0x71b21
	2writetext UnknownText_0x71db3
	closetext
UnknownScript_0x71b25: ; 0x71b25
	loadmovesprites
	end
; 0x71b27

UnknownText_0x71b27: ; 0x71b27
	db $0, "Let me recount a", $4f
	db "terrifying tale…", $57
; 0x71b4a

UnknownText_0x71b4a: ; 0x71b4a
	db $0, "Then again, it's", $4f
	db "not as scary while", $51
	db "it's still light", $4f
	db "outside.", $51
	db "Come back after", $4f
	db "sunset, OK?", $57
; 0x71ba3

UnknownText_0x71ba3: ; 0x71ba3
	db $0, "Once upon a time,", $4f
	db "there was a little", $51
	db "boy who was given", $4f
	db "a new BICYCLE…", $51
	db "He wanted to try", $4f
	db "it right away…", $51
	db "He was having so", $4f
	db "much fun that he", $51
	db "didn't notice the", $4f
	db "sun had set…", $51
	db "While riding home", $4f
	db "in the pitch-black", $51
	db "night, the bike", $4f
	db "suddenly slowed!", $51
	db "The pedals became", $4f
	db "heavy!", $51
	db "When he stopped", $4f
	db "pedaling, the bike", $51
	db "began slipping", $4f
	db "backwards!", $51
	db "It was as if the", $4f
	db "bike were cursed", $51
	db "and trying to drag", $4f
	db "him into oblivion!", $51
	db "…", $51
	db "…", $51
	db "SHRIEEEEK!", $51
	db "The boy had been", $4f
	db "riding uphill on", $55
	db "CYCLING ROAD!", $51
	db "…", $4f
	db "Ba-dum ba-dum!", $51
	db "For listening so", $4f
	db "patiently, you may", $55
	db "take this--TM03!", $57
; 0x71db3

UnknownText_0x71db3: ; 0x71db3
	db $0, "TM03 is CURSE.", $51
	db "It's a terrifying", $4f
	db "move that slowly", $51
	db "whittles down the", $4f
	db "victim's HP.", $57
; 0x71e03

CeladonMansionRoofHouse_MapEventHeader: ; 0x71e03
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_CELADON_MANSION_ROOF, MAP_CELADON_MANSION_ROOF
	warp_def $7, $3, 3, GROUP_CELADON_MANSION_ROOF, MAP_CELADON_MANSION_ROOF

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $4b, 6, 7, $6, $20, 255, 255, $a0, 0, UnknownScript_0x71afd, $ffff
; 0x71e20

CeladonPokeCenter1F_MapScriptHeader: ; 0x71e20
	; trigger count
	db 0

	; callback count
	db 0
; 0x71e22

UnknownScript_0x71e22: ; 0x71e22
	jumpstd $0000
; 0x71e25

UnknownScript_0x71e25: ; 0x71e25
	jumpstd $0033
; 0x71e28

UnknownScript_0x71e28: ; 0x71e28
	jumptextfaceplayer UnknownText_0x71e70
; 0x71e2b

UnknownScript_0x71e2b: ; 0x71e2b
	jumptextfaceplayer UnknownText_0x71ec1
; 0x71e2e

UnknownScript_0x71e2e: ; 0x71e2e
	faceplayer
	loadfont
	2writetext UnknownText_0x71f22
	keeptextopen
	writebyte SUICUNE
	special $0097
	iffalse UnknownScript_0x71e46
	special $0096
	iftrue UnknownScript_0x71e48
	2writetext UnknownText_0x7201a
	closetext
UnknownScript_0x71e46: ; 0x71e46
	loadmovesprites
	end
; 0x71e48

UnknownScript_0x71e48: ; 0x71e48
	2writetext UnknownText_0x71f65
	closetext
	loadmovesprites
	checkcode $9
	if_equal $1, UnknownScript_0x71e5a
	applymovement $6, MovementData_0x71e6b
	2jump UnknownScript_0x71e5e
; 0x71e5a

UnknownScript_0x71e5a: ; 0x71e5a
	applymovement $6, MovementData_0x71e65
UnknownScript_0x71e5e: ; 0x71e5e
	disappear $6
	playsound $0023
	waitbutton
	end
; 0x71e65

MovementData_0x71e65: ; 0x71e65
	step_left
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x71e6b

MovementData_0x71e6b: ; 0x71e6b
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x71e70

UnknownText_0x71e70: ; 0x71e70
	db $0, "ERIKA is a master", $4f
	db "of grass #MON.", $51
	db "She'll make you", $4f
	db "pay if you don't", $55
	db "watch yourself.", $57
; 0x71ec1

UnknownText_0x71ec1: ; 0x71ec1
	db $0, "TEAM ROCKET's", $4f
	db "hideout is in the", $51
	db "basement of the", $4f
	db "GAME CORNER.", $51
	db "Oh, wait. That was", $4f
	db "three years ago.", $57
; 0x71f22

UnknownText_0x71f22: ; 0x71f22
	db $0, "EUSINE: Hi!", $51
	db "I'm back visiting", $4f
	db "my hometown.", $51
	db "It's been quite a", $4f
	db "while.", $57
; 0x71f65

UnknownText_0x71f65: ; 0x71f65
	db $0, $52, ", have you", $4f
	db "heard?", $51
	db "There have been", $4f
	db "fresh rumors of a", $51
	db "rainbow-colored", $4f
	db "#MON appearing", $55
	db "at TIN TOWER.", $51
	db "I've just had my", $4f
	db "party healed, so", $51
	db "now I'm headed to", $4f
	db "ECRUTEAK.", $51
	db "I'll be seeing", $4f
	db "you, ", $52, "!", $57
; 0x7201a

UnknownText_0x7201a: ; 0x7201a
	db $0, "Oh, by the way,", $4f
	db $52, ".", $51
	db "Have you caught", $4f
	db "the legendary", $51
	db "#MON RAIKOU and", $4f
	db "ENTEI?", $51
	db $56, $56, $56, $51
	db "Okay…", $51
	db "If you catch even", $4f
	db "one, I hope that", $55
	db "you'll inform me.", $51
	db "I'm counting on", $4f
	db "you, ", $52, "!", $57
; 0x720b8

CeladonPokeCenter1F_MapEventHeader: ; 0x720b8
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 5, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $7, $4, 5, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 5
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x71e22, $ffff
	person_event $40, 9, 5, $5, $1, 255, 255, $0, 0, UnknownScript_0x71e25, $ffff
	person_event $4b, 7, 4, $6, $0, 255, 255, $80, 0, UnknownScript_0x71e2b, $ffff
	person_event $24, 10, 12, $5, $1, 255, 255, $a0, 0, UnknownScript_0x71e28, $ffff
	person_event $2b, 7, 8, $6, $0, 255, 255, $90, 0, UnknownScript_0x71e2e, $07b7
; 0x7210e

CeladonPokeCenter2FBeta_MapScriptHeader: ; 0x7210e
	; trigger count
	db 0

	; callback count
	db 0
; 0x72110

CeladonPokeCenter2FBeta_MapEventHeader: ; 0x72110
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 3, GROUP_CELADON_POKECENTER_1F, MAP_CELADON_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x7211b

CeladonGameCorner_MapScriptHeader: ; 0x7211b
	; trigger count
	db 0

	; callback count
	db 0
; 0x7211d

UnknownScript_0x7211d: ; 0x7211d
	jumpstd $0032
; 0x72120

UnknownScript_0x72120: ; 0x72120
	jumptextfaceplayer UnknownText_0x721d0
; 0x72123

UnknownScript_0x72123: ; 0x72123
	faceplayer
	loadfont
	2writetext UnknownText_0x72215
	closetext
	loadmovesprites
	spriteface $4, $2
	end
; 0x7212e

UnknownScript_0x7212e: ; 0x7212e
	faceplayer
	loadfont
	2writetext UnknownText_0x72242
	closetext
	loadmovesprites
	spriteface $5, $3
	end
; 0x72139

UnknownScript_0x72139: ; 0x72139
	faceplayer
	loadfont
	2writetext UnknownText_0x72295
	closetext
	loadmovesprites
	spriteface $6, $3
	end
; 0x72144

UnknownScript_0x72144: ; 0x72144
	faceplayer
	loadfont
	checkbit1 $00ce
	iftrue UnknownScript_0x72169
	2writetext UnknownText_0x722dc
	keeptextopen
	checkitem COIN_CASE
	iffalse UnknownScript_0x7217b
	checkcoins 9998
	if_equal $0, UnknownScript_0x72184
	stringtotext $6176, $1
	2call UnknownScript_0x72172
	givecoins 18
	setbit1 $00ce
UnknownScript_0x72169: ; 0x72169
	2writetext UnknownText_0x72345
	closetext
	loadmovesprites
	spriteface $fe, $2
	end
; 0x72172

UnknownScript_0x72172: ; 0x72172
	jumpstd $002f
	end
; 0x72176

UnknownRawText_0x72176: ; 0x72176
	db "COIN@"
; 0x7217b

UnknownScript_0x7217b: ; 0x7217b
	2writetext UnknownText_0x7238a
	closetext
	loadmovesprites
	spriteface $fe, $2
	end
; 0x72184

UnknownScript_0x72184: ; 0x72184
	2writetext UnknownText_0x723d9
	closetext
	loadmovesprites
	spriteface $fe, $2
	end
; 0x7218d

CeladonGymGuyScript: ; 0x7218d
	jumptextfaceplayer CeladonGymGuyText
; 0x72190

UnknownScript_0x72190: ; 0x72190
	faceplayer
	loadfont
	2writetext UnknownText_0x724ad
	closetext
	loadmovesprites
	spriteface $a, $2
	end
; 0x7219b

MapCeladonGameCornerSignpost36Script: ; 0x7219b
	jumptext UnknownText_0x724f3
; 0x7219e

MapCeladonGameCornerSignpost37Script: ; 0x7219e
	jumptext UnknownText_0x72521
; 0x721a1

MapCeladonGameCornerSignpost35Script: ; 0x721a1
	random $6
	if_equal $0, MapCeladonGameCornerSignpost16Script
	refreshscreen $0
	writebyte $0
	special $002a
	loadmovesprites
	end
; 0x721b0

MapCeladonGameCornerSignpost16Script: ; 0x721b0
	refreshscreen $0
	writebyte $1
	special $002a
	loadmovesprites
	end
; 0x721b9

MapCeladonGameCornerSignpost11Script: ; 0x721b9
	refreshscreen $0
	special $002b
	loadmovesprites
	end
; 0x721c0

MapCeladonGameCornerSignpost32Script: ; 0x721c0
	jumptext UnknownText_0x7254f
; 0x721c3

MapCeladonGameCornerSignpost9Script: ; 0x721c3
	loadfont
	2writetext UnknownText_0x72567
	closetext
	special $002b
	loadmovesprites
	end
; 0x721cd

INCBIN "baserom.gbc",$721cd,$721d0 - $721cd

UnknownText_0x721d0: ; 0x721d0
	db $0, "Welcome!", $51
	db "You may exchange", $4f
	db "your coins for", $51
	db "fabulous prizes", $4f
	db "next door.", $57
; 0x72215

UnknownText_0x72215: ; 0x72215
	db $0, "The slot machines", $4f
	db "are all state of", $55
	db "the art.", $57
; 0x72242

UnknownText_0x72242: ; 0x72242
	db $0, "It's this machine", $4f
	db "I want.", $51
	db "It cleaned me out", $4f
	db "yesterday, so it", $51
	db "should pay out", $4f
	db "today.", $57
; 0x72295

UnknownText_0x72295: ; 0x72295
	db $0, "I think this slot", $4f
	db "machine will pay", $55
	db "out…", $51
	db "The odds vary", $4f
	db "among machines.", $57
; 0x722dc

UnknownText_0x722dc: ; 0x722dc
	db $0, "Gahahaha!", $51
	db "The coins just", $4f
	db "keep popping out!", $51
	db "Hm? What, kid? You", $4f
	db "want to play?", $51
	db "I'll share my luck", $4f
	db "with you!", $57
; 0x72345

UnknownText_0x72345: ; 0x72345
	db $0, "Gahahaha!", $51
	db "It makes me feel", $4f
	db "good to do nice", $51
	db "things for other", $4f
	db "people!", $57
; 0x7238a

UnknownText_0x7238a: ; 0x7238a
	db $0, "Hey, you don't", $4f
	db "have a COIN CASE.", $51
	db "How am I supposed", $4f
	db "to give you any", $55
	db "coins, kid?", $57
; 0x723d9

UnknownText_0x723d9: ; 0x723d9
	db $0, "Hey, your COIN", $4f
	db "CASE is full, kid.", $51
	db "You must be riding", $4f
	db "a winning streak", $55
	db "too.", $57
; 0x72425

CeladonGymGuyText: ; 0x72425
	db $0, "Hey! CHAMP in", $4f
	db "making!", $51
	db "Are you playing", $4f
	db "the slots too?", $51
	db "I'm trying to get", $4f
	db "enough coins for a", $55
	db "prize #MON.", $51
	db "But I don't have", $4f
	db "enough coins yet…", $57
; 0x724ad

UnknownText_0x724ad: ; 0x724ad
	db $0, "Hmmm… The odds are", $4f
	db "surely better for", $51
	db "PIKACHU's line,", $4f
	db "but… What to do?", $57
; 0x724f3

UnknownText_0x724f3: ; 0x724f3
	db $0, "Hey!", $51
	db "Underneath this", $4f
	db "poster…", $51
	db "There's nothing!", $57
; 0x72521

UnknownText_0x72521: ; 0x72521
	db $0, "Hey!", $51
	db "Underneath this", $4f
	db "poster…", $51
	db "There's nothing!", $57
; 0x7254f

UnknownText_0x7254f: ; 0x7254f
	db $0, "There's a lighter", $4f
	db "here.", $57
; 0x72567

UnknownText_0x72567: ; 0x72567
	db $0, "A can of soda…", $51
	db "Someone must be", $4f
	db "coming back…", $51
	db "Huh? It's empty!", $57
; 0x725a4

CeladonGameCorner_MapEventHeader: ; 0x725a4
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $d, $e, 6, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $d, $f, 6, GROUP_CELADON_CITY, MAP_CELADON_CITY

	; xy triggers
	db 0

	; signposts
	db 38
	signpost 6, 1, $0, MapCeladonGameCornerSignpost11Script
	signpost 7, 1, $0, MapCeladonGameCornerSignpost11Script
	signpost 8, 1, $0, MapCeladonGameCornerSignpost11Script
	signpost 9, 1, $0, MapCeladonGameCornerSignpost11Script
	signpost 10, 1, $0, MapCeladonGameCornerSignpost11Script
	signpost 11, 1, $4, MapCeladonGameCornerSignpost11Script
	signpost 6, 6, $0, MapCeladonGameCornerSignpost11Script
	signpost 7, 6, $0, MapCeladonGameCornerSignpost11Script
	signpost 8, 6, $0, MapCeladonGameCornerSignpost11Script
	signpost 9, 6, $0, MapCeladonGameCornerSignpost9Script
	signpost 10, 6, $0, MapCeladonGameCornerSignpost11Script
	signpost 11, 6, $3, MapCeladonGameCornerSignpost11Script
	signpost 6, 7, $0, MapCeladonGameCornerSignpost35Script
	signpost 7, 7, $0, MapCeladonGameCornerSignpost35Script
	signpost 8, 7, $0, MapCeladonGameCornerSignpost35Script
	signpost 9, 7, $0, MapCeladonGameCornerSignpost35Script
	signpost 10, 7, $0, MapCeladonGameCornerSignpost16Script
	signpost 11, 7, $4, MapCeladonGameCornerSignpost35Script
	signpost 6, 12, $0, MapCeladonGameCornerSignpost35Script
	signpost 7, 12, $0, MapCeladonGameCornerSignpost35Script
	signpost 8, 12, $0, MapCeladonGameCornerSignpost35Script
	signpost 9, 12, $0, MapCeladonGameCornerSignpost35Script
	signpost 10, 12, $0, MapCeladonGameCornerSignpost35Script
	signpost 11, 12, $3, MapCeladonGameCornerSignpost35Script
	signpost 6, 13, $0, MapCeladonGameCornerSignpost35Script
	signpost 7, 13, $0, MapCeladonGameCornerSignpost35Script
	signpost 8, 13, $0, MapCeladonGameCornerSignpost35Script
	signpost 9, 13, $0, MapCeladonGameCornerSignpost35Script
	signpost 10, 13, $0, MapCeladonGameCornerSignpost35Script
	signpost 11, 13, $4, MapCeladonGameCornerSignpost35Script
	signpost 6, 18, $0, MapCeladonGameCornerSignpost35Script
	signpost 7, 18, $0, MapCeladonGameCornerSignpost35Script
	signpost 8, 18, $0, MapCeladonGameCornerSignpost32Script
	signpost 9, 18, $0, MapCeladonGameCornerSignpost35Script
	signpost 10, 18, $0, MapCeladonGameCornerSignpost35Script
	signpost 11, 18, $3, MapCeladonGameCornerSignpost35Script
	signpost 0, 15, $0, MapCeladonGameCornerSignpost36Script
	signpost 0, 9, $0, MapCeladonGameCornerSignpost37Script

	; people-events
	db 9
	person_event $39, 6, 9, $6, $0, 255, 255, $a0, 0, UnknownScript_0x7211d, $ffff
	person_event $42, 6, 7, $6, $0, 255, 255, $a0, 0, UnknownScript_0x72120, $ffff
	person_event $2d, 14, 18, $8, $0, 255, 255, $80, 0, UnknownScript_0x72123, $ffff
	person_event $29, 11, 21, $9, $0, 255, 255, $90, 0, UnknownScript_0x7212e, $ffff
	person_event $3b, 11, 15, $9, $0, 255, 255, $a0, 0, UnknownScript_0x72139, $ffff
	person_event $3a, 14, 12, $8, $0, 255, 2, $80, 0, UnknownScript_0x72144, $ffff
	person_event $3a, 14, 12, $8, $0, 255, 4, $80, 0, UnknownScript_0x72144, $ffff
	person_event $48, 7, 15, $6, $0, 255, 255, $80, 0, CeladonGymGuyScript, $ffff
	person_event $2f, 12, 6, $8, $0, 255, 255, $a0, 0, UnknownScript_0x72190, $ffff
; 0x726e7

CeladonGameCornerPrizeRoom_MapScriptHeader: ; 0x726e7
	; trigger count
	db 0

	; callback count
	db 0
; 0x726e9

UnknownScript_0x726e9: ; 0x726e9
	jumptextfaceplayer UnknownText_0x728b8
; 0x726ec

UnknownScript_0x726ec: ; 0x726ec
	jumptextfaceplayer UnknownText_0x728e9
; 0x726ef

MapCeladonGameCornerPrizeRoomSignpost0Script: ; 0x726ef
	faceplayer
	loadfont
	2writetext UnknownText_0x7293e
	closetext
	checkitem COIN_CASE
	iffalse UnknownScript_0x7278a
	2writetext UnknownText_0x72974
UnknownScript_0x726fd: ; 0x726fd
	special $004f
	loadmenudata $6790
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x72714
	if_equal $2, UnknownScript_0x72730
	if_equal $3, UnknownScript_0x7274c
	2jump UnknownScript_0x72784
; 0x72714

UnknownScript_0x72714: ; 0x72714
	checkcoins 1500
	if_equal $2, UnknownScript_0x72778
	itemtotext TM_32, $0
	2call UnknownScript_0x72768
	iffalse UnknownScript_0x72784
	giveitem TM_32, $1
	iffalse UnknownScript_0x7277e
	takecoins 1500
	2jump UnknownScript_0x7276d
; 0x72730

UnknownScript_0x72730: ; 0x72730
	checkcoins 3500
	if_equal $2, UnknownScript_0x72778
	itemtotext TM_29, $0
	2call UnknownScript_0x72768
	iffalse UnknownScript_0x72784
	giveitem TM_29, $1
	iffalse UnknownScript_0x7277e
	takecoins 3500
	2jump UnknownScript_0x7276d
; 0x7274c

UnknownScript_0x7274c: ; 0x7274c
	checkcoins 7500
	if_equal $2, UnknownScript_0x72778
	itemtotext TM_15, $0
	2call UnknownScript_0x72768
	iffalse UnknownScript_0x72784
	giveitem TM_15, $1
	iffalse UnknownScript_0x7277e
	takecoins 7500
	2jump UnknownScript_0x7276d
; 0x72768

UnknownScript_0x72768: ; 0x72768
	2writetext UnknownText_0x72991
	yesorno
	end
; 0x7276d

UnknownScript_0x7276d: ; 0x7276d
	waitbutton
	playsound $0022
	2writetext UnknownText_0x729ad
	closetext
	2jump UnknownScript_0x726fd
; 0x72778

UnknownScript_0x72778: ; 0x72778
	2writetext UnknownText_0x729bb
	closetext
	loadmovesprites
	end
; 0x7277e

UnknownScript_0x7277e: ; 0x7277e
	2writetext UnknownText_0x729d8
	closetext
	loadmovesprites
	end
; 0x72784

UnknownScript_0x72784: ; 0x72784
	2writetext UnknownText_0x729f2
	closetext
	loadmovesprites
	end
; 0x7278a

UnknownScript_0x7278a: ; 0x7278a
	2writetext UnknownText_0x72a14
	closetext
	loadmovesprites
	end
; 0x72790

; menu data
INCBIN "baserom.gbc",$72790,$38

MapCeladonGameCornerPrizeRoomSignpost1Script: ; 0x727c8
	faceplayer
	loadfont
	2writetext UnknownText_0x7293e
	closetext
	checkitem COIN_CASE
	iffalse UnknownScript_0x7278a
UnknownScript_0x727d3: ; 0x727d3
	2writetext UnknownText_0x72974
	special $004f
	loadmenudata $6877
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x727ed
	if_equal $2, UnknownScript_0x7281b
	if_equal $3, UnknownScript_0x72849
	2jump UnknownScript_0x72784
; 0x727ed

UnknownScript_0x727ed: ; 0x727ed
	checkcoins 2222
	if_equal $2, UnknownScript_0x72778
	checkcode $1
	if_equal $6, UnknownScript_0x7277e
	pokenamemem PIKACHU, $0
	2call UnknownScript_0x72768
	iffalse UnknownScript_0x72784
	waitbutton
	playsound $0022
	2writetext UnknownText_0x729ad
	closetext
	writebyte PIKACHU
	special $0039
	givepoke PIKACHU, 25, 0, 0
	takecoins 2222
	2jump UnknownScript_0x727d3
; 0x7281b

UnknownScript_0x7281b: ; 0x7281b
	checkcoins 5555
	if_equal $2, UnknownScript_0x72778
	checkcode $1
	if_equal $6, UnknownScript_0x7277e
	pokenamemem PORYGON, $0
	2call UnknownScript_0x72768
	iffalse UnknownScript_0x72784
	waitbutton
	playsound $0022
	2writetext UnknownText_0x729ad
	closetext
	writebyte PORYGON
	special $0039
	givepoke PORYGON, 15, 0, 0
	takecoins 5555
	2jump UnknownScript_0x727d3
; 0x72849

UnknownScript_0x72849: ; 0x72849
	checkcoins 8888
	if_equal $2, UnknownScript_0x72778
	checkcode $1
	if_equal $6, UnknownScript_0x7277e
	pokenamemem LARVITAR, $0
	2call UnknownScript_0x72768
	iffalse UnknownScript_0x72784
	waitbutton
	playsound $0022
	2writetext UnknownText_0x729ad
	closetext
	writebyte LARVITAR
	special $0039
	givepoke LARVITAR, 40, 0, 0
	takecoins 8888
	2jump UnknownScript_0x727d3
; 0x72877

; menu data
INCBIN "baserom.gbc",$72877,$41

UnknownText_0x728b8: ; 0x728b8
	db $0, "I wanted PORYGON,", $4f
	db "but I was short by", $55
	db "100 coins…", $57
; 0x728e9

UnknownText_0x728e9: ; 0x728e9
	db $0, "Whew…", $51
	db "I've got to stay", $4f
	db "calm and cool…", $51
	db "I can't lose my", $4f
	db "cool, or I'll lose", $55
	db "all my money…", $57
; 0x7293e

UnknownText_0x7293e: ; 0x7293e
	db $0, "Welcome!", $51
	db "We exchange your", $4f
	db "coins for fabulous", $55
	db "prizes!", $57
; 0x72974

UnknownText_0x72974: ; 0x72974
	db $0, "Which prize would", $4f
	db "you like?", $57
; 0x72991

UnknownText_0x72991: ; 0x72991
	db $0, "OK, so you wanted", $4f
	db "a @"
	text_from_ram $d099
	db $0, "?", $57
; 0x729ad

UnknownText_0x729ad: ; 0x729ad
	db $0, "Here you go!", $57
; 0x729bb

UnknownText_0x729bb: ; 0x729bb
	db $0, "You don't have", $4f
	db "enough coins.", $57
; 0x729d8

UnknownText_0x729d8: ; 0x729d8
	db $0, "You have no room", $4f
	db "for it.", $57
; 0x729f2

UnknownText_0x729f2: ; 0x729f2
	db $0, "Oh. Please come", $4f
	db "back with coins!", $57
; 0x72a14

UnknownText_0x72a14: ; 0x72a14
	db $0, "Oh? You don't have", $4f
	db "a COIN CASE.", $57
; 0x72a34

CeladonGameCornerPrizeRoom_MapEventHeader: ; 0x72a34
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $5, $2, 7, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $5, $3, 7, GROUP_CELADON_CITY, MAP_CELADON_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 2, $0, MapCeladonGameCornerPrizeRoomSignpost0Script
	signpost 1, 4, $0, MapCeladonGameCornerPrizeRoomSignpost1Script

	; people-events
	db 2
	person_event $40, 6, 4, $6, $0, 255, 255, $80, 0, UnknownScript_0x726e9, $ffff
	person_event $4b, 8, 8, $4, $10, 255, 255, $a0, 0, UnknownScript_0x726ec, $ffff
; 0x72a68

CeladonGym_MapScriptHeader: ; 0x72a68
	; trigger count
	db 0

	; callback count
	db 0
; 0x72a6a

UnknownScript_0x72a6a: ; 0x72a6a
	faceplayer
	loadfont
	checkbit2 $0026
	iftrue UnknownScript_0x72a9b
	2writetext UnknownText_0x72b28
	closetext
	loadmovesprites
	winlosstext UnknownText_0x72c3e, $0000
	loadtrainer ERIKA, 1
	startbattle
	returnafterbattle
	setbit1 $04c8
	setbit1 $051d
	setbit1 $0490
	setbit1 $04ba
	setbit1 $0468
	loadfont
	2writetext UnknownText_0x72c96
	playsound $009c
	waitbutton
	setbit2 $0026
UnknownScript_0x72a9b: ; 0x72a9b
	checkbit1 $00dc
	iftrue UnknownScript_0x72aae
	2writetext UnknownText_0x72cb0
	keeptextopen
	verbosegiveitem TM_19, 1
	iffalse UnknownScript_0x72aae
	setbit1 $00dc
UnknownScript_0x72aae: ; 0x72aae
	2writetext UnknownText_0x72d8f
	closetext
	loadmovesprites
	end
; 0x72ab4

TrainerLassMichelle: ; 0x72ab4
	; bit/flag number
	dw $51d

	; trainer group && trainer id
	db LASS, MICHELLE

	; text when seen
	dw LassMichelleSeenText

	; text when trainer beaten
	dw LassMichelleBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw LassMichelleScript
; 0x72ac0

LassMichelleScript: ; 0x72ac0
	talkaftercancel
	loadfont
	2writetext UnknownText_0x72e30
	closetext
	loadmovesprites
	end
; 0x72ac8

TrainerPicnickerTanya: ; 0x72ac8
	; bit/flag number
	dw $490

	; trainer group && trainer id
	db PICNICKER, TANYA

	; text when seen
	dw PicnickerTanyaSeenText

	; text when trainer beaten
	dw PicnickerTanyaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerTanyaScript
; 0x72ad4

PicnickerTanyaScript: ; 0x72ad4
	talkaftercancel
	loadfont
	2writetext UnknownText_0x72e8e
	closetext
	loadmovesprites
	end
; 0x72adc

TrainerBeautyJulia: ; 0x72adc
	; bit/flag number
	dw $4ba

	; trainer group && trainer id
	db BEAUTY, JULIA

	; text when seen
	dw BeautyJuliaSeenText

	; text when trainer beaten
	dw BeautyJuliaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BeautyJuliaScript
; 0x72ae8

BeautyJuliaScript: ; 0x72ae8
	talkaftercancel
	loadfont
	2writetext UnknownText_0x72f01
	closetext
	loadmovesprites
	end
; 0x72af0

TrainerTwinsJoandzoe1: ; 0x72af0
	; bit/flag number
	dw $468

	; trainer group && trainer id
	db TWINS, JOANDZOE1

	; text when seen
	dw TwinsJoandzoe1SeenText

	; text when trainer beaten
	dw TwinsJoandzoe1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TwinsJoandzoe1Script
; 0x72afc

TwinsJoandzoe1Script: ; 0x72afc
	talkaftercancel
	loadfont
	2writetext UnknownText_0x72f70
	closetext
	loadmovesprites
	end
; 0x72b04

TrainerTwinsJoandzoe2: ; 0x72b04
	; bit/flag number
	dw $468

	; trainer group && trainer id
	db TWINS, JOANDZOE2

	; text when seen
	dw TwinsJoandzoe2SeenText

	; text when trainer beaten
	dw TwinsJoandzoe2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TwinsJoandzoe2Script
; 0x72b10

TwinsJoandzoe2Script: ; 0x72b10
	talkaftercancel
	loadfont
	2writetext UnknownText_0x72fc0
	closetext
	loadmovesprites
	end
; 0x72b18

MapCeladonGymSignpost1Script: ; 0x72b18
	checkbit2 $0026
	iftrue UnknownScript_0x72b21
	jumpstd $002d
; 0x72b21

UnknownScript_0x72b21: ; 0x72b21
	trainertotext ERIKA, 1, $1
	jumpstd $002e
; 0x72b28

UnknownText_0x72b28: ; 0x72b28
	db $0, "ERIKA: Hello…", $4f
	db "Lovely weather,", $51
	db "isn't it?", $4f
	db "It's so pleasant…", $51
	db "…I'm afraid I may", $4f
	db "doze off…", $51
	db "My name is ERIKA.", $4f
	db "I am the LEADER of", $55
	db "CELADON GYM.", $51
	db "…Oh? All the way", $4f
	db "from JOHTO, you", $55
	db "say? How nice…", $51
	db "Oh. I'm sorry, I", $4f
	db "didn't realize", $51
	db "that you wished to", $4f
	db "challenge me.", $51
	db "Very well, but I", $4f
	db "shall not lose.", $57
; 0x72c3e

UnknownText_0x72c3e: ; 0x72c3e
	db $0, "ERIKA: Oh!", $4f
	db "I concede defeat…", $51
	db "You are remarkably", $4f
	db "strong…", $51
	db "I shall give you", $4f
	db "RAINBOWBADGE…", $57
; 0x72c96

UnknownText_0x72c96: ; 0x72c96
	db $0, $52, " received", $4f
	db "RAINBOWBADGE.", $57
; 0x72cb0

UnknownText_0x72cb0: ; 0x72cb0
	db $0, "ERIKA: That was a", $4f
	db "delightful match.", $51
	db "I felt inspired.", $4f
	db "Please, I wish you", $55
	db "to have this TM.", $51
	db "It is GIGA DRAIN.", $51
	db "It is a wonderful", $4f
	db "move that drains", $51
	db "half the damage it", $4f
	db "inflicts to heal", $55
	db "your #MON.", $51
	db "Please use it if", $4f
	db "it pleases you…", $57
; 0x72d8f

UnknownText_0x72d8f: ; 0x72d8f
	db $0, "ERIKA: Losing", $4f
	db "leaves a bitter", $55
	db "aftertaste…", $51
	db "But knowing that", $4f
	db "there are strong", $51
	db "trainers spurs me", $4f
	db "to do better…", $57
; 0x72dfc

LassMichelleSeenText: ; 0x72dfc
	db $0, "Do you think a", $4f
	db "girls-only GYM", $55
	db "is rare?", $57
; 0x72e24

LassMichelleBeatenText: ; 0x72e24
	db $0, "Oh, bleah!", $57
; 0x72e30

UnknownText_0x72e30: ; 0x72e30
	db $0, "I just got care-", $4f
	db "less, that's all!", $57
; 0x72e53

PicnickerTanyaSeenText: ; 0x72e53
	db $0, "Oh, a battle?", $4f
	db "That's kind of", $55
	db "scary, but OK!", $57
; 0x72e7f

PicnickerTanyaBeatenText: ; 0x72e7f
	db $0, "Oh, that's it?", $57
; 0x72e8e

UnknownText_0x72e8e: ; 0x72e8e
	db $0, "Oh, look at all", $4f
	db "your BADGES. No", $51
	db "wonder I couldn't", $4f
	db "win!", $57
; 0x72ec5

BeautyJuliaSeenText: ; 0x72ec5
	db $0, "Were you looking", $4f
	db "at these flowers", $55
	db "or at me?", $57
; 0x72ef2

BeautyJuliaBeatenText: ; 0x72ef2
	db $0, "How annoying!", $57
; 0x72f01

UnknownText_0x72f01: ; 0x72f01
	db $0, "How do I go about", $4f
	db "becoming ladylike", $55
	db "like ERIKA?", $57
; 0x72f32

TwinsJoandzoe1SeenText: ; 0x72f32
	db $0, "We'll show you", $4f
	db "#MON moves that", $55
	db "ERIKA taught us!", $57
; 0x72f62

TwinsJoandzoe1BeatenText: ; 0x72f62
	db $0, "Oh… We lost…", $57
; 0x72f70

UnknownText_0x72f70: ; 0x72f70
	db $0, "ERIKA will get you", $4f
	db "back for us!", $57
; 0x72f91

TwinsJoandzoe2SeenText: ; 0x72f91
	db $0, "We're going to", $4f
	db "protect ERIKA!", $57
; 0x72faf

TwinsJoandzoe2BeatenText: ; 0x72faf
	db $0, "We couldn't win…", $57
; 0x72fc0

UnknownText_0x72fc0: ; 0x72fc0
	db $0, "ERIKA is much,", $4f
	db "much stronger!", $57
; 0x72fdf

CeladonGym_MapEventHeader: ; 0x72fdf
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $11, $4, 8, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $11, $5, 8, GROUP_CELADON_CITY, MAP_CELADON_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 15, 3, $0, MapCeladonGymSignpost1Script
	signpost 15, 6, $0, MapCeladonGymSignpost1Script

	; people-events
	db 6
	person_event $20, 7, 9, $6, $0, 255, 255, $a0, 0, UnknownScript_0x72a6a, $ffff
	person_event $28, 12, 11, $8, $0, 255, 255, $92, 2, TrainerLassMichelle, $ffff
	person_event $28, 12, 6, $9, $0, 255, 255, $a2, 2, TrainerPicnickerTanya, $ffff
	person_event $2a, 9, 7, $9, $0, 255, 255, $92, 2, TrainerBeautyJulia, $ffff
	person_event $26, 14, 8, $6, $0, 255, 255, $82, 1, TrainerTwinsJoandzoe1, $ffff
	person_event $26, 14, 9, $6, $0, 255, 255, $82, 1, TrainerTwinsJoandzoe2, $ffff
; 0x73047

CeladonCafe_MapScriptHeader: ; 0x73047
	; trigger count
	db 0

	; callback count
	db 0
; 0x73049

UnknownScript_0x73049: ; 0x73049
	faceplayer
	loadfont
	2writetext UnknownText_0x730de
	closetext
	loadmovesprites
	end
; 0x73051

UnknownScript_0x73051: ; 0x73051
	loadfont
	2writetext UnknownText_0x73129
	closetext
	loadmovesprites
	faceplayer
	loadfont
	2writetext UnknownText_0x7313a
	closetext
	loadmovesprites
	spriteface $3, $2
	end
; 0x73062

UnknownScript_0x73062: ; 0x73062
	loadfont
	2writetext UnknownText_0x7316a
	closetext
	loadmovesprites
	faceplayer
	loadfont
	2writetext UnknownText_0x73178
	closetext
	loadmovesprites
	spriteface $4, $3
	end
; 0x73073

UnknownScript_0x73073: ; 0x73073
	loadfont
	2writetext UnknownText_0x731ae
	closetext
	loadmovesprites
	faceplayer
	loadfont
	2writetext UnknownText_0x731bd
	closetext
	loadmovesprites
	spriteface $5, $3
	end
; 0x73084

UnknownScript_0x73084: ; 0x73084
	checkitem COIN_CASE
	iftrue UnknownScript_0x7309a
	loadfont
	2writetext UnknownText_0x73201
	closetext
	loadmovesprites
	faceplayer
	loadfont
	2writetext UnknownText_0x73212
	closetext
	loadmovesprites
	spriteface $6, $2
	end
; 0x7309a

UnknownScript_0x7309a: ; 0x7309a
	loadfont
	2writetext UnknownText_0x73254
	closetext
	loadmovesprites
	spriteface $6, $3
	loadfont
	2writetext UnknownText_0x73278
	closetext
	loadmovesprites
	spriteface $6, $2
	end
; 0x730ad

MapCeladonCafeSignpost0Script: ; 0x730ad
	jumptext UnknownText_0x73285
; 0x730b0

MapCeladonCafeSignpost1Script: ; 0x730b0
	checkbit1 $00f9
	iftrue UnknownScript_0x730db
	giveitem LEFTOVERS, $1
	iffalse UnknownScript_0x730cd
	loadfont
	itemtotext LEFTOVERS, $0
	2writetext UnknownText_0x732e7
	playsound $0001
	waitbutton
	itemnotify
	loadmovesprites
	setbit1 $00f9
	end
; 0x730cd

UnknownScript_0x730cd: ; 0x730cd
	loadfont
	itemtotext LEFTOVERS, $0
	2writetext UnknownText_0x732e7
	keeptextopen
	2writetext UnknownText_0x732f7
	closetext
	loadmovesprites
	end
; 0x730db

UnknownScript_0x730db: ; 0x730db
	jumpstd $000d
; 0x730de

UnknownText_0x730de: ; 0x730de
	db $0, "Hi!", $51
	db "We're holding an", $4f
	db "eatathon contest.", $51
	db "We can't serve you", $4f
	db "right now. Sorry.", $57
; 0x73129

UnknownText_0x73129: ; 0x73129
	db $0, "…Snarfle, chew…", $57
; 0x7313a

UnknownText_0x7313a: ; 0x7313a
	db $0, "Don't talk to me!", $51
	db "You'll break my", $4f
	db "concentration!", $57
; 0x7316a

UnknownText_0x7316a: ; 0x7316a
	db $0, "…Gulp… Chew…", $57
; 0x73178

UnknownText_0x73178: ; 0x73178
	db $0, "I take quantity", $4f
	db "over quality!", $51
	db "I'm happy when I'm", $4f
	db "full!", $57
; 0x731ae

UnknownText_0x731ae: ; 0x731ae
	db $0, "Munch, munch…", $57
; 0x731bd

UnknownText_0x731bd: ; 0x731bd
	db $0, "The food is good", $4f
	db "here, but GOLDEN-", $55
	db "ROD has the best", $55
	db "food anywhere.", $57
; 0x73201

UnknownText_0x73201: ; 0x73201
	db $0, "Crunch… Crunch…", $57
; 0x73212

UnknownText_0x73212: ; 0x73212
	db $0, "Nobody here will", $4f
	db "give you a COIN", $51
	db "CASE. You should", $4f
	db "look in JOHTO.", $57
; 0x73254

UnknownText_0x73254: ; 0x73254
	db $0, "Crunch… Crunch…", $51
	db "I can keep eating!", $57
; 0x73278

UnknownText_0x73278: ; 0x73278
	db $0, "More, CHEF!", $57
; 0x73285

UnknownText_0x73285: ; 0x73285
	db $0, "Eatathon Contest!", $4f
	db "No time limit!", $51
	db "A battle without", $4f
	db "end! The biggest", $51
	db "muncher gets it", $4f
	db "all for free!", $57
; 0x732e7

UnknownText_0x732e7: ; 0x732e7
	db $0, $52, " found", $4f
	db "@"
	text_from_ram $d099
	db $0, "!", $57
; 0x732f7

UnknownText_0x732f7: ; 0x732f7
	db $0, "But ", $52, " can't", $4f
	db "hold another item…", $57
; 0x73316

CeladonCafe_MapEventHeader: ; 0x73316
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $6, 9, GROUP_CELADON_CITY, MAP_CELADON_CITY
	warp_def $7, $7, 9, GROUP_CELADON_CITY, MAP_CELADON_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 5, $0, MapCeladonCafeSignpost0Script
	signpost 1, 7, $0, MapCeladonCafeSignpost1Script

	; people-events
	db 5
	person_event $2b, 7, 13, $8, $0, 255, 255, $b0, 0, UnknownScript_0x73049, $ffff
	person_event $3a, 10, 8, $8, $0, 255, 255, $0, 0, UnknownScript_0x73051, $ffff
	person_event $3a, 11, 5, $9, $0, 255, 255, $a0, 0, UnknownScript_0x73062, $ffff
	person_event $3a, 6, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x73073, $ffff
	person_event $29, 7, 8, $8, $0, 255, 255, $0, 0, UnknownScript_0x73084, $ffff
; 0x73371

Route16FuchsiaSpeechHouse_MapScriptHeader: ; 0x73371
	; trigger count
	db 0

	; callback count
	db 0
; 0x73373

UnknownScript_0x73373: ; 0x73373
	jumptextfaceplayer UnknownText_0x73379
; 0x73376

MapRoute16FuchsiaSpeechHouseSignpost1Script: ; 0x73376
	jumpstd $0002
; 0x73379

UnknownText_0x73379: ; 0x73379
	db $0, "If you cruise down", $4f
	db "CYCLING ROAD, you", $51
	db "will end up in", $4f
	db "FUCHSIA CITY.", $57
; 0x733bc

Route16FuchsiaSpeechHouse_MapEventHeader: ; 0x733bc
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_ROUTE_16, MAP_ROUTE_16
	warp_def $7, $3, 1, GROUP_ROUTE_16, MAP_ROUTE_16

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapRoute16FuchsiaSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapRoute16FuchsiaSpeechHouseSignpost1Script

	; people-events
	db 1
	person_event $2b, 7, 6, $6, $0, 255, 255, $a0, 0, UnknownScript_0x73373, $ffff
; 0x733e3

Route16Gate_MapScriptHeader: ; 0x733e3
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x733e9, $0000

	; callback count
	db 0
; 0x733e9

UnknownScript_0x733e9: ; 0x733e9
	end
; 0x733ea

UnknownScript_0x733ea: ; 0x733ea
	jumptextfaceplayer UnknownText_0x73408
; 0x733ed

UnknownScript_0x733ed: ; 0x733ed
	checkitem BICYCLE
	iffalse UnknownScript_0x733f3
	end
; 0x733f3

UnknownScript_0x733f3: ; 0x733f3
	showemote $0, $2, 15
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x73496
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x73405
	end
; 0x73405

MovementData_0x73405: ; 0x73405
	step_right
	turn_head_left
	step_end
; 0x73408

UnknownText_0x73408: ; 0x73408
	db $0, "CYCLING ROAD", $4f
	db "starts here.", $51
	db "It's all downhill,", $4f
	db "so it's totally", $55
	db "exhilarating.", $51
	db "It's a great sort", $4f
	db "of feeling that", $51
	db "you can't get from", $4f
	db "a ship or train.", $57
; 0x73496

UnknownText_0x73496: ; 0x73496
	db $0, "Hey! Whoa! Stop!", $51
	db "You can't go out", $4f
	db "on the CYCLING", $51
	db "ROAD without a", $4f
	db "BICYCLE.", $57
; 0x734df

Route16Gate_MapEventHeader: ; 0x734df
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 4, GROUP_ROUTE_16, MAP_ROUTE_16
	warp_def $5, $0, 5, GROUP_ROUTE_16, MAP_ROUTE_16
	warp_def $4, $9, 2, GROUP_ROUTE_16, MAP_ROUTE_16
	warp_def $5, $9, 3, GROUP_ROUTE_16, MAP_ROUTE_16

	; xy triggers
	db 2
	xy_trigger 0, $4, $5, $0, UnknownScript_0x733ed, $0, $0
	xy_trigger 0, $5, $5, $0, UnknownScript_0x733ed, $0, $0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 6, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x733ea, $ffff
; 0x73516

Route7SaffronGate_MapScriptHeader: ; 0x73516
	; trigger count
	db 0

	; callback count
	db 0
; 0x73518

UnknownScript_0x73518: ; 0x73518
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x73526
	2writetext UnknownText_0x7352c
	closetext
	loadmovesprites
	end
; 0x73526

UnknownScript_0x73526: ; 0x73526
	2writetext UnknownText_0x73592
	closetext
	loadmovesprites
	end
; 0x7352c

UnknownText_0x7352c: ; 0x7352c
	db $0, "Did you hear about", $4f
	db "the accident at", $55
	db "the POWER PLANT?", $51
	db "It's located in", $4f
	db "the East, close to", $55
	db "LAVENDER TOWN.", $57
; 0x73592

UnknownText_0x73592: ; 0x73592
	db $0, "I take my GUARD", $4f
	db "job seriously.", $51
	db "Hey! You have a", $4f
	db "#DEX.", $51
	db "OK. You can go", $4f
	db "through.", $57
; 0x735e0

Route7SaffronGate_MapEventHeader: ; 0x735e0
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 1, GROUP_ROUTE_7, MAP_ROUTE_7
	warp_def $5, $0, 2, GROUP_ROUTE_7, MAP_ROUTE_7
	warp_def $4, $9, 10, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $5, $9, 11, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 6, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x73518, $ffff
; 0x73607

Route1718Gate_MapScriptHeader: ; 0x73607
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x7360d, $0000

	; callback count
	db 0
; 0x7360d

UnknownScript_0x7360d: ; 0x7360d
	end
; 0x7360e

UnknownScript_0x7360e: ; 0x7360e
	jumptextfaceplayer UnknownText_0x7362c
; 0x73611

UnknownScript_0x73611: ; 0x73611
	checkitem BICYCLE
	iffalse UnknownScript_0x73617
	end
; 0x73617

UnknownScript_0x73617: ; 0x73617
	showemote $0, $2, 15
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x7364d
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x73629
	end
; 0x73629

MovementData_0x73629: ; 0x73629
	step_right
	turn_head_left
	step_end
; 0x7362c

UnknownText_0x7362c: ; 0x7362c
	db $0, "CYCLING ROAD", $4f
	db "Uphill Starts Here", $57
; 0x7364d

UnknownText_0x7364d: ; 0x7364d
	db $0, "Hang on! Don't you", $4f
	db "have a BICYCLE?", $51
	db "The CYCLING ROAD", $4f
	db "is beyond here.", $51
	db "You have to have a", $4f
	db "BICYCLE to go on.", $57
; 0x736b6

Route1718Gate_MapEventHeader: ; 0x736b6
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 1, GROUP_ROUTE_17, MAP_ROUTE_17
	warp_def $5, $0, 2, GROUP_ROUTE_17, MAP_ROUTE_17
	warp_def $4, $9, 1, GROUP_ROUTE_18, MAP_ROUTE_18
	warp_def $5, $9, 2, GROUP_ROUTE_18, MAP_ROUTE_18

	; xy triggers
	db 2
	xy_trigger 0, $4, $5, $0, UnknownScript_0x73611, $0, $0
	xy_trigger 0, $5, $5, $0, UnknownScript_0x73611, $0, $0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 6, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x7360e, $ffff
; 0x736ed

SECTION "bank1D",DATA,BANK[$1D]

DiglettsCave_MapScriptHeader: ; 0x74000
	; trigger count
	db 0

	; callback count
	db 0
; 0x74002

UnknownScript_0x74002: ; 0x74002
	jumptextfaceplayer UnknownText_0x74008
; 0x74005

MapDiglettsCaveSignpostItem0: ; 0x74005
	dw $00e4
	db MAX_REVIVE
	
; 0x74008

UnknownText_0x74008: ; 0x74008
	db $0, "A bunch of DIGLETT", $4f
	db "popped out of the", $51
	db "ground! That was", $4f
	db "shocking.", $57
; 0x74049

DiglettsCave_MapEventHeader: ; 0x74049
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $21, $3, 10, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $1f, $5, 5, GROUP_DIGLETTS_CAVE, MAP_DIGLETTS_CAVE
	warp_def $5, $f, 5, GROUP_ROUTE_2, MAP_ROUTE_2
	warp_def $3, $11, 6, GROUP_DIGLETTS_CAVE, MAP_DIGLETTS_CAVE
	warp_def $21, $11, 2, GROUP_DIGLETTS_CAVE, MAP_DIGLETTS_CAVE
	warp_def $3, $3, 4, GROUP_DIGLETTS_CAVE, MAP_DIGLETTS_CAVE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 11, 6, $7, MapDiglettsCaveSignpostItem0

	; people-events
	db 1
	person_event $2d, 35, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x74002, $ffff
; 0x7407f

MountMoon_MapScriptHeader: ; 0x7407f
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x74089, $0000
	dw UnknownScript_0x7408d, $0000

	; callback count
	db 0
; 0x74089

UnknownScript_0x74089: ; 0x74089
	priorityjump UnknownScript_0x7408e
	end
; 0x7408d

UnknownScript_0x7408d: ; 0x7408d
	end
; 0x7408e

UnknownScript_0x7408e: ; 0x7408e
	spriteface $0, $3
	showemote $0, $0, 15
	special $006a
	pause 15
	applymovement $2, MovementData_0x740f9
	playmusic $001f
	loadfont
	2writetext UnknownText_0x74105
	closetext
	loadmovesprites
	checkbit1 $001c
	iftrue UnknownScript_0x740c3
	checkbit1 $001d
	iftrue UnknownScript_0x740d3
	winlosstext UnknownText_0x7419d, UnknownText_0x742e0
	setlasttalked $2
	loadtrainer RIVAL2, 3
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x740e3
; 0x740c3

UnknownScript_0x740c3: ; 0x740c3
	winlosstext UnknownText_0x7419d, UnknownText_0x742e0
	setlasttalked $2
	loadtrainer RIVAL2, 1
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x740e3
; 0x740d3

UnknownScript_0x740d3: ; 0x740d3
	winlosstext UnknownText_0x7419d, UnknownText_0x742e0
	setlasttalked $2
	loadtrainer RIVAL2, 2
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x740e3
; 0x740e3

UnknownScript_0x740e3: ; 0x740e3
	playmusic $0020
	loadfont
	2writetext UnknownText_0x741fa
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x740fd
	disappear $2
	dotrigger $1
	setbit1 $0319
	playmapmusic
	end
; 0x740f9

MovementData_0x740f9: ; 0x740f9
	step_left
	step_left
	step_left
	step_end
; 0x740fd

MovementData_0x740fd: ; 0x740fd
	step_right
	step_right
	step_down
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x74105

UnknownText_0x74105: ; 0x74105
	db $0, $56, " ", $56, " ", $56, $51
	db "It's been a while,", $4f
	db $52, ".", $51
	db "…Since I lost to", $4f
	db "you, I thought", $51
	db "about what I was", $4f
	db "lacking with my", $55
	db "#MON…", $51
	db "And we came up", $4f
	db "with an answer.", $51
	db $52, ", now we'll", $4f
	db "show you!", $57
; 0x7419d

UnknownText_0x7419d: ; 0x7419d
	db $0, $56, " ", $56, " ", $56, $51
	db "I thought I raised", $4f
	db "my #MON to be", $51
	db "the best they", $4f
	db "could be…", $51
	db "…But it still ", $4f
	db "wasn't enough…", $57
; 0x741fa

UnknownText_0x741fa: ; 0x741fa
	db $0, $56, " ", $56, " ", $56, $51
	db "…You won, fair", $4f
	db "and square.", $51
	db "I admit it. But", $4f
	db "this isn't the", $55
	db "end.", $51
	db "I'm going to be", $4f
	db "the greatest #-", $55
	db "MON trainer ever.", $51
	db "Because these guys", $4f
	db "are behind me.", $51
	db "…Listen, ", $52, ".", $51
	db "One of these days", $4f
	db "I'm going to prove", $51
	db "how good I am by", $4f
	db "beating you.", $57
; 0x742e0

UnknownText_0x742e0: ; 0x742e0
	db $0, $56, " ", $56, " ", $56, $51
	db "I've repaid my", $4f
	db "debt to you.", $51
	db "With my #MON,", $4f
	db "I'm going to beat", $51
	db "the CHAMPION and", $4f
	db "become the world's", $55
	db "greatest trainer.", $57
; 0x74356

MountMoon_MapEventHeader: ; 0x74356
	; filler
	db 0, 0

	; warps
	db 8
	warp_def $3, $3, 1, GROUP_ROUTE_3, MAP_ROUTE_3
	warp_def $f, $f, 1, GROUP_ROUTE_4, MAP_ROUTE_4
	warp_def $3, $d, 7, GROUP_MOUNT_MOON, MAP_MOUNT_MOON
	warp_def $b, $f, 8, GROUP_MOUNT_MOON, MAP_MOUNT_MOON
	warp_def $5, $19, 1, GROUP_MOUNT_MOON_SQUARE, MAP_MOUNT_MOON_SQUARE
	warp_def $f, $19, 2, GROUP_MOUNT_MOON_SQUARE, MAP_MOUNT_MOON_SQUARE
	warp_def $3, $19, 3, GROUP_MOUNT_MOON, MAP_MOUNT_MOON
	warp_def $d, $19, 4, GROUP_MOUNT_MOON, MAP_MOUNT_MOON

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $4, 7, 11, $8, $0, 255, 255, $0, 0, ObjectEvent, $077a
; 0x74391

Underground_MapScriptHeader: ; 0x74391
	; trigger count
	db 0

	; callback count
	db 0
; 0x74393

MapUndergroundSignpostItem0: ; 0x74393
	dw $00e5
	db FULL_RESTORE
	
; 0x74396

MapUndergroundSignpostItem1: ; 0x74396
	dw $00e6
	db X_SPECIAL
	
; 0x74399

Underground_MapEventHeader: ; 0x74399
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $2, $3, 3, GROUP_ROUTE_5_UNDERGROUND_ENTRANCE, MAP_ROUTE_5_UNDERGROUND_ENTRANCE
	warp_def $18, $3, 3, GROUP_ROUTE_6_UNDERGROUND_ENTRANCE, MAP_ROUTE_6_UNDERGROUND_ENTRANCE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 9, 3, $7, MapUndergroundSignpostItem0
	signpost 19, 1, $7, MapUndergroundSignpostItem1

	; people-events
	db 0
; 0x743b3

RockTunnel1F_MapScriptHeader: ; 0x743b3
	; trigger count
	db 0

	; callback count
	db 0
; 0x743b5

ItemFragment_0x743b5: ; 0x743b5
	db ELIXER, 1
; 0x743b7

ItemFragment_0x743b7: ; 0x743b7
	db TM_47, 1
; 0x743b9

MapRockTunnel1FSignpostItem0: ; 0x743b9
	dw $00e7
	db X_ACCURACY
	
; 0x743bc

MapRockTunnel1FSignpostItem1: ; 0x743bc
	dw $00e8
	db X_DEFEND
	
; 0x743bf

RockTunnel1F_MapEventHeader: ; 0x743bf
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $3, $f, 1, GROUP_ROUTE_9, MAP_ROUTE_9
	warp_def $19, $b, 1, GROUP_ROUTE_10_SOUTH, MAP_ROUTE_10_SOUTH
	warp_def $3, $5, 3, GROUP_ROCK_TUNNEL_B1F, MAP_ROCK_TUNNEL_B1F
	warp_def $9, $f, 2, GROUP_ROCK_TUNNEL_B1F, MAP_ROCK_TUNNEL_B1F
	warp_def $3, $1b, 4, GROUP_ROCK_TUNNEL_B1F, MAP_ROCK_TUNNEL_B1F
	warp_def $d, $1b, 1, GROUP_ROCK_TUNNEL_B1F, MAP_ROCK_TUNNEL_B1F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 4, 24, $7, MapRockTunnel1FSignpostItem0
	signpost 15, 21, $7, MapRockTunnel1FSignpostItem1

	; people-events
	db 2
	person_event $54, 22, 8, $1, $0, 255, 255, $1, 0, ItemFragment_0x743b5, $077e
	person_event $54, 19, 14, $1, $0, 255, 255, $1, 0, ItemFragment_0x743b7, $077f
; 0x74407

RockTunnelB1F_MapScriptHeader: ; 0x74407
	; trigger count
	db 0

	; callback count
	db 0
; 0x74409

ItemFragment_0x74409: ; 0x74409
	db IRON, 1
; 0x7440b

ItemFragment_0x7440b: ; 0x7440b
	db PP_UP, 1
; 0x7440d

ItemFragment_0x7440d: ; 0x7440d
	db REVIVE, 1
; 0x7440f

MapRockTunnelB1FSignpostItem0: ; 0x7440f
	dw $00e9
	db MAX_POTION
	
; 0x74412

RockTunnelB1F_MapEventHeader: ; 0x74412
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $3, $3, 6, GROUP_ROCK_TUNNEL_1F, MAP_ROCK_TUNNEL_1F
	warp_def $9, $11, 4, GROUP_ROCK_TUNNEL_1F, MAP_ROCK_TUNNEL_1F
	warp_def $3, $17, 3, GROUP_ROCK_TUNNEL_1F, MAP_ROCK_TUNNEL_1F
	warp_def $17, $19, 5, GROUP_ROCK_TUNNEL_1F, MAP_ROCK_TUNNEL_1F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 14, 4, $7, MapRockTunnelB1FSignpostItem0

	; people-events
	db 3
	person_event $54, 29, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x74409, $0780
	person_event $54, 21, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x7440b, $0781
	person_event $54, 6, 19, $1, $0, 255, 255, $1, 0, ItemFragment_0x7440d, $0782
; 0x74458

SafariZoneFuchsiaGateBeta_MapScriptHeader: ; 0x74458
	; trigger count
	db 0

	; callback count
	db 0
; 0x7445a

SafariZoneFuchsiaGateBeta_MapEventHeader: ; 0x7445a
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 1, GROUP_SAFARI_ZONE_BETA, MAP_SAFARI_ZONE_BETA
	warp_def $0, $5, 2, GROUP_SAFARI_ZONE_BETA, MAP_SAFARI_ZONE_BETA
	warp_def $7, $4, 7, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $7, $5, 7, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x74474

SafariZoneBeta_MapScriptHeader: ; 0x74474
	; trigger count
	db 0

	; callback count
	db 0
; 0x74476

SafariZoneBeta_MapEventHeader: ; 0x74476
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $17, $9, 1, GROUP_SAFARI_ZONE_FUCHSIA_GATE_BETA, MAP_SAFARI_ZONE_FUCHSIA_GATE_BETA
	warp_def $17, $a, 2, GROUP_SAFARI_ZONE_FUCHSIA_GATE_BETA, MAP_SAFARI_ZONE_FUCHSIA_GATE_BETA

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x74486

VictoryRoad_MapScriptHeader: ; 0x74486
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x74490, $0000
	dw UnknownScript_0x74491, $0000

	; callback count
	db 0
; 0x74490

UnknownScript_0x74490: ; 0x74490
	end
; 0x74491

UnknownScript_0x74491: ; 0x74491
	end
; 0x74492

UnknownScript_0x74492: ; 0x74492
	moveperson $2, $12, $b
	spriteface $0, $0
	showemote $0, $0, 15
	special $006a
	pause 15
	appear $2
	applymovement $2, MovementData_0x74539
	2call UnknownScript_0x744d4
	applymovement $2, MovementData_0x7454c
	disappear $2
	dotrigger $1
	playmapmusic
	end
; 0x744b5

UnknownScript_0x744b5: ; 0x744b5
	spriteface $0, $0
	showemote $0, $0, 15
	special $006a
	pause 15
	appear $2
	applymovement $2, MovementData_0x74542
	2call UnknownScript_0x744d4
	applymovement $2, MovementData_0x74555
	disappear $2
	dotrigger $1
	playmapmusic
	end
; 0x744d4

UnknownScript_0x744d4: ; 0x744d4
	spriteface $0, $0
	playmusic $001f
	loadfont
	2writetext UnknownText_0x7455f
	closetext
	loadmovesprites
	setbit1 $06c2
	checkbit1 $001c
	iftrue UnknownScript_0x744ff
	checkbit1 $001d
	iftrue UnknownScript_0x7450f
	winlosstext UnknownText_0x7463d, UnknownText_0x747aa
	setlasttalked $2
	loadtrainer RIVAL1, RIVAL1_15
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x7451f
; 0x744ff

UnknownScript_0x744ff: ; 0x744ff
	winlosstext UnknownText_0x7463d, UnknownText_0x747aa
	setlasttalked $2
	loadtrainer RIVAL1, RIVAL1_13
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x7451f
; 0x7450f

UnknownScript_0x7450f: ; 0x7450f
	winlosstext UnknownText_0x7463d, UnknownText_0x747aa
	setlasttalked $2
	loadtrainer RIVAL1, RIVAL1_14
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x7451f
; 0x7451f

UnknownScript_0x7451f: ; 0x7451f
	playmusic $0020
	loadfont
	2writetext UnknownText_0x746ce
	closetext
	loadmovesprites
	end
; 0x74529

ItemFragment_0x74529: ; 0x74529
	db TM_26, 1
; 0x7452b

ItemFragment_0x7452b: ; 0x7452b
	db MAX_REVIVE, 1
; 0x7452d

ItemFragment_0x7452d: ; 0x7452d
	db FULL_RESTORE, 1
; 0x7452f

ItemFragment_0x7452f: ; 0x7452f
	db FULL_HEAL, 1
; 0x74531

ItemFragment_0x74531: ; 0x74531
	db HP_UP, 1
; 0x74533

MapVictoryRoadSignpostItem0: ; 0x74533
	dw $009e
	db MAX_POTION
	
; 0x74536

MapVictoryRoadSignpostItem1: ; 0x74536
	dw $009f
	db FULL_HEAL
	
; 0x74539

MovementData_0x74539: ; 0x74539
	step_left
	step_left
	step_left
	step_left
	step_left
	step_left
	step_up
	step_up
	step_end
; 0x74542

MovementData_0x74542: ; 0x74542
	step_up
	step_up
	step_left
	step_left
	step_left
	step_left
	step_left
	step_up
	step_up
	step_end
; 0x7454c

MovementData_0x7454c: ; 0x7454c
	step_down
	step_down
	step_right
	step_right
	step_right
	step_right
	step_right
	step_right
	step_end
; 0x74555

MovementData_0x74555: ; 0x74555
	step_down
	step_down
	step_right
	step_right
	step_right
	step_right
	step_right
	step_down
	step_down
	step_end
; 0x7455f

UnknownText_0x7455f: ; 0x7455f
	db $0, "Hold it.", $51
	db "…Are you going to", $4f
	db "take the #MON", $55
	db "LEAGUE challenge?", $51
	db "…Don't make me", $4f
	db "laugh.", $51
	db "You're so much", $4f
	db "weaker than I am.", $51
	db "I'm not like I was", $4f
	db "before.", $51
	db "I now have the", $4f
	db "best and strongest", $51
	db "#MON with me.", $4f
	db "I'm invincible!", $51
	db $52, "!", $4f
	db "I challenge you!", $57
; 0x7463d

UnknownText_0x7463d: ; 0x7463d
	db $0, "…I couldn't win…", $51
	db "I gave it every-", $4f
	db "thing I had…", $51
	db "What you possess,", $4f
	db "and what I lack…", $51
	db "I'm beginning to", $4f
	db "understand what", $51
	db "that dragon master", $4f
	db "said to me…", $57
; 0x746ce

UnknownText_0x746ce: ; 0x746ce
	db $0, "…I haven't given up", $4f
	db "on becoming the", $55
	db "greatest trainer…", $51
	db "I'm going to find", $4f
	db "out why I can't", $51
	db "win and become", $4f
	db "stronger…", $51
	db "When I do, I will", $4f
	db "challenge you.", $51
	db "And I'll beat you", $4f
	db "down with all my", $55
	db "power.", $51
	db "…Humph! You keep", $4f
	db "at it until then.", $57
; 0x747aa

UnknownText_0x747aa: ; 0x747aa
	db $0, "…Humph!", $51
	db "When it comes down", $4f
	db "to it, nothing can", $55
	db "beat power.", $51
	db "I don't need any-", $4f
	db "thing else.", $57
; 0x74802

VictoryRoad_MapEventHeader: ; 0x74802
	; filler
	db 0, 0

	; warps
	db 10
	warp_def $43, $9, 5, GROUP_VICTORY_ROAD_GATE, MAP_VICTORY_ROAD_GATE
	warp_def $31, $1, 3, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $23, $1, 2, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $1f, $d, 5, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $11, $d, 4, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $21, $11, 7, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $13, $11, 6, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $b, $0, 9, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $1b, $0, 8, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $5, $d, 3, GROUP_ROUTE_23, MAP_ROUTE_23

	; xy triggers
	db 2
	xy_trigger 0, $8, $c, $0, UnknownScript_0x74492, $0, $0
	xy_trigger 0, $8, $d, $0, UnknownScript_0x744b5, $0, $0

	; signposts
	db 2
	signpost 29, 3, $7, MapVictoryRoadSignpostItem0
	signpost 65, 3, $7, MapVictoryRoadSignpostItem1

	; people-events
	db 6
	person_event $4, 17, 22, $7, $0, 255, 255, $0, 0, ObjectEvent, $06c2
	person_event $54, 32, 7, $1, $0, 255, 255, $1, 0, ItemFragment_0x74529, $06a3
	person_event $54, 52, 16, $1, $0, 255, 255, $1, 0, ItemFragment_0x7452b, $06a4
	person_event $54, 33, 22, $1, $0, 255, 255, $1, 0, ItemFragment_0x7452d, $06a5
	person_event $54, 52, 19, $1, $0, 255, 255, $1, 0, ItemFragment_0x7452f, $06a6
	person_event $54, 42, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x74531, $06a7
; 0x748a2

OlivinePort_MapScriptHeader: ; 0x748a2
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x748ac, $0000
	dw UnknownScript_0x748ad, $0000

	; callback count
	db 0
; 0x748ac

UnknownScript_0x748ac: ; 0x748ac
	end
; 0x748ad

UnknownScript_0x748ad: ; 0x748ad
	priorityjump UnknownScript_0x748b1
	end
; 0x748b1

UnknownScript_0x748b1: ; 0x748b1
	applymovement $0, MovementData_0x74a32
	appear $2
	dotrigger $0
	setbit1 $0000
	blackoutmod GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	end
; 0x748c0

UnknownScript_0x748c0: ; 0x748c0
	faceplayer
	loadfont
	checkbit1 $0000
	iftrue UnknownScript_0x74919
	2writetext UnknownText_0x74a55
	closetext
	loadmovesprites
	spriteface $2, $0
	pause 10
	playsound $0023
	disappear $2
	waitbutton
	applymovement $0, MovementData_0x74a30
	playsound $0023
	special $002e
	waitbutton
	checkbit1 $0030
	iffalse UnknownScript_0x7490a
	clearbit1 $073a
	setbit1 $073b
	clearbit1 $0557
	clearbit1 $0567
	clearbit1 $049b
	clearbit1 $04b2
	clearbit1 $0445
	clearbit1 $0589
	clearbit1 $057b
	clearbit1 $0459
	clearbit1 $04ac
UnknownScript_0x7490a: ; 0x7490a
	clearbit1 $002f
	appear $2
	domaptrigger GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F, $1
	warp GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F, $19, $1
	end
; 0x74919

UnknownScript_0x74919: ; 0x74919
	2writetext UnknownText_0x74a80
	closetext
	loadmovesprites
	end
; 0x7491f

UnknownScript_0x7491f: ; 0x7491f
	spriteface $4, $3
	checkbit1 $0000
	iftrue UnknownScript_0x7498b
	checkbit1 $0001
	iftrue UnknownScript_0x7498b
	spriteface $0, $2
	loadfont
	checkbit1 $0030
	iffalse UnknownScript_0x7494e
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x74977
	if_equal SATURDAY, UnknownScript_0x74977
	if_equal TUESDAY, UnknownScript_0x74981
	if_equal WEDNESDAY, UnknownScript_0x74981
	if_equal THURSDAY, UnknownScript_0x74981
UnknownScript_0x7494e: ; 0x7494e
	2writetext UnknownText_0x74a9c
	yesorno
	iffalse UnknownScript_0x74992
	2writetext UnknownText_0x74ada
	keeptextopen
	checkitem S_S_TICKET
	iffalse UnknownScript_0x7496d
	2writetext UnknownText_0x74b11
	closetext
	loadmovesprites
	setbit1 $0001
	applymovement $0, MovementData_0x74a37
	2jump UnknownScript_0x748c0
; 0x7496d

UnknownScript_0x7496d: ; 0x7496d
	2writetext UnknownText_0x74b41
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x74a34
	end
; 0x74977

UnknownScript_0x74977: ; 0x74977
	2writetext UnknownText_0x74ba8
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x74a34
	end
; 0x74981

UnknownScript_0x74981: ; 0x74981
	2writetext UnknownText_0x74bce
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x74a34
	end
; 0x7498b

UnknownScript_0x7498b: ; 0x7498b
	end
; 0x7498c

UnknownScript_0x7498c: ; 0x7498c
	2writetext UnknownText_0x74af6
	closetext
	loadmovesprites
	end
; 0x74992

UnknownScript_0x74992: ; 0x74992
	2writetext UnknownText_0x74af6
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x74a34
	end
; 0x7499c

UnknownScript_0x7499c: ; 0x7499c
	faceplayer
	loadfont
	checkbit1 $0000
	iftrue UnknownScript_0x74919
	checkbit1 $0030
	iffalse UnknownScript_0x749c0
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x749f2
	if_equal SATURDAY, UnknownScript_0x749f2
	if_equal TUESDAY, UnknownScript_0x749f8
	if_equal WEDNESDAY, UnknownScript_0x749f8
	if_equal THURSDAY, UnknownScript_0x749f8
UnknownScript_0x749c0: ; 0x749c0
	2writetext UnknownText_0x74a9c
	yesorno
	iffalse UnknownScript_0x7498c
	2writetext UnknownText_0x74ada
	keeptextopen
	checkitem S_S_TICKET
	iffalse UnknownScript_0x749ec
	2writetext UnknownText_0x74b11
	closetext
	loadmovesprites
	setbit1 $0001
	checkcode $9
	if_equal $3, UnknownScript_0x749e5
	applymovement $0, MovementData_0x74a3f
	2jump UnknownScript_0x748c0
; 0x749e5

UnknownScript_0x749e5: ; 0x749e5
	applymovement $0, MovementData_0x74a49
	2jump UnknownScript_0x748c0
; 0x749ec

UnknownScript_0x749ec: ; 0x749ec
	2writetext UnknownText_0x74b41
	closetext
	loadmovesprites
	end
; 0x749f2

UnknownScript_0x749f2: ; 0x749f2
	2writetext UnknownText_0x74ba8
	closetext
	loadmovesprites
	end
; 0x749f8

UnknownScript_0x749f8: ; 0x749f8
	2writetext UnknownText_0x74bce
	closetext
	loadmovesprites
	end
; 0x749fe

UnknownScript_0x749fe: ; 0x749fe
	jumptextfaceplayer UnknownText_0x74cd7
; 0x74a01

UnknownScript_0x74a01: ; 0x74a01
	faceplayer
	loadfont
	2writetext UnknownText_0x74bf4
	closetext
	loadmovesprites
	spriteface $5, $1
	end
; 0x74a0c

UnknownScript_0x74a0c: ; 0x74a0c
	faceplayer
	loadfont
	2writetext UnknownText_0x74c35
	closetext
	loadmovesprites
	spriteface $6, $1
	end
; 0x74a17

UnknownScript_0x74a17: ; 0x74a17
	faceplayer
	loadfont
	2writetext UnknownText_0x74c76
	closetext
	loadmovesprites
	spriteface $7, $0
	end
; 0x74a22

UnknownScript_0x74a22: ; 0x74a22
	faceplayer
	loadfont
	2writetext UnknownText_0x74ca2
	closetext
	loadmovesprites
	spriteface $8, $0
	end
; 0x74a2d

MapOlivinePortSignpostItem0: ; 0x74a2d
	dw $00ea
	db PROTEIN
	
; 0x74a30

MovementData_0x74a30: ; 0x74a30
	step_down
	step_end
; 0x74a32

MovementData_0x74a32: ; 0x74a32
	step_up
	step_end
; 0x74a34

MovementData_0x74a34: ; 0x74a34
	step_right
	turn_head_left
	step_end
; 0x74a37

MovementData_0x74a37: ; 0x74a37
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x74a3f

MovementData_0x74a3f: ; 0x74a3f
	step_right
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x74a49

MovementData_0x74a49: ; 0x74a49
	step_up
	step_right
	step_right
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x74a55

UnknownText_0x74a55: ; 0x74a55
	db $0, "We're departing", $4f
	db "soon. Please get", $55
	db "on board.", $57
; 0x74a80

UnknownText_0x74a80: ; 0x74a80
	db $0, "Sorry. You can't", $4f
	db "board now.", $57
; 0x74a9c

UnknownText_0x74a9c: ; 0x74a9c
	db $0, "Welcome to FAST", $4f
	db "SHIP S.S.AQUA.", $51
	db "Will you be board-", $4f
	db "ing today?", $57
; 0x74ada

UnknownText_0x74ada: ; 0x74ada
	db $0, "May I see your", $4f
	db "S.S.TICKET?", $57
; 0x74af6

UnknownText_0x74af6: ; 0x74af6
	db $0, "We hope to see you", $4f
	db "again!", $57
; 0x74b11

UnknownText_0x74b11: ; 0x74b11
	db $0, $52, " flashed", $4f
	db "the S.S.TICKET.", $51
	db "That's it.", $4f
	db "Thank you!", $57
; 0x74b41

UnknownText_0x74b41: ; 0x74b41
	db $0, $52, " tried to", $4f
	db "show the S.S.", $55
	db "TICKET…", $51
	db "…But no TICKET!", $51
	db "Sorry!", $4f
	db "You may board only", $51
	db "if you have an", $4f
	db "S.S.TICKET.", $57
; 0x74ba8

UnknownText_0x74ba8: ; 0x74ba8
	db $0, "The FAST SHIP will", $4f
	db "sail next Monday.", $57
; 0x74bce

UnknownText_0x74bce: ; 0x74bce
	db $0, "The FAST SHIP will", $4f
	db "sail next Friday.", $57
; 0x74bf4

UnknownText_0x74bf4: ; 0x74bf4
	db $0, "SHELLDER are easy", $4f
	db "to catch here.", $51
	db "They're kind of", $4f
	db "rare elsewhere.", $57
; 0x74c35

UnknownText_0x74c35: ; 0x74c35
	db $0, "How many RODS do", $4f
	db "you have?", $51
	db "Different RODS", $4f
	db "catch different", $55
	db "#MON.", $57
; 0x74c76

UnknownText_0x74c76: ; 0x74c76
	db $0, "S.S.AQUA uses jets", $4f
	db "to skim over the", $55
	db "waves!", $57
; 0x74ca2

UnknownText_0x74ca2: ; 0x74ca2
	db $0, "There are lots of", $4f
	db "#MON in KANTO.", $51
	db "I wish I could go…", $57
; 0x74cd7

UnknownText_0x74cd7: ; 0x74cd7
	db $0, "We don't want you", $4f
	db "to fall into the", $51
	db "sea, so you're not", $4f
	db "allowed in.", $57
; 0x74d18

OlivinePort_MapEventHeader: ; 0x74d18
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $b, 5, GROUP_OLIVINE_PORT_PASSAGE, MAP_OLIVINE_PORT_PASSAGE
	warp_def $17, $7, 1, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F

	; xy triggers
	db 1
	xy_trigger 0, $f, $7, $0, UnknownScript_0x7491f, $0, $0

	; signposts
	db 1
	signpost 22, 1, $7, MapOlivinePortSignpostItem0

	; people-events
	db 7
	person_event $49, 27, 11, $7, $0, 255, 255, $0, 0, UnknownScript_0x748c0, $072a
	person_event $49, 19, 11, $7, $0, 255, 255, $0, 0, UnknownScript_0x749fe, $0737
	person_event $49, 19, 10, $9, $0, 255, 255, $0, 0, UnknownScript_0x7499c, $0738
	person_event $3b, 18, 8, $7, $0, 255, 255, $0, 0, UnknownScript_0x74a01, $0737
	person_event $3b, 18, 17, $7, $0, 255, 255, $0, 0, UnknownScript_0x74a0c, $0737
	person_event $27, 19, 8, $6, $0, 255, 255, $0, 0, UnknownScript_0x74a17, $0738
	person_event $24, 19, 15, $6, $0, 255, 255, $0, 0, UnknownScript_0x74a22, $0738
; 0x74d90

VermilionPort_MapScriptHeader: ; 0x74d90
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x74d9d, $0000
	dw UnknownScript_0x74d9e, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x74da2
; 0x74d9d

UnknownScript_0x74d9d: ; 0x74d9d
	end
; 0x74d9e

UnknownScript_0x74d9e: ; 0x74d9e
	priorityjump UnknownScript_0x74da6
	end
; 0x74da2

UnknownScript_0x74da2: ; 0x74da2
	setbit2 $003a
	return
; 0x74da6

UnknownScript_0x74da6: ; 0x74da6
	applymovement $0, MovementData_0x74ef3
	appear $2
	dotrigger $0
	setbit1 $0731
	setbit1 $0730
	setbit1 $0739
	clearbit1 $0733
	setbit1 $0030
	setbit1 $0000
	blackoutmod GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	end
; 0x74dc4

UnknownScript_0x74dc4: ; 0x74dc4
	faceplayer
	loadfont
	checkbit1 $0000
	iftrue UnknownScript_0x74e1a
	2writetext UnknownText_0x74f06
	closetext
	loadmovesprites
	spriteface $2, $0
	pause 10
	playsound $0023
	disappear $2
	waitbutton
	applymovement $0, MovementData_0x74ef1
	playsound $0023
	special $002e
	waitbutton
	setbit1 $073a
	clearbit1 $073b
	clearbit1 $04eb
	clearbit1 $042f
	clearbit1 $0540
	clearbit1 $0493
	clearbit1 $04d4
	clearbit1 $04dd
	clearbit1 $057c
	clearbit1 $05b7
	clearbit1 $0476
	clearbit1 $0477
	setbit1 $002f
	appear $2
	domaptrigger GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F, $1
	warp GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F, $19, $1
	end
; 0x74e1a

UnknownScript_0x74e1a: ; 0x74e1a
	2writetext UnknownText_0x74f31
	closetext
	loadmovesprites
	end
; 0x74e20

UnknownScript_0x74e20: ; 0x74e20
	spriteface $3, $3
	checkbit1 $0000
	iftrue UnknownScript_0x74e86
	checkbit1 $0001
	iftrue UnknownScript_0x74e86
	spriteface $0, $2
	loadfont
	checkcode $b
	if_equal MONDAY, UnknownScript_0x74e72
	if_equal TUESDAY, UnknownScript_0x74e72
	if_equal THURSDAY, UnknownScript_0x74e7c
	if_equal FRIDAY, UnknownScript_0x74e7c
	if_equal SATURDAY, UnknownScript_0x74e7c
	2writetext UnknownText_0x74f4d
	yesorno
	iffalse UnknownScript_0x74e8d
	2writetext UnknownText_0x74f8b
	keeptextopen
	checkitem S_S_TICKET
	iffalse UnknownScript_0x74e68
	2writetext UnknownText_0x74fc2
	closetext
	loadmovesprites
	setbit1 $0001
	applymovement $0, MovementData_0x74ef8
	2jump UnknownScript_0x74dc4
; 0x74e68

UnknownScript_0x74e68: ; 0x74e68
	2writetext UnknownText_0x74ff2
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x74ef5
	end
; 0x74e72

UnknownScript_0x74e72: ; 0x74e72
	2writetext UnknownText_0x75059
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x74ef5
	end
; 0x74e7c

UnknownScript_0x74e7c: ; 0x74e7c
	2writetext UnknownText_0x75080
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x74ef5
	end
; 0x74e86

UnknownScript_0x74e86: ; 0x74e86
	end
; 0x74e87

UnknownScript_0x74e87: ; 0x74e87
	2writetext UnknownText_0x74fa7
	closetext
	loadmovesprites
	end
; 0x74e8d

UnknownScript_0x74e8d: ; 0x74e8d
	2writetext UnknownText_0x74fa7
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x74ef5
	end
; 0x74e97

UnknownScript_0x74e97: ; 0x74e97
	faceplayer
	loadfont
	checkbit1 $0000
	iftrue UnknownScript_0x74e1a
	checkcode $b
	if_equal MONDAY, UnknownScript_0x74eda
	if_equal TUESDAY, UnknownScript_0x74eda
	if_equal THURSDAY, UnknownScript_0x74ee0
	if_equal FRIDAY, UnknownScript_0x74ee0
	if_equal SATURDAY, UnknownScript_0x74ee0
	2writetext UnknownText_0x74f4d
	yesorno
	iffalse UnknownScript_0x74e87
	2writetext UnknownText_0x74f8b
	keeptextopen
	checkitem S_S_TICKET
	iffalse UnknownScript_0x74ed4
	2writetext UnknownText_0x74fc2
	closetext
	loadmovesprites
	setbit1 $0001
	applymovement $0, MovementData_0x74efe
	2jump UnknownScript_0x74dc4
; 0x74ed4

UnknownScript_0x74ed4: ; 0x74ed4
	2writetext UnknownText_0x74ff2
	closetext
	loadmovesprites
	end
; 0x74eda

UnknownScript_0x74eda: ; 0x74eda
	2writetext UnknownText_0x75059
	closetext
	loadmovesprites
	end
; 0x74ee0

UnknownScript_0x74ee0: ; 0x74ee0
	2writetext UnknownText_0x75080
	closetext
	loadmovesprites
	end
; 0x74ee6

UnknownScript_0x74ee6: ; 0x74ee6
	faceplayer
	loadfont
	2writetext UnknownText_0x750a6
	closetext
	loadmovesprites
	end
; 0x74eee

MapVermilionPortSignpostItem0: ; 0x74eee
	dw $00eb
	db IRON
	
; 0x74ef1

MovementData_0x74ef1: ; 0x74ef1
	step_down
	step_end
; 0x74ef3

MovementData_0x74ef3: ; 0x74ef3
	step_up
	step_end
; 0x74ef5

MovementData_0x74ef5: ; 0x74ef5
	step_right
	turn_head_left
	step_end
; 0x74ef8

MovementData_0x74ef8: ; 0x74ef8
	step_down
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x74efe

MovementData_0x74efe: ; 0x74efe
	step_right
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x74f06

UnknownText_0x74f06: ; 0x74f06
	db $0, "We're departing", $4f
	db "soon. Please get", $55
	db "on board.", $57
; 0x74f31

UnknownText_0x74f31: ; 0x74f31
	db $0, "Sorry. You can't", $4f
	db "board now.", $57
; 0x74f4d

UnknownText_0x74f4d: ; 0x74f4d
	db $0, "Welcome to FAST", $4f
	db "SHIP S.S.AQUA.", $51
	db "Will you be board-", $4f
	db "ing today?", $57
; 0x74f8b

UnknownText_0x74f8b: ; 0x74f8b
	db $0, "May I see your", $4f
	db "S.S.TICKET?", $57
; 0x74fa7

UnknownText_0x74fa7: ; 0x74fa7
	db $0, "We hope to see you", $4f
	db "again!", $57
; 0x74fc2

UnknownText_0x74fc2: ; 0x74fc2
	db $0, $52, " flashed", $4f
	db "the S.S.TICKET.", $51
	db "That's it.", $4f
	db "Thank you!", $57
; 0x74ff2

UnknownText_0x74ff2: ; 0x74ff2
	db $0, $52, " tried to", $4f
	db "show the S.S.", $55
	db "TICKET…", $51
	db "…But no TICKET!", $51
	db "Sorry!", $4f
	db "You may board only", $51
	db "if you have an", $4f
	db "S.S.TICKET.", $57
; 0x75059

UnknownText_0x75059: ; 0x75059
	db $0, "The FAST SHIP will", $4f
	db "sail on Wednesday.", $57
; 0x75080

UnknownText_0x75080: ; 0x75080
	db $0, "The FAST SHIP will", $4f
	db "sail next Sunday.", $57
; 0x750a6

UnknownText_0x750a6: ; 0x750a6
	db $0, "You came from", $4f
	db "JOHTO?", $51
	db "I hear many rare", $4f
	db "#MON live over", $55
	db "there.", $57
; 0x750e3

VermilionPort_MapEventHeader: ; 0x750e3
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $5, $9, 5, GROUP_VERMILION_PORT_PASSAGE, MAP_VERMILION_PORT_PASSAGE
	warp_def $11, $7, 1, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F

	; xy triggers
	db 1
	xy_trigger 0, $b, $7, $0, UnknownScript_0x74e20, $0, $0

	; signposts
	db 1
	signpost 13, 16, $7, MapVermilionPortSignpostItem0

	; people-events
	db 3
	person_event $49, 21, 11, $7, $0, 255, 255, $0, 0, UnknownScript_0x74dc4, $072b
	person_event $49, 15, 10, $9, $0, 255, 255, $0, 0, UnknownScript_0x74e97, $ffff
	person_event $2b, 15, 15, $5, $2, 255, 255, $0, 0, UnknownScript_0x74ee6, $ffff
; 0x75127

FastShip1F_MapScriptHeader: ; 0x75127
	; trigger count
	db 3

	; triggers
	dw UnknownScript_0x75135, $0000
	dw UnknownScript_0x75136, $0000
	dw UnknownScript_0x7513a, $0000

	; callback count
	db 0
; 0x75135

UnknownScript_0x75135: ; 0x75135
	end
; 0x75136

UnknownScript_0x75136: ; 0x75136
	priorityjump UnknownScript_0x7513b
	end
; 0x7513a

UnknownScript_0x7513a: ; 0x7513a
	end
; 0x7513b

UnknownScript_0x7513b: ; 0x7513b
	applymovement $2, MovementData_0x7520e
	applymovement $0, MovementData_0x75217
	applymovement $2, MovementData_0x75211
	pause 30
	playsound $001c
	earthquake 30
	blackoutmod GROUP_FAST_SHIP_CABINS_SW_SSW_NW, MAP_FAST_SHIP_CABINS_SW_SSW_NW
	clearbit1 $0031
	checkbit1 $0030
	iftrue UnknownScript_0x7515d
	dotrigger $2
	end
; 0x7515d

UnknownScript_0x7515d: ; 0x7515d
	dotrigger $0
	end
; 0x75160

UnknownScript_0x75160: ; 0x75160
	faceplayer
	loadfont
	checkbit1 $0031
	iftrue UnknownScript_0x7517a
	checkbit1 $002f
	iftrue UnknownScript_0x75174
	2writetext UnknownText_0x7523b
	closetext
	loadmovesprites
	end
; 0x75174

UnknownScript_0x75174: ; 0x75174
	2writetext UnknownText_0x7529b
	closetext
	loadmovesprites
	end
; 0x7517a

UnknownScript_0x7517a: ; 0x7517a
	checkbit1 $002f
	iftrue UnknownScript_0x7519c
	2writetext UnknownText_0x754be
	closetext
	loadmovesprites
	2call UnknownScript_0x751b8
	playsound $0023
	special $002e
	waitbutton
	setbit1 $072b
	domaptrigger GROUP_VERMILION_PORT, MAP_VERMILION_PORT, $1
	warp GROUP_VERMILION_PORT, MAP_VERMILION_PORT, $7, $11
	end
; 0x7519c

UnknownScript_0x7519c: ; 0x7519c
	2writetext UnknownText_0x7548d
	closetext
	loadmovesprites
	2call UnknownScript_0x751b8
	playsound $0023
	special $002e
	waitbutton
	setbit1 $072a
	domaptrigger GROUP_OLIVINE_PORT, MAP_OLIVINE_PORT, $1
	warp GROUP_OLIVINE_PORT, MAP_OLIVINE_PORT, $7, $17
	end
; 0x751b8

UnknownScript_0x751b8: ; 0x751b8
	checkcode $9
	if_equal $3, UnknownScript_0x751c7
	applymovement $2, MovementData_0x7520e
	applymovement $0, MovementData_0x75235
	end
; 0x751c7

UnknownScript_0x751c7: ; 0x751c7
	applymovement $2, MovementData_0x75214
	applymovement $0, MovementData_0x75238
	end
; 0x751d0

UnknownScript_0x751d0: ; 0x751d0
	faceplayer
	loadfont
	checkbit1 $0030
	iftrue UnknownScript_0x751de
	2writetext UnknownText_0x752f9
	closetext
	loadmovesprites
	end
; 0x751de

UnknownScript_0x751de: ; 0x751de
	2writetext UnknownText_0x7534f
	closetext
	loadmovesprites
	end
; 0x751e4

UnknownScript_0x751e4: ; 0x751e4
	jumptextfaceplayer UnknownText_0x753c0
; 0x751e7

UnknownScript_0x751e7: ; 0x751e7
	moveperson $5, $14, $6
; 0x751eb

UnknownScript_0x751eb: ; 0x751eb
	appear $5
	applymovement $5, MovementData_0x7521b
	playsound $0041
	applymovement $0, MovementData_0x7522e
	applymovement $5, MovementData_0x75220
	loadfont
	2writetext UnknownText_0x75412
	closetext
	loadmovesprites
	spriteface $0, $3
	applymovement $5, MovementData_0x75222
	disappear $5
	dotrigger $0
	end
; 0x7520e

MovementData_0x7520e: ; 0x7520e
	slow_step_left
	turn_head_right
	step_end
; 0x75211

MovementData_0x75211: ; 0x75211
	slow_step_right
	turn_head_down
	step_end
; 0x75214

MovementData_0x75214: ; 0x75214
	slow_step_down
	turn_head_up
	step_end
; 0x75217

MovementData_0x75217: ; 0x75217
	step_down
	step_down
	turn_head_down
	step_end
; 0x7521b

MovementData_0x7521b: ; 0x7521b
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	step_end
; 0x75220

MovementData_0x75220: ; 0x75220
	step_right
	step_end
; 0x75222

MovementData_0x75222: ; 0x75222
	big_step_down
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	step_end
; 0x7522e

MovementData_0x7522e: ; 0x7522e
	big_step_right
	turn_head_left
	step_end
; 0x75231

MovementData_0x75231: ; 0x75231
	step_up
	step_end
; 0x75233

MovementData_0x75233: ; 0x75233
	step_down
	step_end
; 0x75235

MovementData_0x75235: ; 0x75235
	step_up
	step_up
	step_end
; 0x75238

MovementData_0x75238: ; 0x75238
	step_right
	step_up
	step_end
; 0x7523b

UnknownText_0x7523b: ; 0x7523b
	db $0, "FAST SHIP S.S.AQUA", $4f
	db "is en route to", $55
	db "VERMILION CITY.", $51
	db "We will make an", $4f
	db "announcement when", $55
	db "we arrive.", $57
; 0x7529b

UnknownText_0x7529b: ; 0x7529b
	db $0, "FAST SHIP S.S.AQUA", $4f
	db "is en route to", $55
	db "OLIVINE CITY.", $51
	db "We will make an", $4f
	db "announcement when", $55
	db "we arrive.", $57
; 0x752f9

UnknownText_0x752f9: ; 0x752f9
	db $0, "Here's your cabin.", $51
	db "If your #MON", $4f
	db "are hurt, take a", $55
	db "nap in the bed.", $51
	db "That will heal", $4f
	db "them.", $57
; 0x7534f

UnknownText_0x7534f: ; 0x7534f
	db $0, "Here's your cabin.", $51
	db "You can heal your", $4f
	db "#MON by taking", $55
	db "a nap in the bed.", $51
	db "The ship will", $4f
	db "arrive while", $55
	db "you're sleeping.", $57
; 0x753c0

UnknownText_0x753c0: ; 0x753c0
	db $0, "The passengers are", $4f
	db "all trainers.", $51
	db "They're all itch-", $4f
	db "ing to battle in", $55
	db "their cabins.", $57
; 0x75412

UnknownText_0x75412: ; 0x75412
	db $0, "Whoa! Excuse me.", $4f
	db "I was in a hurry!", $51
	db "My granddaughter", $4f
	db "is missing!", $51
	db "She's just a wee", $4f
	db "girl. If you see", $51
	db "her, please let me", $4f
	db "know!", $57
; 0x7548d

UnknownText_0x7548d: ; 0x7548d
	db $0, "FAST SHIP S.S.AQUA", $4f
	db "has arrived in", $55
	db "OLIVINE CITY.", $57
; 0x754be

UnknownText_0x754be: ; 0x754be
	db $0, "FAST SHIP S.S.AQUA", $4f
	db "has arrived in", $55
	db "VERMILION CITY.", $57
; 0x754f1

FastShip1F_MapEventHeader: ; 0x754f1
	; filler
	db 0, 0

	; warps
	db 12
	warp_def $1, $19, 255, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $8, $1b, 1, GROUP_FAST_SHIP_CABINS_NNW_NNE_NE, MAP_FAST_SHIP_CABINS_NNW_NNE_NE
	warp_def $8, $17, 2, GROUP_FAST_SHIP_CABINS_NNW_NNE_NE, MAP_FAST_SHIP_CABINS_NNW_NNE_NE
	warp_def $8, $13, 3, GROUP_FAST_SHIP_CABINS_NNW_NNE_NE, MAP_FAST_SHIP_CABINS_NNW_NNE_NE
	warp_def $8, $f, 1, GROUP_FAST_SHIP_CABINS_SW_SSW_NW, MAP_FAST_SHIP_CABINS_SW_SSW_NW
	warp_def $f, $f, 2, GROUP_FAST_SHIP_CABINS_SW_SSW_NW, MAP_FAST_SHIP_CABINS_SW_SSW_NW
	warp_def $f, $13, 4, GROUP_FAST_SHIP_CABINS_SW_SSW_NW, MAP_FAST_SHIP_CABINS_SW_SSW_NW
	warp_def $f, $17, 1, GROUP_FAST_SHIP_CABINS_SE_SSE_CAPTAINS_CABIN, MAP_FAST_SHIP_CABINS_SE_SSE_CAPTAINS_CABIN
	warp_def $f, $1b, 3, GROUP_FAST_SHIP_CABINS_SE_SSE_CAPTAINS_CABIN, MAP_FAST_SHIP_CABINS_SE_SSE_CAPTAINS_CABIN
	warp_def $d, $3, 5, GROUP_FAST_SHIP_CABINS_SE_SSE_CAPTAINS_CABIN, MAP_FAST_SHIP_CABINS_SE_SSE_CAPTAINS_CABIN
	warp_def $c, $6, 1, GROUP_FAST_SHIP_B1F, MAP_FAST_SHIP_B1F
	warp_def $e, $1e, 2, GROUP_FAST_SHIP_B1F, MAP_FAST_SHIP_B1F

	; xy triggers
	db 2
	xy_trigger 2, $6, $18, $0, UnknownScript_0x751eb, $0, $0
	xy_trigger 2, $6, $19, $0, UnknownScript_0x751e7, $0, $0

	; signposts
	db 0

	; people-events
	db 4
	person_event $49, 6, 29, $6, $0, 255, 255, $0, 0, UnknownScript_0x75160, $ffff
	person_event $49, 11, 18, $9, $0, 255, 255, $0, 0, UnknownScript_0x751d0, $ffff
	person_event $49, 21, 26, $5, $2, 255, 255, $0, 0, UnknownScript_0x751e4, $ffff
	person_event $40, 10, 23, $9, $0, 255, 255, $0, 0, ObjectEvent, $072c
; 0x75577

FastShipCabins_NNW_NNE_NE_MapScriptHeader: ; 0x75577
	; trigger count
	db 0

	; callback count
	db 0
; 0x75579

TrainerCooltrainermSean: ; 0x75579
	; bit/flag number
	dw $557

	; trainer group && trainer id
	db COOLTRAINERM, SEAN

	; text when seen
	dw CooltrainermSeanSeenText

	; text when trainer beaten
	dw CooltrainermSeanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermSeanScript
; 0x75585

CooltrainermSeanScript: ; 0x75585
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7567b
	closetext
	loadmovesprites
	end
; 0x7558d

TrainerCooltrainerfCarol: ; 0x7558d
	; bit/flag number
	dw $567

	; trainer group && trainer id
	db COOLTRAINERF, CAROL

	; text when seen
	dw CooltrainerfCarolSeenText

	; text when trainer beaten
	dw CooltrainerfCarolBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfCarolScript
; 0x75599

CooltrainerfCarolScript: ; 0x75599
	talkaftercancel
	loadfont
	2writetext UnknownText_0x756f7
	closetext
	loadmovesprites
	end
; 0x755a1

TrainerPokemaniacEthan: ; 0x755a1
	; bit/flag number
	dw $4eb

	; trainer group && trainer id
	db POKEMANIAC, ETHAN

	; text when seen
	dw PokemaniacEthanSeenText

	; text when trainer beaten
	dw PokemaniacEthanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacEthanScript
; 0x755ad

PokemaniacEthanScript: ; 0x755ad
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7574b
	closetext
	loadmovesprites
	end
; 0x755b5

TrainerHikerNoland: ; 0x755b5
	; bit/flag number
	dw $531

	; trainer group && trainer id
	db HIKER, NOLAND

	; text when seen
	dw HikerNolandSeenText

	; text when trainer beaten
	dw HikerNolandBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerNolandScript
; 0x755c1

HikerNolandScript: ; 0x755c1
	talkaftercancel
	loadfont
	2writetext UnknownText_0x757d4
	closetext
	loadmovesprites
	end
; 0x755c9

TrainerGentlemanEdward: ; 0x755c9
	; bit/flag number
	dw $49b

	; trainer group && trainer id
	db GENTLEMAN, EDWARD

	; text when seen
	dw GentlemanEdwardSeenText

	; text when trainer beaten
	dw GentlemanEdwardBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GentlemanEdwardScript
; 0x755d5

GentlemanEdwardScript: ; 0x755d5
	talkaftercancel
	loadfont
	2writetext UnknownText_0x75937
	closetext
	loadmovesprites
	end
; 0x755dd

TrainerBurglarCorey: ; 0x755dd
	; bit/flag number
	dw $42f

	; trainer group && trainer id
	db BURGLAR, COREY

	; text when seen
	dw BurglarCoreySeenText

	; text when trainer beaten
	dw BurglarCoreyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BurglarCoreyScript
; 0x755e9

BurglarCoreyScript: ; 0x755e9
	talkaftercancel
	loadfont
	2writetext UnknownText_0x75996
	closetext
	loadmovesprites
	end
; 0x755f1

UnknownScript_0x755f1: ; 0x755f1
	playmusic $000a
	faceplayer
	loadfont
	2writetext UnknownText_0x75812
	closetext
	loadmovesprites
	winlosstext UnknownText_0x75897, $0000
	loadtrainer SAILOR, STANLY
	startbattle
	reloadmap
	special $001b
	setbit1 $057d
	loadfont
	2writetext UnknownText_0x758b1
	closetext
	loadmovesprites
	setbit1 $0033
	domaptrigger GROUP_FAST_SHIP_B1F, MAP_FAST_SHIP_B1F, $1
	checkcode $9
	if_equal $3, UnknownScript_0x75629
	applymovement $6, MovementData_0x75637
	playsound $0023
	disappear $6
	waitbutton
	end
; 0x75629

UnknownScript_0x75629: ; 0x75629
	applymovement $6, MovementData_0x7563c
	playsound $0023
	disappear $6
	waitbutton
	end
; 0x75634

MapFastShipCabins_NNW_NNE_NESignpost2Script: ; 0x75634
	jumpstd $000d
; 0x75637

MovementData_0x75637: ; 0x75637
	step_left
	step_left
	step_up
	step_up
	step_end
; 0x7563c

MovementData_0x7563c: ; 0x7563c
	step_down
	step_left
	step_left
	step_up
	step_up
	step_up
	step_end
; 0x75643

CooltrainermSeanSeenText: ; 0x75643
	db $0, "I'm going to KANTO", $4f
	db "to test my skills.", $57
; 0x75669

CooltrainermSeanBeatenText: ; 0x75669
	db $0, "I wanted to win!", $57
; 0x7567b

UnknownText_0x7567b: ; 0x7567b
	db $0, "Trainers from", $4f
	db "JOHTO can battle", $51
	db "with KANTO GYM", $4f
	db "LEADERS.", $57
; 0x756b3

CooltrainerfCarolSeenText: ; 0x756b3
	db $0, "I'm training to", $4f
	db "become the CHAMP!", $57
; 0x756d5

CooltrainerfCarolBeatenText: ; 0x756d5
	db $0, "What's so differ-", $4f
	db "ent between us?", $57
; 0x756f7

UnknownText_0x756f7: ; 0x756f7
	db $0, "I'm going to beat", $4f
	db "you someday!", $57
; 0x75716

PokemaniacEthanSeenText: ; 0x75716
	db $0, "Do you know LILY?", $4f
	db "She's a hot DJ in", $55
	db "KANTO.", $57
; 0x75741

PokemaniacEthanBeatenText: ; 0x75741
	db $0, "Gyaaaah!", $57
; 0x7574b

UnknownText_0x7574b: ; 0x7574b
	db $0, "LILY's nice, but", $4f
	db "MARY's the best!", $51
	db "I want to check", $4f
	db "out JOHTO's radio", $55
	db "programs!", $57
; 0x75797

HikerNolandSeenText: ; 0x75797
	db $0, "Are you alone?", $4f
	db "Then let's battle!", $57
; 0x757b9

HikerNolandBeatenText: ; 0x757b9
	db $0, "That's too much to", $4f
	db "handle!", $57
; 0x757d4

UnknownText_0x757d4: ; 0x757d4
	db $0, "I wonder if there", $4f
	db "are any mountains", $51
	db "worth climbing in", $4f
	db "KANTO?", $57
; 0x75812

UnknownText_0x75812: ; 0x75812
	db $0, "Yeah, I'm a sail-", $4f
	db "or, all right.", $51
	db "I wasn't goofing", $4f
	db "off!", $51
	db "This cabin was", $4f
	db "vacant, so I just", $55
	db "took a quick nap!", $51
	db "Ah, forget it!", $4f
	db "Let's battle!", $57
; 0x75897

UnknownText_0x75897: ; 0x75897
	db $0, "Sorry! It's all my", $4f
	db "fault!", $57
; 0x758b1

UnknownText_0x758b1: ; 0x758b1
	db $0, "Being a sailor, I", $4f
	db "have to do phys-", $55
	db "ical labor. It's", $55
	db "exhausting!", $57
; 0x758f1

GentlemanEdwardSeenText: ; 0x758f1
	db $0, "Oh, no. I've lost", $4f
	db "something that's", $55
	db "very important.", $57
; 0x75923

GentlemanEdwardBeatenText: ; 0x75923
	db $0, "I… I can't find", $4f
	db "it…", $57
; 0x75937

UnknownText_0x75937: ; 0x75937
	db $0, "I give up.", $4f
	db "You don't have to", $51
	db "look. Just forget", $4f
	db "about it!", $57
; 0x75970

BurglarCoreySeenText: ; 0x75970
	db $0, "Yeehaw!", $4f
	db "Lucky!", $57
; 0x75980

BurglarCoreyBeatenText: ; 0x75980
	db $0, "How unlucky!", $4f
	db "I lost!", $57
; 0x75996

UnknownText_0x75996: ; 0x75996
	db $0, "I found a pretty", $4f
	db "coin here.", $51
	db "Someone must have", $4f
	db "lost it…", $57
; 0x759ce

FastShipCabins_NNW_NNE_NE_MapEventHeader: ; 0x759ce
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $0, $2, 2, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $c, $2, 3, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $18, $2, 4, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 13, 6, $0, MapFastShipCabins_NNW_NNE_NESignpost2Script
	signpost 19, 7, $0, MapFastShipCabins_NNW_NNE_NESignpost2Script
	signpost 31, 7, $0, MapFastShipCabins_NNW_NNE_NESignpost2Script

	; people-events
	db 7
	person_event $23, 7, 8, $a, $0, 255, 255, $82, 2, TrainerCooltrainermSean, $073a
	person_event $24, 9, 5, $7, $0, 255, 255, $82, 3, TrainerCooltrainerfCarol, $073a
	person_event $2b, 9, 5, $7, $0, 255, 255, $92, 3, TrainerPokemaniacEthan, $073b
	person_event $2d, 21, 8, $7, $0, 255, 255, $b2, 3, TrainerHikerNoland, $0739
	person_event $49, 30, 8, $3, $0, 255, 255, $90, 0, UnknownScript_0x755f1, $072d
	person_event $40, 34, 11, $3, $0, 255, 255, $92, 1, TrainerGentlemanEdward, $073a
	person_event $4b, 34, 6, $7, $0, 255, 255, $a2, 4, TrainerBurglarCorey, $073b
; 0x75a4d

FastShipCabins_SW_SSW_NW_MapScriptHeader: ; 0x75a4d
	; trigger count
	db 0

	; callback count
	db 0
; 0x75a4f

TrainerFirebreatherLyle: ; 0x75a4f
	; bit/flag number
	dw $44d

	; trainer group && trainer id
	db FIREBREATHER, LYLE

	; text when seen
	dw FirebreatherLyleSeenText

	; text when trainer beaten
	dw FirebreatherLyleBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FirebreatherLyleScript
; 0x75a5b

FirebreatherLyleScript: ; 0x75a5b
	talkaftercancel
	loadfont
	2writetext UnknownText_0x75b52
	closetext
	loadmovesprites
	end
; 0x75a63

TrainerBug_catcherKen: ; 0x75a63
	; bit/flag number
	dw $540

	; trainer group && trainer id
	db BUG_CATCHER, KEN

	; text when seen
	dw Bug_catcherKenSeenText

	; text when trainer beaten
	dw Bug_catcherKenBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherKenScript
; 0x75a6f

Bug_catcherKenScript: ; 0x75a6f
	talkaftercancel
	loadfont
	2writetext UnknownText_0x75bd5
	closetext
	loadmovesprites
	end
; 0x75a77

TrainerBeautyCassie: ; 0x75a77
	; bit/flag number
	dw $4b2

	; trainer group && trainer id
	db BEAUTY, CASSIE

	; text when seen
	dw BeautyCassieSeenText

	; text when trainer beaten
	dw BeautyCassieBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BeautyCassieScript
; 0x75a83

BeautyCassieScript: ; 0x75a83
	talkaftercancel
	loadfont
	2writetext UnknownText_0x75c43
	closetext
	loadmovesprites
	end
; 0x75a8b

TrainerGuitaristClyde: ; 0x75a8b
	; bit/flag number
	dw $493

	; trainer group && trainer id
	db GUITARIST, CLYDE

	; text when seen
	dw GuitaristClydeSeenText

	; text when trainer beaten
	dw GuitaristClydeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GuitaristClydeScript
; 0x75a97

GuitaristClydeScript: ; 0x75a97
	talkaftercancel
	special $00a0
	iftrue UnknownScript_0x75aa5
	loadfont
	2writetext UnknownText_0x75d65
	closetext
	loadmovesprites
	end
; 0x75aa5

UnknownScript_0x75aa5: ; 0x75aa5
	loadfont
	2writetext UnknownText_0x75cfe
	closetext
	loadmovesprites
	end
; 0x75aac

MapFastShipCabins_SW_SSW_NWSignpost1Script: ; 0x75aac
	loadfont
	2writetext UnknownText_0x75da4
	closetext
	loadmovesprites
	special $0030
	special $0033
	special $009d
	special $001b
	playmusic $000d
	pause 60
	special $003d
	special $0032
	loadfont
	2writetext UnknownText_0x75dc1
	closetext
	loadmovesprites
	checkbit1 $0031
	iftrue UnknownScript_0x75ae1
	checkbit1 $0032
	iftrue UnknownScript_0x75ae2
	checkbit1 $0030
	iftrue UnknownScript_0x75ae2
UnknownScript_0x75ae1: ; 0x75ae1
	end
; 0x75ae2

UnknownScript_0x75ae2: ; 0x75ae2
	playsound $0027
	pause 30
	checkbit1 $002f
	iftrue UnknownScript_0x75af7
	loadfont
	2writetext UnknownText_0x75e0f
	closetext
	loadmovesprites
	setbit1 $0031
	end
; 0x75af7

UnknownScript_0x75af7: ; 0x75af7
	loadfont
	2writetext UnknownText_0x75dde
	closetext
	loadmovesprites
	setbit1 $0031
	end
; 0x75b01

MapFastShipCabins_SW_SSW_NWSignpost2Script: ; 0x75b01
	jumpstd $000d
; 0x75b04

FirebreatherLyleSeenText: ; 0x75b04
	db $0, "I'm going to KANTO", $4f
	db "to put on fire-", $55
	db "breathing shows!", $57
; 0x75b38

FirebreatherLyleBeatenText: ; 0x75b38
	db $0, "Fizzle… The", $4f
	db "flame's tiny…", $57
; 0x75b52

UnknownText_0x75b52: ; 0x75b52
	db $0, "I guess fire is", $4f
	db "weak on the sea.", $51
	db "It doesn't matter?", $4f
	db "Really?", $57
; 0x75b8e

Bug_catcherKenSeenText: ; 0x75b8e
	db $0, "I'm visiting my", $4f
	db "grandma to catch", $55
	db "me some bugs!", $57
; 0x75bbd

Bug_catcherKenBeatenText: ; 0x75bbd
	db $0, "Ooh, wow.", $4f
	db "You're tough!", $57
; 0x75bd5

UnknownText_0x75bd5: ; 0x75bd5
	db $0, "You can find lots", $4f
	db "of #MON in the", $55
	db "trees of JOHTO!", $57
; 0x75c07

BeautyCassieSeenText: ; 0x75c07
	db $0, "I'm trying to", $4f
	db "forget my woes.", $55
	db "Let's battle!", $57
; 0x75c32

BeautyCassieBeatenText: ; 0x75c32
	db $0, "My heart weeps…", $57
; 0x75c43

UnknownText_0x75c43: ; 0x75c43
	db $0, "A voyage is best", $4f
	db "for getting over", $55
	db "a broken heart.", $51
	db "But a FAST SHIP", $4f
	db "trip is too short", $55
	db "for grieving.", $57
; 0x75ca6

GuitaristClydeSeenText: ; 0x75ca6
	db $0, "I'm going to audi-", $4f
	db "tion my songs at", $51
	db "GOLDENROD's RADIO", $4f
	db "STATION.", $57
; 0x75ce4

GuitaristClydeBeatenText: ; 0x75ce4
	db $0, "Yowza!", $4f
	db "Total distortion!", $57
; 0x75cfe

UnknownText_0x75cfe: ; 0x75cfe
	db $0, "I was going to", $4f
	db "make my debut at", $55
	db "the BATTLE TOWER…", $51
	db "I should go back", $4f
	db "to VERMILION and", $55
	db "redo my training…", $57
; 0x75d65

UnknownText_0x75d65: ; 0x75d65
	db $0, "Speaking of the", $4f
	db "RADIO STATION,", $51
	db "what's this week's", $4f
	db "lucky number?", $57
; 0x75da4

UnknownText_0x75da4: ; 0x75da4
	db $0, "A comfy bed!", $4f
	db "Time to sleep…", $57
; 0x75dc1

UnknownText_0x75dc1: ; 0x75dc1
	db $0, "Ah, refreshed and", $4f
	db "restored!", $57
; 0x75dde

UnknownText_0x75dde: ; 0x75dde
	db $0, "FAST SHIP S.S.AQUA", $4f
	db "has arrived in", $55
	db "OLIVINE CITY.", $57
; 0x75e0f

UnknownText_0x75e0f: ; 0x75e0f
	db $0, "FAST SHIP S.S.AQUA", $4f
	db "has arrived in", $55
	db "VERMILION CITY.", $57
; 0x75e42

FastShipCabins_SW_SSW_NW_MapEventHeader: ; 0x75e42
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $0, $2, 5, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $13, $2, 6, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $13, $3, 6, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $1f, $2, 7, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $1f, $3, 7, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 1, 7, $0, MapFastShipCabins_SW_SSW_NWSignpost1Script
	signpost 2, 7, $0, MapFastShipCabins_SW_SSW_NWSignpost1Script
	signpost 7, 7, $0, MapFastShipCabins_SW_SSW_NWSignpost2Script

	; people-events
	db 4
	person_event $3a, 19, 5, $1e, $0, 255, 255, $82, 2, TrainerFirebreatherLyle, $0739
	person_event $25, 19, 10, $a, $0, 255, 255, $b2, 2, TrainerBug_catcherKen, $073b
	person_event $2a, 30, 5, $a, $0, 255, 255, $92, 3, TrainerBeautyCassie, $073a
	person_event $2c, 32, 7, $1e, $0, 255, 255, $82, 2, TrainerGuitaristClyde, $073b
; 0x75ea4

FastShipCabins_SE_SSE_CaptainsCabin_MapScriptHeader: ; 0x75ea4
	; trigger count
	db 0

	; callback count
	db 0
; 0x75ea6

UnknownScript_0x75ea6: ; 0x75ea6
	end
; 0x75ea7

UnknownScript_0x75ea7: ; 0x75ea7
	faceplayer
	loadfont
	checkbit1 $0030
	iftrue UnknownScript_0x75eb5
	2writetext UnknownText_0x76012
	closetext
	loadmovesprites
	end
; 0x75eb5

UnknownScript_0x75eb5: ; 0x75eb5
	2writetext UnknownText_0x76064
	closetext
	loadmovesprites
	end
; 0x75ebb

UnknownScript_0x75ebb: ; 0x75ebb
	spriteface $5, $3
	loadfont
	2writetext UnknownText_0x761e0
	closetext
	loadmovesprites
	faceplayer
	loadfont
	2writetext UnknownText_0x7621f
	closetext
	loadmovesprites
	special $0030
	special $0033
	disappear $5
	applymovement $0, MovementData_0x76004
	moveperson $4, $3, $13
	appear $4
	spriteface $0, $1
	spriteface $4, $1
	special $0032
	spriteface $3, $0
	showemote $0, $3, 15
	applymovement $4, MovementData_0x7600c
	spriteface $3, $3
	checkbit2 $0063
	iftrue UnknownScript_0x75f03
	loadfont
	2writetext UnknownText_0x76284
	closetext
	loadmovesprites
	2jump UnknownScript_0x75f09
; 0x75f03

UnknownScript_0x75f03: ; 0x75f03
	loadfont
	2writetext UnknownText_0x762c6
	closetext
	loadmovesprites
UnknownScript_0x75f09: ; 0x75f09
	spriteface $5, $0
	applymovement $3, MovementData_0x76010
	loadfont
	2writetext UnknownText_0x76143
	keeptextopen
	setbit1 $072b
	domaptrigger GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F, $0
	2jump UnknownScript_0x75f37
; 0x75f1f

UnknownScript_0x75f1f: ; 0x75f1f
	faceplayer
	loadfont
	checkbit1 $0071
	iftrue UnknownScript_0x75f67
	checkbit1 $0732
	iftrue UnknownScript_0x75f58
	2writetext UnknownText_0x760ae
	closetext
	loadmovesprites
	domaptrigger GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F, $0
	end
; 0x75f37

UnknownScript_0x75f37: ; 0x75f37
	2writetext UnknownText_0x7619b
	keeptextopen
	verbosegiveitem METAL_COAT, 1
	iffalse UnknownScript_0x75f44
	setbit1 $0071
UnknownScript_0x75f44: ; 0x75f44
	loadmovesprites
	waitbutton
	playsound $0027
	pause 30
	loadfont
	2writetext UnknownText_0x76645
	closetext
	setbit1 $0031
	setbit1 $0032
	loadmovesprites
	end
; 0x75f58

UnknownScript_0x75f58: ; 0x75f58
	2writetext UnknownText_0x7619b
	keeptextopen
	verbosegiveitem METAL_COAT, 1
	iffalse UnknownScript_0x75f65
	setbit1 $0071
UnknownScript_0x75f65: ; 0x75f65
	loadmovesprites
	end
; 0x75f67

UnknownScript_0x75f67: ; 0x75f67
	2writetext UnknownText_0x761be
	closetext
	loadmovesprites
	end
; 0x75f6d

UnknownScript_0x75f6d: ; 0x75f6d
	faceplayer
	loadfont
	2writetext UnknownText_0x7630d
	closetext
	loadmovesprites
	end
; 0x75f75

TrainerPokefanmColin: ; 0x75f75
	; bit/flag number
	dw $4d5

	; trainer group && trainer id
	db POKEFANM, COLIN

	; text when seen
	dw PokefanmColinSeenText

	; text when trainer beaten
	dw PokefanmColinBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmColinScript
; 0x75f81

PokefanmColinScript: ; 0x75f81
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7635b
	closetext
	loadmovesprites
	end
; 0x75f89

TrainerTwinsMegandpeg1: ; 0x75f89
	; bit/flag number
	dw $46a

	; trainer group && trainer id
	db TWINS, MEGANDPEG1

	; text when seen
	dw TwinsMegandpeg1SeenText

	; text when trainer beaten
	dw TwinsMegandpeg1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TwinsMegandpeg1Script
; 0x75f95

TwinsMegandpeg1Script: ; 0x75f95
	talkaftercancel
	loadfont
	2writetext UnknownText_0x763c2
	closetext
	loadmovesprites
	end
; 0x75f9d

TrainerTwinsMegandpeg2: ; 0x75f9d
	; bit/flag number
	dw $46a

	; trainer group && trainer id
	db TWINS, MEGANDPEG2

	; text when seen
	dw TwinsMegandpeg2SeenText

	; text when trainer beaten
	dw TwinsMegandpeg2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TwinsMegandpeg2Script
; 0x75fa9

TwinsMegandpeg2Script: ; 0x75fa9
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76428
	closetext
	loadmovesprites
	end
; 0x75fb1

TrainerPsychicRodney: ; 0x75fb1
	; bit/flag number
	dw $445

	; trainer group && trainer id
	db PSYCHIC_T, RODNEY

	; text when seen
	dw PsychicRodneySeenText

	; text when trainer beaten
	dw PsychicRodneyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicRodneyScript
; 0x75fbd

PsychicRodneyScript: ; 0x75fbd
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76497
	closetext
	loadmovesprites
	end
; 0x75fc5

TrainerPokefanmJeremy: ; 0x75fc5
	; bit/flag number
	dw $4d4

	; trainer group && trainer id
	db POKEFANM, JEREMY

	; text when seen
	dw PokefanmJeremySeenText

	; text when trainer beaten
	dw PokefanmJeremyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmJeremyScript
; 0x75fd1

PokefanmJeremyScript: ; 0x75fd1
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7651c
	closetext
	loadmovesprites
	end
; 0x75fd9

TrainerPokefanfGeorgia: ; 0x75fd9
	; bit/flag number
	dw $4dd

	; trainer group && trainer id
	db POKEFANF, GEORGIA

	; text when seen
	dw PokefanfGeorgiaSeenText

	; text when trainer beaten
	dw PokefanfGeorgiaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanfGeorgiaScript
; 0x75fe5

PokefanfGeorgiaScript: ; 0x75fe5
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76596
	closetext
	loadmovesprites
	end
; 0x75fed

TrainerSupernerdShawn: ; 0x75fed
	; bit/flag number
	dw $589

	; trainer group && trainer id
	db SUPER_NERD, SHAWN

	; text when seen
	dw SupernerdShawnSeenText

	; text when trainer beaten
	dw SupernerdShawnBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SupernerdShawnScript
; 0x75ff9

SupernerdShawnScript: ; 0x75ff9
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7660f
	closetext
	loadmovesprites
	end
; 0x76001

MapFastShipCabins_SE_SSE_CaptainsCabinSignpost0Script: ; 0x76001
	jumpstd $000d
; 0x76004

MovementData_0x76004: ; 0x76004
	big_step_right
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	big_step_up
	step_end
; 0x7600c

MovementData_0x7600c: ; 0x7600c
	step_up
	step_up
	turn_head_left
	step_end
; 0x76010

MovementData_0x76010: ; 0x76010
	step_down
	step_end
; 0x76012

UnknownText_0x76012: ; 0x76012
	db $0, "Whew! Thanks for", $4f
	db "coming along.", $51
	db "Keeping that lit-", $4f
	db "tle girl amused", $55
	db "was exhausting.", $57
; 0x76064

UnknownText_0x76064: ; 0x76064
	db $0, "How do you like", $4f
	db "S.S.AQUA's ride?", $51
	db "She practically", $4f
	db "skates across the", $55
	db "waves.", $57
; 0x760ae

UnknownText_0x760ae: ; 0x760ae
	db $0, "Oh, hello…", $51
	db "I still can't find", $4f
	db "my granddaughter.", $51
	db "If she's on the", $4f
	db "ship, that's OK.", $51
	db "She's an energetic", $4f
	db "child, so she may", $51
	db "be bugging some-", $4f
	db "one. I'm worried…", $57
; 0x76143

UnknownText_0x76143: ; 0x76143
	db $0, $14, ", was it?", $4f
	db "I heard you enter-", $55
	db "tained my grand-", $55
	db "daughter.", $51
	db "I want to thank", $4f
	db "you for that.", $57
; 0x7619b

UnknownText_0x7619b: ; 0x7619b
	db $0, "I know! I'd like", $4f
	db "you to have this!", $57
; 0x761be

UnknownText_0x761be: ; 0x761be
	db $0, "We're traveling", $4f
	db "around the world.", $57
; 0x761e0

UnknownText_0x761e0: ; 0x761e0
	db $0, "CAPTAIN, play with", $4f
	db "me, please?", $51
	db "I'm bored! I want", $4f
	db "to play more!", $57
; 0x7621f

UnknownText_0x7621f: ; 0x7621f
	db $0, "Hi! Will you play", $4f
	db "with me?", $51
	db "…Oh!", $51
	db "Grandpa's worried", $4f
	db "about me?", $51
	db "I have to go!", $51
	db "I have to go find", $4f
	db "Grandpa!", $57
; 0x76284

UnknownText_0x76284: ; 0x76284
	db $0, "Grandpa, here I", $4f
	db "am! I was playing", $51
	db "with the CAPTAIN", $4f
	db "and this guy!", $57
; 0x762c6

UnknownText_0x762c6: ; 0x762c6
	db $0, "Grandpa, here I", $4f
	db "am! I was playing", $51
	db "with the CAPTAIN", $4f
	db "and this big girl!", $57
; 0x7630d

UnknownText_0x7630d: ; 0x7630d
	db $0, "I had lots of fun", $4f
	db "playing!", $57
; 0x76329

PokefanmColinSeenText: ; 0x76329
	db $0, "Hey, kid! Want to", $4f
	db "battle with me?", $57
; 0x7634c

PokefanmColinBeatenText: ; 0x7634c
	db $0, "You're strong!", $57
; 0x7635b

UnknownText_0x7635b: ; 0x7635b
	db $0, "You're traveling", $4f
	db "all alone?", $51
	db "Isn't your mom", $4f
	db "worried?", $57
; 0x7638e

TwinsMegandpeg1SeenText: ; 0x7638e
	db $0, "You think I'm a", $4f
	db "baby?", $55
	db "That's not fair!", $57
; 0x763b4

TwinsMegandpeg1BeatenText: ; 0x763b4
	db $0, "Oh! We lost!", $57
; 0x763c2

UnknownText_0x763c2: ; 0x763c2
	db $0, "Baby is a rude", $4f
	db "name to call us", $55
	db "girls!", $57
; 0x763e9

TwinsMegandpeg2SeenText: ; 0x763e9
	db $0, "I'm not a baby!", $51
	db "That's not nice to", $4f
	db "say to a lady!", $57
; 0x7641a

TwinsMegandpeg2BeatenText: ; 0x7641a
	db $0, "Oh! We lost!", $57
; 0x76428

UnknownText_0x76428: ; 0x76428
	db $0, "Sometimes, kids", $4f
	db "are smarter than", $55
	db "grown-ups!", $57
; 0x76455

PsychicRodneySeenText: ; 0x76455
	db $0, "Ssh! My brain is", $4f
	db "picking up radio", $55
	db "signals!", $57
; 0x76481

PsychicRodneyBeatenText: ; 0x76481
	db $0, "…I hear some-", $4f
	db "thing!", $57
; 0x76497

UnknownText_0x76497: ; 0x76497
	db $0, "I get it. You can", $4f
	db "hear JOHTO's radio", $55
	db "on the FAST SHIP.", $57
; 0x764ce

PokefanmJeremySeenText: ; 0x764ce
	db $0, "What do you think?", $4f
	db "My #MON are", $55
	db "beautiful, yes?", $57
; 0x764fe

PokefanmJeremyBeatenText: ; 0x764fe
	db $0, "Oh, no! My beauti-", $4f
	db "ful #MON!", $57
; 0x7651c

UnknownText_0x7651c: ; 0x7651c
	db $0, "I must go to the", $4f
	db "#MON SALON and", $55
	db "fix them up nice!", $57
; 0x7654f

PokefanfGeorgiaSeenText: ; 0x7654f
	db $0, "I'm going to shop", $4f
	db "at the DEPT.STORE", $55
	db "and then…", $57
; 0x7657d

PokefanfGeorgiaBeatenText: ; 0x7657d
	db $0, "What was I going", $4f
	db "to do?", $57
; 0x76596

UnknownText_0x76596: ; 0x76596
	db $0, "Oh, yes! I have to", $4f
	db "get my #MON out", $55
	db "of DAY-CARE!", $57
; 0x765c7

SupernerdShawnSeenText: ; 0x765c7
	db $0, "What kinds of #", $4f
	db "BALLS do you have", $55
	db "with you?", $57
; 0x765f4

SupernerdShawnBeatenText: ; 0x765f4
	db $0, "Wait! Stop! Don't!", $4f
	db "Please!", $57
; 0x7660f

UnknownText_0x7660f: ; 0x7660f
	db $0, "You should use the", $4f
	db "right BALLS to fit", $55
	db "the situation.", $57
; 0x76645

UnknownText_0x76645: ; 0x76645
	db $0, "FAST SHIP S.S.AQUA", $4f
	db "has arrived in", $55
	db "VERMILION CITY.", $57
; 0x76678

FastShipCabins_SE_SSE_CaptainsCabin_MapEventHeader: ; 0x76678
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $7, $2, 8, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $7, $3, 8, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $13, $2, 9, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $13, $3, 9, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $21, $2, 10, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $21, $3, 10, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 25, 4, $0, MapFastShipCabins_SE_SSE_CaptainsCabinSignpost0Script

	; people-events
	db 11
	person_event $46, 29, 7, $6, $0, 255, 255, $90, 0, UnknownScript_0x75ea7, $ffff
	person_event $40, 21, 6, $9, $0, 255, 255, $90, 0, UnknownScript_0x75f1f, $0730
	person_event $26, 21, 7, $a, $0, 255, 255, $0, 0, UnknownScript_0x75f6d, $0731
	person_event $26, 29, 6, $a, $0, 255, 255, $0, 0, UnknownScript_0x75ebb, $0732
	person_event $2d, 10, 9, $8, $0, 255, 255, $82, 5, TrainerPokefanmColin, $0739
	person_event $26, 8, 6, $6, $0, 255, 255, $82, 1, TrainerTwinsMegandpeg1, $0739
	person_event $26, 8, 7, $6, $0, 255, 255, $82, 1, TrainerTwinsMegandpeg2, $0739
	person_event $2b, 9, 9, $8, $0, 255, 255, $92, 5, TrainerPsychicRodney, $073a
	person_event $2d, 7, 6, $6, $0, 255, 255, $82, 3, TrainerPokefanmJeremy, $073b
	person_event $2e, 9, 9, $9, $0, 255, 255, $82, 1, TrainerPokefanfGeorgia, $073b
	person_event $2b, 19, 5, $3, $0, 255, 255, $b2, 2, TrainerSupernerdShawn, $073a
; 0x76730

FastShipB1F_MapScriptHeader: ; 0x76730
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x7673a, $0000
	dw UnknownScript_0x7673b, $0000

	; callback count
	db 0
; 0x7673a

UnknownScript_0x7673a: ; 0x7673a
	end
; 0x7673b

UnknownScript_0x7673b: ; 0x7673b
	end
; 0x7673c

UnknownScript_0x7673c: ; 0x7673c
	checkbit1 $072f
	iftrue UnknownScript_0x76766
	applymovement $3, MovementData_0x76876
	moveperson $2, $1e, $6
	appear $2
	pause 5
	disappear $3
	end
; 0x76751

UnknownScript_0x76751: ; 0x76751
	checkbit1 $072e
	iftrue UnknownScript_0x76766
	applymovement $2, MovementData_0x76871
	moveperson $3, $1f, $6
	appear $3
	pause 5
	disappear $2
	end
; 0x76766

UnknownScript_0x76766: ; 0x76766
	end
; 0x76767

UnknownScript_0x76767: ; 0x76767
	faceplayer
	loadfont
	checkbit1 $0030
	iftrue UnknownScript_0x767a0
	checkbit1 $0033
	iftrue UnknownScript_0x7678d
	checkbit1 $0034
	iftrue UnknownScript_0x76787
	2writetext UnknownText_0x7687b
	closetext
	loadmovesprites
	setbit1 $0034
	clearbit1 $072d
	end
; 0x76787

UnknownScript_0x76787: ; 0x76787
	2writetext UnknownText_0x76907
	closetext
	loadmovesprites
	end
; 0x7678d

UnknownScript_0x7678d: ; 0x7678d
	2writetext UnknownText_0x7692e
	checkbit1 $0032
	iffalse UnknownScript_0x76799
	closetext
	loadmovesprites
	end
; 0x76799

UnknownScript_0x76799: ; 0x76799
	keeptextopen
	2writetext UnknownText_0x7696d
	closetext
	loadmovesprites
	end
; 0x767a0

UnknownScript_0x767a0: ; 0x767a0
	2writetext UnknownText_0x7699d
	closetext
	loadmovesprites
	end
; 0x767a6

TrainerSailorJeff: ; 0x767a6
	; bit/flag number
	dw $57a

	; trainer group && trainer id
	db SAILOR, JEFF

	; text when seen
	dw SailorJeffSeenText

	; text when trainer beaten
	dw SailorJeffBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SailorJeffScript
; 0x767b2

SailorJeffScript: ; 0x767b2
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76a38
	closetext
	loadmovesprites
	end
; 0x767ba

TrainerPicnickerDebra: ; 0x767ba
	; bit/flag number
	dw $485

	; trainer group && trainer id
	db PICNICKER, DEBRA

	; text when seen
	dw PicnickerDebraSeenText

	; text when trainer beaten
	dw PicnickerDebraBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerDebraScript
; 0x767c6

PicnickerDebraScript: ; 0x767c6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76a99
	closetext
	loadmovesprites
	end
; 0x767ce

TrainerJugglerFritz: ; 0x767ce
	; bit/flag number
	dw $496

	; trainer group && trainer id
	db JUGGLER, FRITZ

	; text when seen
	dw JugglerFritzSeenText

	; text when trainer beaten
	dw JugglerFritzBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw JugglerFritzScript
; 0x767da

JugglerFritzScript: ; 0x767da
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76b02
	closetext
	loadmovesprites
	end
; 0x767e2

TrainerSailorGarrett: ; 0x767e2
	; bit/flag number
	dw $57b

	; trainer group && trainer id
	db SAILOR, GARRETT

	; text when seen
	dw SailorGarrettSeenText

	; text when trainer beaten
	dw SailorGarrettBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SailorGarrettScript
; 0x767ee

SailorGarrettScript: ; 0x767ee
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76b7a
	closetext
	loadmovesprites
	end
; 0x767f6

TrainerFisherJonah: ; 0x767f6
	; bit/flag number
	dw $459

	; trainer group && trainer id
	db FISHER, JONAH

	; text when seen
	dw FisherJonahSeenText

	; text when trainer beaten
	dw FisherJonahBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherJonahScript
; 0x76802

FisherJonahScript: ; 0x76802
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76c22
	closetext
	loadmovesprites
	end
; 0x7680a

TrainerBlackbeltWai: ; 0x7680a
	; bit/flag number
	dw $4ac

	; trainer group && trainer id
	db BLACKBELT_T, WAI

	; text when seen
	dw BlackbeltWaiSeenText

	; text when trainer beaten
	dw BlackbeltWaiBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BlackbeltWaiScript
; 0x76816

BlackbeltWaiScript: ; 0x76816
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76c9e
	closetext
	loadmovesprites
	end
; 0x7681e

TrainerSailorKenneth: ; 0x7681e
	; bit/flag number
	dw $57c

	; trainer group && trainer id
	db SAILOR, KENNETH

	; text when seen
	dw SailorKennethSeenText

	; text when trainer beaten
	dw SailorKennethBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SailorKennethScript
; 0x7682a

SailorKennethScript: ; 0x7682a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76d5f
	closetext
	loadmovesprites
	end
; 0x76832

TrainerTeacherShirley: ; 0x76832
	; bit/flag number
	dw $5b7

	; trainer group && trainer id
	db TEACHER, SHIRLEY

	; text when seen
	dw TeacherShirleySeenText

	; text when trainer beaten
	dw TeacherShirleyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TeacherShirleyScript
; 0x7683e

TeacherShirleyScript: ; 0x7683e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76de1
	closetext
	loadmovesprites
	end
; 0x76846

TrainerSchoolboyNate: ; 0x76846
	; bit/flag number
	dw $476

	; trainer group && trainer id
	db SCHOOLBOY, NATE

	; text when seen
	dw SchoolboyNateSeenText

	; text when trainer beaten
	dw SchoolboyNateBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyNateScript
; 0x76852

SchoolboyNateScript: ; 0x76852
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76e3d
	closetext
	loadmovesprites
	end
; 0x7685a

TrainerSchoolboyRicky: ; 0x7685a
	; bit/flag number
	dw $477

	; trainer group && trainer id
	db SCHOOLBOY, RICKY

	; text when seen
	dw SchoolboyRickySeenText

	; text when trainer beaten
	dw SchoolboyRickyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyRickyScript
; 0x76866

SchoolboyRickyScript: ; 0x76866
	talkaftercancel
	loadfont
	2writetext UnknownText_0x76eb6
	closetext
	loadmovesprites
	end
; 0x7686e

MapFastShipB1FSignpost0Script: ; 0x7686e
	jumpstd $000d
; 0x76871

MovementData_0x76871: ; 0x76871
	fix_facing
	big_step_right
	remove_fixed_facing
	turn_head_down
	step_end
; 0x76876

MovementData_0x76876: ; 0x76876
	fix_facing
	big_step_left
	remove_fixed_facing
	turn_head_down
	step_end
; 0x7687b

UnknownText_0x7687b: ; 0x7687b
	db $0, "Hey, kid. Could I", $4f
	db "get you to look", $55
	db "for my buddy?", $51
	db "He's goofing off", $4f
	db "somewhere, that", $55
	db "lazy bum!", $51
	db "I want to go find", $4f
	db "him, but I'm on", $55
	db "duty right now.", $57
; 0x76907

UnknownText_0x76907: ; 0x76907
	db $0, "Oh, gee…", $51
	db "The CAPTAIN will", $4f
	db "be furious…", $57
; 0x7692e

UnknownText_0x7692e: ; 0x7692e
	db $0, "Thanks, kid!", $4f
	db "I chewed him out", $51
	db "good so he'll quit", $4f
	db "slacking off!", $57
; 0x7696d

UnknownText_0x7696d: ; 0x7696d
	db $0, "A little girl?", $51
	db "I may have seen", $4f
	db "her go by here.", $57
; 0x7699d

UnknownText_0x7699d: ; 0x7699d
	db $0, "The dining room is", $4f
	db "up ahead.", $51
	db "The stairs at the", $4f
	db "end lead to the", $55
	db "CAPTAIN's cabin.", $57
; 0x769ed

SailorJeffSeenText: ; 0x769ed
	db $0, "Nothing beats a", $4f
	db "battle when I'm", $55
	db "on my break.", $57
; 0x76a1a

SailorJeffBeatenText: ; 0x76a1a
	db $0, "Win or lose, my", $4f
	db "break's over!", $57
; 0x76a38

UnknownText_0x76a38: ; 0x76a38
	db $0, "I guess I can't", $4f
	db "win if I don't get", $55
	db "serious.", $57
; 0x76a63

PicnickerDebraSeenText: ; 0x76a63
	db $0, "I'm so bored.", $4f
	db "Want to battle?", $57
; 0x76a81

PicnickerDebraBeatenText: ; 0x76a81
	db $0, "Yow! You're too", $4f
	db "strong!", $57
; 0x76a99

UnknownText_0x76a99: ; 0x76a99
	db $0, "SAFFRON, CELADON…", $4f
	db "I hear there are", $51
	db "many big cities", $4f
	db "in KANTO.", $57
; 0x76ad7

JugglerFritzSeenText: ; 0x76ad7
	db $0, "Urrf…", $4f
	db "I'm seasick!", $57
; 0x76aea

JugglerFritzBeatenText: ; 0x76aea
	db $0, "I can't move any-", $4f
	db "more…", $57
; 0x76b02

UnknownText_0x76b02: ; 0x76b02
	db $0, "No more ships for", $4f
	db "me. Next time,", $51
	db "I'm taking the", $4f
	db "MAGNET TRAIN.", $57
; 0x76b40

SailorGarrettSeenText: ; 0x76b40
	db $0, "This is where we", $4f
	db "sailors work!", $57
; 0x76b60

SailorGarrettBeatenText: ; 0x76b60
	db $0, "I lost on my home", $4f
	db "field…", $57
; 0x76b7a

UnknownText_0x76b7a: ; 0x76b7a
	db $0, "We get different", $4f
	db "passengers from", $51
	db "VERMILION CITY to", $4f
	db "OLIVINE CITY.", $57
; 0x76bbc

FisherJonahSeenText: ; 0x76bbc
	db $0, "Even though we're", $4f
	db "out on the sea, I", $55
	db "can't fish!", $51
	db "This is boring!", $4f
	db "Let's battle!", $57
; 0x76c08

FisherJonahBeatenText: ; 0x76c08
	db $0, "I… I'm not bored", $4f
	db "anymore…", $57
; 0x76c22

UnknownText_0x76c22: ; 0x76c22
	db $0, "I plan to fish off", $4f
	db "VERMILION's pier.", $57
; 0x76c47

BlackbeltWaiSeenText: ; 0x76c47
	db $0, "I'm building up my", $4f
	db "legs by bracing", $51
	db "against the ship's", $4f
	db "rocking!", $57
; 0x76c85

BlackbeltWaiBeatenText: ; 0x76c85
	db $0, "Rocked and rolled", $4f
	db "over!", $57
; 0x76c9e

UnknownText_0x76c9e: ; 0x76c9e
	db $0, "I couldn't find", $4f
	db "the KARATE KING in", $55
	db "JOHTO.", $51
	db "He's supposed to", $4f
	db "be training in a", $55
	db "cave somewhere.", $57
; 0x76cf9

SailorKennethSeenText: ; 0x76cf9
	db $0, "I'm a sailor man!", $51
	db "But I'm training", $4f
	db "#MON, so I can", $55
	db "become the CHAMP!", $57
; 0x76d3c

SailorKennethBeatenText: ; 0x76d3c
	db $0, "My lack of train-", $4f
	db "ing is obvious…", $57
; 0x76d5f

UnknownText_0x76d5f: ; 0x76d5f
	db $0, "Eight BADGES!", $4f
	db "They must prove", $51
	db "that you've beaten", $4f
	db "GYM LEADERS.", $51
	db "No wonder you're", $4f
	db "so good!", $57
; 0x76db6

TeacherShirleySeenText: ; 0x76db6
	db $0, "Don't lay a finger", $4f
	db "on my students!", $57
; 0x76dd9

TeacherShirleyBeatenText: ; 0x76dd9
	db $0, "Aaack!", $57
; 0x76de1

UnknownText_0x76de1: ; 0x76de1
	db $0, "We're on a field", $4f
	db "trip to the RUINS", $55
	db "outside VIOLET.", $57
; 0x76e14

SchoolboyNateSeenText: ; 0x76e14
	db $0, "Do you know the", $4f
	db "RUINS OF ALPH?", $57
; 0x76e34

SchoolboyNateBeatenText: ; 0x76e34
	db $0, "Yaargh!", $57
; 0x76e3d

UnknownText_0x76e3d: ; 0x76e3d
	db $0, "Radios pick up", $4f
	db "strange signals", $55
	db "inside the RUINS.", $57
; 0x76e6f

SchoolboyRickySeenText: ; 0x76e6f
	db $0, "There are some odd", $4f
	db "stone panels in", $55
	db "the RUINS OF ALPH.", $57
; 0x76ea6

SchoolboyRickyBeatenText: ; 0x76ea6
	db $0, "I was done in!", $57
; 0x76eb6

UnknownText_0x76eb6: ; 0x76eb6
	db $0, "I read that there", $4f
	db "are four of those", $55
	db "stone panels.", $57
; 0x76ee9

FastShipB1F_MapEventHeader: ; 0x76ee9
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $b, $5, 11, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F
	warp_def $d, $1f, 12, GROUP_FAST_SHIP_1F, MAP_FAST_SHIP_1F

	; xy triggers
	db 2
	xy_trigger 0, $7, $1e, $0, UnknownScript_0x7673c, $0, $0
	xy_trigger 0, $7, $1f, $0, UnknownScript_0x76751, $0, $0

	; signposts
	db 1
	signpost 9, 27, $0, MapFastShipB1FSignpost0Script

	; people-events
	db 12
	person_event $49, 10, 34, $6, $0, 255, 255, $90, 0, UnknownScript_0x76767, $072e
	person_event $49, 10, 35, $6, $0, 255, 255, $90, 0, UnknownScript_0x76767, $072f
	person_event $49, 15, 13, $7, $0, 255, 255, $92, 3, TrainerSailorJeff, $0739
	person_event $28, 8, 10, $7, $0, 255, 255, $a2, 1, TrainerPicnickerDebra, $0739
	person_event $2b, 13, 30, $9, $0, 255, 255, $92, 1, TrainerJugglerFritz, $0739
	person_event $49, 8, 21, $9, $0, 255, 255, $92, 4, TrainerSailorGarrett, $073a
	person_event $3a, 12, 29, $7, $0, 255, 255, $a2, 3, TrainerFisherJonah, $073a
	person_event $41, 15, 19, $1f, $0, 255, 255, $b2, 3, TrainerBlackbeltWai, $073a
	person_event $49, 8, 27, $9, $0, 255, 255, $92, 4, TrainerSailorKenneth, $073b
	person_event $29, 15, 13, $7, $0, 255, 255, $82, 3, TrainerTeacherShirley, $073b
	person_event $27, 13, 18, $3, $0, 255, 255, $92, 1, TrainerSchoolboyNate, $073b
	person_event $27, 15, 18, $a, $0, 255, 255, $92, 1, TrainerSchoolboyRicky, $073b
; 0x76faa

OlivinePortPassage_MapScriptHeader: ; 0x76faa
	; trigger count
	db 0

	; callback count
	db 0
; 0x76fac

UnknownScript_0x76fac: ; 0x76fac
	jumptextfaceplayer UnknownText_0x76faf
; 0x76faf

UnknownText_0x76faf: ; 0x76faf
	db $0, "FAST SHIP S.S.AQUA", $4f
	db "sails to KANTO on", $51
	db "Mondays and Fri-", $4f
	db "days.", $57
; 0x76fec

OlivinePortPassage_MapEventHeader: ; 0x76fec
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $0, $f, 10, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $0, $10, 11, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $4, $f, 4, GROUP_OLIVINE_PORT_PASSAGE, MAP_OLIVINE_PORT_PASSAGE
	warp_def $2, $3, 3, GROUP_OLIVINE_PORT_PASSAGE, MAP_OLIVINE_PORT_PASSAGE
	warp_def $e, $3, 1, GROUP_OLIVINE_PORT, MAP_OLIVINE_PORT

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $2d, 5, 21, $8, $0, 255, 255, $0, 0, UnknownScript_0x76fac, $0733
; 0x77018

VermilionPortPassage_MapScriptHeader: ; 0x77018
	; trigger count
	db 0

	; callback count
	db 0
; 0x7701a

UnknownScript_0x7701a: ; 0x7701a
	jumptextfaceplayer UnknownText_0x7701d
; 0x7701d

UnknownText_0x7701d: ; 0x7701d
	db $0, "The FAST SHIP", $4f
	db "sails on Wednes-", $55
	db "days and Sundays", $55
	db "every week.", $57
; 0x7705a

VermilionPortPassage_MapEventHeader: ; 0x7705a
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $0, $f, 8, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $0, $10, 9, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $4, $f, 4, GROUP_VERMILION_PORT_PASSAGE, MAP_VERMILION_PORT_PASSAGE
	warp_def $2, $3, 3, GROUP_VERMILION_PORT_PASSAGE, MAP_VERMILION_PORT_PASSAGE
	warp_def $e, $3, 1, GROUP_VERMILION_PORT, MAP_VERMILION_PORT

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $29, 5, 21, $8, $0, 255, 255, $0, 0, UnknownScript_0x7701a, $ffff
; 0x77086

MountMoonSquare_MapScriptHeader: ; 0x77086
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x77092, $0000

	; callback count
	db 2

	; callbacks

	dbw 5, UnknownScript_0x77093

	dbw 2, UnknownScript_0x77097
; 0x77092

UnknownScript_0x77092: ; 0x77092
	end
; 0x77093

UnknownScript_0x77093: ; 0x77093
	setbit1 $00ec
	return
; 0x77097

UnknownScript_0x77097: ; 0x77097
	disappear $4
	return
; 0x7709a

UnknownScript_0x7709a: ; 0x7709a
	checkbit2 $0058
	iftrue UnknownScript_0x77117
	checkcode $b
	if_not_equal MONDAY, UnknownScript_0x77117
	checktime $4
	iffalse UnknownScript_0x77117
	appear $2
	appear $3
	applymovement $0, MovementData_0x77121
	pause 15
	appear $4
	spriteface $2, $3
	cry CLEFAIRY
	waitbutton
	pause 30
	follow $2, $3
	cry CLEFAIRY
	applymovement $2, MovementData_0x77123
	cry CLEFAIRY
	applymovement $2, MovementData_0x77126
	cry CLEFAIRY
	applymovement $2, MovementData_0x77128
	cry CLEFAIRY
	applymovement $2, MovementData_0x7712b
	cry CLEFAIRY
	applymovement $2, MovementData_0x7712d
	stopfollow
	applymovement $3, MovementData_0x77130
	follow $2, $3
	applymovement $2, MovementData_0x77132
	stopfollow
	spriteface $2, $0
	pause 10
	showemote $0, $2, 15
	spriteface $2, $0
	cry CLEFAIRY
	pause 15
	follow $2, $3
	applymovement $2, MovementData_0x77134
	disappear $2
	disappear $3
	stopfollow
	clearbit1 $00ec
	setbit2 $0058
	end
; 0x77117

UnknownScript_0x77117: ; 0x77117
	end
; 0x77118

MapMountMoonSquareSignpostItem0: ; 0x77118
	dw $00ec
	db MOON_STONE
	
; 0x7711b

MapMountMoonSquareSignpost1Script: ; 0x7711b
	jumptext UnknownText_0x7713b
; 0x7711e

UnknownScript_0x7711e: ; 0x7711e
	jumpstd $000f
; 0x77121

MovementData_0x77121: ; 0x77121
	step_up
	step_end
; 0x77123

MovementData_0x77123: ; 0x77123
	slow_step_down
	slow_jump_step_down
	step_end
; 0x77126

MovementData_0x77126: ; 0x77126
	slow_jump_step_right
	step_end
; 0x77128

MovementData_0x77128: ; 0x77128
	slow_step_up
	slow_jump_step_up
	step_end
; 0x7712b

MovementData_0x7712b: ; 0x7712b
	slow_jump_step_left
	step_end
; 0x7712d

MovementData_0x7712d: ; 0x7712d
	slow_step_down
	slow_jump_step_down
	step_end
; 0x77130

MovementData_0x77130: ; 0x77130
	slow_step_down
	step_end
; 0x77132

MovementData_0x77132: ; 0x77132
	slow_step_right
	step_end
; 0x77134

MovementData_0x77134: ; 0x77134
	step_right
	step_right
	step_right
	jump_step_right
	step_right
	step_right
	step_end
; 0x7713b

UnknownText_0x7713b: ; 0x7713b
	db $0, "MT.MOON SQUARE", $4f
	db "DON'T LITTER", $57
; 0x77158

MountMoonSquare_MapEventHeader: ; 0x77158
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $5, $14, 5, GROUP_MOUNT_MOON, MAP_MOUNT_MOON
	warp_def $b, $16, 6, GROUP_MOUNT_MOON, MAP_MOUNT_MOON
	warp_def $7, $d, 1, GROUP_MOUNT_MOON_GIFT_SHOP, MAP_MOUNT_MOON_GIFT_SHOP

	; xy triggers
	db 1
	xy_trigger 0, $b, $7, $0, UnknownScript_0x7709a, $0, $0

	; signposts
	db 2
	signpost 7, 7, $7, MapMountMoonSquareSignpostItem0
	signpost 7, 17, $0, MapMountMoonSquareSignpost1Script

	; people-events
	db 3
	person_event $4d, 10, 10, $6, $0, 255, 255, $0, 0, ObjectEvent, $0779
	person_event $4d, 10, 11, $6, $0, 255, 255, $0, 0, ObjectEvent, $0779
	person_event $59, 11, 11, $18, $0, 255, 255, $0, 0, UnknownScript_0x7711e, $0778
; 0x771a6

MountMoonGiftShop_MapScriptHeader: ; 0x771a6
	; trigger count
	db 0

	; callback count
	db 0
; 0x771a8

UnknownScript_0x771a8: ; 0x771a8
	faceplayer
	loadfont
	pokemart $0, $001f
	loadmovesprites
	end
; 0x771b0

UnknownScript_0x771b0: ; 0x771b0
	jumptextfaceplayer UnknownText_0x771b3
; 0x771b3

UnknownText_0x771b3: ; 0x771b3
	db $0, "When the sun goes", $4f
	db "down, CLEFAIRY", $55
	db "come out to play.", $57
; 0x771e7

MountMoonGiftShop_MapEventHeader: ; 0x771e7
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $3, 3, GROUP_MOUNT_MOON_SQUARE, MAP_MOUNT_MOON_SQUARE
	warp_def $7, $4, 3, GROUP_MOUNT_MOON_SQUARE, MAP_MOUNT_MOON_SQUARE

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $2f, 7, 8, $6, $0, 255, 1, $0, 0, UnknownScript_0x771a8, $ffff
	person_event $2f, 6, 5, $9, $0, 255, 2, $0, 0, UnknownScript_0x771a8, $ffff
	person_event $28, 10, 5, $5, $1, 255, 1, $0, 0, UnknownScript_0x771b0, $ffff
	person_event $28, 8, 9, $4, $10, 255, 2, $0, 0, UnknownScript_0x771b0, $ffff
; 0x7722b

TinTowerRoof_MapScriptHeader: ; 0x7722b
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x77230
; 0x77230

UnknownScript_0x77230: ; 0x77230
	checkbit1 $0317
	iftrue UnknownScript_0x77241
	checkitem RAINBOW_WING
	iftrue UnknownScript_0x7723e
	2jump UnknownScript_0x77241
; 0x7723e

UnknownScript_0x7723e: ; 0x7723e
	appear $2
	return
; 0x77241

UnknownScript_0x77241: ; 0x77241
	disappear $2
	return
; 0x77244

UnknownScript_0x77244: ; 0x77244
	faceplayer
	loadfont
	2writetext UnknownText_0x77260
	cry HO_OH
	pause 15
	loadmovesprites
	setbit1 $0317
	writecode $3, $a
	loadpokedata HO_OH, 60
	startbattle
	disappear $2
	returnafterbattle
	setbit1 $07b7
	end
; 0x77260

UnknownText_0x77260: ; 0x77260
	db $0, "Shaoooh!", $57
; 0x7726a

TinTowerRoof_MapEventHeader: ; 0x7726a
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $d, $9, 4, GROUP_TIN_TOWER_9F, MAP_TIN_TOWER_9F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $a2, 9, 13, $16, $0, 255, 255, $80, 0, UnknownScript_0x77244, $073c
; 0x77282

SECTION "bank1E",DATA,BANK[$1E]

Route34_MapScriptHeader: ; 0x78000
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x78005
; 0x78005

UnknownScript_0x78005: ; 0x78005
	checkbit2 $0005
	iftrue UnknownScript_0x78014
	clearbit1 $06e5
	setbit1 $06e6
	2jump UnknownScript_0x7801d
; 0x78014

UnknownScript_0x78014: ; 0x78014
	setbit1 $06e5
	clearbit1 $06e6
	2jump UnknownScript_0x7801d
; 0x7801d

UnknownScript_0x7801d: ; 0x7801d
	checkbit2 $0006
	iffalse UnknownScript_0x78029
	clearbit1 $06e7
	2jump UnknownScript_0x7802f
; 0x78029

UnknownScript_0x78029: ; 0x78029
	setbit1 $06e7
	2jump UnknownScript_0x7802f
; 0x7802f

UnknownScript_0x7802f: ; 0x7802f
	checkbit2 $0007
	iffalse UnknownScript_0x78039
	clearbit1 $06e8
	return
; 0x78039

UnknownScript_0x78039: ; 0x78039
	setbit1 $06e8
	return
; 0x7803d

UnknownScript_0x7803d: ; 0x7803d
	faceplayer
	loadfont
	special $0020
	closetext
	loadmovesprites
	if_equal $1, UnknownScript_0x7805a
	clearbit2 $0005
	checkcode $9
	if_equal $3, UnknownScript_0x7805b
	applymovement $8, MovementData_0x78333
	playsound $001f
	disappear $8
UnknownScript_0x7805a: ; 0x7805a
	end
; 0x7805b

UnknownScript_0x7805b: ; 0x7805b
	applymovement $8, MovementData_0x78337
	playsound $001f
	disappear $8
	end
; 0x78065

UnknownScript_0x78065: ; 0x78065
	loadfont
	special $0045
	loadmovesprites
	end
; 0x7806b

UnknownScript_0x7806b: ; 0x7806b
	loadfont
	special $0046
	loadmovesprites
	end
; 0x78071

TrainerCamperTodd1: ; 0x78071
	; bit/flag number
	dw $41b

	; trainer group && trainer id
	db CAMPER, TODD1

	; text when seen
	dw CamperTodd1SeenText

	; text when trainer beaten
	dw CamperTodd1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperTodd1Script
; 0x7807d

CamperTodd1Script: ; 0x7807d
	writecode $17, $14
	talkaftercancel
	loadfont
	checkbit2 $0070
	iftrue UnknownScript_0x780bd
	checkbit2 $0061
	iftrue UnknownScript_0x78131
	checkcellnum $14
	iftrue UnknownScript_0x78143
	checkbit1 $027d
	iftrue UnknownScript_0x780a6
	2writetext UnknownText_0x784f0
	keeptextopen
	setbit1 $027d
	2call UnknownScript_0x78137
	2jump UnknownScript_0x780a9
; 0x780a6

UnknownScript_0x780a6: ; 0x780a6
	2call UnknownScript_0x7813b
UnknownScript_0x780a9: ; 0x780a9
	askforphonenumber $14
	if_equal $1, UnknownScript_0x7814b
	if_equal $2, UnknownScript_0x78147
	trainertotext CAMPER, TODD1, $0
	2call UnknownScript_0x7813f
	2jump UnknownScript_0x78143
; 0x780bd

UnknownScript_0x780bd: ; 0x780bd
	2call UnknownScript_0x7814f
	winlosstext CamperTodd1BeatenText, $0000
	copybytetovar $d9fe
	if_equal $4, UnknownScript_0x780dc
	if_equal $3, UnknownScript_0x780e2
	if_equal $2, UnknownScript_0x780e8
	if_equal $1, UnknownScript_0x780ee
	if_equal $0, UnknownScript_0x780f4
UnknownScript_0x780dc: ; 0x780dc
	checkbit1 $00cd
	iftrue UnknownScript_0x78128
UnknownScript_0x780e2: ; 0x780e2
	checkbit1 $0044
	iftrue UnknownScript_0x7811b
UnknownScript_0x780e8: ; 0x780e8
	checkbit2 $004b
	iftrue UnknownScript_0x7810e
UnknownScript_0x780ee: ; 0x780ee
	checkbit2 $0045
	iftrue UnknownScript_0x78101
UnknownScript_0x780f4: ; 0x780f4
	loadtrainer CAMPER, TODD1
	startbattle
	returnafterbattle
	loadvar $d9fe, $1
	clearbit2 $0070
	end
; 0x78101

UnknownScript_0x78101: ; 0x78101
	loadtrainer CAMPER, TODD2
	startbattle
	returnafterbattle
	loadvar $d9fe, $2
	clearbit2 $0070
	end
; 0x7810e

UnknownScript_0x7810e: ; 0x7810e
	loadtrainer CAMPER, TODD3
	startbattle
	returnafterbattle
	loadvar $d9fe, $3
	clearbit2 $0070
	end
; 0x7811b

UnknownScript_0x7811b: ; 0x7811b
	loadtrainer CAMPER, TODD4
	startbattle
	returnafterbattle
	loadvar $d9fe, $4
	clearbit2 $0070
	end
; 0x78128

UnknownScript_0x78128: ; 0x78128
	loadtrainer CAMPER, TODD5
	startbattle
	returnafterbattle
	clearbit2 $0070
	end
; 0x78131

UnknownScript_0x78131: ; 0x78131
	2writetext UnknownText_0x78532
	closetext
	loadmovesprites
	end
; 0x78137

UnknownScript_0x78137: ; 0x78137
	jumpstd $0019
	end
; 0x7813b

UnknownScript_0x7813b: ; 0x7813b
	jumpstd $001a
	end
; 0x7813f

UnknownScript_0x7813f: ; 0x7813f
	jumpstd $001b
	end
; 0x78143

UnknownScript_0x78143: ; 0x78143
	jumpstd $001c
	end
; 0x78147

UnknownScript_0x78147: ; 0x78147
	jumpstd $001d
	end
; 0x7814b

UnknownScript_0x7814b: ; 0x7814b
	jumpstd $001e
	end
; 0x7814f

UnknownScript_0x7814f: ; 0x7814f
	jumpstd $001f
	end
; 0x78153

TrainerPicnickerGina1: ; 0x78153
	; bit/flag number
	dw $47f

	; trainer group && trainer id
	db PICNICKER, GINA1

	; text when seen
	dw PicnickerGina1SeenText

	; text when trainer beaten
	dw PicnickerGina1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerGina1Script
; 0x7815f

PicnickerGina1Script: ; 0x7815f
	writecode $17, $15
	talkaftercancel
	loadfont
	checkbit2 $0071
	iftrue UnknownScript_0x7819f
	checkbit2 $0080
	iftrue UnknownScript_0x78213
	checkcellnum $15
	iftrue UnknownScript_0x78234
	checkbit1 $027f
	iftrue UnknownScript_0x78188
	2writetext UnknownText_0x785b8
	keeptextopen
	setbit1 $027f
	2call UnknownScript_0x78228
	2jump UnknownScript_0x7818b
; 0x78188

UnknownScript_0x78188: ; 0x78188
	2call UnknownScript_0x7822c
UnknownScript_0x7818b: ; 0x7818b
	askforphonenumber $15
	if_equal $1, UnknownScript_0x7823c
	if_equal $2, UnknownScript_0x78238
	trainertotext PICNICKER, GINA1, $0
	2call UnknownScript_0x78230
	2jump UnknownScript_0x78234
; 0x7819f

UnknownScript_0x7819f: ; 0x7819f
	2call UnknownScript_0x78240
	winlosstext PicnickerGina1BeatenText, $0000
	copybytetovar $d9ff
	if_equal $4, UnknownScript_0x781be
	if_equal $3, UnknownScript_0x781c4
	if_equal $2, UnknownScript_0x781ca
	if_equal $1, UnknownScript_0x781d0
	if_equal $0, UnknownScript_0x781d6
UnknownScript_0x781be: ; 0x781be
	checkbit1 $00cd
	iftrue UnknownScript_0x7820a
UnknownScript_0x781c4: ; 0x781c4
	checkbit1 $0044
	iftrue UnknownScript_0x781fd
UnknownScript_0x781ca: ; 0x781ca
	checkbit1 $0021
	iftrue UnknownScript_0x781f0
UnknownScript_0x781d0: ; 0x781d0
	checkbit2 $0049
	iftrue UnknownScript_0x781e3
UnknownScript_0x781d6: ; 0x781d6
	loadtrainer PICNICKER, GINA1
	startbattle
	returnafterbattle
	loadvar $d9ff, $1
	clearbit2 $0071
	end
; 0x781e3

UnknownScript_0x781e3: ; 0x781e3
	loadtrainer PICNICKER, GINA2
	startbattle
	returnafterbattle
	loadvar $d9ff, $2
	clearbit2 $0071
	end
; 0x781f0

UnknownScript_0x781f0: ; 0x781f0
	loadtrainer PICNICKER, GINA3
	startbattle
	returnafterbattle
	loadvar $d9ff, $3
	clearbit2 $0071
	end
; 0x781fd

UnknownScript_0x781fd: ; 0x781fd
	loadtrainer PICNICKER, GINA4
	startbattle
	returnafterbattle
	loadvar $d9ff, $4
	clearbit2 $0071
	end
; 0x7820a

UnknownScript_0x7820a: ; 0x7820a
	loadtrainer PICNICKER, GINA5
	startbattle
	returnafterbattle
	clearbit2 $0071
	end
; 0x78213

UnknownScript_0x78213: ; 0x78213
	2call UnknownScript_0x78244
	verbosegiveitem LEAF_STONE, 1
	iffalse UnknownScript_0x78225
	clearbit2 $0080
	setbit1 $0100
	2jump UnknownScript_0x78234
; 0x78225

UnknownScript_0x78225: ; 0x78225
	2jump UnknownScript_0x78248
; 0x78228

UnknownScript_0x78228: ; 0x78228
	jumpstd $0023
	end
; 0x7822c

UnknownScript_0x7822c: ; 0x7822c
	jumpstd $0024
	end
; 0x78230

UnknownScript_0x78230: ; 0x78230
	jumpstd $0025
	end
; 0x78234

UnknownScript_0x78234: ; 0x78234
	jumpstd $0026
	end
; 0x78238

UnknownScript_0x78238: ; 0x78238
	jumpstd $0027
	end
; 0x7823c

UnknownScript_0x7823c: ; 0x7823c
	jumpstd $0028
	end
; 0x78240

UnknownScript_0x78240: ; 0x78240
	jumpstd $0029
	end
; 0x78244

UnknownScript_0x78244: ; 0x78244
	jumpstd $002a
	end
; 0x78248

UnknownScript_0x78248: ; 0x78248
	jumpstd $002b
	end
; 0x7824c

UnknownScript_0x7824c: ; 0x7824c
	faceplayer
	loadfont
	checktime $4
	iffalse UnknownScript_0x78276
	checkbit1 $0546
	iftrue UnknownScript_0x78270
	playmusic $000c
	2writetext UnknownText_0x785e4
	closetext
	loadmovesprites
	winlosstext UnknownText_0x78609, $0000
	loadtrainer OFFICER, KEITH
	startbattle
	returnafterbattle
	setbit1 $0546
	loadmovesprites
	end
; 0x78270

UnknownScript_0x78270: ; 0x78270
	2writetext UnknownText_0x78624
	closetext
	loadmovesprites
	end
; 0x78276

UnknownScript_0x78276: ; 0x78276
	2writetext UnknownText_0x7866a
	closetext
	loadmovesprites
	end
; 0x7827c

TrainerYoungsterSamuel: ; 0x7827c
	; bit/flag number
	dw $5ad

	; trainer group && trainer id
	db YOUNGSTER, SAMUEL

	; text when seen
	dw YoungsterSamuelSeenText

	; text when trainer beaten
	dw YoungsterSamuelBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterSamuelScript
; 0x78288

YoungsterSamuelScript: ; 0x78288
	talkaftercancel
	loadfont
	2writetext UnknownText_0x783d8
	closetext
	loadmovesprites
	end
; 0x78290

TrainerYoungsterIan: ; 0x78290
	; bit/flag number
	dw $5ae

	; trainer group && trainer id
	db YOUNGSTER, IAN

	; text when seen
	dw YoungsterIanSeenText

	; text when trainer beaten
	dw YoungsterIanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterIanScript
; 0x7829c

YoungsterIanScript: ; 0x7829c
	talkaftercancel
	loadfont
	2writetext UnknownText_0x78469
	closetext
	loadmovesprites
	end
; 0x782a4

TrainerPokefanmBrandon: ; 0x782a4
	; bit/flag number
	dw $4d3

	; trainer group && trainer id
	db POKEFANM, BRANDON

	; text when seen
	dw PokefanmBrandonSeenText

	; text when trainer beaten
	dw PokefanmBrandonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmBrandonScript
; 0x782b0

PokefanmBrandonScript: ; 0x782b0
	talkaftercancel
	loadfont
	2writetext UnknownText_0x786fc
	closetext
	loadmovesprites
	end
; 0x782b8

TrainerCooltrainerfIrene: ; 0x782b8
	; bit/flag number
	dw $560

	; trainer group && trainer id
	db COOLTRAINERF, IRENE

	; text when seen
	dw CooltrainerfIreneSeenText

	; text when trainer beaten
	dw CooltrainerfIreneBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfIreneScript
; 0x782c4

CooltrainerfIreneScript: ; 0x782c4
	talkaftercancel
	loadfont
	checkbit1 $0070
	iftrue UnknownScript_0x782d2
	2writetext UnknownText_0x7877f
	closetext
	loadmovesprites
	end
; 0x782d2

UnknownScript_0x782d2: ; 0x782d2
	2writetext UnknownText_0x787ad
	closetext
	loadmovesprites
	end
; 0x782d8

TrainerCooltrainerfJenn: ; 0x782d8
	; bit/flag number
	dw $56b

	; trainer group && trainer id
	db COOLTRAINERF, JENN

	; text when seen
	dw CooltrainerfJennSeenText

	; text when trainer beaten
	dw CooltrainerfJennBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfJennScript
; 0x782e4

CooltrainerfJennScript: ; 0x782e4
	talkaftercancel
	loadfont
	checkbit1 $0070
	iftrue UnknownScript_0x782f2
	2writetext UnknownText_0x78836
	closetext
	loadmovesprites
	end
; 0x782f2

UnknownScript_0x782f2: ; 0x782f2
	2writetext UnknownText_0x78866
	closetext
	loadmovesprites
	end
; 0x782f8

TrainerCooltrainerfKate: ; 0x782f8
	; bit/flag number
	dw $55f

	; trainer group && trainer id
	db COOLTRAINERF, KATE

	; text when seen
	dw CooltrainerfKateSeenText

	; text when trainer beaten
	dw CooltrainerfKateBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfKateScript
; 0x78304

CooltrainerfKateScript: ; 0x78304
	talkaftercancel
	loadfont
	checkbit1 $0070
	iftrue UnknownScript_0x78319
	2writetext UnknownText_0x788e2
	keeptextopen
	verbosegiveitem SOFT_SAND, 1
	iffalse UnknownScript_0x7831d
	setbit1 $0070
UnknownScript_0x78319: ; 0x78319
	2writetext UnknownText_0x7892b
	closetext
UnknownScript_0x7831d: ; 0x7831d
	loadmovesprites
	end
; 0x7831f

UnknownScript_0x7831f: ; 0x7831f
	jumptext UnknownText_0x7898a
; 0x78322

MapRoute34Signpost0Script: ; 0x78322
	jumptext UnknownText_0x789a8
; 0x78325

MapRoute34Signpost1Script: ; 0x78325
	jumptext UnknownText_0x789ed
; 0x78328

MapRoute34Signpost2Script: ; 0x78328
	jumptext UnknownText_0x78a52
; 0x7832b

ItemFragment_0x7832b: ; 0x7832b
	db NUGGET, 1
; 0x7832d

MapRoute34SignpostItem3: ; 0x7832d
	dw $00a7
	db RARE_CANDY
	
; 0x78330

MapRoute34SignpostItem4: ; 0x78330
	dw $00a8
	db SUPER_POTION
	
; 0x78333

MovementData_0x78333: ; 0x78333
	slow_step_left
	slow_step_left
	slow_step_up
	step_end
; 0x78337

MovementData_0x78337: ; 0x78337
	slow_step_down
	slow_step_left
	slow_step_left
	slow_step_up
	slow_step_up
	step_end
; 0x7833d

YoungsterSamuelSeenText: ; 0x7833d
	db $0, "This is where I do", $4f
	db "my training!", $57
; 0x7835e

YoungsterSamuelBeatenText: ; 0x7835e
	db $0, "Beaten by a", $4f
	db "passing stranger!", $57
; 0x7837d

UnknownText_0x7837d: ; 0x7837d
	db $0, "Have you been to", $4f
	db "GOLDENROD CITY?", $51
	db "Weren't you amazed", $4f
	db "by how they've", $51
	db "changed the", $4f
	db "#MON CENTER?", $57
; 0x783d8

UnknownText_0x783d8: ; 0x783d8
	db $0, "I'm going to train", $4f
	db "even harder.", $51
	db "After all, I'm", $4f
	db "trying to become", $55
	db "a GYM LEADER.", $57
; 0x78425

YoungsterIanSeenText: ; 0x78425
	db $0, "I'm the best in my", $4f
	db "class at #MON.", $57
; 0x78447

YoungsterIanBeatenText: ; 0x78447
	db $0, "No! There are bet-", $4f
	db "ter trainers…", $57
; 0x78469

UnknownText_0x78469: ; 0x78469
	db $0, "I'm trying hard so", $4f
	db "I can be the star", $55
	db "in my class.", $57
; 0x7849b

CamperTodd1SeenText: ; 0x7849b
	db $0, "I'm confident in", $4f
	db "my ability to", $55
	db "raise #MON.", $51
	db "Want to see?", $57
; 0x784d3

CamperTodd1BeatenText: ; 0x784d3
	db $0, "Did I screw up my", $4f
	db "training?", $57
; 0x784f0

UnknownText_0x784f0: ; 0x784f0
	db $0, "Maybe I should", $4f
	db "take one to a DAY-", $51
	db "CARE. Or maybe use", $4f
	db "some items…", $57
; 0x78532

UnknownText_0x78532: ; 0x78532
	db $0, "Shopping under the", $4f
	db "sky!", $51
	db "It feels so nice", $4f
	db "up on a rooftop.", $57
; 0x7856d

PicnickerGina1SeenText: ; 0x7856d
	db $0, "Are you a trainer?", $51
	db "Let's have a", $4f
	db "practice battle.", $57
; 0x7859e

PicnickerGina1BeatenText: ; 0x7859e
	db $0, "Oh, no! I just", $4f
	db "can't win…", $57
; 0x785b8

UnknownText_0x785b8: ; 0x785b8
	db $0, "You're too strong", $4f
	db "to be a practice", $55
	db "partner.", $57
; 0x785e4

UnknownText_0x785e4: ; 0x785e4
	db $0, "Who goes there?", $4f
	db "What are you up", $55
	db "to?", $57
; 0x78609

UnknownText_0x78609: ; 0x78609
	db $0, "You're a tough", $4f
	db "little kid.", $57
; 0x78624

UnknownText_0x78624: ; 0x78624
	db $0, "Yep, I see nothing", $4f
	db "wrong today. You", $51
	db "be good and stay", $4f
	db "out of trouble.", $57
; 0x7866a

UnknownText_0x7866a: ; 0x7866a
	db $0, "I'm on patrol for", $4f
	db "suspicious indi-", $55
	db "viduals.", $57
; 0x78696

PokefanmBrandonSeenText: ; 0x78696
	db $0, "I just got my", $4f
	db "#MON back from", $55
	db "DAY-CARE.", $51
	db "Let's see how much", $4f
	db "stronger it got!", $57
; 0x786e1

PokefanmBrandonBeatenText: ; 0x786e1
	db $0, "Why does it end", $4f
	db "this way?", $57
; 0x786fc

UnknownText_0x786fc: ; 0x786fc
	db $0, "My #MON knew", $4f
	db "moves I didn't", $55
	db "know it had.", $51
	db "That confounded me", $4f
	db "to no end!", $57
; 0x78743

CooltrainerfIreneSeenText: ; 0x78743
	db $0, "IRENE: Kyaaah!", $4f
	db "Someone found us!", $57
; 0x78765

CooltrainerfIreneBeatenText: ; 0x78765
	db $0, "IRENE: Ohhh!", $4f
	db "Too strong!", $57
; 0x7877f

UnknownText_0x7877f: ; 0x7877f
	db $0, "IRENE: My sister", $4f
	db "KATE will get you", $55
	db "for this!", $57
; 0x787ad

UnknownText_0x787ad: ; 0x787ad
	db $0, "IRENE: Isn't this", $4f
	db "beach great?", $51
	db "It's our secret", $4f
	db "little getaway!", $57
; 0x787eb

CooltrainerfJennSeenText: ; 0x787eb
	db $0, "JENN: You can't", $4f
	db "beat IRENE and go", $55
	db "unpunished!", $57
; 0x78819

CooltrainerfJennBeatenText: ; 0x78819
	db $0, "JENN: So sorry,", $4f
	db "IRENE! Sis!", $57
; 0x78836

UnknownText_0x78836: ; 0x78836
	db $0, "JENN: Don't get", $4f
	db "cocky! My sister", $55
	db "KATE is tough!", $57
; 0x78866

UnknownText_0x78866: ; 0x78866
	db $0, "JENN: Sunlight", $4f
	db "makes your body", $55
	db "stronger.", $57
; 0x78890

CooltrainerfKateSeenText: ; 0x78890
	db $0, "KATE: You sure", $4f
	db "were mean to my", $55
	db "little sisters!", $57
; 0x788c0

CooltrainerfKateBeatenText: ; 0x788c0
	db $0, "KATE: No! I can't", $4f
	db "believe I lost.", $57
; 0x788e2

UnknownText_0x788e2: ; 0x788e2
	db $0, "KATE: You're too", $4f
	db "strong. I didn't", $55
	db "stand a chance.", $51
	db "Here. You deserve", $4f
	db "this.", $57
; 0x7892b

UnknownText_0x7892b: ; 0x7892b
	db $0, "KATE: I'm sorry we", $4f
	db "jumped you.", $51
	db "We never expected", $4f
	db "anyone to find us", $51
	db "here. You sure", $4f
	db "startled us.", $57
; 0x7898a

UnknownText_0x7898a: ; 0x7898a
	db $0, "ILEX FOREST", $4f
	db "THROUGH THE GATE", $57
; 0x789a8

UnknownText_0x789a8: ; 0x789a8
	db $0, "ROUTE 34", $51
	db "GOLDENROD CITY -", $4f
	db "AZALEA TOWN", $51
	db "ILEX FOREST", $4f
	db "SOMEWHERE BETWEEN", $57
; 0x789ed

UnknownText_0x789ed: ; 0x789ed
	db $0, "TRAINER TIPS", $51
	db "BERRY trees grow", $4f
	db "new BERRIES", $55
	db "every day.", $51
	db "Make a note of", $4f
	db "which trees bear", $55
	db "which BERRIES.", $57
; 0x78a52

UnknownText_0x78a52: ; 0x78a52
	db $0, "DAY-CARE", $51
	db "LET US RAISE YOUR", $4f
	db "#MON FOR YOU!", $57
; 0x78a7c

Route34_MapEventHeader: ; 0x78a7c
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $25, $d, 1, GROUP_ROUTE_34_ILEX_FOREST_GATE, MAP_ROUTE_34_ILEX_FOREST_GATE
	warp_def $25, $e, 2, GROUP_ROUTE_34_ILEX_FOREST_GATE, MAP_ROUTE_34_ILEX_FOREST_GATE
	warp_def $e, $b, 1, GROUP_DAY_CARE, MAP_DAY_CARE
	warp_def $f, $b, 2, GROUP_DAY_CARE, MAP_DAY_CARE
	warp_def $f, $d, 3, GROUP_DAY_CARE, MAP_DAY_CARE

	; xy triggers
	db 0

	; signposts
	db 5
	signpost 6, 12, $0, MapRoute34Signpost0Script
	signpost 33, 13, $0, MapRoute34Signpost1Script
	signpost 13, 10, $0, MapRoute34Signpost2Script
	signpost 32, 8, $7, MapRoute34SignpostItem3
	signpost 19, 17, $7, MapRoute34SignpostItem4

	; people-events
	db 13
	person_event $27, 11, 17, $8, $0, 255, 255, $a2, 5, TrainerCamperTodd1, $ffff
	person_event $27, 36, 19, $6, $0, 255, 255, $92, 3, TrainerYoungsterSamuel, $ffff
	person_event $27, 24, 15, $6, $0, 255, 255, $92, 3, TrainerYoungsterIan, $ffff
	person_event $28, 30, 14, $9, $0, 255, 255, $a2, 3, TrainerPicnickerGina1, $ffff
	person_event $43, 15, 13, $6, $0, 255, 255, $90, 0, UnknownScript_0x7824c, $ffff
	person_event $2d, 32, 22, $1e, $0, 255, 255, $82, 3, TrainerPokefanmBrandon, $ffff
	person_event $2f, 20, 19, $6, $0, 255, 255, $0, 0, UnknownScript_0x7803d, $06e6
	person_event $e0, 22, 18, $16, $22, 255, 255, $0, 0, UnknownScript_0x78065, $06e7
	person_event $e1, 23, 21, $16, $22, 255, 255, $0, 0, UnknownScript_0x7806b, $06e8
	person_event $24, 52, 15, $8, $0, 255, 255, $82, 5, TrainerCooltrainerfIrene, $ffff
	person_event $24, 52, 7, $9, $0, 255, 255, $82, 3, TrainerCooltrainerfJenn, $ffff
	person_event $24, 55, 10, $7, $0, 255, 255, $82, 2, TrainerCooltrainerfKate, $ffff
	person_event $54, 34, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x7832b, $07bc
; 0x78b5d

ElmsLab_MapScriptHeader: ; 0x78b5d
	; trigger count
	db 6

	; triggers
	dw UnknownScript_0x78b7a, $0000
	dw UnknownScript_0x78b7e, $0000
	dw UnknownScript_0x78b7f, $0000
	dw UnknownScript_0x78b80, $0000
	dw UnknownScript_0x78b81, $0000
	dw UnknownScript_0x78b82, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x78b83
; 0x78b7a

UnknownScript_0x78b7a: ; 0x78b7a
	priorityjump UnknownScript_0x78b8c
	end
; 0x78b7e

UnknownScript_0x78b7e: ; 0x78b7e
	end
; 0x78b7f

UnknownScript_0x78b7f: ; 0x78b7f
	end
; 0x78b80

UnknownScript_0x78b80: ; 0x78b80
	end
; 0x78b81

UnknownScript_0x78b81: ; 0x78b81
	end
; 0x78b82

UnknownScript_0x78b82: ; 0x78b82
	end
; 0x78b83

UnknownScript_0x78b83: ; 0x78b83
	checktriggers
	iftrue UnknownScript_0x78b8b
	moveperson $2, $3, $4
UnknownScript_0x78b8b: ; 0x78b8b
	return
; 0x78b8c

UnknownScript_0x78b8c: ; 0x78b8c
	applymovement $0, MovementData_0x78f67
	showemote $0, $2, 15
	spriteface $2, $3
	loadfont
	2writetext UnknownText_0x78fb6
UnknownScript_0x78b9b: ; 0x78b9b
	yesorno
	iftrue UnknownScript_0x78ba5
	2writetext UnknownText_0x7911a
	2jump UnknownScript_0x78b9b
; 0x78ba5

UnknownScript_0x78ba5: ; 0x78ba5
	2writetext UnknownText_0x790fa
	keeptextopen
	2writetext UnknownText_0x7913a
	closetext
	loadmovesprites
	playsound $00bc
	pause 30
	showemote $0, $2, 10
	spriteface $2, $0
	loadfont
	2writetext UnknownText_0x791ae
	closetext
	loadmovesprites
	loadfont
	spriteface $2, $3
	2writetext UnknownText_0x791df
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x78fa0
	spriteface $0, $1
	applymovement $2, MovementData_0x78fa2
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x792ff
	closetext
	dotrigger $1
	loadmovesprites
	end
; 0x78be0

ProfElmScript: ; 0x78be0
	faceplayer
	loadfont
	checkbit1 $0024
	iftrue UnknownScript_0x78bee
	checkbit1 $0044
	iftrue ElmGiveTicketScript
UnknownScript_0x78bee: ; 0x78bee
	checkbit1 $007c
	iftrue UnknownScript_0x78bfa
	checkbit2 $0022
	iftrue ElmGiveMasterBallScript
UnknownScript_0x78bfa: ; 0x78bfa
	checkbit1 $0056
	iftrue UnknownScript_0x78e16
	checkbit1 $0055
	iftrue UnknownScript_0x78e03
	checkbit1 $0077
	iffalse UnknownScript_0x78c35
	writebyte TOGEPI
	special $0043
	iftrue ShowElmTogepiScript
	writebyte TOGETIC
	special $0043
	iftrue ShowElmTogepiScript
	2writetext UnknownText_0x79a40
	closetext
	loadmovesprites
	end
; 0x78c22

UnknownScript_0x78c22: ; 0x78c22
	writebyte TOGEPI
	special $0043
	iftrue ShowElmTogepiScript
	writebyte TOGETIC
	special $0043
	iftrue ShowElmTogepiScript
	2jump UnknownScript_0x78c41
; 0x78c35

UnknownScript_0x78c35: ; 0x78c35
	checkbit1 $002d
	iffalse UnknownScript_0x78c41
	checkbit1 $0054
	iftrue UnknownScript_0x78c22
UnknownScript_0x78c41: ; 0x78c41
	checkbit1 $002d ; why are we checking it again?
	iftrue ElmWaitingEggHatchScript
	checkbit2 $001b
	iftrue ElmAideHasEggScript
	checkbit1 $001f
	iftrue ElmStudyingEggScript
	checkbit1 $001e
	iftrue ElmAfterTheftScript
	checkbit1 $001a
	iftrue ElmDescribesMrPokemonScript
	2writetext UnknownText_0x79375
	closetext
	loadmovesprites
	end
; 0x78c65

LabTryToLeaveScript: ; 0x78c65
	spriteface $2, $0
	loadfont
	2writetext LabWhereGoingText
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x78f70
	end
; 0x78c73

CyndaquilPokeBallScript: ; 0x78c73
	checkbit1 $001a
	iftrue LookAtElmPokeBallScript
	spriteface $2, $0
	refreshscreen $0
	pokepic CYNDAQUIL
	cry CYNDAQUIL
	closetext
	pokepicyesorno
	loadfont
	2writetext TakeCyndaquilText
	yesorno
	iffalse DidntChooseStarterScript
	disappear $4
	setbit1 $001b
	2writetext ChoseStarterText
	keeptextopen
	waitbutton
	pokenamemem CYNDAQUIL, $0
	2writetext ReceivedStarterText
	playsound $0002
	waitbutton
	keeptextopen
	givepoke CYNDAQUIL, 5, BERRY, 0
	loadmovesprites
	checkcode $9
	if_equal $3, ElmDirectionsScript
	applymovement $0, AfterCyndaquilMovement
	2jump ElmDirectionsScript
; 0x78cb5

TotodilePokeBallScript: ; 0x78cb5
	checkbit1 $001a
	iftrue LookAtElmPokeBallScript
	spriteface $2, $0
	refreshscreen $0
	pokepic TOTODILE
	cry TOTODILE
	closetext
	pokepicyesorno
	loadfont
	2writetext TakeTotodileText
	yesorno
	iffalse DidntChooseStarterScript
	disappear $5
	setbit1 $001c
	2writetext ChoseStarterText
	keeptextopen
	waitbutton
	pokenamemem TOTODILE, $0
	2writetext ReceivedStarterText
	playsound $0002
	waitbutton
	keeptextopen
	givepoke TOTODILE, 5, BERRY, 0
	loadmovesprites
	applymovement $0, AfterTotodileMovement
	2jump ElmDirectionsScript
; 0x78cf1

ChikoritaPokeBallScript: ; 0x78cf1
	checkbit1 $001a
	iftrue LookAtElmPokeBallScript
	spriteface $2, $0
	refreshscreen $0
	pokepic CHIKORITA
	cry CHIKORITA
	closetext
	pokepicyesorno
	loadfont
	2writetext TakeChikoritaText
	yesorno
	iffalse DidntChooseStarterScript
	disappear $6
	setbit1 $001d
	2writetext ChoseStarterText
	keeptextopen
	waitbutton
	pokenamemem CHIKORITA, $0
	2writetext ReceivedStarterText
	playsound $0002
	waitbutton
	keeptextopen
	givepoke CHIKORITA, 5, BERRY, 0
	loadmovesprites
	applymovement $0, AfterChikoritaMovement
	2jump ElmDirectionsScript
; 0x78d2d

DidntChooseStarterScript: ; 0x78d2d
	2writetext DidntChooseStarterText
	closetext
	loadmovesprites
	end
; 0x78d33

ElmDirectionsScript: ; 0x78d33
	spriteface $0, $1
	loadfont
	2writetext ElmDirectionsText1
	closetext
	loadmovesprites
	addcellnum $4
	loadfont
	2writetext GotElmsNumberText
	playsound $0093
	waitbutton
	closetext
	loadmovesprites
	spriteface $2, $2
	loadfont
	2writetext ElmDirectionsText2
	closetext
	loadmovesprites
	spriteface $2, $0
	loadfont
	2writetext ElmDirectionsText3
	closetext
	loadmovesprites
	setbit1 $001a
	setbit1 $06be
	dotrigger $5
	domaptrigger GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN, $1
	end
; 0x78d67

ElmDescribesMrPokemonScript: ; 0x78d67
	2writetext ElmDescribesMrPokemonText
	closetext
	loadmovesprites
	end
; 0x78d6d

LookAtElmPokeBallScript: ; 0x78d6d
	loadfont
	2writetext ElmPokeBallText
	closetext
	loadmovesprites
	end
; 0x78d74

MapElmsLabSignpost0Script: ; 0x78d74
	loadfont
	checkbit1 $001a
	iftrue UnknownScript_0x78d81
	2writetext UnknownText_0x79690
	closetext
	loadmovesprites
	end
; 0x78d81

UnknownScript_0x78d81: ; 0x78d81
	2writetext UnknownText_0x796aa
	yesorno
	iftrue UnknownScript_0x78d8a
	loadmovesprites
	end
; 0x78d8a

UnknownScript_0x78d8a: ; 0x78d8a
	special $009d
	special $001b
	playmusic $0000
	writebyte $1
	special $003e
	pause 30
	special $003d
	loadmovesprites
	end
; 0x78d9f

ElmAfterTheftDoneScript: ; 0x78d9f
	closetext
	loadmovesprites
	end
; 0x78da2

ElmAfterTheftScript: ; 0x78da2
	2writetext ElmAfterTheftText1
	checkitem MYSTERY_EGG
	iffalse ElmAfterTheftDoneScript
	keeptextopen
	2writetext ElmAfterTheftText2
	closetext
	takeitem MYSTERY_EGG, 1
	2call ElmJumpBackScript1
	2writetext ElmAfterTheftText3
	closetext
	2call ElmJumpBackScript2
	2writetext ElmAfterTheftText4
	keeptextopen
	2writetext ElmAfterTheftText5
	keeptextopen
	setbit1 $001f
	setbit2 $0010
	domaptrigger GROUP_ROUTE_29, MAP_ROUTE_29, $1
	clearbit1 $0715
	setbit1 $0714
	2writetext ElmAfterTheftText6
	closetext
	loadmovesprites
	dotrigger $6
	end
; 0x78ddc

ElmStudyingEggScript: ; 0x78ddc
	2writetext ElmStudyingEggText
	closetext
	loadmovesprites
	end
; 0x78de2

ElmAideHasEggScript: ; 0x78de2
	2writetext ElmAideHasEggText
	closetext
	loadmovesprites
	end
; 0x78de8

ElmWaitingEggHatchScript: ; 0x78de8
	2writetext ElmWaitingEggHatchText
	closetext
	loadmovesprites
	end
; 0x78dee

ShowElmTogepiScript: ; 0x78dee
	2writetext ShowElmTogepiText1
	closetext
	loadmovesprites
	showemote $0, $2, 15
	setbit1 $0055
	loadfont
	2writetext ShowElmTogepiText2
	keeptextopen
	2writetext ShowElmTogepiText3
	keeptextopen
UnknownScript_0x78e03: ; 0x78e03
	2writetext ElmGiveEverstoneText1
	keeptextopen
	verbosegiveitem EVERSTONE, 1
	iffalse UnknownScript_0x78e1a
	2writetext ElmGiveEverstoneText2
	closetext
	loadmovesprites
	setbit1 $0056
	end
; 0x78e16

UnknownScript_0x78e16: ; 0x78e16
	2writetext UnknownText_0x79c37
	closetext
UnknownScript_0x78e1a: ; 0x78e1a
	loadmovesprites
	end
; 0x78e1c

ElmGiveMasterBallScript: ; 0x78e1c
	2writetext ElmGiveMasterBallText1
	keeptextopen
	verbosegiveitem MASTER_BALL, 1
	iffalse .notdone
	setbit1 $007c
	2writetext ElmGiveMasterBallText2
	closetext
.notdone
	loadmovesprites
	end
; 0x78e2f

ElmGiveTicketScript: ; 0x78e2f
	2writetext ElmGiveTicketText1
	keeptextopen
	verbosegiveitem S_S_TICKET, 1
	setbit1 $0024
	2writetext ElmGiveTicketText2
	closetext
	loadmovesprites
	end
; 0x78e3f

ElmJumpBackScript1: ; 0x78e3f
	loadmovesprites
	checkcode $9
	if_equal $0, UnknownScript_0x78e6d
	if_equal $1, UnknownScript_0x78e67
	if_equal $2, UnknownScript_0x78e73
	if_equal $3, UnknownScript_0x78e79
	end
; 0x78e53

ElmJumpBackScript2: ; 0x78e53
	loadmovesprites
	checkcode $9
	if_equal $0, UnknownScript_0x78e67
	if_equal $1, UnknownScript_0x78e6d
	if_equal $2, UnknownScript_0x78e79
	if_equal $3, UnknownScript_0x78e73
	end
; 0x78e67

UnknownScript_0x78e67: ; 0x78e67
	applymovement $2, MovementData_0x78f90
	loadfont
	end
; 0x78e6d

UnknownScript_0x78e6d: ; 0x78e6d
	applymovement $2, MovementData_0x78f94
	loadfont
	end
; 0x78e73

UnknownScript_0x78e73: ; 0x78e73
	applymovement $2, MovementData_0x78f98
	loadfont
	end
; 0x78e79

UnknownScript_0x78e79: ; 0x78e79
	applymovement $2, MovementData_0x78f9c
	loadfont
	end
; 0x78e7f

UnknownScript_0x78e7f: ; 0x78e7f
	applymovement $3, MovementData_0x78f7e
	spriteface $0, $0
	2call UnknownScript_0x78e9d
	applymovement $3, MovementData_0x78f87
	end
; 0x78e8e

UnknownScript_0x78e8e: ; 0x78e8e
	applymovement $3, MovementData_0x78f82
	spriteface $0, $0
	2call UnknownScript_0x78e9d
	applymovement $3, MovementData_0x78f8b
	end
; 0x78e9d

UnknownScript_0x78e9d: ; 0x78e9d
	loadfont
	2writetext UnknownText_0x79f38
	keeptextopen
	verbosegiveitem POTION, 1
	2writetext UnknownText_0x79f65
	closetext
	loadmovesprites
	dotrigger $2
	end
; 0x78ead

UnknownScript_0x78ead: ; 0x78ead
	applymovement $3, MovementData_0x78f7e
	spriteface $0, $0
	2call UnknownScript_0x78ecb
	applymovement $3, MovementData_0x78f87
	end
; 0x78ebc

UnknownScript_0x78ebc: ; 0x78ebc
	applymovement $3, MovementData_0x78f82
	spriteface $0, $0
	2call UnknownScript_0x78ecb
	applymovement $3, MovementData_0x78f8b
	end
; 0x78ecb

UnknownScript_0x78ecb: ; 0x78ecb
	loadfont
	2writetext UnknownText_0x7a078
	keeptextopen
	itemtotext POKE_BALL, $1
	2call UnknownScript_0x78ee2
	giveitem POKE_BALL, $5
	2writetext UnknownText_0x7a09a
	keeptextopen
	itemnotify
	loadmovesprites
	dotrigger $2
	end
; 0x78ee2

UnknownScript_0x78ee2: ; 0x78ee2
	jumpstd $002f
	end
; 0x78ee6

ElmsAideScript: ; 0x78ee6
	faceplayer
	loadfont
	checkbit1 $002d
	iftrue UnknownScript_0x78f0c
	checkbit1 $001f
	iftrue UnknownScript_0x78f06
	checkbit1 $001e
	iftrue UnknownScript_0x78f00
	2writetext UnknownText_0x79f65
	closetext
	loadmovesprites
	end
; 0x78f00

UnknownScript_0x78f00: ; 0x78f00
	2writetext UnknownText_0x79f95
	closetext
	loadmovesprites
	end
; 0x78f06

UnknownScript_0x78f06: ; 0x78f06
	2writetext UnknownText_0x7a09a
	closetext
	loadmovesprites
	end
; 0x78f0c

UnknownScript_0x78f0c: ; 0x78f0c
	2writetext UnknownText_0x79c65
	closetext
	loadmovesprites
	end
; 0x78f12

UnknownScript_0x78f12: ; 0x78f12
	applymovement $0, MovementData_0x78f72
; 0x78f16

MeetCopScript: ; 0x78f16
	applymovement $0, MovementData_0x78f74
	spriteface $7, $2
	loadfont
	2writetext UnknownText_0x7a0f0
	keeptextopen
	special $0024
	2writetext UnknownText_0x7a1c0
	closetext
	loadmovesprites
	applymovement $7, MovementData_0x78f78
	disappear $7
	dotrigger $2
	end
; 0x78f33

MapElmsLabSignpost14Script: ; 0x78f33
	loadfont
	checkbit2 $0043
	iftrue UnknownScript_0x78f49
	checkbit1 $0043
	iftrue UnknownScript_0x78f43
	2jump UnknownScript_0x78f49
; 0x78f43

UnknownScript_0x78f43: ; 0x78f43
	2writetext UnknownText_0x7a231
	closetext
	loadmovesprites
	end
; 0x78f49

UnknownScript_0x78f49: ; 0x78f49
	2writetext UnknownText_0x7a1fd
	closetext
	loadmovesprites
	end
; 0x78f4f

MapElmsLabSignpost5Script: ; 0x78f4f
	jumptext UnknownText_0x7a24c
; 0x78f52

MapElmsLabSignpost6Script: ; 0x78f52
	jumptext UnknownText_0x7a28a
; 0x78f55

MapElmsLabSignpost7Script: ; 0x78f55
	jumptext UnknownText_0x7a2c6
; 0x78f58

MapElmsLabSignpost8Script: ; 0x78f58
	jumptext UnknownText_0x7a315
; 0x78f5b

MapElmsLabSignpost13Script: ; 0x78f5b
	jumptext UnknownText_0x7a370
; 0x78f5e

MapElmsLabSignpost15Script: ; 0x78f5e
	jumptext UnknownText_0x7a3a6
; 0x78f61

UnknownScript_0x78f61: ; 0x78f61
	jumpstd $000d
; 0x78f64

MapElmsLabSignpost12Script: ; 0x78f64
	jumpstd $0001
; 0x78f67

MovementData_0x78f67: ; 0x78f67
	step_up
	step_up
	step_up
	step_up
	step_up
	step_up
	step_up
	turn_head_left
	step_end
; 0x78f70

MovementData_0x78f70: ; 0x78f70
	step_up
	step_end
; 0x78f72

MovementData_0x78f72: ; 0x78f72
	step_left
	step_end
; 0x78f74

MovementData_0x78f74: ; 0x78f74
	step_up
	step_up
	turn_head_right
	step_end
; 0x78f78

MovementData_0x78f78: ; 0x78f78
	step_down
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x78f7e

MovementData_0x78f7e: ; 0x78f7e
	step_right
	step_right
	turn_head_up
	step_end
; 0x78f82

MovementData_0x78f82: ; 0x78f82
	step_right
	step_right
	step_right
	turn_head_up
	step_end
; 0x78f87

MovementData_0x78f87: ; 0x78f87
	step_left
	step_left
	turn_head_down
	step_end
; 0x78f8b

MovementData_0x78f8b: ; 0x78f8b
	step_left
	step_left
	step_left
	turn_head_down
	step_end
; 0x78f90

MovementData_0x78f90: ; 0x78f90
	fix_facing
	big_step_up
	remove_fixed_facing
	step_end
; 0x78f94

MovementData_0x78f94: ; 0x78f94
	fix_facing
	big_step_down
	remove_fixed_facing
	step_end
; 0x78f98

MovementData_0x78f98: ; 0x78f98
	fix_facing
	big_step_left
	remove_fixed_facing
	step_end
; 0x78f9c

MovementData_0x78f9c: ; 0x78f9c
	fix_facing
	big_step_right
	remove_fixed_facing
	step_end
; 0x78fa0

MovementData_0x78fa0: ; 0x78fa0
	step_up
	step_end
; 0x78fa2

MovementData_0x78fa2: ; 0x78fa2
	step_right
	step_right
	step_up
	turn_head_down
	step_end
; 0x78fa7

AfterCyndaquilMovement: ; 0x78fa7
	step_left
	step_up
	turn_head_up
	step_end
; 0x78fab

AfterTotodileMovement: ; 0x78fab
	step_left
	step_left
	step_up
	turn_head_up
	step_end
; 0x78fb0

AfterChikoritaMovement: ; 0x78fb0
	step_left
	step_left
	step_left
	step_up
	turn_head_up
	step_end
; 0x78fb6

UnknownText_0x78fb6: ; 0x78fb6
	db $0, "ELM: ", $14, "!", $4f
	db "There you are!", $51
	db "I needed to ask", $4f
	db "you a favor.", $51
	db "I'm conducting new", $4f
	db "#MON research", $51
	db "right now. I was", $4f
	db "wondering if you", $51
	db "could help me with", $4f
	db "it, ", $14, ".", $51
	db "You see…", $51
	db "I'm writing a", $4f
	db "paper that I want", $51
	db "to present at a", $4f
	db "conference.", $51
	db "But there are some", $4f
	db "things I don't", $51
	db "quite understand", $4f
	db "yet.", $51
	db "So!", $51
	db "I'd like you to", $4f
	db "raise a #MON", $51
	db "that I recently", $4f
	db "caught.", $57
; 0x790fa

UnknownText_0x790fa: ; 0x790fa
	db $0, "Thanks, ", $14, "!", $51
	db "You're a great", $4f
	db "help!", $57
; 0x7911a

UnknownText_0x7911a: ; 0x7911a
	db $0, "But… Please, I", $4f
	db "need your help!", $57
; 0x7913a

UnknownText_0x7913a: ; 0x7913a
	db $0, "When I announce my", $4f
	db "findings, I'm sure", $51
	db "we'll delve a bit", $4f
	db "deeper into the", $51
	db "many mysteries of", $4f
	db "#MON.", $51
	db "You can count on", $4f
	db "it!", $57
; 0x791ae

UnknownText_0x791ae: ; 0x791ae
	db $0, "Oh, hey! I got an", $4f
	db "e-mail!", $51
	db $56, $56, $56, $4f
	db "Hm… Uh-huh…", $51
	db "Okay…", $57
; 0x791df

UnknownText_0x791df: ; 0x791df
	db $0, "Hey, listen.", $51
	db "I have an acquain-", $4f
	db "tance called MR.", $55
	db "#MON.", $51
	db "He keeps finding", $4f
	db "weird things and", $51
	db "raving about his", $4f
	db "discoveries.", $51
	db "Anyway, I just got", $4f
	db "an e-mail from him", $51
	db "saying that this", $4f
	db "time it's real.", $51
	db "It is intriguing,", $4f
	db "but we're busy", $51
	db "with our #MON", $4f
	db "research…", $51
	db "Wait!", $51
	db "I know!", $51
	db $14, ", can you", $4f
	db "go in our place?", $57
; 0x792ff

UnknownText_0x792ff: ; 0x792ff
	db $0, "I want you to", $4f
	db "raise one of the", $51
	db "#MON contained", $4f
	db "in these BALLS.", $51
	db "You'll be that", $4f
	db "#MON's first", $55
	db "partner, ", $14, "!", $51
	db "Go on. Pick one!", $57
; 0x79375

UnknownText_0x79375: ; 0x79375
	db $0, "If a wild #MON", $4f
	db "appears, let your", $55
	db "#MON battle it!", $57
; 0x793a7

LabWhereGoingText: ; 0x793a7
	db $0, "ELM: Wait! Where", $4f
	db "are you going?", $57
; 0x793c8

TakeCyndaquilText: ; 0x793c8
	db $0, "ELM: You'll take", $4f
	db "CYNDAQUIL, the", $55
	db "fire #MON?", $57
; 0x793f3

TakeTotodileText: ; 0x793f3
	db $0, "ELM: Do you want", $4f
	db "TOTODILE, the", $55
	db "water #MON?", $57
; 0x7941f

TakeChikoritaText: ; 0x7941f
	db $0, "ELM: So, you like", $4f
	db "CHIKORITA, the", $55
	db "grass #MON?", $57
; 0x7944d

DidntChooseStarterText: ; 0x7944d
	db $0, "ELM: Think it over", $4f
	db "carefully.", $51
	db "Your partner is", $4f
	db "important.", $57
; 0x79487

ChoseStarterText: ; 0x79487
	db $0, "ELM: I think", $4f
	db "that's a great", $55
	db "#MON too!", $57
; 0x794ad

ReceivedStarterText: ; 0x794ad
	db $0, $52, " received", $4f
	db "@"
	text_from_ram $d099
	db $0, "!", $57
; 0x794c0

ElmDirectionsText1: ; 0x794c0
	db $0, "MR.#MON lives a", $4f
	db "little bit beyond", $51
	db "CHERRYGROVE, the", $4f
	db "next city over.", $51
	db "It's almost a", $4f
	db "direct route", $51
	db "there, so you", $4f
	db "can't miss it.", $51
	db "But just in case,", $4f
	db "here's my phone", $51
	db "number. Call me if", $4f
	db "anything comes up!", $57
; 0x79581

ElmDirectionsText2: ; 0x79581
	db $0, "If your #MON is", $4f
	db "hurt, you should", $51
	db "heal it with this", $4f
	db "machine.", $51
	db "Feel free to use", $4f
	db "it anytime.", $57
; 0x795db

ElmDirectionsText3: ; 0x795db
	db $0, $14, ", I'm", $4f
	db "counting on you!", $57
; 0x795f3

GotElmsNumberText: ; 0x795f3
	db $0, $52, " got ELM's", $4f
	db "phone number.", $57
; 0x7960d

ElmDescribesMrPokemonText: ; 0x7960d
	db $0, "MR.#MON goes", $4f
	db "everywhere and", $55
	db "finds rarities.", $51
	db "Too bad they're", $4f
	db "just rare and", $55
	db "not very useful…", $57
; 0x79668

ElmPokeBallText: ; 0x79668
	db $0, "It contains a", $4f
	db "#MON caught by", $55
	db "PROF.ELM.", $57
; 0x79690

UnknownText_0x79690: ; 0x79690
	db $0, "I wonder what this", $4f
	db "does?", $57
; 0x796aa

UnknownText_0x796aa: ; 0x796aa
	db $0, "Would you like to", $4f
	db "heal your #MON?", $57
; 0x796cd

ElmAfterTheftText1: ; 0x796cd
	db $0, "ELM: ", $14, ", this", $4f
	db "is terrible…", $51
	db "Oh, yes, what was", $4f
	db "MR.#MON's big", $55
	db "discovery?", $57
; 0x79712

ElmAfterTheftText2: ; 0x79712
	db $0, $52, " handed", $4f
	db "the MYSTERY EGG to", $55
	db "PROF.ELM.", $57
; 0x79739

ElmAfterTheftText3: ; 0x79739
	db $0, "ELM: This?", $57
; 0x79745

ElmAfterTheftText4: ; 0x79745
	db $0, "But… Is it a", $4f
	db "#MON EGG?", $51
	db "If it is, it is a", $4f
	db "great discovery!", $57
; 0x79780

ElmAfterTheftText5: ; 0x79780
	db $0, "ELM: What?!?", $51
	db "PROF.OAK gave you", $4f
	db "a #DEX?", $51
	db $14, ", is that", $4f
	db "true? Th-that's", $55
	db "incredible!", $51
	db "He is superb at", $4f
	db "seeing the poten-", $55
	db "tial of people as", $55
	db "trainers.", $51
	db "Wow, ", $14, ". You", $4f
	db "may have what it", $51
	db "takes to become", $4f
	db "the CHAMPION.", $51
	db "You seem to be", $4f
	db "getting on great", $55
	db "with #MON too.", $51
	db "You should take", $4f
	db "the #MON GYM", $55
	db "challenge.", $51
	db "The closest GYM", $4f
	db "would be the one", $55
	db "in VIOLET CITY.", $57
; 0x798cf

ElmAfterTheftText6: ; 0x798cf
	db $0, "…", $14, ". The", $4f
	db "road to the", $51
	db "championship will", $4f
	db "be a long one.", $51
	db "Before you leave,", $4f
	db "make sure that you", $55
	db "talk to your mom.", $57
; 0x7993c

ElmStudyingEggText: ; 0x7993c
	db $0, "ELM: Don't give", $4f
	db "up! I'll call if", $51
	db "I learn anything", $4f
	db "about that EGG!", $57
; 0x7997d

ElmAideHasEggText: ; 0x7997d
	db $0, "ELM: ", $14, "?", $4f
	db "Didn't you meet my", $55
	db "assistant?", $51
	db "He should have met", $4f
	db "you with the EGG", $51
	db "at VIOLET CITY's", $4f
	db "#MON CENTER.", $51
	db "You must have just", $4f
	db "missed him. Try to", $55
	db "catch him there.", $57
; 0x79a1b

ElmWaitingEggHatchText: ; 0x79a1b
	db $0, "ELM: Hey, has that", $4f
	db "EGG changed any?", $57
; 0x79a40

UnknownText_0x79a40: ; 0x79a40
	db $0, $14, "? I thought", $4f
	db "the EGG hatched.", $51
	db "Where is the", $4f
	db "#MON?", $57
; 0x79a72

ShowElmTogepiText1: ; 0x79a72
	db $0, "ELM: ", $14, ", you", $4f
	db "look great!", $57
; 0x79a8b

ShowElmTogepiText2: ; 0x79a8b
	db $0, "What?", $4f
	db "That #MON!?!", $57
; 0x79a9f

ShowElmTogepiText3: ; 0x79a9f
	db $0, "The EGG hatched!", $4f
	db "So, #MON are", $55
	db "born from EGGS…", $51
	db "No, perhaps not", $4f
	db "all #MON are.", $51
	db "Wow, there's still", $4f
	db "a lot of research", $55
	db "to be done.", $57
; 0x79b1c

ElmGiveEverstoneText1: ; 0x79b1c
	db $0, "Thanks, ", $14, "!", $4f
	db "You're helping", $51
	db "unravel #MON", $4f
	db "mysteries for us!", $51
	db "I want you to have", $4f
	db "this as a token of", $55
	db "our appreciation.", $57
; 0x79b8d

ElmGiveEverstoneText2: ; 0x79b8d
	db $0, "That's an", $4f
	db "EVERSTONE.", $51
	db "Some species of", $4f
	db "#MON evolve", $51
	db "when they grow to", $4f
	db "certain levels.", $51
	db "A #MON holding", $4f
	db "the EVERSTONE", $55
	db "won't evolve.", $51
	db "Give it to a #-", $4f
	db "MON you don't want", $55
	db "to evolve.", $57
; 0x79c37

UnknownText_0x79c37: ; 0x79c37
	db $0, "ELM: ", $14, ", I'll", $4f
	db "call you if any-", $55
	db "thing comes up.", $57
; 0x79c65

UnknownText_0x79c65: ; 0x79c65
	db $0, "…sigh… That", $4f
	db "stolen #MON.", $51
	db "I wonder how it's", $4f
	db "doing.", $51
	db "They say a #MON", $4f
	db "raised by a bad", $51
	db "person turns bad", $4f
	db "itself.", $57
; 0x79cd0

ElmGiveMasterBallText1: ; 0x79cd0
	db $0, "ELM: Hi, ", $14, "!", $4f
	db "Thanks to you, my", $51
	db "research is going", $4f
	db "great!", $51
	db "Take this as a", $4f
	db "token of my", $55
	db "appreciation.", $57
; 0x79d31

ElmGiveMasterBallText2: ; 0x79d31
	db $0, "The MASTER BALL is", $4f
	db "the best!", $51
	db "It's the ultimate", $4f
	db "BALL! It'll catch", $51
	db "any #MON with-", $4f
	db "out fail.", $51
	db "It's given only to", $4f
	db "recognized #MON", $55
	db "researchers.", $51
	db "I think you can", $4f
	db "make much better", $51
	db "use of it than I", $4f
	db "can, ", $14, "!", $57
; 0x79df3

ElmGiveTicketText1: ; 0x79df3
	db $0, "ELM: ", $14, "!", $4f
	db "There you are!", $51
	db "I called because I", $4f
	db "have something for", $55
	db "you.", $51
	db "See? It's an", $4f
	db "S.S.TICKET.", $51
	db "Now you can catch", $4f
	db "#MON in KANTO.", $57
; 0x79e6f

ElmGiveTicketText2: ; 0x79e6f
	db $0, "The ship departs", $4f
	db "from OLIVINE CITY.", $51
	db "But you knew that", $4f
	db "already, ", $14, ".", $51
	db "After all, you've", $4f
	db "traveled all over", $55
	db "with your #MON.", $51
	db "Give my regards to", $4f
	db "PROF.OAK in KANTO!", $57
; 0x79f0b

UnknownText_0x79f0b: ; 0x79f0b
	db $0, "It's the #MON", $4f
	db "EGG being studied", $55
	db "by PROF.ELM.", $57
; 0x79f38

UnknownText_0x79f38: ; 0x79f38
	db $0, $14, ", I want", $4f
	db "you to have this", $55
	db "for your errand.", $57
; 0x79f65

UnknownText_0x79f65: ; 0x79f65
	db $0, "There are only two", $4f
	db "of us, so we're", $55
	db "always busy.", $57
; 0x79f95

UnknownText_0x79f95: ; 0x79f95
	db $0, "There was a loud", $4f
	db "noise outside…", $51
	db "When we went to", $4f
	db "look, someone", $55
	db "stole a #MON.", $51
	db "It's unbelievable", $4f
	db "that anyone would", $55
	db "do that!", $51
	db "…sigh… That", $4f
	db "stolen #MON.", $51
	db "I wonder how it's", $4f
	db "doing.", $51
	db "They say a #MON", $4f
	db "raised by a bad", $51
	db "person turns bad", $4f
	db "itself.", $57
; 0x7a078

UnknownText_0x7a078: ; 0x7a078
	db $0, $14, "!", $51
	db "Use these on your", $4f
	db "#DEX quest!", $57
; 0x7a09a

UnknownText_0x7a09a: ; 0x7a09a
	db $0, "To add to your", $4f
	db "#DEX, you have", $55
	db "to catch #MON.", $51
	db "Throw # BALLS", $4f
	db "at wild #MON", $55
	db "to get them.", $57
; 0x7a0f0

UnknownText_0x7a0f0: ; 0x7a0f0
	db $0, "I heard a #MON", $4f
	db "was stolen here…", $51
	db "I was just getting", $4f
	db "some information", $55
	db "from PROF.ELM.", $51
	db "Apparently, it was", $4f
	db "a young male with", $55
	db "long, red hair…", $51
	db "What?", $51
	db "You battled a", $4f
	db "trainer like that?", $51
	db "Did you happen to", $4f
	db "get his name?", $57
; 0x7a1c0

UnknownText_0x7a1c0: ; 0x7a1c0
	db $0, "OK! So ", $53, $4f
	db "was his name.", $51
	db "Thanks for helping", $4f
	db "my investigation!", $57
; 0x7a1fd

UnknownText_0x7a1fd: ; 0x7a1fd
	db $0, "The window's open.", $51
	db "A pleasant breeze", $4f
	db "is blowing in.", $57
; 0x7a231

UnknownText_0x7a231: ; 0x7a231
	db $0, "He broke in", $4f
	db "through here!", $57
; 0x7a24c

UnknownText_0x7a24c: ; 0x7a24c
	db $0, $52, " opened a", $4f
	db "book.", $51
	db "Travel Tip 1:", $51
	db "Press START to", $4f
	db "open the MENU.", $57
; 0x7a28a

UnknownText_0x7a28a: ; 0x7a28a
	db $0, $52, " opened a", $4f
	db "book.", $51
	db "Travel Tip 2:", $51
	db "Record your trip", $4f
	db "with SAVE!", $57
; 0x7a2c6

UnknownText_0x7a2c6: ; 0x7a2c6
	db $0, $52, " opened a", $4f
	db "book.", $51
	db "Travel Tip 3:", $51
	db "Open your PACK and", $4f
	db "press SELECT to", $55
	db "move items.", $57
; 0x7a315

UnknownText_0x7a315: ; 0x7a315
	db $0, $52, " opened a", $4f
	db "book.", $51
	db "Travel Tip 4:", $51
	db "Check your #MON", $4f
	db "moves. Press the", $51
	db "A Button to switch", $4f
	db "moves.", $57
; 0x7a370

UnknownText_0x7a370: ; 0x7a370
	db $0, "The wrapper from", $4f
	db "the snack PROF.ELM", $55
	db "ate is in there…", $57
; 0x7a3a6

UnknownText_0x7a3a6: ; 0x7a3a6
	db $0, "OBSERVATIONS ON", $4f
	db "#MON EVOLUTION", $51
	db "…It says on the", $4f
	db "screen…", $57
; 0x7a3de

ElmsLab_MapEventHeader: ; 0x7a3de
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $b, $4, 1, GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN
	warp_def $b, $5, 1, GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN

	; xy triggers
	db 8
	xy_trigger 1, $6, $4, $0, LabTryToLeaveScript, $0, $0
	xy_trigger 1, $6, $5, $0, LabTryToLeaveScript, $0, $0
	xy_trigger 3, $5, $4, $0, MeetCopScript, $0, $0
	xy_trigger 3, $5, $5, $0, UnknownScript_0x78f12, $0, $0
	xy_trigger 5, $8, $4, $0, UnknownScript_0x78e7f, $0, $0
	xy_trigger 5, $8, $5, $0, UnknownScript_0x78e8e, $0, $0
	xy_trigger 6, $8, $4, $0, UnknownScript_0x78ead, $0, $0
	xy_trigger 6, $8, $5, $0, UnknownScript_0x78ebc, $0, $0

	; signposts
	db 16
	signpost 1, 2, $0, MapElmsLabSignpost0Script
	signpost 1, 6, $0, MapElmsLabSignpost12Script
	signpost 1, 7, $0, MapElmsLabSignpost12Script
	signpost 1, 8, $0, MapElmsLabSignpost12Script
	signpost 1, 9, $0, MapElmsLabSignpost12Script
	signpost 7, 0, $0, MapElmsLabSignpost5Script
	signpost 7, 1, $0, MapElmsLabSignpost6Script
	signpost 7, 2, $0, MapElmsLabSignpost7Script
	signpost 7, 3, $0, MapElmsLabSignpost8Script
	signpost 7, 6, $0, MapElmsLabSignpost12Script
	signpost 7, 7, $0, MapElmsLabSignpost12Script
	signpost 7, 8, $0, MapElmsLabSignpost12Script
	signpost 7, 9, $0, MapElmsLabSignpost12Script
	signpost 3, 9, $0, MapElmsLabSignpost13Script
	signpost 0, 5, $0, MapElmsLabSignpost14Script
	signpost 5, 3, $2, MapElmsLabSignpost15Script

	; people-events
	db 6
	person_event $10, 6, 9, $6, $0, 255, 255, $0, 0, ProfElmScript, $ffff
	person_event $3c, 13, 6, $3, $0, 255, 255, $90, 0, ElmsAideScript, $0701
	person_event $54, 7, 10, $1, $0, 255, 255, $0, 0, CyndaquilPokeBallScript, $0640
	person_event $54, 7, 11, $1, $0, 255, 255, $0, 0, TotodilePokeBallScript, $0641
	person_event $54, 7, 12, $1, $0, 255, 255, $0, 0, ChikoritaPokeBallScript, $0642
	person_event $43, 7, 9, $7, $0, 255, 255, $90, 0, $4f1a, $0702
; 0x7a4cc

KrissHouse1F_MapScriptHeader: ; 0x7a4cc
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x7a4d6, $0000
	dw UnknownScript_0x7a4d7, $0000

	; callback count
	db 0
; 0x7a4d6

UnknownScript_0x7a4d6: ; 0x7a4d6
	end
; 0x7a4d7

UnknownScript_0x7a4d7: ; 0x7a4d7
	end
; 0x7a4d8

UnknownScript_0x7a4d8: ; 0x7a4d8
	setbit1 $0000
; 0x7a4db

UnknownScript_0x7a4db: ; 0x7a4db
	playmusic $004e
	showemote $0, $2, 15
	spriteface $0, $2
	checkbit1 $0000
	iffalse UnknownScript_0x7a4f2
	applymovement $2, MovementData_0x7a5fc
	2jump UnknownScript_0x7a4f6
; 0x7a4f2

UnknownScript_0x7a4f2: ; 0x7a4f2
	applymovement $2, MovementData_0x7a5fe
UnknownScript_0x7a4f6: ; 0x7a4f6
	loadfont
	2writetext UnknownText_0x7a604
	keeptextopen
	stringtotext $6578, $1
	2call UnknownScript_0x7a57e
	setbit2 $0004
	setbit2 $0002
	addcellnum $1
	dotrigger $1
	setbit1 $06c7
	clearbit1 $06c8
	2writetext UnknownText_0x7a6bd
	keeptextopen
	special $0025
UnknownScript_0x7a519: ; 0x7a519
	2writetext UnknownText_0x7a742
	yesorno
	iffalse UnknownScript_0x7a52a
	special $00a6
	yesorno
	iffalse UnknownScript_0x7a519
	2jump UnknownScript_0x7a531
; 0x7a52a

UnknownScript_0x7a52a: ; 0x7a52a
	special $00a7
	yesorno
	iffalse UnknownScript_0x7a519
UnknownScript_0x7a531: ; 0x7a531
	2writetext UnknownText_0x7a763
	yesorno
	iffalse UnknownScript_0x7a542
	2jump UnknownScript_0x7a53b
; 0x7a53b

UnknownScript_0x7a53b: ; 0x7a53b
	2writetext UnknownText_0x7a7cb
	keeptextopen
	2jump UnknownScript_0x7a549
; 0x7a542

UnknownScript_0x7a542: ; 0x7a542
	2writetext UnknownText_0x7a807
	keeptextopen
	2jump UnknownScript_0x7a549
; 0x7a549

UnknownScript_0x7a549: ; 0x7a549
	2writetext UnknownText_0x7a850
	closetext
	loadmovesprites
	checkbit1 $0000
	iftrue UnknownScript_0x7a55d
	checkbit1 $0001
	iffalse UnknownScript_0x7a564
	2jump UnknownScript_0x7a56b
; 0x7a55d

UnknownScript_0x7a55d: ; 0x7a55d
	applymovement $2, MovementData_0x7a600
	2jump UnknownScript_0x7a56b
; 0x7a564

UnknownScript_0x7a564: ; 0x7a564
	applymovement $2, MovementData_0x7a602
	2jump UnknownScript_0x7a56b
; 0x7a56b

UnknownScript_0x7a56b: ; 0x7a56b
	special $003d
	spriteface $2, $2
	end
; 0x7a572

UnknownScript_0x7a572: ; 0x7a572
	playmusic $004e
	2jump UnknownScript_0x7a4f6
; 0x7a578

UnknownRawText_0x7a578: ; 0x7a578
	db $54, "GEAR@"
; 0x7a57e

UnknownScript_0x7a57e: ; 0x7a57e
	jumpstd $002f
	end
; 0x7a582

UnknownScript_0x7a582: ; 0x7a582
	faceplayer
	setbit1 $0001
	checktriggers
	iffalse UnknownScript_0x7a572
	loadfont
	checkbit1 $0076
	iftrue UnknownScript_0x7a5af
	checkbit1 $0040
	iftrue UnknownScript_0x7a5b8
	checkbit1 $001f
	iftrue UnknownScript_0x7a5b5
	checkbit1 $001a
	iftrue UnknownScript_0x7a5a9
	2writetext UnknownText_0x7a8b5
	closetext
	loadmovesprites
	end
; 0x7a5a9

UnknownScript_0x7a5a9: ; 0x7a5a9
	2writetext UnknownText_0x7a8e5
	closetext
	loadmovesprites
	end
; 0x7a5af

UnknownScript_0x7a5af: ; 0x7a5af
	2writetext UnknownText_0x7a957
	closetext
	loadmovesprites
	end
; 0x7a5b5

UnknownScript_0x7a5b5: ; 0x7a5b5
	setbit1 $0076
UnknownScript_0x7a5b8: ; 0x7a5b8
	setbit1 $0040
	special $0022
	closetext
	loadmovesprites
	end
; 0x7a5c1

UnknownScript_0x7a5c1: ; 0x7a5c1
	faceplayer
	loadfont
	checktime $1
	iftrue UnknownScript_0x7a5d2
	checktime $2
	iftrue UnknownScript_0x7a5d9
	checktime $4
	iftrue UnknownScript_0x7a5e0
UnknownScript_0x7a5d2: ; 0x7a5d2
	2writetext UnknownText_0x7a97d
	keeptextopen
	2jump UnknownScript_0x7a5e7
; 0x7a5d9

UnknownScript_0x7a5d9: ; 0x7a5d9
	2writetext UnknownText_0x7a99c
	keeptextopen
	2jump UnknownScript_0x7a5e7
; 0x7a5e0

UnknownScript_0x7a5e0: ; 0x7a5e0
	2writetext UnknownText_0x7a9b4
	keeptextopen
	2jump UnknownScript_0x7a5e7
; 0x7a5e7

UnknownScript_0x7a5e7: ; 0x7a5e7
	2writetext UnknownText_0x7a9d3
	closetext
	loadmovesprites
	spriteface $6, $3
	end
; 0x7a5f0

MapKrissHouse1FSignpost3Script: ; 0x7a5f0
	jumptext UnknownText_0x7aad0
; 0x7a5f3

MapKrissHouse1FSignpost0Script: ; 0x7a5f3
	jumptext UnknownText_0x7aa3a
; 0x7a5f6

MapKrissHouse1FSignpost1Script: ; 0x7a5f6
	jumptext UnknownText_0x7aa64
; 0x7a5f9

MapKrissHouse1FSignpost2Script: ; 0x7a5f9
	jumptext UnknownText_0x7aa91
; 0x7a5fc

MovementData_0x7a5fc: ; 0x7a5fc
	turn_head_right
	step_end
; 0x7a5fe

MovementData_0x7a5fe: ; 0x7a5fe
	slow_step_right
	step_end
; 0x7a600

MovementData_0x7a600: ; 0x7a600
	turn_head_left
	step_end
; 0x7a602

MovementData_0x7a602: ; 0x7a602
	slow_step_left
	step_end
; 0x7a604

UnknownText_0x7a604: ; 0x7a604
	db $0, "Oh, ", $52, "…! Our", $4f
	db "neighbor, PROF.", $51
	db "ELM, was looking", $4f
	db "for you.", $51
	db "He said he wanted", $4f
	db "you to do some-", $55
	db "thing for him.", $51
	db "Oh! I almost for-", $4f
	db "got! Your #MON", $51
	db "GEAR is back from", $4f
	db "the repair shop.", $51
	db "Here you go!", $57
; 0x7a6bd

UnknownText_0x7a6bd: ; 0x7a6bd
	db $0, "#MON GEAR, or", $4f
	db "just #GEAR.", $51
	db "It's essential if", $4f
	db "you want to be a", $55
	db "good trainer.", $51
	db "Oh, the day of the", $4f
	db "week isn't set.", $51
	db "You mustn't forget", $4f
	db "that!", $57
; 0x7a742

UnknownText_0x7a742: ; 0x7a742
	db $0, "Is it Daylight", $4f
	db "Saving Time now?", $57
; 0x7a763

UnknownText_0x7a763: ; 0x7a763
	db $0, "Come home to", $4f
	db "adjust your clock", $51
	db "for Daylight", $4f
	db "Saving Time.", $51
	db "By the way, do you", $4f
	db "know how to use", $55
	db "the PHONE?", $57
; 0x7a7cb

UnknownText_0x7a7cb: ; 0x7a7cb
	db $0, "Don't you just", $4f
	db "turn the #GEAR", $51
	db "on and select the", $4f
	db "PHONE icon?", $57
; 0x7a807

UnknownText_0x7a807: ; 0x7a807
	db $0, "I'll read the", $4f
	db "instructions.", $51
	db "Turn the #GEAR", $4f
	db "on and select the", $55
	db "PHONE icon.", $57
; 0x7a850

UnknownText_0x7a850: ; 0x7a850
	db $0, "Phone numbers are", $4f
	db "stored in memory.", $51
	db "Just choose a name", $4f
	db "you want to call.", $51
	db "Gee, isn't that", $4f
	db "convenient?", $57
; 0x7a8b5

UnknownText_0x7a8b5: ; 0x7a8b5
	db $0, "PROF.ELM is wait-", $4f
	db "ing for you.", $51
	db "Hurry up, baby!", $57
; 0x7a8e5

UnknownText_0x7a8e5: ; 0x7a8e5
	db $0, "So, what was PROF.", $4f
	db "ELM's errand?", $51
	db "…", $51
	db "That does sound", $4f
	db "challenging.", $51
	db "But, you should be", $4f
	db "proud that people", $55
	db "rely on you.", $57
; 0x7a957

UnknownText_0x7a957: ; 0x7a957
	db $0, $52, ", do it!", $51
	db "I'm behind you all", $4f
	db "the way!", $57
; 0x7a97d

UnknownText_0x7a97d: ; 0x7a97d
	db $0, "Good morning,", $4f
	db $14, "!", $51
	db "I'm visiting!", $57
; 0x7a99c

UnknownText_0x7a99c: ; 0x7a99c
	db $0, "Hello, ", $14, "!", $4f
	db "I'm visiting!", $57
; 0x7a9b4

UnknownText_0x7a9b4: ; 0x7a9b4
	db $0, "Good evening,", $4f
	db $14, "!", $51
	db "I'm visiting!", $57
; 0x7a9d3

UnknownText_0x7a9d3: ; 0x7a9d3
	db $0, $14, ", have you", $4f
	db "heard?", $51
	db "My daughter is", $4f
	db "adamant about", $51
	db "becoming PROF.", $4f
	db "ELM's assistant.", $51
	db "She really loves", $4f
	db "#MON!", $57
; 0x7aa3a

UnknownText_0x7aa3a: ; 0x7aa3a
	db $0, "Mom's specialty!", $51
	db "CINNABAR VOLCANO", $4f
	db "BURGER!", $57
; 0x7aa64

UnknownText_0x7aa64: ; 0x7aa64
	db $0, "The sink is spot-", $4f
	db "less. Mom likes it", $55
	db "clean.", $57
; 0x7aa91

UnknownText_0x7aa91: ; 0x7aa91
	db $0, "Let's see what's", $4f
	db "in the fridge…", $51
	db "FRESH WATER and", $4f
	db "tasty LEMONADE!", $57
; 0x7aad0

UnknownText_0x7aad0: ; 0x7aad0
	db $0, "There's a movie on", $4f
	db "TV: Stars dot the", $51
	db "sky as two boys", $4f
	db "ride on a train…", $51
	db "I'd better get", $4f
	db "rolling too!", $57
; 0x7ab31

KrissHouse1F_MapEventHeader: ; 0x7ab31
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $6, 2, GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN
	warp_def $7, $7, 2, GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN
	warp_def $0, $9, 1, GROUP_KRISS_HOUSE_2F, MAP_KRISS_HOUSE_2F

	; xy triggers
	db 2
	xy_trigger 0, $4, $8, $0, UnknownScript_0x7a4d8, $0, $0
	xy_trigger 0, $4, $9, $0, UnknownScript_0x7a4db, $0, $0

	; signposts
	db 4
	signpost 1, 0, $0, MapKrissHouse1FSignpost0Script
	signpost 1, 1, $0, MapKrissHouse1FSignpost1Script
	signpost 1, 2, $0, MapKrissHouse1FSignpost2Script
	signpost 1, 4, $0, MapKrissHouse1FSignpost3Script

	; people-events
	db 5
	person_event $c, 8, 11, $8, $0, 255, 255, $0, 0, UnknownScript_0x7a582, $06c7
	person_event $c, 6, 6, $7, $0, 255, 1, $0, 0, UnknownScript_0x7a582, $06c8
	person_event $c, 8, 11, $8, $0, 255, 2, $0, 0, UnknownScript_0x7a582, $06c8
	person_event $c, 6, 4, $7, $0, 255, 4, $0, 0, UnknownScript_0x7a582, $06c8
	person_event $2e, 8, 8, $9, $0, 255, 255, $80, 0, UnknownScript_0x7a5c1, $0792
; 0x7abab

KrissHouse2F_MapScriptHeader: ; 0x7abab
	; trigger count
	db 0

	; callback count
	db 2

	; callbacks

	dbw 5, UnknownScript_0x7abb4

	dbw 1, UnknownScript_0x7abc5
; 0x7abb3

UnknownScript_0x7abb3: ; 0x7abb3
	end
; 0x7abb4

UnknownScript_0x7abb4: ; 0x7abb4
	special $004a
	setbit1 $0007
	checkbit1 $0036
	iftrue UnknownScript_0x7abc4
	jumpstd $0018
	return
; 0x7abc4

UnknownScript_0x7abc4: ; 0x7abc4
	return
; 0x7abc5

UnknownScript_0x7abc5: ; 0x7abc5
	special $0049
	return
; 0x7abc9

INCBIN "baserom.gbc",$7abc9,$7abcc - $7abc9

UnknownScript_0x7abcc: ; 0x7abcc
	describedecoration $1
	describedecoration $2
	describedecoration $3
	describedecoration $4
	unknown0xcc
; 0x7abd5

INCBIN "baserom.gbc",$7abd5,$3d

MapKrissHouse2FSignpost2Script: ; 0x7ac12
	jumpstd $0002
; 0x7ac15

MapKrissHouse2FSignpost0Script: ; 0x7ac15
	loadfont
	special $001d
	iftrue UnknownScript_0x7ac1e
	loadmovesprites
	end
; 0x7ac1e

UnknownScript_0x7ac1e: ; 0x7ac1e
	warp 0, 0, $0, $0
	end
; 0x7ac24

UnknownText_0x7ac24: ; 0x7ac24
	db $0, "PROF.OAK'S #MON", $4f
	db "TALK! Please tune", $55
	db "in next time!", $57
; 0x7ac55

UnknownText_0x7ac55: ; 0x7ac55
	db $0, "#MON CHANNEL!", $57
; 0x7ac64

UnknownText_0x7ac64: ; 0x7ac64
	db $0, "This is DJ MARY,", $4f
	db "your co-host!", $57
; 0x7ac84

UnknownText_0x7ac84: ; 0x7ac84
	db $0, "#MON!", $4f
	db "#MON CHANNEL…", $57
; 0x7ac99

KrissHouse2F_MapEventHeader: ; 0x7ac99
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $0, $7, 3, GROUP_KRISS_HOUSE_1F, MAP_KRISS_HOUSE_1F

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 1, 2, $1, MapKrissHouse2FSignpost0Script
	signpost 1, 3, $0, $6bda
	signpost 1, 5, $0, MapKrissHouse2FSignpost2Script
	signpost 0, 6, $5, $6bd4

	; people-events
	db 4
	person_event $f0, 6, 8, $1, $0, 255, 255, $0, 0, $6bd2, $0741
	person_event $f1, 8, 8, $1, $0, 255, 255, $0, 0, UnknownScript_0x7abcc, $0742
	person_event $f2, 8, 9, $1, $0, 255, 255, $0, 0, $6bce, $0743
	person_event $f3, 5, 4, $21, $0, 255, 255, $0, 0, $6bd0, $0744
; 0x7acec

KrissNeighborsHouse_MapScriptHeader: ; 0x7acec
	; trigger count
	db 0

	; callback count
	db 0
; 0x7acee

UnknownScript_0x7acee: ; 0x7acee
	jumptextfaceplayer UnknownText_0x7ad2f
; 0x7acf1

UnknownScript_0x7acf1: ; 0x7acf1
	jumptextfaceplayer UnknownText_0x7add4
; 0x7acf4

MapKrissNeighborsHouseSignpost1Script: ; 0x7acf4
	jumpstd $0003
; 0x7acf7

MapKrissNeighborsHouseSignpost2Script: ; 0x7acf7
	checkbit1 $001a
	iftrue UnknownScript_0x7ad24
	checkbit1 $0325
	iftrue UnknownScript_0x7ad27
	playmusic $001d
	loadfont
	2writetext UnknownText_0x7ae3b
	pause 45
	2writetext UnknownText_0x7ae6c
	pause 45
	2writetext UnknownText_0x7ae7b
	pause 45
	musicfadeout $003c, $10
	2writetext UnknownText_0x7ae9b
	pause 45
	loadmovesprites
	setbit1 $0325
	end
; 0x7ad24

UnknownScript_0x7ad24: ; 0x7ad24
	jumpstd $000b
; 0x7ad27

UnknownScript_0x7ad27: ; 0x7ad27
	loadfont
	2writetext UnknownText_0x7ae9b
	pause 45
	loadmovesprites
	end
; 0x7ad2f

UnknownText_0x7ad2f: ; 0x7ad2f
	db $0, "PIKACHU is an", $4f
	db "evolved #MON.", $51
	db "I was amazed by", $4f
	db "PROF.ELM's find-", $55
	db "ings.", $51
	db "He's so famous for", $4f
	db "his research on", $55
	db "#MON evolution.", $51
	db "…sigh…", $51
	db "I wish I could be", $4f
	db "a researcher like", $55
	db "him…", $57
; 0x7add4

UnknownText_0x7add4: ; 0x7add4
	db $0, "My daughter is", $4f
	db "adamant about", $51
	db "becoming PROF.", $4f
	db "ELM's assistant.", $51
	db "She really loves", $4f
	db "#MON!", $51
	db "But then, so do I!", $57
; 0x7ae3b

UnknownText_0x7ae3b: ; 0x7ae3b
	db $0, "PROF.OAK'S #MON", $4f
	db "TALK! Please tune", $55
	db "in next time!", $57
; 0x7ae6c

UnknownText_0x7ae6c: ; 0x7ae6c
	db $0, "#MON CHANNEL!", $57
; 0x7ae7b

UnknownText_0x7ae7b: ; 0x7ae7b
	db $0, "This is DJ MARY,", $4f
	db "your co-host!", $57
; 0x7ae9b

UnknownText_0x7ae9b: ; 0x7ae9b
	db $0, "#MON!", $4f
	db "#MON CHANNEL…", $57
; 0x7aeb0

KrissNeighborsHouse_MapEventHeader: ; 0x7aeb0
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN
	warp_def $7, $3, 3, GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 1, 0, $0, MapKrissNeighborsHouseSignpost1Script
	signpost 1, 1, $0, MapKrissNeighborsHouseSignpost1Script
	signpost 1, 7, $0, MapKrissNeighborsHouseSignpost2Script

	; people-events
	db 2
	person_event $24, 7, 6, $9, $0, 255, 255, $80, 0, UnknownScript_0x7acee, $ffff
	person_event $2e, 7, 9, $8, $0, 255, 255, $80, 0, UnknownScript_0x7acf1, $0793
; 0x7aee9

ElmsHouse_MapScriptHeader: ; 0x7aee9
	; trigger count
	db 0

	; callback count
	db 0
; 0x7aeeb

UnknownScript_0x7aeeb: ; 0x7aeeb
	jumptextfaceplayer UnknownText_0x7aef7
; 0x7aeee

UnknownScript_0x7aeee: ; 0x7aeee
	jumptextfaceplayer UnknownText_0x7af6b
; 0x7aef1

MapElmsHouseSignpost0Script: ; 0x7aef1
	jumptext UnknownText_0x7b01b
; 0x7aef4

MapElmsHouseSignpost2Script: ; 0x7aef4
	jumpstd $0001
; 0x7aef7

UnknownText_0x7aef7: ; 0x7aef7
	db $0, "Hi, ", $14, "! My", $4f
	db "husband's always", $51
	db "so busy--I hope", $4f
	db "he's OK.", $51
	db "When he's caught", $4f
	db "up in his #MON", $51
	db "research, he even", $4f
	db "forgets to eat.", $57
; 0x7af6b

UnknownText_0x7af6b: ; 0x7af6b
	db $0, "When I grow up,", $4f
	db "I'm going to help", $55
	db "my dad!", $51
	db "I'm going to be a", $4f
	db "great #MON", $55
	db "professor!", $57
; 0x7afbc

UnknownText_0x7afbc: ; 0x7afbc
	db $0, "There's some food", $4f
	db "here. It must be", $55
	db "for the LAB.", $57
; 0x7afec

UnknownText_0x7afec: ; 0x7afec
	db $0, "There's some food", $4f
	db "here. This must be", $55
	db "for #MON.", $57
; 0x7b01b

UnknownText_0x7b01b: ; 0x7b01b
	db $0, "#MON. Where do", $4f
	db "they come from? ", $51
	db "Where are they", $4f
	db "going?", $51
	db "Why has no one", $4f
	db "ever witnessed a", $55
	db "#MON's birth?", $51
	db "I want to know! I", $4f
	db "will dedicate my", $51
	db "life to the study", $4f
	db "of #MON!", $51
	db "…", $51
	db "It's a part of", $4f
	db "PROF.ELM's re-", $55
	db "search papers.", $57
; 0x7b0ea

ElmsHouse_MapEventHeader: ; 0x7b0ea
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN
	warp_def $7, $3, 4, GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 1, 0, $0, MapElmsHouseSignpost0Script
	signpost 1, 6, $0, MapElmsHouseSignpost2Script
	signpost 1, 7, $0, MapElmsHouseSignpost2Script

	; people-events
	db 2
	person_event $29, 9, 5, $4, $10, 255, 255, $a0, 0, UnknownScript_0x7aeeb, $ffff
	person_event $25, 8, 9, $7, $0, 255, 255, $0, 0, UnknownScript_0x7aeee, $ffff
; 0x7b123

Route26HealSpeechHouse_MapScriptHeader: ; 0x7b123
	; trigger count
	db 0

	; callback count
	db 0
; 0x7b125

UnknownScript_0x7b125: ; 0x7b125
	faceplayer
	loadfont
	2writetext UnknownText_0x7b14d
	closetext
	loadmovesprites
	special $0030
	special $0033
	special $009d
	playmusic $000d
	special $001b
	pause 60
	special $0032
	special $003d
	loadfont
	2writetext UnknownText_0x7b18b
	closetext
	loadmovesprites
	end
; 0x7b14a

MapRoute26HealSpeechHouseSignpost1Script: ; 0x7b14a
	jumpstd $0002
; 0x7b14d

UnknownText_0x7b14d: ; 0x7b14d
	db $0, "Your #MON look", $4f
	db "a little tired.", $51
	db "You should rest", $4f
	db "them a while.", $57
; 0x7b18b

UnknownText_0x7b18b: ; 0x7b18b
	db $0, "There!", $51
	db "Your #MON are", $4f
	db "looking good!", $51
	db "Keep at it!", $57
; 0x7b1bb

Route26HealSpeechHouse_MapEventHeader: ; 0x7b1bb
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_ROUTE_26, MAP_ROUTE_26
	warp_def $7, $3, 2, GROUP_ROUTE_26, MAP_ROUTE_26

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapRoute26HealSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapRoute26HealSpeechHouseSignpost1Script

	; people-events
	db 1
	person_event $29, 7, 6, $6, $0, 255, 255, $90, 0, UnknownScript_0x7b125, $ffff
; 0x7b1e2

Route26DayofWeekSiblingsHouse_MapScriptHeader: ; 0x7b1e2
	; trigger count
	db 0

	; callback count
	db 0
; 0x7b1e4

UnknownScript_0x7b1e4: ; 0x7b1e4
	loadfont
	2writetext UnknownText_0x7b1f9
	yesorno
	iffalse UnknownText_0x7b1f7
	2writetext UnknownText_0x7b222
	yesorno
	iffalse UnknownText_0x7b1f7
	2writetext UnknownText_0x7b2b9
	closetext
UnknownText_0x7b1f7: ; 0x7b1f7
	loadmovesprites
	end
; 0x7b1f9

UnknownText_0x7b1f9: ; 0x7b1f9
	db $0, "There's something", $4f
	db "written here.", $51
	db "Read it?", $57
; 0x7b222

UnknownText_0x7b222: ; 0x7b222
	db $0, "To my brothers and", $4f
	db "sisters:", $51
	db "We take pride in", $4f
	db "serving #MON", $55
	db "trainers.", $51
	db "When trainers talk", $4f
	db "to you, give them", $55
	db "something useful.", $51
	db "Love,", $4f
	db "MONICA", $51
	db "Keep reading?", $57
; 0x7b2b9

UnknownText_0x7b2b9: ; 0x7b2b9
	db $0, "Monday, MONICA", $4f
	db "ROUTE 40", $51
	db "Tuesday, TUSCANY", $4f
	db "ROUTE 29", $51
	db "Wednesday, WESLEY", $4f
	db "LAKE OF RAGE", $51
	db "Thursday, ARTHUR", $4f
	db "ROUTE 36", $51
	db "Friday, FRIEDA", $4f
	db "ROUTE 32", $51
	db "Saturday, SANTOS", $4f
	db "BLACKTHORN CITY", $51
	db "Sunday, SUNNY", $4f
	db "ROUTE 37", $57
; 0x7b375

Route26DayofWeekSiblingsHouse_MapEventHeader: ; 0x7b375
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_ROUTE_26, MAP_ROUTE_26
	warp_def $7, $3, 3, GROUP_ROUTE_26, MAP_ROUTE_26

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $55, 7, 7, $1, $0, 255, 255, $0, 0, UnknownScript_0x7b1e4, $ffff
; 0x7b392

Route27SandstormHouse_MapScriptHeader: ; 0x7b392
	; trigger count
	db 0

	; callback count
	db 0
; 0x7b394

UnknownScript_0x7b394: ; 0x7b394
	faceplayer
	loadfont
	checkbit1 $0075
	iftrue UnknownScript_0x7b3b7
	special $0059
	2writetext UnknownText_0x7b3c6
	keeptextopen
	if_less_than $95, UnknownScript_0x7b3aa
	2jump UnknownScript_0x7b3bd
; 0x7b3aa

UnknownScript_0x7b3aa: ; 0x7b3aa
	2writetext UnknownText_0x7b42b
	keeptextopen
	verbosegiveitem TM_37, 1
	iffalse UnknownScript_0x7b3bb
	setbit1 $0075
UnknownScript_0x7b3b7: ; 0x7b3b7
	2writetext UnknownText_0x7b48f
	closetext
UnknownScript_0x7b3bb: ; 0x7b3bb
	loadmovesprites
	end
; 0x7b3bd

UnknownScript_0x7b3bd: ; 0x7b3bd
	2writetext UnknownText_0x7b51f
	closetext
	loadmovesprites
	end
; 0x7b3c3

MapRoute27SandstormHouseSignpost1Script: ; 0x7b3c3
	jumpstd $0003
; 0x7b3c6

UnknownText_0x7b3c6: ; 0x7b3c6
	db $0, "Where are you off", $4f
	db "to with #MON?", $51
	db "#MON LEAGUE?", $51
	db "Are your #MON", $4f
	db "loyal enough for", $55
	db "you to win?", $51
	db "Let me see…", $57
; 0x7b42b

UnknownText_0x7b42b: ; 0x7b42b
	db $0, "Ah! Your #MON", $4f
	db "trusts you very", $55
	db "much.", $51
	db "It's nice to see a", $4f
	db "good trainer.", $51
	db "Here. A gift for", $4f
	db "your journey.", $57
; 0x7b48f

UnknownText_0x7b48f: ; 0x7b48f
	db $0, "TM37 happens to be", $4f
	db "SANDSTORM.", $51
	db "It's a move that", $4f
	db "inflicts damage on", $55
	db "both battlers.", $51
	db "It's for advanced", $4f
	db "trainers only.", $51
	db "Use it if you", $4f
	db "dare. Good luck!", $57
; 0x7b51f

UnknownText_0x7b51f: ; 0x7b51f
	db $0, "If it doesn't come", $4f
	db "to trust you some", $51
	db "more, it could be", $4f
	db "tough going.", $51
	db "Trust is the tie", $4f
	db "that binds #MON", $55
	db "and trainers.", $57
; 0x7b592

Route27SandstormHouse_MapEventHeader: ; 0x7b592
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_ROUTE_27, MAP_ROUTE_27
	warp_def $7, $3, 1, GROUP_ROUTE_27, MAP_ROUTE_27

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapRoute27SandstormHouseSignpost1Script
	signpost 1, 1, $0, MapRoute27SandstormHouseSignpost1Script

	; people-events
	db 1
	person_event $30, 8, 6, $6, $0, 255, 255, $0, 0, UnknownScript_0x7b394, $ffff
; 0x7b5b9

Route2946Gate_MapScriptHeader: ; 0x7b5b9
	; trigger count
	db 0

	; callback count
	db 0
; 0x7b5bb

UnknownScript_0x7b5bb: ; 0x7b5bb
	jumptextfaceplayer UnknownText_0x7b5c1
; 0x7b5be

UnknownScript_0x7b5be: ; 0x7b5be
	jumptextfaceplayer UnknownText_0x7b60d
; 0x7b5c1

UnknownText_0x7b5c1: ; 0x7b5c1
	db $0, "You can't climb", $4f
	db "ledges.", $51
	db "But you can jump", $4f
	db "down from them to", $55
	db "take a shortcut.", $57
; 0x7b60d

UnknownText_0x7b60d: ; 0x7b60d
	db $0, "Different kinds of", $4f
	db "#MON appear", $55
	db "past here.", $51
	db "If you want to", $4f
	db "catch them all,", $51
	db "you have to look", $4f
	db "everywhere.", $57
; 0x7b674

Route2946Gate_MapEventHeader: ; 0x7b674
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 1, GROUP_ROUTE_46, MAP_ROUTE_46
	warp_def $0, $5, 2, GROUP_ROUTE_46, MAP_ROUTE_46
	warp_def $7, $4, 1, GROUP_ROUTE_29, MAP_ROUTE_29
	warp_def $7, $5, 1, GROUP_ROUTE_29, MAP_ROUTE_29

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $43, 8, 4, $9, $0, 255, 255, $80, 0, UnknownScript_0x7b5bb, $ffff
	person_event $27, 8, 10, $4, $10, 255, 255, $a0, 0, UnknownScript_0x7b5be, $ffff
; 0x7b6a8

SECTION "bank1F",DATA,BANK[$1F]

Route22_MapScriptHeader: ; 0x7c000
	; trigger count
	db 0

	; callback count
	db 0
; 0x7c002

MapRoute22Signpost0Script: ; 0x7c002
	jumptext UnknownText_0x7c005
; 0x7c005

UnknownText_0x7c005: ; 0x7c005
	db $0, "#MON LEAGUE", $51
	db "VICTORY ROAD", $4f
	db "ENTRANCE", $57
; 0x7c028

Route22_MapEventHeader: ; 0x7c028
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $5, $d, 1, GROUP_VICTORY_ROAD_GATE, MAP_VICTORY_ROAD_GATE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 7, 15, $0, MapRoute22Signpost0Script

	; people-events
	db 0
; 0x7c038

WarehouseEntrance_MapScriptHeader: ; 0x7c038
	; trigger count
	db 0

	; callback count
	db 3

	; callbacks

	dbw 5, UnknownScript_0x7c043

	dbw 1, UnknownScript_0x7c076

	dbw 2, UnknownScript_0x7c082
; 0x7c043

UnknownScript_0x7c043: ; 0x7c043
	clearbit1 $02d3
	clearbit1 $02d4
	clearbit1 $02d5
	clearbit1 $02d6
	clearbit1 $02d7
	clearbit1 $02d8
	clearbit1 $02d9
	clearbit1 $02da
	clearbit1 $02db
	clearbit1 $02dc
	clearbit1 $02dd
	clearbit1 $02de
	clearbit1 $02df
	clearbit1 $02e0
	clearbit1 $02e1
	writebyte $0
	copyvartobyte UndergroundSwitchPositions
	return
; 0x7c076

UnknownScript_0x7c076: ; 0x7c076
	checkbit1 $0049
	iffalse UnknownScript_0x7c07d
	return
; 0x7c07d

UnknownScript_0x7c07d: ; 0x7c07d
	changeblock $12, $6, $3d
	return
; 0x7c082

UnknownScript_0x7c082: ; 0x7c082
	checkcode $b
	if_equal MONDAY, UnknownScript_0x7c0a5
	if_equal TUESDAY, UnknownScript_0x7c0b5
	if_equal WEDNESDAY, UnknownScript_0x7c0be
	if_equal THURSDAY, UnknownScript_0x7c0c7
	if_equal FRIDAY, UnknownScript_0x7c0d0
	if_equal SATURDAY, UnknownScript_0x7c0d9
	disappear $7
	disappear $8
	appear $9
	appear $a
	return
; 0x7c0a5

UnknownScript_0x7c0a5: ; 0x7c0a5
	disappear $7
	checktime $1
	iffalse UnknownScript_0x7c0ae
	appear $7
UnknownScript_0x7c0ae: ; 0x7c0ae
	disappear $8
	disappear $9
	disappear $a
	return
; 0x7c0b5

UnknownScript_0x7c0b5: ; 0x7c0b5
	disappear $7
	appear $8
	disappear $9
	disappear $a
	return
; 0x7c0be

UnknownScript_0x7c0be: ; 0x7c0be
	disappear $7
	disappear $8
	appear $9
	disappear $a
	return
; 0x7c0c7

UnknownScript_0x7c0c7: ; 0x7c0c7
	disappear $7
	appear $8
	disappear $9
	disappear $a
	return
; 0x7c0d0

UnknownScript_0x7c0d0: ; 0x7c0d0
	disappear $7
	disappear $8
	appear $9
	disappear $a
	return
; 0x7c0d9

UnknownScript_0x7c0d9: ; 0x7c0d9
	disappear $7
	appear $8
	disappear $9
	appear $a
	return
; 0x7c0e2

TrainerSupernerdEric: ; 0x7c0e2
	; bit/flag number
	dw $582

	; trainer group && trainer id
	db SUPER_NERD, ERIC

	; text when seen
	dw SupernerdEricSeenText

	; text when trainer beaten
	dw SupernerdEricBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SupernerdEricScript
; 0x7c0ee

SupernerdEricScript: ; 0x7c0ee
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7c36c
	closetext
	loadmovesprites
	end
; 0x7c0f6

TrainerSupernerdTeru: ; 0x7c0f6
	; bit/flag number
	dw $58a

	; trainer group && trainer id
	db SUPER_NERD, TERU

	; text when seen
	dw SupernerdTeruSeenText

	; text when trainer beaten
	dw SupernerdTeruBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SupernerdTeruScript
; 0x7c102

SupernerdTeruScript: ; 0x7c102
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7c410
	closetext
	loadmovesprites
	end
; 0x7c10a

TrainerPokemaniacIssac: ; 0x7c10a
	; bit/flag number
	dw $4ee

	; trainer group && trainer id
	db POKEMANIAC, ISSAC

	; text when seen
	dw PokemaniacIssacSeenText

	; text when trainer beaten
	dw PokemaniacIssacBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacIssacScript
; 0x7c116

PokemaniacIssacScript: ; 0x7c116
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7c498
	closetext
	loadmovesprites
	end
; 0x7c11e

TrainerPokemaniacDonald: ; 0x7c11e
	; bit/flag number
	dw $4ef

	; trainer group && trainer id
	db POKEMANIAC, DONALD

	; text when seen
	dw PokemaniacDonaldSeenText

	; text when trainer beaten
	dw PokemaniacDonaldBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacDonaldScript
; 0x7c12a

PokemaniacDonaldScript: ; 0x7c12a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7c52f
	closetext
	loadmovesprites
	end
; 0x7c132

UnknownScript_0x7c132: ; 0x7c132
	loadfont
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x7c140
	if_equal SATURDAY, UnknownScript_0x7c140
	2jump UnknownScript_0x7c300
; 0x7c140

UnknownScript_0x7c140: ; 0x7c140
	pokemart $1, $0021
	loadmovesprites
	end
; 0x7c146

UnknownScript_0x7c146: ; 0x7c146
	loadfont
	checkbit2 $0056
	iftrue UnknownScript_0x7c300
	checkcode $b
	if_equal MONDAY, UnknownScript_0x7c156
	2jump UnknownScript_0x7c300
; 0x7c156

UnknownScript_0x7c156: ; 0x7c156
	checktime $1
	iffalse UnknownScript_0x7c300
	pokemart $2, $0000
	loadmovesprites
	end
; 0x7c161

UnknownScript_0x7c161: ; 0x7c161
	loadfont
	checkcode $b
	if_equal TUESDAY, UnknownScript_0x7c173
	if_equal THURSDAY, UnknownScript_0x7c173
	if_equal SATURDAY, UnknownScript_0x7c173
	2jump UnknownScript_0x7c300
; 0x7c173

UnknownScript_0x7c173: ; 0x7c173
	checkbit2 $005a
	iftrue UnknownScript_0x7c208
	special $0051
	2writetext UnknownText_0x7c5f9
	yesorno
	iffalse UnknownScript_0x7c1fc
	checkmoney $0, 500
	if_equal $2, UnknownScript_0x7c202
	2writetext UnknownText_0x7c69a
	keeptextopen
	special $0061
	if_equal $0, UnknownScript_0x7c1fc
	if_equal $1, UnknownScript_0x7c1fc
	setbit2 $005a
	if_equal $2, UnknownScript_0x7c1a9
	if_equal $3, UnknownScript_0x7c1b5
	2jump UnknownScript_0x7c1c1
; 0x7c1a9

UnknownScript_0x7c1a9: ; 0x7c1a9
	setbit1 $0000
	clearbit1 $0001
	clearbit1 $0002
	2jump UnknownScript_0x7c1cd
; 0x7c1b5

UnknownScript_0x7c1b5: ; 0x7c1b5
	clearbit1 $0000
	setbit1 $0001
	clearbit1 $0002
	2jump UnknownScript_0x7c1cd
; 0x7c1c1

UnknownScript_0x7c1c1: ; 0x7c1c1
	clearbit1 $0000
	clearbit1 $0001
	setbit1 $0002
	2jump UnknownScript_0x7c1cd
; 0x7c1cd

UnknownScript_0x7c1cd: ; 0x7c1cd
	takemoney $0, 500
	special $0051
	2writetext UnknownText_0x7c6b8
	closetext
	loadmovesprites
	special $002e
	playmusic $000d
	pause 60
	special $0031
	special $003d
	loadfont
	2writetext UnknownText_0x7c6d8
	closetext
	checkbit1 $0000
	iftrue UnknownScript_0x7c2bb
	checkbit1 $0001
	iftrue UnknownScript_0x7c2c4
	2jump UnknownScript_0x7c2cd
; 0x7c1fc

UnknownScript_0x7c1fc: ; 0x7c1fc
	2writetext UnknownText_0x7c6ea
	closetext
	loadmovesprites
	end
; 0x7c202

UnknownScript_0x7c202: ; 0x7c202
	2writetext UnknownText_0x7c709
	closetext
	loadmovesprites
	end
; 0x7c208

UnknownScript_0x7c208: ; 0x7c208
	2writetext UnknownText_0x7c72b
	closetext
	loadmovesprites
	end
; 0x7c20e

UnknownScript_0x7c20e: ; 0x7c20e
	loadfont
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x7c220
	if_equal WEDNESDAY, UnknownScript_0x7c220
	if_equal FRIDAY, UnknownScript_0x7c220
	2jump UnknownScript_0x7c300
; 0x7c220

UnknownScript_0x7c220: ; 0x7c220
	checkbit2 $005a
	iftrue UnknownScript_0x7c2b5
	special $0051
	2writetext UnknownText_0x7c75c
	yesorno
	iffalse UnknownScript_0x7c2a9
	checkmoney $0, 300
	if_equal $2, UnknownScript_0x7c2af
	2writetext UnknownText_0x7c7f1
	keeptextopen
	special $0062
	if_equal $0, UnknownScript_0x7c2a9
	if_equal $1, UnknownScript_0x7c2a9
	setbit2 $005a
	if_equal $2, UnknownScript_0x7c256
	if_equal $3, UnknownScript_0x7c262
	2jump UnknownScript_0x7c26e
; 0x7c256

UnknownScript_0x7c256: ; 0x7c256
	setbit1 $0000
	clearbit1 $0001
	clearbit1 $0002
	2jump UnknownScript_0x7c27a
; 0x7c262

UnknownScript_0x7c262: ; 0x7c262
	clearbit1 $0000
	setbit1 $0001
	clearbit1 $0002
	2jump UnknownScript_0x7c27a
; 0x7c26e

UnknownScript_0x7c26e: ; 0x7c26e
	clearbit1 $0000
	clearbit1 $0001
	setbit1 $0002
	2jump UnknownScript_0x7c27a
; 0x7c27a

UnknownScript_0x7c27a: ; 0x7c27a
	takemoney $0, 300
	special $0051
	2writetext UnknownText_0x7c80e
	closetext
	loadmovesprites
	special $002e
	playmusic $000d
	pause 60
	special $0031
	special $003d
	loadfont
	2writetext UnknownText_0x7c82a
	closetext
	checkbit1 $0000
	iftrue UnknownScript_0x7c2bb
	checkbit1 $0001
	iftrue UnknownScript_0x7c2c4
	2jump UnknownScript_0x7c2cd
; 0x7c2a9

UnknownScript_0x7c2a9: ; 0x7c2a9
	2writetext UnknownText_0x7c842
	closetext
	loadmovesprites
	end
; 0x7c2af

UnknownScript_0x7c2af: ; 0x7c2af
	2writetext UnknownText_0x7c85b
	closetext
	loadmovesprites
	end
; 0x7c2b5

UnknownScript_0x7c2b5: ; 0x7c2b5
	2writetext UnknownText_0x7c87b
	closetext
	loadmovesprites
	end
; 0x7c2bb

UnknownScript_0x7c2bb: ; 0x7c2bb
	2writetext UnknownText_0x7c8bf
	special $0064
	closetext
	loadmovesprites
	end
; 0x7c2c4

UnknownScript_0x7c2c4: ; 0x7c2c4
	2writetext UnknownText_0x7c8dc
	special $0064
	closetext
	loadmovesprites
	end
; 0x7c2cd

UnknownScript_0x7c2cd: ; 0x7c2cd
	2writetext UnknownText_0x7c8ee
	special $0064
	closetext
	loadmovesprites
	end
; 0x7c2d6

MapWarehouseEntranceSignpost0Script: ; 0x7c2d6
	loadfont
	checkbit1 $0049
	iftrue UnknownScript_0x7c2fa
	checkitem BASEMENT_KEY
	iftrue UnknownScript_0x7c2e8
	2writetext UnknownText_0x7c5b0
	closetext
	loadmovesprites
	end
; 0x7c2e8

UnknownScript_0x7c2e8: ; 0x7c2e8
	playsound $0022
	2writetext UnknownText_0x7c5d6
	closetext
	loadmovesprites
	changeblock $12, $6, $2e
	reloadmappart
	loadmovesprites
	setbit1 $0049
	end
; 0x7c2fa

UnknownScript_0x7c2fa: ; 0x7c2fa
	2writetext UnknownText_0x7c5c3
	closetext
	loadmovesprites
	end
; 0x7c300

UnknownScript_0x7c300: ; 0x7c300
	2writetext UnknownText_0x7c904
	closetext
	loadmovesprites
	end
; 0x7c306

ItemFragment_0x7c306: ; 0x7c306
	db COIN_CASE, 1
; 0x7c308

MapWarehouseEntranceSignpost1Script: ; 0x7c308
	jumptext UnknownText_0x7c91a
; 0x7c30b

MapWarehouseEntranceSignpostItem2: ; 0x7c30b
	dw $008b
	db PARLYZ_HEAL
	
; 0x7c30e

MapWarehouseEntranceSignpostItem3: ; 0x7c30e
	dw $008c
	db SUPER_POTION
	
; 0x7c311

MapWarehouseEntranceSignpostItem4: ; 0x7c311
	dw $008d
	db ANTIDOTE
	
; 0x7c314

SupernerdEricSeenText: ; 0x7c314
	db $0, "I got booted out", $4f
	db "of the GAME COR-", $55
	db "NER.", $51
	db "I was trying to", $4f
	db "cheat using my", $55
	db "#MON…", $57
; 0x7c361

SupernerdEricBeatenText: ; 0x7c361
	db $0, "…Grumble…", $57
; 0x7c36c

UnknownText_0x7c36c: ; 0x7c36c
	db $0, "I guess I have to", $4f
	db "do things fair and", $55
	db "square…", $57
; 0x7c39a

SupernerdTeruSeenText: ; 0x7c39a
	db $0, "Do you consider", $4f
	db "type alignments in", $55
	db "battle?", $51
	db "If you know your", $4f
	db "type advantages,", $51
	db "you'll do better", $4f
	db "in battle.", $57
; 0x7c403

SupernerdTeruBeatenText: ; 0x7c403
	db $0, "Ow, ow, ow!", $57
; 0x7c410

UnknownText_0x7c410: ; 0x7c410
	db $0, "I know my #MON", $4f
	db "type alignments.", $51
	db "But I only use one", $4f
	db "type of #MON.", $57
; 0x7c452

PokemaniacIssacSeenText: ; 0x7c452
	db $0, "My #MON just", $4f
	db "got a haircut!", $51
	db "I'll show you how", $4f
	db "strong it is!", $57
; 0x7c48e

PokemaniacIssacBeatenText: ; 0x7c48e
	db $0, "Aiyeeee!", $57
; 0x7c498

UnknownText_0x7c498: ; 0x7c498
	db $0, "Your #MON will", $4f
	db "like you more if", $51
	db "you give them", $4f
	db "haircuts.", $57
; 0x7c4d1

PokemaniacDonaldSeenText: ; 0x7c4d1
	db $0, "I think you have", $4f
	db "some rare #MON", $55
	db "with you.", $51
	db "Let me see them!", $57
; 0x7c50d

PokemaniacDonaldBeatenText: ; 0x7c50d
	db $0, "Gaah! I lost!", $4f
	db "That makes me mad!", $57
; 0x7c52f

UnknownText_0x7c52f: ; 0x7c52f
	db $0, "Are you making a", $4f
	db "#DEX? Here's a", $55
	db "hot tip.", $51
	db "The HIKER on ROUTE", $4f
	db "33, ANTHONY, is a", $55
	db "good guy.", $51
	db "He'll phone you if", $4f
	db "he sees any rare", $55
	db "#MON.", $57
; 0x7c5b0

UnknownText_0x7c5b0: ; 0x7c5b0
	db $0, "The door's locked…", $57
; 0x7c5c3

UnknownText_0x7c5c3: ; 0x7c5c3
	db $0, "The door is open.", $57
; 0x7c5d6

UnknownText_0x7c5d6: ; 0x7c5d6
	db $0, "The BASEMENT KEY", $4f
	db "opened the door.", $57
; 0x7c5f9

UnknownText_0x7c5f9: ; 0x7c5f9
	db $0, "Welcome!", $51
	db "I run the #MON", $4f
	db "SALON!", $51
	db "I'm the older and", $4f
	db "better of the two", $55
	db "HAIRCUT BROTHERS.", $51
	db "I can make your", $4f
	db "#MON beautiful", $55
	db "for just ¥500.", $51
	db "Would you like me", $4f
	db "to do that?", $57
; 0x7c69a

UnknownText_0x7c69a: ; 0x7c69a
	db $0, "Which #MON", $4f
	db "should I work on?", $57
; 0x7c6b8

UnknownText_0x7c6b8: ; 0x7c6b8
	db $0, "OK! Watch it", $4f
	db "become beautiful!", $57
; 0x7c6d8

UnknownText_0x7c6d8: ; 0x7c6d8
	db $0, "There! All done!", $57
; 0x7c6ea

UnknownText_0x7c6ea: ; 0x7c6ea
	db $0, "Is that right?", $4f
	db "That's a shame!", $57
; 0x7c709

UnknownText_0x7c709: ; 0x7c709
	db $0, "You'll need more", $4f
	db "money than that.", $57
; 0x7c72b

UnknownText_0x7c72b: ; 0x7c72b
	db $0, "I do only one", $4f
	db "haircut a day. I'm", $55
	db "done for today.", $57
; 0x7c75c

UnknownText_0x7c75c: ; 0x7c75c
	db $0, "Welcome to the", $4f
	db "#MON SALON!", $51
	db "I'm the younger", $4f
	db "and less expen-", $55
	db "sive of the two", $55
	db "HAIRCUT BROTHERS.", $51
	db "I'll spiff up your", $4f
	db "#MON for just", $55
	db "¥300.", $51
	db "So? How about it?", $57
; 0x7c7f1

UnknownText_0x7c7f1: ; 0x7c7f1
	db $0, "OK, which #MON", $4f
	db "should I do?", $57
; 0x7c80e

UnknownText_0x7c80e: ; 0x7c80e
	db $0, "OK! I'll make it", $4f
	db "look cool!", $57
; 0x7c82a

UnknownText_0x7c82a: ; 0x7c82a
	db $0, "There we go!", $4f
	db "All done!", $57
; 0x7c842

UnknownText_0x7c842: ; 0x7c842
	db $0, "No? ", $4f
	db "How disappointing!", $57
; 0x7c85b

UnknownText_0x7c85b: ; 0x7c85b
	db $0, "You're a little", $4f
	db "short on funds.", $57
; 0x7c87b

UnknownText_0x7c87b: ; 0x7c87b
	db $0, "I can do only one", $4f
	db "haircut a day.", $51
	db "Sorry, but I'm all", $4f
	db "done for today.", $57
; 0x7c8bf

UnknownText_0x7c8bf: ; 0x7c8bf
	text_from_ram $d099
	db $0, " looks a", $4f
	db "little happier.", $57
; 0x7c8dc

UnknownText_0x7c8dc: ; 0x7c8dc
	text_from_ram $d099
	db $0, " looks", $4f
	db "happy.", $57
; 0x7c8ee

UnknownText_0x7c8ee: ; 0x7c8ee
	text_from_ram $d099
	db $0, " looks", $4f
	db "delighted!", $57
; 0x7c904

UnknownText_0x7c904: ; 0x7c904
	db $0, "We're not open", $4f
	db "today.", $57
; 0x7c91a

UnknownText_0x7c91a: ; 0x7c91a
	db $0, "NO ENTRY BEYOND", $4f
	db "THIS POINT", $57
; 0x7c936

WarehouseEntrance_MapEventHeader: ; 0x7c936
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $2, $3, 7, GROUP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES, MAP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES
	warp_def $22, $3, 4, GROUP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES, MAP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES
	warp_def $6, $12, 4, GROUP_WAREHOUSE_ENTRANCE, MAP_WAREHOUSE_ENTRANCE
	warp_def $1f, $15, 3, GROUP_WAREHOUSE_ENTRANCE, MAP_WAREHOUSE_ENTRANCE
	warp_def $1f, $16, 3, GROUP_WAREHOUSE_ENTRANCE, MAP_WAREHOUSE_ENTRANCE
	warp_def $1b, $16, 1, GROUP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES, MAP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES

	; xy triggers
	db 0

	; signposts
	db 5
	signpost 6, 18, $0, MapWarehouseEntranceSignpost0Script
	signpost 6, 19, $0, MapWarehouseEntranceSignpost1Script
	signpost 13, 6, $7, MapWarehouseEntranceSignpostItem2
	signpost 18, 4, $7, MapWarehouseEntranceSignpostItem3
	signpost 8, 17, $7, MapWarehouseEntranceSignpostItem4

	; people-events
	db 9
	person_event $2b, 35, 9, $8, $0, 255, 255, $b2, 3, TrainerSupernerdEric, $ffff
	person_event $2b, 13, 10, $7, $0, 255, 255, $b2, 2, TrainerSupernerdTeru, $ffff
	person_event $2b, 31, 7, $a, $0, 255, 255, $92, 2, TrainerPokemaniacIssac, $ffff
	person_event $2b, 10, 6, $9, $0, 255, 255, $92, 3, TrainerPokemaniacDonald, $ffff
	person_event $54, 29, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x7c306, $0672
	person_event $2f, 15, 11, $8, $0, 255, 255, $b0, 0, UnknownScript_0x7c146, $0753
	person_event $2b, 18, 11, $8, $0, 255, 255, $90, 0, UnknownScript_0x7c161, $0754
	person_event $2b, 19, 11, $8, $0, 255, 255, $a0, 0, UnknownScript_0x7c20e, $0755
	person_event $30, 25, 11, $8, $0, 255, 255, $b0, 0, UnknownScript_0x7c132, $0752
; 0x7c9e8

UndergroundPathSwitchRoomEntrances_MapScriptHeader: ; 0x7c9e8
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x7c9f5, $0000
	dw UnknownScript_0x7c9f6, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x7c9f7
; 0x7c9f5

UnknownScript_0x7c9f5: ; 0x7c9f5
	end
; 0x7c9f6

UnknownScript_0x7c9f6: ; 0x7c9f6
	end
; 0x7c9f7

UnknownScript_0x7c9f7: ; 0x7c9f7
	checkbit1 $02d7
	iffalse UnknownScript_0x7ca01
	changeblock $10, $6, $2d
UnknownScript_0x7ca01: ; 0x7ca01
	checkbit1 $02d8
	iffalse UnknownScript_0x7ca0b
	changeblock $a, $6, $2d
UnknownScript_0x7ca0b: ; 0x7ca0b
	checkbit1 $02d9
	iffalse UnknownScript_0x7ca15
	changeblock $2, $6, $2d
UnknownScript_0x7ca15: ; 0x7ca15
	checkbit1 $02da
	iffalse UnknownScript_0x7ca1f
	changeblock $2, $a, $2d
UnknownScript_0x7ca1f: ; 0x7ca15
	checkbit1 $02db
	iffalse UnknownScript_0x7ca29
	changeblock $a, $a, $2d
UnknownScript_0x7ca29: ; 0x7ca29
	checkbit1 $02dc
	iffalse UnknownScript_0x7ca33
	changeblock $10, $a, $2d
UnknownScript_0x7ca33: ; 0x7ca33
	checkbit1 $02dd
	iffalse UnknownScript_0x7ca41
	changeblock $c, $6, $2a
	changeblock $c, $8, $2d
UnknownScript_0x7ca41: ; 0x7ca41
	checkbit1 $02de
	iffalse UnknownScript_0x7ca4f
	changeblock $6, $6, $2a
	changeblock $6, $8, $2d
UnknownScript_0x7ca4f: ; 0x7ca4f
	checkbit1 $02df
	iffalse UnknownScript_0x7ca5d
	changeblock $c, $a, $2a
	changeblock $c, $c, $2d
UnknownScript_0x7ca5d: ; 0x7ca5d
	checkbit1 $02e0
	iffalse UnknownScript_0x7ca6b
	changeblock $6, $a, $2a
	changeblock $6, $c, $2d
UnknownScript_0x7ca6b: ; 0x7ca6b
	checkbit1 $02e1
	iffalse UnknownScript_0x7ca79
	changeblock $12, $a, $2a
	changeblock $12, $c, $2d
UnknownScript_0x7ca79: ; 0x7ca79
	return
; 0x7ca7a

UnknownScript_0x7ca7a: ; 0x7ca7a
	jumptextfaceplayer UnknownText_0x7d176
; 0x7ca7d

UnknownScript_0x7ca7d: ; 0x7ca7d
	jumptextfaceplayer UnknownText_0x7d1d0
; 0x7ca80

UnknownScript_0x7ca80: ; 0x7ca80
	spriteface $0, $3
	showemote $0, $0, 15
	special $006a
	pause 15
	playsound $0023
	appear $c
	waitbutton
	applymovement $c, MovementData_0x7ce87
	spriteface $0, $3
	2call UnknownScript_0x7cad4
	applymovement $c, MovementData_0x7ce92
	playsound $0023
	disappear $c
	dotrigger $1
	waitbutton
	playmapmusic
	end
; 0x7caaa

UnknownScript_0x7caaa: ; 0x7caaa
	spriteface $0, $3
	showemote $0, $0, 15
	special $006a
	pause 15
	playsound $0023
	appear $c
	waitbutton
	applymovement $c, MovementData_0x7ce8c
	spriteface $0, $3
	2call UnknownScript_0x7cad4
	applymovement $c, MovementData_0x7ce97
	playsound $0023
	disappear $c
	dotrigger $1
	waitbutton
	playmapmusic
	end
; 0x7cad4

UnknownScript_0x7cad4: ; 0x7cad4
	checkbit1 $06c5
	iftrue UnknownScript_0x7cae1
	setbit1 $06c5
	domaptrigger GROUP_BURNED_TOWER_1F, MAP_BURNED_TOWER_1F, $1
UnknownScript_0x7cae1: ; 0x7cae1
	playmusic $001f
	loadfont
	2writetext UnknownText_0x7ce9d
	closetext
	loadmovesprites
	setbit1 $06c1
	checkbit1 $001c
	iftrue UnknownScript_0x7cb09
	checkbit1 $001d
	iftrue UnknownScript_0x7cb19
	winlosstext UnknownText_0x7cf5d, UnknownText_0x7d102
	setlasttalked $c
	loadtrainer RIVAL1, RIVAL1_12
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x7cb29
; 0x7cb09

UnknownScript_0x7cb09: ; 0x7cb09
	winlosstext UnknownText_0x7cf5d, UnknownText_0x7d102
	setlasttalked $c
	loadtrainer RIVAL1, RIVAL1_10
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x7cb29
; 0x7cb19

UnknownScript_0x7cb19: ; 0x7cb19
	winlosstext UnknownText_0x7cf5d, UnknownText_0x7d102
	setlasttalked $c
	loadtrainer RIVAL1, RIVAL1_11
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x7cb29
; 0x7cb29

UnknownScript_0x7cb29: ; 0x7cb29
	playmusic $0020
	loadfont
	2writetext UnknownText_0x7cfc2
	closetext
	loadmovesprites
	end
; 0x7cb33

TrainerGruntM11: ; 0x7cb33
	; bit/flag number
	dw $4fb

	; trainer group && trainer id
	db GRUNTM, 11

	; text when seen
	dw GruntM11SeenText

	; text when trainer beaten
	dw GruntM11BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM11Script
; 0x7cb3f

GruntM11Script: ; 0x7cb3f
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7d290
	closetext
	loadmovesprites
	end
; 0x7cb47

TrainerGruntM25: ; 0x7cb47
	; bit/flag number
	dw $509

	; trainer group && trainer id
	db GRUNTM, 25

	; text when seen
	dw GruntM25SeenText

	; text when trainer beaten
	dw GruntM25BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM25Script
; 0x7cb53

GruntM25Script: ; 0x7cb53
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7d347
	closetext
	loadmovesprites
	end
; 0x7cb5b

TrainerBurglarDuncan: ; 0x7cb5b
	; bit/flag number
	dw $42d

	; trainer group && trainer id
	db BURGLAR, DUNCAN

	; text when seen
	dw BurglarDuncanSeenText

	; text when trainer beaten
	dw BurglarDuncanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BurglarDuncanScript
; 0x7cb67

BurglarDuncanScript: ; 0x7cb67
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7d3cf
	closetext
	loadmovesprites
	end
; 0x7cb6f

TrainerBurglarEddie: ; 0x7cb6f
	; bit/flag number
	dw $42e

	; trainer group && trainer id
	db BURGLAR, EDDIE

	; text when seen
	dw BurglarEddieSeenText

	; text when trainer beaten
	dw BurglarEddieBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BurglarEddieScript
; 0x7cb7b

BurglarEddieScript: ; 0x7cb7b
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7d45b
	closetext
	loadmovesprites
	end
; 0x7cb83

TrainerGruntM13: ; 0x7cb83
	; bit/flag number
	dw $4fd

	; trainer group && trainer id
	db GRUNTM, 13

	; text when seen
	dw GruntM13SeenText

	; text when trainer beaten
	dw GruntM13BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM13Script
; 0x7cb8f

GruntM13Script: ; 0x7cb8f
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7d51f
	closetext
	loadmovesprites
	end
; 0x7cb97

TrainerGruntF3: ; 0x7cb97
	; bit/flag number
	dw $512

	; trainer group && trainer id
	db GRUNTF, 3

	; text when seen
	dw GruntF3SeenText

	; text when trainer beaten
	dw GruntF3BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntF3Script
; 0x7cba3

GruntF3Script: ; 0x7cba3
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7d5e6
	closetext
	loadmovesprites
	end
; 0x7cbab

MapUndergroundPathSwitchRoomEntrancesSignpost0Script: ; 0x7cbab
	loadfont
	2writetext UnknownText_0x7d554
	keeptextopen
	checkbit1 $02d3
	iftrue UnknownScript_0x7cbcb
	2writetext UnknownText_0x7d617
	yesorno
	iffalse UnknownScript_0x7cc8b
	copybytetovar UndergroundSwitchPositions
	addvar $1
	copyvartobyte UndergroundSwitchPositions
	setbit1 $02d3
	2jump UnknownScript_0x7cc8d
; 0x7cbcb

UnknownScript_0x7cbcb: ; 0x7cbcb
	2writetext UnknownText_0x7d62d
	yesorno
	iffalse UnknownScript_0x7cc8b
	copybytetovar UndergroundSwitchPositions
	addvar -1
	copyvartobyte UndergroundSwitchPositions
	clearbit1 $02d3
	2jump UnknownScript_0x7cc8d
; 0x7cbe0

MapUndergroundPathSwitchRoomEntrancesSignpost1Script: ; 0x7cbe0
	loadfont
	2writetext UnknownText_0x7d643
	keeptextopen
	checkbit1 $02d4
	iftrue UnknownScript_0x7cc00
	2writetext UnknownText_0x7d617
	yesorno
	iffalse UnknownScript_0x7cc8b
	copybytetovar UndergroundSwitchPositions
	addvar $2
	copyvartobyte UndergroundSwitchPositions
	setbit1 $02d4
	2jump UnknownScript_0x7cc8d
; 0x7cc00

UnknownScript_0x7cc00: ; 0x7cc00
	2writetext UnknownText_0x7d62d
	yesorno
	iffalse UnknownScript_0x7cc8b
	copybytetovar UndergroundSwitchPositions
	addvar -2
	copyvartobyte UndergroundSwitchPositions
	clearbit1 $02d4
	2jump UnknownScript_0x7cc8d
; 0x7cc15

MapUndergroundPathSwitchRoomEntrancesSignpost2Script: ; 0x7cc15
	loadfont
	2writetext UnknownText_0x7d65a
	keeptextopen
	checkbit1 $02d5
	iftrue UnknownScript_0x7cc35
	2writetext UnknownText_0x7d617
	yesorno
	iffalse UnknownScript_0x7cc8b
	copybytetovar UndergroundSwitchPositions
	addvar $3
	copyvartobyte UndergroundSwitchPositions
	setbit1 $02d5
	2jump UnknownScript_0x7cc8d
; 0x7cc35

UnknownScript_0x7cc35: ; 0x7cc35
	2writetext UnknownText_0x7d62d
	yesorno
	iffalse UnknownScript_0x7cc8b
	copybytetovar UndergroundSwitchPositions
	addvar -3
	copyvartobyte UndergroundSwitchPositions
	clearbit1 $02d5
	2jump UnknownScript_0x7cc8d
; 0x7cc4a

MapUndergroundPathSwitchRoomEntrancesSignpost3Script: ; 0x7cc4a
	loadfont
	2writetext UnknownText_0x7d671
	keeptextopen
	checkbit1 $02d6
	iftrue UnknownScript_0x7cc70
	2writetext UnknownText_0x7d617
	yesorno
	iffalse UnknownScript_0x7cc8b
	writebyte $7
	copyvartobyte UndergroundSwitchPositions
	setbit1 $02d6
	setbit1 $02d3
	setbit1 $02d4
	setbit1 $02d5
	2jump UnknownScript_0x7cc8d
; 0x7cc70

UnknownScript_0x7cc70: ; 0x7cc70
	2writetext UnknownText_0x7d62d
	yesorno
	iffalse UnknownScript_0x7cc8b
	writebyte $0
	copyvartobyte UndergroundSwitchPositions
	clearbit1 $02d6
	clearbit1 $02d3
	clearbit1 $02d4
	clearbit1 $02d5
	2jump UnknownScript_0x7cc8d
; 0x7cc8b

UnknownScript_0x7cc8b: ; 0x7cc8b
	loadmovesprites
	end
; 0x7cc8d

UnknownScript_0x7cc8d: ; 0x7cc8d
	copybytetovar UndergroundSwitchPositions
	if_equal $0, UnknownScript_0x7ccb0
	if_equal $1, UnknownScript_0x7ccd7
	if_equal $2, UnknownScript_0x7ccf2
	if_equal $3, UnknownScript_0x7cd0d
	if_equal $4, UnknownScript_0x7cd28
	if_equal $5, UnknownScript_0x7cd43
	if_equal $6, UnknownScript_0x7cd5e
	if_equal $7, UnknownScript_0x7cd79
UnknownScript_0x7ccb0: ; 0x7ccb0
	playsound $001f
	2call UnknownScript_0x7ce11
	2call UnknownScript_0x7ce19
	2call UnknownScript_0x7ce21
	2call UnknownScript_0x7ce29
	2call UnknownScript_0x7ce31
	2call UnknownScript_0x7ce39
	2call UnknownScript_0x7ce41
	2call UnknownScript_0x7ce4d
	2call UnknownScript_0x7ce59
	2call UnknownScript_0x7ce65
	2call UnknownScript_0x7ce71
	reloadmappart
	loadmovesprites
	end
; 0x7ccd7

UnknownScript_0x7ccd7: ; 0x7ccd7
	playsound $001f
	2call UnknownScript_0x7cda5
	2call UnknownScript_0x7cdd5
	2call UnknownScript_0x7cdf9
	2call UnknownScript_0x7ce39
	2call UnknownScript_0x7ce4d
	2call UnknownScript_0x7ce59
	2call UnknownScript_0x7ce71
	reloadmappart
	loadmovesprites
	end
; 0x7ccf2

UnknownScript_0x7ccf2: ; 0x7ccf2
	playsound $001f
	2call UnknownScript_0x7cdad
	2call UnknownScript_0x7cde1
	2call UnknownScript_0x7cded
	2call UnknownScript_0x7ce31
	2call UnknownScript_0x7ce41
	2call UnknownScript_0x7ce65
	2call UnknownScript_0x7ce71
	reloadmappart
	loadmovesprites
	end
; 0x7cd0d

UnknownScript_0x7cd0d: ; 0x7cd0d
	playsound $001f
	2call UnknownScript_0x7cdb5
	2call UnknownScript_0x7cdd5
	2call UnknownScript_0x7cdf9
	2call UnknownScript_0x7ce29
	2call UnknownScript_0x7ce4d
	2call UnknownScript_0x7ce59
	2call UnknownScript_0x7ce71
	reloadmappart
	loadmovesprites
	end
; 0x7cd28

UnknownScript_0x7cd28: ; 0x7cd28
	playsound $001f
	2call UnknownScript_0x7cdbd
	2call UnknownScript_0x7cde1
	2call UnknownScript_0x7cded
	2call UnknownScript_0x7ce21
	2call UnknownScript_0x7ce41
	2call UnknownScript_0x7ce65
	2call UnknownScript_0x7ce71
	reloadmappart
	loadmovesprites
	end
; 0x7cd43

UnknownScript_0x7cd43: ; 0x7cd43
	playsound $001f
	2call UnknownScript_0x7cdc5
	2call UnknownScript_0x7cdd5
	2call UnknownScript_0x7cdf9
	2call UnknownScript_0x7ce19
	2call UnknownScript_0x7ce4d
	2call UnknownScript_0x7ce59
	2call UnknownScript_0x7ce71
	reloadmappart
	loadmovesprites
	end
; 0x7cd5e

UnknownScript_0x7cd5e: ; 0x7cd5e
	playsound $001f
	2call UnknownScript_0x7cdcd
	2call UnknownScript_0x7cde1
	2call UnknownScript_0x7cded
	2call UnknownScript_0x7ce05
	2call UnknownScript_0x7ce11
	2call UnknownScript_0x7ce41
	2call UnknownScript_0x7ce65
	reloadmappart
	loadmovesprites
	end
; 0x7cd79

UnknownScript_0x7cd79: ; 0x7cd79
	playsound $001f
	2call UnknownScript_0x7ce11
	2call UnknownScript_0x7ce19
	2call UnknownScript_0x7cdb5
	2call UnknownScript_0x7ce29
	2call UnknownScript_0x7cdc5
	2call UnknownScript_0x7cdcd
	2call UnknownScript_0x7ce41
	2call UnknownScript_0x7cde1
	2call UnknownScript_0x7cded
	2call UnknownScript_0x7ce65
	2call UnknownScript_0x7ce05
	reloadmappart
	loadmovesprites
	writebyte $6
	copyvartobyte UndergroundSwitchPositions
	end
; 0x7cda5

UnknownScript_0x7cda5: ; 0x7cda5
	changeblock $10, $6, $2d
	setbit1 $02d7
	end
; 0x7cdad

UnknownScript_0x7cdad: ; 0x7cdad
	changeblock $a, $6, $2d
	setbit1 $02d8
	end
; 0x7cdb5

UnknownScript_0x7cdb5: ; 0x7cdb5
	changeblock $2, $6, $2d
	setbit1 $02d9
	end
; 0x7cdbd

UnknownScript_0x7cdbd: ; 0x7cdbd
	changeblock $2, $a, $2d
	setbit1 $02da
	end
; 0x7cdc5

UnknownScript_0x7cdc5: ; 0x7cdc5
	changeblock $a, $a, $2d
	setbit1 $02db
	end
; 0x7cdcd

UnknownScript_0x7cdcd: ; 0x7cdcd
	changeblock $10, $a, $2d
	setbit1 $02dc
	end
; 0x7cdd5

UnknownScript_0x7cdd5: ; 0x7cdd5
	changeblock $c, $6, $2a
	changeblock $c, $8, $2d
	setbit1 $02dd
	end
; 0x7cde1

UnknownScript_0x7cde1: ; 0x7cde1
	changeblock $6, $6, $2a
	changeblock $6, $8, $2d
	setbit1 $02de
	end
; 0x7cded

UnknownScript_0x7cded: ; 0x7cded
	changeblock $c, $a, $2a
	changeblock $c, $c, $2d
	setbit1 $02df
	end
; 0x7cdf9

UnknownScript_0x7cdf9: ; 0x7cdf9
	changeblock $6, $a, $2a
	changeblock $6, $c, $2d
	setbit1 $02e0
	end
; 0x7ce05

UnknownScript_0x7ce05: ; 0x7ce05
	changeblock $12, $a, $2a
	changeblock $12, $c, $2d
	setbit1 $02e1
	end
; 0x7ce11

UnknownScript_0x7ce11: ; 0x7ce11
	changeblock $10, $6, $3e
	clearbit1 $02d7
	end
; 0x7ce19

UnknownScript_0x7ce19: ; 0x7ce19
	changeblock $a, $6, $3e
	clearbit1 $02d8
	end
; 0x7ce21

UnknownScript_0x7ce21: ; 0x7ce21
	changeblock $2, $6, $3e
	clearbit1 $02d9
	end
; 0x7ce29

UnknownScript_0x7ce29: ; 0x7ce29
	changeblock $2, $a, $3e
	clearbit1 $02da
	end
; 0x7ce31

UnknownScript_0x7ce31: ; 0x7ce31
	changeblock $a, $a, $3e
	clearbit1 $02db
	end
; 0x7ce39

UnknownScript_0x7ce39: ; 0x7ce39
	changeblock $10, $a, $3e
	clearbit1 $02dc
	end
; 0x7ce41

UnknownScript_0x7ce41: ; 0x7ce41
	changeblock $c, $6, $3f
	changeblock $c, $8, $3d
	clearbit1 $02dd
	end
; 0x7ce4d

UnknownScript_0x7ce4d: ; 0x7ce4d
	changeblock $6, $6, $3f
	changeblock $6, $8, $3d
	clearbit1 $02de
	end
; 0x7ce59

UnknownScript_0x7ce59: ; 0x7ce59
	changeblock $c, $a, $3f
	changeblock $c, $c, $3d
	clearbit1 $02df
	end
; 0x7ce65

UnknownScript_0x7ce65: ; 0x7ce65
	changeblock $6, $a, $3f
	changeblock $6, $c, $3d
	clearbit1 $02e0
	end
; 0x7ce71

UnknownScript_0x7ce71: ; 0x7ce71
	changeblock $12, $a, $3f
	changeblock $12, $c, $3d
	clearbit1 $02e1
	end
; 0x7ce7d

ItemFragment_0x7ce7d: ; 0x7ce7d
	db SMOKE_BALL, 1
; 0x7ce7f

ItemFragment_0x7ce7f: ; 0x7ce7f
	db FULL_HEAL, 1
; 0x7ce81

MapUndergroundPathSwitchRoomEntrancesSignpostItem4: ; 0x7ce81
	dw $008e
	db MAX_POTION
	
; 0x7ce84

MapUndergroundPathSwitchRoomEntrancesSignpostItem5: ; 0x7ce84
	dw $008f
	db REVIVE
	
; 0x7ce87

MovementData_0x7ce87: ; 0x7ce87
	step_down
	step_left
	step_left
	step_left
	step_end
; 0x7ce8c

MovementData_0x7ce8c: ; 0x7ce8c
	step_down
	step_down
	step_left
	step_left
	step_left
	step_end
; 0x7ce92

MovementData_0x7ce92: ; 0x7ce92
	step_right
	step_right
	step_right
	step_up
	step_end
; 0x7ce97

MovementData_0x7ce97: ; 0x7ce97
	step_right
	step_right
	step_right
	step_up
	step_up
	step_end
; 0x7ce9d

UnknownText_0x7ce9d: ; 0x7ce9d
	db $0, "Hold it!", $51
	db "I saw you, so I", $4f
	db "tailed you.", $51
	db "I don't need you", $4f
	db "underfoot while I", $51
	db "take care of TEAM", $4f
	db "ROCKET.", $51
	db "…Wait a second.", $4f
	db "You beat me be-", $55
	db "fore, didn't you?", $51
	db "That was just a", $4f
	db "fluke.", $51
	db "But I repay my", $4f
	db "debts!", $57
; 0x7cf5d

UnknownText_0x7cf5d: ; 0x7cf5d
	db $0, "…Why…", $4f
	db "Why do I lose?", $51
	db "I've assembled the", $4f
	db "toughest #MON.", $51
	db "I didn't ease up", $4f
	db "on the gas.", $51
	db "So why do I lose?", $57
; 0x7cfc2

UnknownText_0x7cfc2: ; 0x7cfc2
	db $0, "…I don't under-", $4f
	db "stand…", $51
	db "Is what that LANCE", $4f
	db "guy said true?", $51
	db "That I don't treat", $4f
	db "#MON properly?", $51
	db "Love…", $51
	db "Trust…", $51
	db "Are they really", $4f
	db "what I lack?", $51
	db "Are they keeping", $4f
	db "me from winning?", $51
	db "I… I just don't", $4f
	db "understand.", $51
	db "But it's not going", $4f
	db "to end here.", $51
	db "Not now. Not", $4f
	db "because of this.", $51
	db "I won't give up my", $4f
	db "dream of becoming", $51
	db "the world's best", $4f
	db "#MON trainer!", $57
; 0x7d102

UnknownText_0x7d102: ; 0x7d102
	db $0, "Humph. This is my", $4f
	db "real power, wimp.", $51
	db "I'll make TEAM", $4f
	db "ROCKET history.", $51
	db "And I'm going to", $4f
	db "grind that LANCE", $55
	db "under my heels.", $57
; 0x7d176

UnknownText_0x7d176: ; 0x7d176
	db $0, "I was challenged", $4f
	db "to a battle down-", $55
	db "stairs.", $51
	db "It's rough down", $4f
	db "there. You'd", $55
	db "better be careful.", $57
; 0x7d1d0

UnknownText_0x7d1d0: ; 0x7d1d0
	db $0, "There are some", $4f
	db "shops downstairs…", $51
	db "But there are", $4f
	db "also trainers.", $51
	db "I'm scared to go", $4f
	db "down there.", $57
; 0x7d22b

GruntM11SeenText: ; 0x7d22b
	db $0, "Open one shutter,", $4f
	db "another closes.", $51
	db "Bet you can't get", $4f
	db "where you want!", $57
; 0x7d26f

GruntM11BeatenText: ; 0x7d26f
	db $0, "Drat! I was sunk", $4f
	db "by indecision!", $57
; 0x7d290

UnknownText_0x7d290: ; 0x7d290
	db $0, "I'm confused too…", $4f
	db "The switch on the", $51
	db "end is the one to", $4f
	db "press first, but…", $57
; 0x7d2d8

GruntM25SeenText: ; 0x7d2d8
	db $0, "Kwahaha!", $51
	db "Confounded by the", $4f
	db "shutters, are we?", $51
	db "I'll let you in on", $4f
	db "a secret if you", $55
	db "can beat me!", $57
; 0x7d335

GruntM25BeatenText: ; 0x7d335
	db $0, "Uwww…", $4f
	db "I blew it.", $57
; 0x7d347

UnknownText_0x7d347: ; 0x7d347
	db $0, "All right. A hint!", $51
	db "Change the order", $4f
	db "of switching.", $51
	db "That'll change the", $4f
	db "ways the shutters", $55
	db "open and close.", $57
; 0x7d3ae

BurglarDuncanSeenText: ; 0x7d3ae
	db $0, "Fork over your", $4f
	db "goodies!", $57
; 0x7d3c7

BurglarDuncanBeatenText: ; 0x7d3c7
	db $0, "Mercy!", $57
; 0x7d3cf

UnknownText_0x7d3cf: ; 0x7d3cf
	db $0, "Steal and sell!", $4f
	db "That's basic in", $55
	db "crime, kid!", $57
; 0x7d3fb

BurglarEddieSeenText: ; 0x7d3fb
	db $0, "They ditched this", $4f
	db "project before", $55
	db "they finished.", $51
	db "I'm searching for", $4f
	db "leftover loot.", $57
; 0x7d44c

BurglarEddieBeatenText: ; 0x7d44c
	db $0, "Over the top!", $57
; 0x7d45b

UnknownText_0x7d45b: ; 0x7d45b
	db $0, "UNDERGROUND WARE-", $4f
	db "HOUSE?", $51
	db "What do you want", $4f
	db "to go there for?", $51
	db "There's nothing", $4f
	db "down there.", $57
; 0x7d4b2

GruntM13SeenText: ; 0x7d4b2
	db $0, "I don't care if", $4f
	db "you're lost.", $51
	db "You show up here,", $4f
	db "you're nothing but", $55
	db "a victim!", $57
; 0x7d4fc

GruntM13BeatenText: ; 0x7d4fc
	db $0, "Urk! Yeah, think", $4f
	db "you're cool, huh?", $57
; 0x7d51f

UnknownText_0x7d51f: ; 0x7d51f
	db $0, "You must have ice", $4f
	db "in your veins to", $55
	db "dis TEAM ROCKET.", $57
; 0x7d554

UnknownText_0x7d554: ; 0x7d554
	db $0, "It's labeled", $4f
	db "SWITCH 1.", $57
; 0x7d56b

GruntF3SeenText: ; 0x7d56b
	db $0, "Are you lost? No,", $4f
	db "you can't be.", $51
	db "You don't have", $4f
	db "that scared look.", $51
	db "I'll give you", $4f
	db "something to be", $55
	db "scared about!", $57
; 0x7d5d6

GruntF3BeatenText: ; 0x7d5d6
	db $0, "How could you?", $57
; 0x7d5e6

UnknownText_0x7d5e6: ; 0x7d5e6
	db $0, "Go wherever you'd", $4f
	db "like! Get lost!", $55
	db "See if I care!", $57
; 0x7d617

UnknownText_0x7d617: ; 0x7d617
	db $0, "It's OFF.", $4f
	db "Turn it ON?", $57
; 0x7d62d

UnknownText_0x7d62d: ; 0x7d62d
	db $0, "It's ON.", $4f
	db "Turn it OFF?", $57
; 0x7d643

UnknownText_0x7d643: ; 0x7d643
	db $0, "It's labeled", $4f
	db "SWITCH 2.", $57
; 0x7d65a

UnknownText_0x7d65a: ; 0x7d65a
	db $0, "It's labeled", $4f
	db "SWITCH 3.", $57
; 0x7d671

UnknownText_0x7d671: ; 0x7d671
	db $0, "It's labeled", $4f
	db "EMERGENCY.", $57
; 0x7d689

UndergroundPathSwitchRoomEntrances_MapEventHeader: ; 0x7d689
	; filler
	db 0, 0

	; warps
	db 9
	warp_def $3, $17, 6, GROUP_WAREHOUSE_ENTRANCE, MAP_WAREHOUSE_ENTRANCE
	warp_def $a, $16, 1, GROUP_UNDERGROUND_WAREHOUSE, MAP_UNDERGROUND_WAREHOUSE
	warp_def $a, $17, 2, GROUP_UNDERGROUND_WAREHOUSE, MAP_UNDERGROUND_WAREHOUSE
	warp_def $19, $5, 2, GROUP_WAREHOUSE_ENTRANCE, MAP_WAREHOUSE_ENTRANCE
	warp_def $1d, $4, 14, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $1d, $5, 14, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $19, $15, 1, GROUP_WAREHOUSE_ENTRANCE, MAP_WAREHOUSE_ENTRANCE
	warp_def $1d, $14, 13, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY
	warp_def $1d, $15, 13, GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY

	; xy triggers
	db 2
	xy_trigger 0, $4, $13, $0, UnknownScript_0x7ca80, $0, $0
	xy_trigger 0, $5, $13, $0, UnknownScript_0x7caaa, $0, $0

	; signposts
	db 6
	signpost 1, 16, $0, MapUndergroundPathSwitchRoomEntrancesSignpost0Script
	signpost 1, 10, $0, MapUndergroundPathSwitchRoomEntrancesSignpost1Script
	signpost 1, 2, $0, MapUndergroundPathSwitchRoomEntrancesSignpost2Script
	signpost 11, 20, $0, MapUndergroundPathSwitchRoomEntrancesSignpost3Script
	signpost 9, 8, $7, MapUndergroundPathSwitchRoomEntrancesSignpostItem4
	signpost 8, 1, $7, MapUndergroundPathSwitchRoomEntrancesSignpostItem5

	; people-events
	db 11
	person_event $4b, 16, 13, $9, $0, 255, 255, $a2, 2, TrainerBurglarDuncan, $06ce
	person_event $4b, 12, 8, $8, $0, 255, 255, $a2, 2, TrainerBurglarEddie, $06ce
	person_event $35, 6, 21, $6, $0, 255, 255, $2, 3, TrainerGruntM13, $06ce
	person_event $35, 6, 15, $6, $0, 255, 255, $2, 3, TrainerGruntM11, $06ce
	person_event $35, 6, 7, $6, $0, 255, 255, $2, 3, TrainerGruntM25, $06ce
	person_event $36, 16, 23, $6, $0, 255, 255, $82, 1, TrainerGruntF3, $06ce
	person_event $29, 31, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x7ca7d, $ffff
	person_event $2b, 31, 23, $6, $0, 255, 255, $0, 0, UnknownScript_0x7ca7a, $ffff
	person_event $54, 16, 5, $1, $0, 255, 255, $1, 0, ItemFragment_0x7ce7d, $0673
	person_event $54, 13, 18, $1, $0, 255, 255, $1, 0, ItemFragment_0x7ce7f, $0674
	person_event $4, 7, 27, $6, $0, 255, 255, $0, 0, ObjectEvent, $06c1
; 0x7d779

GoldenrodDeptStoreB1F_MapScriptHeader: ; 0x7d779
	; trigger count
	db 0

	; callback count
	db 2

	; callbacks

	dbw 1, UnknownScript_0x7d781

	dbw 5, UnknownScript_0x7d7ac
; 0x7d781

UnknownScript_0x7d781: ; 0x7d781
	checkbit1 $004a
	iftrue UnknownScript_0x7d78a
	2jump UnknownScript_0x7d791
; 0x7d78a

UnknownScript_0x7d78a: ; 0x7d78a
	changeblock $10, $4, $d
	2jump UnknownScript_0x7d791
; 0x7d791

UnknownScript_0x7d791: ; 0x7d791
	checkbit1 $0305
	iftrue UnknownScript_0x7d7a2
	checkbit1 $0306
	iftrue UnknownScript_0x7d7a7
	changeblock $a, $8, $d
	return
; 0x7d7a2

UnknownScript_0x7d7a2: ; 0x7d7a2
	changeblock $4, $a, $d
	return
; 0x7d7a7

UnknownScript_0x7d7a7: ; 0x7d7a7
	changeblock $a, $c, $d
	return
; 0x7d7ac

UnknownScript_0x7d7ac: ; 0x7d7ac
	clearbit1 $0307
	return
; 0x7d7b0

UnknownScript_0x7d7b0: ; 0x7d7b0
	jumptextfaceplayer UnknownText_0x7d7cb
; 0x7d7b3

UnknownScript_0x7d7b3: ; 0x7d7b3
	jumptextfaceplayer UnknownText_0x7d82c
; 0x7d7b6

UnknownScript_0x7d7b6: ; 0x7d7b6
	jumptextfaceplayer UnknownText_0x7d875
; 0x7d7b9

UnknownScript_0x7d7b9: ; 0x7d7b9
	loadfont
	2writetext UnknownText_0x7d8bb
	cry MACHOKE
	closetext
	loadmovesprites
	end
; 0x7d7c3

ItemFragment_0x7d7c3: ; 0x7d7c3
	db ETHER, 1
; 0x7d7c5

ItemFragment_0x7d7c5: ; 0x7d7c5
	db AMULET_COIN, 1
; 0x7d7c7

ItemFragment_0x7d7c7: ; 0x7d7c7
	db BURN_HEAL, 1
; 0x7d7c9

ItemFragment_0x7d7c9: ; 0x7d7c9
	db ULTRA_BALL, 1
; 0x7d7cb

UnknownText_0x7d7cb: ; 0x7d7cb
	db $0, "Hey, kid! You're", $4f
	db "holding us up!", $51
	db "Our policy is to", $4f
	db "work behind the", $51
	db "scenes where no", $4f
	db "one can see us!", $57
; 0x7d82c

UnknownText_0x7d82c: ; 0x7d82c
	db $0, "I lose my passion", $4f
	db "for work if some-", $55
	db "one's watching.", $51
	db "Come on, kid,", $4f
	db "scoot!", $57
; 0x7d875

UnknownText_0x7d875: ; 0x7d875
	db $0, "Oohah! Oohah!", $51
	db "The stuff on the", $4f
	db "ground's junk.", $51
	db "Take it if you", $4f
	db "want it!", $57
; 0x7d8bb

UnknownText_0x7d8bb: ; 0x7d8bb
	db $0, "MACHOKE: Maaacho!", $57
; 0x7d8ce

GoldenrodDeptStoreB1F_MapEventHeader: ; 0x7d8ce
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $2, $11, 3, GROUP_UNDERGROUND_WAREHOUSE, MAP_UNDERGROUND_WAREHOUSE
	warp_def $4, $9, 1, GROUP_GOLDENROD_DEPT_STORE_ELEVATOR, MAP_GOLDENROD_DEPT_STORE_ELEVATOR
	warp_def $4, $a, 2, GROUP_GOLDENROD_DEPT_STORE_ELEVATOR, MAP_GOLDENROD_DEPT_STORE_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 8
	person_event $54, 19, 14, $1, $0, 255, 255, $1, 0, ItemFragment_0x7d7c3, $0675
	person_event $54, 6, 18, $1, $0, 255, 255, $1, 0, ItemFragment_0x7d7c5, $0676
	person_event $54, 7, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x7d7c7, $0677
	person_event $54, 19, 19, $1, $0, 255, 255, $1, 0, ItemFragment_0x7d7c9, $0678
	person_event $41, 14, 13, $4, $10, 255, 255, $a0, 0, UnknownScript_0x7d7b0, $ffff
	person_event $41, 12, 8, $3, $0, 255, 255, $80, 0, UnknownScript_0x7d7b3, $ffff
	person_event $41, 17, 10, $5, $1, 255, 255, $90, 0, UnknownScript_0x7d7b6, $ffff
	person_event $9a, 11, 11, $16, $0, 255, 255, $90, 0, UnknownScript_0x7d7b9, $ffff
; 0x7d94b

UndergroundWarehouse_MapScriptHeader: ; 0x7d94b
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x7d950
; 0x7d950

UnknownScript_0x7d950: ; 0x7d950
	clearbit1 $02d3
	clearbit1 $02d4
	clearbit1 $02d5
	clearbit1 $02d6
	clearbit1 $02d7
	clearbit1 $02d8
	clearbit1 $02d9
	clearbit1 $02da
	clearbit1 $02db
	clearbit1 $02dc
	clearbit1 $02dd
	clearbit1 $02de
	clearbit1 $02df
	clearbit1 $02e0
	clearbit1 $02e1
	writebyte $0
	copyvartobyte UndergroundSwitchPositions
	return
; 0x7d983

TrainerGruntM24: ; 0x7d983
	; bit/flag number
	dw $508

	; trainer group && trainer id
	db GRUNTM, 24

	; text when seen
	dw GruntM24SeenText

	; text when trainer beaten
	dw GruntM24BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM24Script
; 0x7d98f

GruntM24Script: ; 0x7d98f
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7da48
	closetext
	loadmovesprites
	end
; 0x7d997

TrainerGruntM14: ; 0x7d997
	; bit/flag number
	dw $4fe

	; trainer group && trainer id
	db GRUNTM, 14

	; text when seen
	dw GruntM14SeenText

	; text when trainer beaten
	dw GruntM14BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM14Script
; 0x7d9a3

GruntM14Script: ; 0x7d9a3
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7db01
	closetext
	loadmovesprites
	end
; 0x7d9ab

TrainerGruntM15: ; 0x7d9ab
	; bit/flag number
	dw $4ff

	; trainer group && trainer id
	db GRUNTM, 15

	; text when seen
	dw GruntM15SeenText

	; text when trainer beaten
	dw GruntM15BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GruntM15Script
; 0x7d9b7

GruntM15Script: ; 0x7d9b7
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7db8e
	closetext
	loadmovesprites
	end
; 0x7d9bf

UnknownScript_0x7d9bf: ; 0x7d9bf
	faceplayer
	loadfont
	checkbit1 $004a
	iftrue UnknownScript_0x7d9de
	2writetext UnknownText_0x7dbc6
	keeptextopen
	verbosegiveitem CARD_KEY, 1
	setbit1 $004a
	setbit1 $0304
	clearbit1 $0305
	clearbit1 $0306
	2writetext UnknownText_0x7dc5b
	keeptextopen
UnknownScript_0x7d9de: ; 0x7d9de
	2writetext UnknownText_0x7dc8d
	closetext
	loadmovesprites
	end
; 0x7d9e4

ItemFragment_0x7d9e4: ; 0x7d9e4
	db MAX_ETHER, 1
; 0x7d9e6

ItemFragment_0x7d9e6: ; 0x7d9e6
	db TM_35, 1
; 0x7d9e8

ItemFragment_0x7d9e8: ; 0x7d9e8
	db ULTRA_BALL, 1
; 0x7d9ea

GruntM24SeenText: ; 0x7d9ea
	db $0, "How did you get", $4f
	db "this far?", $51
	db "I guess it can't", $4f
	db "be helped. I'll", $55
	db "dispose of you.", $57
; 0x7da34

GruntM24BeatenText: ; 0x7da34
	db $0, "I got disposed of…", $57
; 0x7da48

UnknownText_0x7da48: ; 0x7da48
	db $0, "TEAM ROCKET will", $4f
	db "keep going, wait-", $55
	db "ing for the return", $55
	db "of GIOVANNI.", $51
	db "We'll do whatever", $4f
	db "it takes.", $57
; 0x7daa7

GruntM14SeenText: ; 0x7daa7
	db $0, "You're not going", $4f
	db "any farther!", $51
	db "I don't show mercy", $4f
	db "to my enemies, not", $55
	db "even brats!", $57
; 0x7daf6

GruntM14BeatenText: ; 0x7daf6
	db $0, "Blast it!", $57
; 0x7db01

UnknownText_0x7db01: ; 0x7db01
	db $0, "I lost…", $51
	db "Please forgive me,", $4f
	db "GIOVANNI!", $57
; 0x7db27

GruntM15SeenText: ; 0x7db27
	db $0, "Hyuck-hyuck-hyuck!", $4f
	db "I remember you!", $51
	db "You got me good", $4f
	db "at our hideout!", $57
; 0x7db6b

GruntM15BeatenText: ; 0x7db6b
	db $0, "Hyuck-hyuck-hyuck!", $4f
	db "So, that's how?", $57
; 0x7db8e

UnknownText_0x7db8e: ; 0x7db8e
	db $0, "Hyuck-hyuck-hyuck!", $4f
	db "That was a blast!", $55
	db "I'll remember you!", $57
; 0x7dbc6

UnknownText_0x7dbc6: ; 0x7dbc6
	db $0, "DIRECTOR: Who?", $4f
	db "What? You came to", $55
	db "rescue me?", $51
	db "Thank you!", $51
	db "The RADIO TOWER!", $51
	db "What's happening", $4f
	db "there?", $51
	db "Taken over by TEAM", $4f
	db "ROCKET?", $51
	db "Here. Take this", $4f
	db "CARD KEY.", $57
; 0x7dc5b

UnknownText_0x7dc5b: ; 0x7dc5b
	db $0, "DIRECTOR: Use that", $4f
	db "to open the shut-", $55
	db "ters on 3F.", $57
; 0x7dc8d

UnknownText_0x7dc8d: ; 0x7dc8d
	db $0, "I'm begging you to", $4f
	db "help.", $51
	db "There's no telling", $4f
	db "what they'll do if", $51
	db "they control the", $4f
	db "transmitter.", $51
	db "They may even be", $4f
	db "able to control", $51
	db "#MON using a", $4f
	db "special signal!", $51
	db "You're the only", $4f
	db "one I can call on.", $51
	db "Please save the", $4f
	db "RADIO TOWER…", $51
	db "And all the #-", $4f
	db "MON nationwide!", $57
; 0x7dd84

UndergroundWarehouse_MapEventHeader: ; 0x7dd84
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $c, $2, 2, GROUP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES, MAP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES
	warp_def $c, $3, 3, GROUP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES, MAP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES
	warp_def $2, $11, 1, GROUP_GOLDENROD_DEPT_STORE_B1F, MAP_GOLDENROD_DEPT_STORE_B1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 7
	person_event $35, 12, 13, $7, $0, 255, 255, $2, 3, TrainerGruntM24, $06ce
	person_event $35, 19, 12, $7, $0, 255, 255, $2, 3, TrainerGruntM14, $06ce
	person_event $35, 7, 18, $9, $0, 255, 255, $2, 4, TrainerGruntM15, $06ce
	person_event $40, 12, 16, $3, $0, 255, 255, $0, 0, UnknownScript_0x7d9bf, $06ce
	person_event $54, 19, 22, $1, $0, 255, 255, $1, 0, ItemFragment_0x7d9e4, $0679
	person_event $54, 13, 17, $1, $0, 255, 255, $1, 0, ItemFragment_0x7d9e6, $067a
	person_event $54, 5, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x7d9e8, $0655
; 0x7ddf4

MountMortar1FOutside_MapScriptHeader: ; 0x7ddf4
	; trigger count
	db 0

	; callback count
	db 0
; 0x7ddf6

ItemFragment_0x7ddf6: ; 0x7ddf6
	db ETHER, 1
; 0x7ddf8

ItemFragment_0x7ddf8: ; 0x7ddf8
	db REVIVE, 1
; 0x7ddfa

MapMountMortar1FOutsideSignpostItem0: ; 0x7ddfa
	dw $0090
	db HYPER_POTION
	
; 0x7ddfd

MountMortar1FOutside_MapEventHeader: ; 0x7ddfd
	; filler
	db 0, 0

	; warps
	db 9
	warp_def $21, $3, 3, GROUP_ROUTE_42, MAP_ROUTE_42
	warp_def $21, $11, 4, GROUP_ROUTE_42, MAP_ROUTE_42
	warp_def $21, $25, 5, GROUP_ROUTE_42, MAP_ROUTE_42
	warp_def $5, $11, 1, GROUP_MOUNT_MORTAR_2F_INSIDE, MAP_MOUNT_MORTAR_2F_INSIDE
	warp_def $15, $b, 1, GROUP_MOUNT_MORTAR_1F_INSIDE, MAP_MOUNT_MORTAR_1F_INSIDE
	warp_def $15, $1d, 2, GROUP_MOUNT_MORTAR_1F_INSIDE, MAP_MOUNT_MORTAR_1F_INSIDE
	warp_def $1d, $11, 2, GROUP_MOUNT_MORTAR_B1F, MAP_MOUNT_MORTAR_B1F
	warp_def $d, $7, 3, GROUP_MOUNT_MORTAR_1F_INSIDE, MAP_MOUNT_MORTAR_1F_INSIDE
	warp_def $d, $21, 4, GROUP_MOUNT_MORTAR_1F_INSIDE, MAP_MOUNT_MORTAR_1F_INSIDE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 22, 25, $7, MapMountMortar1FOutsideSignpostItem0

	; people-events
	db 2
	person_event $54, 19, 17, $1, $0, 255, 255, $1, 0, ItemFragment_0x7ddf6, $067b
	person_event $54, 22, 35, $1, $0, 255, 255, $1, 0, ItemFragment_0x7ddf8, $067c
; 0x7de4f

MountMortar1FInside_MapScriptHeader: ; 0x7de4f
	; trigger count
	db 0

	; callback count
	db 0
; 0x7de51

TrainerPokemaniacMiller: ; 0x7de51
	; bit/flag number
	dw $5c4

	; trainer group && trainer id
	db POKEMANIAC, MILLER

	; text when seen
	dw PokemaniacMillerSeenText

	; text when trainer beaten
	dw PokemaniacMillerBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacMillerScript
; 0x7de5d

PokemaniacMillerScript: ; 0x7de5d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7debd
	closetext
	loadmovesprites
	end
; 0x7de65

TrainerSupernerdMarkus: ; 0x7de65
	; bit/flag number
	dw $5c6

	; trainer group && trainer id
	db SUPER_NERD, MARKUS

	; text when seen
	dw SupernerdMarkusSeenText

	; text when trainer beaten
	dw SupernerdMarkusBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SupernerdMarkusScript
; 0x7de71

SupernerdMarkusScript: ; 0x7de71
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7df97
	closetext
	loadmovesprites
	end
; 0x7de79

UnknownScript_0x7de79: ; 0x7de79
	jumpstd $000e
; 0x7de7c

ItemFragment_0x7de7c: ; 0x7de7c
	db ESCAPE_ROPE, 1
; 0x7de7e

ItemFragment_0x7de7e: ; 0x7de7e
	db MAX_REVIVE, 1
; 0x7de80

ItemFragment_0x7de80: ; 0x7de80
	db HYPER_POTION, 1
; 0x7de82

ItemFragment_0x7de82: ; 0x7de82
	db MAX_POTION, 1
; 0x7de84

ItemFragment_0x7de84: ; 0x7de84
	db NUGGET, 1
; 0x7de86

ItemFragment_0x7de86: ; 0x7de86
	db IRON, 1
; 0x7de88

ItemFragment_0x7de88: ; 0x7de88
	db ULTRA_BALL, 1
; 0x7de8a

MapMountMortar1FInsideSignpostItem0: ; 0x7de8a
	dw $0091
	db MAX_REPEL
	
; 0x7de8d

PokemaniacMillerSeenText: ; 0x7de8d
	db $0, "I'm not losing", $4f
	db "this time!", $57
; 0x7dea7

PokemaniacMillerBeatenText: ; 0x7dea7
	db $0, "I lost to some", $4f
	db "kid…?", $57
; 0x7debd

UnknownText_0x7debd: ; 0x7debd
	db $0, "A while back, this", $4f
	db "karate dude wanted", $51
	db "to battle. He was", $4f
	db "ridiculously good.", $51
	db "He just thrashed", $4f
	db "us silly.", $51
	db "He went in deeper", $4f
	db "saying it was for", $51
	db "his training. I", $4f
	db "wonder how he is?", $57
; 0x7df6a

SupernerdMarkusSeenText: ; 0x7df6a
	db $0, "Hey! HUGH!", $57
; 0x7df76

SupernerdMarkusBeatenText: ; 0x7df76
	db $0, "I mistook you for", $4f
	db "someone else…", $57
; 0x7df97

UnknownText_0x7df97: ; 0x7df97
	db $0, "I came to explore", $4f
	db "MT.MORTAR, but I", $51
	db "got separated from", $4f
	db "my partner…", $51
	db "Did you run into a", $4f
	db "trainer who uses a", $51
	db "SEADRA that knows", $4f
	db "WATERFALL?", $57
; 0x7e01d

MountMortar1FInside_MapEventHeader: ; 0x7e01d
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $2f, $b, 5, GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE
	warp_def $2f, $1d, 6, GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE
	warp_def $27, $5, 8, GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE
	warp_def $29, $21, 9, GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE
	warp_def $13, $3, 1, GROUP_MOUNT_MORTAR_B1F, MAP_MOUNT_MORTAR_B1F
	warp_def $9, $9, 2, GROUP_MOUNT_MORTAR_2F_INSIDE, MAP_MOUNT_MORTAR_2F_INSIDE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 11, 30, $7, MapMountMortar1FInsideSignpostItem0

	; people-events
	db 10
	person_event $5a, 47, 25, $19, $0, 255, 255, $0, 0, UnknownScript_0x7de79, $ffff
	person_event $54, 42, 39, $1, $0, 255, 255, $1, 0, ItemFragment_0x7de7c, $067d
	person_event $54, 14, 20, $1, $0, 255, 255, $1, 0, ItemFragment_0x7de7e, $067e
	person_event $54, 31, 14, $1, $0, 255, 255, $1, 0, ItemFragment_0x7de80, $067f
	person_event $54, 24, 26, $1, $0, 255, 255, $1, 0, ItemFragment_0x7de82, $07a6
	person_event $54, 23, 39, $1, $0, 255, 255, $1, 0, ItemFragment_0x7de84, $07a7
	person_event $2b, 47, 37, $8, $0, 255, 255, $92, 3, TrainerPokemaniacMiller, $ffff
	person_event $2b, 32, 28, $a, $0, 255, 255, $b2, 3, TrainerSupernerdMarkus, $ffff
	person_event $54, 20, 12, $1, $0, 255, 255, $1, 0, ItemFragment_0x7de86, $07c8
	person_event $54, 21, 21, $1, $0, 255, 255, $1, 0, ItemFragment_0x7de88, $07c9
; 0x7e0c8

MountMortar2FInside_MapScriptHeader: ; 0x7e0c8
	; trigger count
	db 0

	; callback count
	db 0
; 0x7e0ca

TrainerSupernerdHugh: ; 0x7e0ca
	; bit/flag number
	dw $5c5

	; trainer group && trainer id
	db SUPER_NERD, HUGH

	; text when seen
	dw SupernerdHughSeenText

	; text when trainer beaten
	dw SupernerdHughBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SupernerdHughScript
; 0x7e0d6

SupernerdHughScript: ; 0x7e0d6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x7e10e
	closetext
	loadmovesprites
	end
; 0x7e0de

ItemFragment_0x7e0de: ; 0x7e0de
	db MAX_POTION, 1
; 0x7e0e0

ItemFragment_0x7e0e0: ; 0x7e0e0
	db RARE_CANDY, 1
; 0x7e0e2

ItemFragment_0x7e0e2: ; 0x7e0e2
	db TM_40, 1
; 0x7e0e4

ItemFragment_0x7e0e4: ; 0x7e0e4
	db DRAGON_SCALE, 1
; 0x7e0e6

ItemFragment_0x7e0e6: ; 0x7e0e6
	db ELIXER, 1
; 0x7e0e8

ItemFragment_0x7e0e8: ; 0x7e0e8
	db ESCAPE_ROPE, 1
; 0x7e0ea

MapMountMortar2FInsideSignpostItem0: ; 0x7e0ea
	dw $0092
	db FULL_RESTORE
	
; 0x7e0ed

SupernerdHughSeenText: ; 0x7e0ed
	db $0, "Yo! MARKUS!", $57
; 0x7e0fa

SupernerdHughBeatenText: ; 0x7e0fa
	db $0, "Sorry, my mistake.", $57
; 0x7e10e

UnknownText_0x7e10e: ; 0x7e10e
	db $0, "I'm investigating", $4f
	db "MT.MORTAR, but my", $55
	db "pal's gone AWOL.", $51
	db "Have you seen a", $4f
	db "trainer who has a", $51
	db "SLOWPOKE that can", $4f
	db "use STRENGTH?", $57
; 0x7e184

MountMortar2FInside_MapEventHeader: ; 0x7e184
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $21, $11, 4, GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE
	warp_def $5, $3, 6, GROUP_MOUNT_MORTAR_1F_INSIDE, MAP_MOUNT_MORTAR_1F_INSIDE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 8, 24, $7, MapMountMortar2FInsideSignpostItem0

	; people-events
	db 7
	person_event $54, 26, 32, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e0de, $0680
	person_event $54, 37, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e0e0, $0681
	person_event $54, 21, 23, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e0e2, $0682
	person_event $54, 9, 20, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e0e4, $0683
	person_event $54, 15, 13, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e0e6, $0684
	person_event $54, 9, 32, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e0e8, $0685
	person_event $2b, 30, 17, $a, $0, 255, 255, $b2, 2, TrainerSupernerdHugh, $ffff
; 0x7e1f4

MountMortarB1F_MapScriptHeader: ; 0x7e1f4
	; trigger count
	db 0

	; callback count
	db 0
; 0x7e1f6

UnknownScript_0x7e1f6: ; 0x7e1f6
	faceplayer
	loadfont
	checkbit1 $0061
	iftrue UnknownScript_0x7e231
	checkbit1 $04a9
	iftrue UnknownScript_0x7e217
	2writetext UnknownText_0x7e24d
	closetext
	loadmovesprites
	winlosstext UnknownText_0x7e2a9, $0000
	loadtrainer BLACKBELT_T, KIYO
	startbattle
	returnafterbattle
	setbit1 $04a9
	loadfont
UnknownScript_0x7e217: ; 0x7e217
	2writetext UnknownText_0x7e2c0
	keeptextopen
	waitbutton
	checkcode $1
	if_equal $6, UnknownScript_0x7e237
	2writetext UnknownText_0x7e355
	playsound $0002
	waitbutton
	givepoke TYROGUE, 10, 0, 0
	setbit1 $0061
UnknownScript_0x7e231: ; 0x7e231
	2writetext UnknownText_0x7e36a
	closetext
	loadmovesprites
	end
; 0x7e237

UnknownScript_0x7e237: ; 0x7e237
	2writetext UnknownText_0x7e3df
	closetext
	loadmovesprites
	end
; 0x7e23d

UnknownScript_0x7e23d: ; 0x7e23d
	jumpstd $000e
; 0x7e240

ItemFragment_0x7e240: ; 0x7e240
	db HYPER_POTION, 1
; 0x7e242

ItemFragment_0x7e242: ; 0x7e242
	db CARBOS, 1
; 0x7e244

ItemFragment_0x7e244: ; 0x7e244
	db FULL_RESTORE, 1
; 0x7e246

ItemFragment_0x7e246: ; 0x7e246
	db MAX_ETHER, 1
; 0x7e248

ItemFragment_0x7e248: ; 0x7e248
	db PP_UP, 1
; 0x7e24a

MapMountMortarB1FSignpostItem0: ; 0x7e24a
	dw $0093
	db MAX_REVIVE
	
; 0x7e24d

UnknownText_0x7e24d: ; 0x7e24d
	db $0, "Hey!", $51
	db "I am the KARATE", $4f
	db "KING!", $51
	db "I train alone here", $4f
	db "in the dark!", $51
	db "You!", $4f
	db "Battle with me!", $51
	db "Hwaaarggh!", $57
; 0x7e2a9

UnknownText_0x7e2a9: ; 0x7e2a9
	db $0, "Waaaarggh!", $4f
	db "I'm beaten!", $57
; 0x7e2c0

UnknownText_0x7e2c0: ; 0x7e2c0
	db $0, "I… I'm crushed…", $51
	db "My training is", $4f
	db "still not enough…", $51
	db "But a loss is a", $4f
	db "loss. I admit it.", $51
	db "As proof that you", $4f
	db "defeated me, I'll", $51
	db "give you a rare", $4f
	db "fighting #MON.", $57
; 0x7e355

UnknownText_0x7e355: ; 0x7e355
	db $0, $52, " received", $4f
	db "TYROGUE.", $57
; 0x7e36a

UnknownText_0x7e36a: ; 0x7e36a
	db $0, "TYROGUE is a", $4f
	db "fighting-type.", $51
	db "It evolves into a", $4f
	db "tougher #MON.", $51
	db "Keep up the hard", $4f
	db "work. I'll keep", $55
	db "training too.", $51
	db "Farewell!", $57
; 0x7e3df

UnknownText_0x7e3df: ; 0x7e3df
	db $0, "You have no room", $4f
	db "in your party!", $57
; 0x7e400

MountMortarB1F_MapEventHeader: ; 0x7e400
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $3, 5, GROUP_MOUNT_MORTAR_1F_INSIDE, MAP_MOUNT_MORTAR_1F_INSIDE
	warp_def $1d, $13, 7, GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 6, 4, $7, MapMountMortarB1FSignpostItem0

	; people-events
	db 7
	person_event $54, 16, 33, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e240, $0686
	person_event $54, 20, 8, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e242, $0687
	person_event $5a, 14, 13, $19, $0, 255, 255, $0, 0, UnknownScript_0x7e23d, $ffff
	person_event $41, 8, 20, $6, $0, 255, 255, $b0, 0, UnknownScript_0x7e1f6, $ffff
	person_event $54, 28, 38, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e244, $07ca
	person_event $54, 7, 36, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e246, $07cb
	person_event $54, 30, 25, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e248, $07cc
; 0x7e470

IcePath1F_MapScriptHeader: ; 0x7e470
	; trigger count
	db 0

	; callback count
	db 0
; 0x7e472

ItemFragment_0x7e472: ; 0x7e472
	db HM_07, 1
; 0x7e474

ItemFragment_0x7e474: ; 0x7e474
	db PP_UP, 1
; 0x7e476

ItemFragment_0x7e476: ; 0x7e476
	db PROTEIN, 1
; 0x7e478

IcePath1F_MapEventHeader: ; 0x7e478
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $13, $4, 1, GROUP_ROUTE_44, MAP_ROUTE_44
	warp_def $1b, $24, 7, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $5, $25, 1, GROUP_ICE_PATH_B1F, MAP_ICE_PATH_B1F
	warp_def $d, $25, 7, GROUP_ICE_PATH_B1F, MAP_ICE_PATH_B1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $54, 11, 35, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e472, $0688
	person_event $54, 27, 36, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e474, $0689
	person_event $54, 13, 39, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e476, $07be
; 0x7e4b9

IcePathB1F_MapScriptHeader: ; 0x7e4b9
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 3, UnknownScript_0x7e4be
; 0x7e4be

UnknownScript_0x7e4be: ; 0x7e4be
	writecmdqueue $64c2
	return
; 0x7e4c2

INCBIN "baserom.gbc",$7e4c2,$7e50a - $7e4c2

UnknownScript_0x7e50a: ; 0x7e50a
	jumpstd $000e
; 0x7e50d

ItemFragment_0x7e50d: ; 0x7e50d
	db IRON, 1
; 0x7e50f

MapIcePathB1FSignpostItem0: ; 0x7e50f
	dw $0094
	db MAX_POTION
; 0x7e512

INCBIN "baserom.gbc",$7e512,$1b

IcePathB1F_MapEventHeader: ; 0x7e52d
	; filler
	db 0, 0

	; warps
	db 8
	warp_def $f, $3, 3, GROUP_ICE_PATH_1F, MAP_ICE_PATH_1F
	warp_def $3, $11, 1, GROUP_ICE_PATH_B2F_MAHOGANY_SIDE, MAP_ICE_PATH_B2F_MAHOGANY_SIDE
	warp_def $2, $b, 3, GROUP_ICE_PATH_B2F_MAHOGANY_SIDE, MAP_ICE_PATH_B2F_MAHOGANY_SIDE
	warp_def $7, $4, 4, GROUP_ICE_PATH_B2F_MAHOGANY_SIDE, MAP_ICE_PATH_B2F_MAHOGANY_SIDE
	warp_def $c, $5, 5, GROUP_ICE_PATH_B2F_MAHOGANY_SIDE, MAP_ICE_PATH_B2F_MAHOGANY_SIDE
	warp_def $d, $c, 6, GROUP_ICE_PATH_B2F_MAHOGANY_SIDE, MAP_ICE_PATH_B2F_MAHOGANY_SIDE
	warp_def $19, $5, 4, GROUP_ICE_PATH_1F, MAP_ICE_PATH_1F
	warp_def $1b, $b, 1, GROUP_ICE_PATH_B2F_BLACKTHORN_SIDE, MAP_ICE_PATH_B2F_BLACKTHORN_SIDE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 30, 17, $7, MapIcePathB1FSignpostItem0

	; people-events
	db 5
	person_event $5a, 11, 15, $19, $0, 255, 255, $0, 0, UnknownScript_0x7e50a, $0709
	person_event $5a, 12, 11, $19, $0, 255, 255, $0, 0, UnknownScript_0x7e50a, $070a
	person_event $5a, 13, 12, $19, $0, 255, 255, $0, 0, UnknownScript_0x7e50a, $070b
	person_event $5a, 11, 21, $19, $0, 255, 255, $0, 0, UnknownScript_0x7e50a, $070c
	person_event $54, 39, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e50d, $068a
; 0x7e5a1

IcePathB2FMahoganySide_MapScriptHeader: ; 0x7e5a1
	; trigger count
	db 0

	; callback count
	db 0
; 0x7e5a3

UnknownScript_0x7e5a3: ; 0x7e5a3
	jumptext UnknownText_0x7e5ad
; 0x7e5a6

ItemFragment_0x7e5a6: ; 0x7e5a6
	db FULL_HEAL, 1
; 0x7e5a8

ItemFragment_0x7e5a8: ; 0x7e5a8
	db MAX_POTION, 1
; 0x7e5aa

MapIcePathB2FMahoganySideSignpostItem0: ; 0x7e5aa
	dw $0095
	db CARBOS
	
; 0x7e5ad

UnknownText_0x7e5ad: ; 0x7e5ad
	db $0, "It's immovably", $4f
	db "imbedded in ice.", $57
; 0x7e5cd

IcePathB2FMahoganySide_MapEventHeader: ; 0x7e5cd
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $1, $11, 2, GROUP_ICE_PATH_B1F, MAP_ICE_PATH_B1F
	warp_def $b, $9, 1, GROUP_ICE_PATH_B3F, MAP_ICE_PATH_B3F
	warp_def $4, $b, 3, GROUP_ICE_PATH_B1F, MAP_ICE_PATH_B1F
	warp_def $6, $4, 4, GROUP_ICE_PATH_B1F, MAP_ICE_PATH_B1F
	warp_def $c, $4, 5, GROUP_ICE_PATH_B1F, MAP_ICE_PATH_B1F
	warp_def $c, $c, 6, GROUP_ICE_PATH_B1F, MAP_ICE_PATH_B1F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 17, 0, $7, MapIcePathB2FMahoganySideSignpostItem0

	; people-events
	db 6
	person_event $5a, 7, 15, $1, $0, 255, 255, $0, 0, UnknownScript_0x7e5a3, $070d
	person_event $5a, 11, 8, $1, $0, 255, 255, $0, 0, UnknownScript_0x7e5a3, $070e
	person_event $5a, 16, 7, $1, $0, 255, 255, $0, 0, UnknownScript_0x7e5a3, $070f
	person_event $5a, 17, 16, $1, $0, 255, 255, $0, 0, UnknownScript_0x7e5a3, $0710
	person_event $54, 13, 12, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e5a6, $068b
	person_event $54, 6, 4, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e5a8, $068c
; 0x7e644

IcePathB2FBlackthornSide_MapScriptHeader: ; 0x7e644
	; trigger count
	db 0

	; callback count
	db 0
; 0x7e646

ItemFragment_0x7e646: ; 0x7e646
	db TM_44, 1
; 0x7e648

MapIcePathB2FBlackthornSideSignpostItem0: ; 0x7e648
	dw $0096
	db ICE_HEAL
	
; 0x7e64b

IcePathB2FBlackthornSide_MapEventHeader: ; 0x7e64b
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $f, $3, 8, GROUP_ICE_PATH_B1F, MAP_ICE_PATH_B1F
	warp_def $3, $3, 2, GROUP_ICE_PATH_B3F, MAP_ICE_PATH_B3F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 10, 2, $7, MapIcePathB2FBlackthornSideSignpostItem0

	; people-events
	db 1
	person_event $54, 20, 12, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e646, $068d
; 0x7e66d

IcePathB3F_MapScriptHeader: ; 0x7e66d
	; trigger count
	db 0

	; callback count
	db 0
; 0x7e66f

ItemFragment_0x7e66f: ; 0x7e66f
	db NEVERMELTICE, 1
; 0x7e671

UnknownScript_0x7e671: ; 0x7e671
	jumpstd $000f
; 0x7e674

IcePathB3F_MapEventHeader: ; 0x7e674
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $5, $3, 2, GROUP_ICE_PATH_B2F_MAHOGANY_SIDE, MAP_ICE_PATH_B2F_MAHOGANY_SIDE
	warp_def $5, $f, 2, GROUP_ICE_PATH_B2F_BLACKTHORN_SIDE, MAP_ICE_PATH_B2F_BLACKTHORN_SIDE

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $54, 11, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x7e66f, $068e
	person_event $59, 10, 10, $18, $0, 255, 255, $0, 0, UnknownScript_0x7e671, $ffff
; 0x7e69e

LavenderPokeCenter1F_MapScriptHeader: ; 0x7e69e
	; trigger count
	db 0

	; callback count
	db 0
; 0x7e6a0

UnknownScript_0x7e6a0: ; 0x7e6a0
	jumpstd $0000
; 0x7e6a3

UnknownScript_0x7e6a3: ; 0x7e6a3
	jumptextfaceplayer UnknownText_0x7e6bd
; 0x7e6a6

UnknownScript_0x7e6a6: ; 0x7e6a6
	jumptextfaceplayer UnknownText_0x7e710
; 0x7e6a9

UnknownScript_0x7e6a9: ; 0x7e6a9
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x7e6b7
	2writetext UnknownText_0x7e779
	closetext
	loadmovesprites
	end
; 0x7e6b7

UnknownScript_0x7e6b7: ; 0x7e6b7
	2writetext UnknownText_0x7e7ed
	closetext
	loadmovesprites
	end
; 0x7e6bd

UnknownText_0x7e6bd: ; 0x7e6bd
	db $0, "To the north of", $4f
	db "LAVENDER is ROCK", $51
	db "TUNNEL. Go through", $4f
	db "it to get to the", $55
	db "POWER PLANT.", $57
; 0x7e710

UnknownText_0x7e710: ; 0x7e710
	db $0, "There's a radio", $4f
	db "program that plays", $55
	db "# FLUTE music.", $51
	db "Oh? Ah, your radio", $4f
	db "needs an EXPN CARD", $55
	db "to tune into it.", $57
; 0x7e779

UnknownText_0x7e779: ; 0x7e779
	db $0, "If the POWER PLANT", $4f
	db "isn't running, the", $51
	db "MAGNET TRAIN won't", $4f
	db "run either…", $51
	db "It also means the", $4f
	db "RADIO STATION", $55
	db "can't broadcast…", $57
; 0x7e7ed

UnknownText_0x7e7ed: ; 0x7e7ed
	db $0, "The DIRECTOR of", $4f
	db "the RADIO STATION", $55
	db "sure was happy.", $51
	db "He said they're", $4f
	db "back on the air", $51
	db "because the POWER", $4f
	db "PLANT is running", $55
	db "smoothly again.", $57
; 0x7e872

LavenderPokeCenter1F_MapEventHeader: ; 0x7e872
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN
	warp_def $7, $4, 1, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x7e6a0, $ffff
	person_event $40, 10, 11, $5, $1, 255, 255, $0, 0, UnknownScript_0x7e6a3, $ffff
	person_event $29, 7, 9, $6, $0, 255, 255, $a0, 0, UnknownScript_0x7e6a6, $ffff
	person_event $27, 9, 5, $4, $10, 255, 255, $80, 0, UnknownScript_0x7e6a9, $ffff
; 0x7e8bb

LavenderPokeCenter2FBeta_MapScriptHeader: ; 0x7e8bb
	; trigger count
	db 0

	; callback count
	db 0
; 0x7e8bd

LavenderPokeCenter2FBeta_MapEventHeader: ; 0x7e8bd
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 3, GROUP_LAVENDER_POKECENTER_1F, MAP_LAVENDER_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x7e8c8

MrFujisHouse_MapScriptHeader: ; 0x7e8c8
	; trigger count
	db 0

	; callback count
	db 0
; 0x7e8ca

UnknownScript_0x7e8ca: ; 0x7e8ca
	jumptextfaceplayer UnknownText_0x7e8f1
; 0x7e8cd

UnknownScript_0x7e8cd: ; 0x7e8cd
	jumptextfaceplayer UnknownText_0x7e940
; 0x7e8d0

UnknownScript_0x7e8d0: ; 0x7e8d0
	loadfont
	2writetext UnknownText_0x7e9b6
	cry PSYDUCK
	closetext
	loadmovesprites
	end
; 0x7e8da

UnknownScript_0x7e8da: ; 0x7e8da
	loadfont
	2writetext UnknownText_0x7e9c9
	cry NIDORINO
	closetext
	loadmovesprites
	end
; 0x7e8e4

UnknownScript_0x7e8e4: ; 0x7e8e4
	loadfont
	2writetext UnknownText_0x7e9da
	cry PIDGEY
	closetext
	loadmovesprites
	end
; 0x7e8ee

MapMrFujisHouseSignpost1Script: ; 0x7e8ee
	jumpstd $0001
; 0x7e8f1

UnknownText_0x7e8f1: ; 0x7e8f1
	db $0, "MR.FUJI does live", $4f
	db "here, but he's not", $51
	db "home now.", $51
	db "He should be at", $4f
	db "the SOUL HOUSE.", $57
; 0x7e940

UnknownText_0x7e940: ; 0x7e940
	db $0, "Some cold-hearted", $4f
	db "people stop caring", $55
	db "for their #MON.", $51
	db "Grandpa takes in", $4f
	db "the poor homeless", $51
	db "#MON and takes", $4f
	db "care of them.", $57
; 0x7e9b6

UnknownText_0x7e9b6: ; 0x7e9b6
	db $0, "PSYDUCK: Gu-guwa?", $57
; 0x7e9c9

UnknownText_0x7e9c9: ; 0x7e9c9
	db $0, "NIDORINO: Gyun!", $57
; 0x7e9da

UnknownText_0x7e9da: ; 0x7e9da
	db $0, "PIDGEY: Pijji!", $57
; 0x7e9ea

MrFujisHouse_MapEventHeader: ; 0x7e9ea
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN
	warp_def $7, $3, 2, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapMrFujisHouseSignpost1Script
	signpost 1, 1, $0, MapMrFujisHouseSignpost1Script

	; people-events
	db 5
	person_event $2b, 5, 8, $6, $0, 255, 255, $a0, 0, UnknownScript_0x7e8ca, $ffff
	person_event $28, 8, 7, $2, $11, 255, 255, $0, 0, UnknownScript_0x7e8cd, $ffff
	person_event $9d, 8, 11, $16, $0, 255, 255, $0, 0, UnknownScript_0x7e8d0, $ffff
	person_event $82, 9, 9, $16, $0, 255, 255, $90, 0, UnknownScript_0x7e8da, $ffff
	person_event $9e, 7, 5, $16, $0, 255, 255, $b0, 0, UnknownScript_0x7e8e4, $ffff
; 0x7ea45

LavenderTownSpeechHouse_MapScriptHeader: ; 0x7ea45
	; trigger count
	db 0

	; callback count
	db 0
; 0x7ea47

UnknownScript_0x7ea47: ; 0x7ea47
	jumptextfaceplayer UnknownText_0x7ea4d
; 0x7ea4a

MapLavenderTownSpeechHouseSignpost1Script: ; 0x7ea4a
	jumpstd $0002
; 0x7ea4d

UnknownText_0x7ea4d: ; 0x7ea4d
	db $0, "LAVENDER is a", $4f
	db "tiny, quiet town", $51
	db "at the foot of the", $4f
	db "mountains.", $51
	db "It's gotten a bit", $4f
	db "busier since the", $51
	db "RADIO TOWER was", $4f
	db "built.", $57
; 0x7eac4

LavenderTownSpeechHouse_MapEventHeader: ; 0x7eac4
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN
	warp_def $7, $3, 3, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapLavenderTownSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapLavenderTownSpeechHouseSignpost1Script

	; people-events
	db 1
	person_event $2e, 7, 6, $7, $0, 255, 255, $90, 0, UnknownScript_0x7ea47, $ffff
; 0x7eaeb

LavenderNameRater_MapScriptHeader: ; 0x7eaeb
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x7eaf1, $0000

	; callback count
	db 0
; 0x7eaf1

UnknownScript_0x7eaf1: ; 0x7eaf1
	end
; 0x7eaf2

UnknownScript_0x7eaf2: ; 0x7eaf2
	faceplayer
	loadfont
	special $0057
	closetext
	loadmovesprites
	end
; 0x7eafa

UnknownScript_0x7eafa: ; 0x7eafa
	jumpstd $0001
; 0x7eafd

LavenderNameRater_MapEventHeader: ; 0x7eafd
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN
	warp_def $7, $3, 4, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $40, 7, 6, $6, $0, 255, 255, $80, 0, UnknownScript_0x7eaf2, $ffff
; 0x7eb1a

LavenderMart_MapScriptHeader: ; 0x7eb1a
	; trigger count
	db 0

	; callback count
	db 0
; 0x7eb1c

UnknownScript_0x7eb1c: ; 0x7eb1c
	loadfont
	pokemart $0, $0015
	loadmovesprites
	end
; 0x7eb23

UnknownScript_0x7eb23: ; 0x7eb23
	jumptextfaceplayer UnknownText_0x7eb29
; 0x7eb26

UnknownScript_0x7eb26: ; 0x7eb26
	jumptextfaceplayer UnknownText_0x7ebac
; 0x7eb29

UnknownText_0x7eb29: ; 0x7eb29
	db $0, "REPEL is a neces-", $4f
	db "sity if you are", $51
	db "going to explore a", $4f
	db "cave.", $51
	db "Even though I like", $4f
	db "exploring, I still", $51
	db "haven't made it to", $4f
	db "all the caves.", $57
; 0x7ebac

UnknownText_0x7ebac: ; 0x7ebac
	db $0, "I heard about a", $4f
	db "craftsman who", $51
	db "makes custom BALLS", $4f
	db "in the JOHTO town", $51
	db "of AZALEA. I wish", $4f
	db "I had some.", $57
; 0x7ec0e

LavenderMart_MapEventHeader: ; 0x7ec0e
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 5, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN
	warp_def $7, $3, 5, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x7eb1c, $ffff
	person_event $2d, 10, 10, $5, $2, 255, 255, $80, 0, UnknownScript_0x7eb23, $ffff
	person_event $2c, 6, 13, $3, $0, 255, 255, $0, 0, UnknownScript_0x7eb26, $ffff
; 0x7ec45

SoulHouse_MapScriptHeader: ; 0x7ec45
	; trigger count
	db 0

	; callback count
	db 0
; 0x7ec47

UnknownScript_0x7ec47: ; 0x7ec47
	jumptextfaceplayer UnknownText_0x7ec53
; 0x7ec4a

UnknownScript_0x7ec4a: ; 0x7ec4a
	jumptextfaceplayer UnknownText_0x7ed4d
; 0x7ec4d

UnknownScript_0x7ec4d: ; 0x7ec4d
	jumptextfaceplayer UnknownText_0x7edb1
; 0x7ec50

UnknownScript_0x7ec50: ; 0x7ec50
	jumptextfaceplayer UnknownText_0x7eddb
; 0x7ec53

UnknownText_0x7ec53: ; 0x7ec53
	db $0, "MR.FUJI: Welcome.", $51
	db "Hmm… You appear to", $4f
	db "be raising your", $51
	db "#MON in a kind", $4f
	db "and loving manner.", $51
	db "#MON lovers", $4f
	db "come here to pay", $51
	db "their respects to", $4f
	db "departed #MON.", $51
	db "Please offer con-", $4f
	db "dolences for the", $51
	db "souls of the de-", $4f
	db "parted #MON.", $51
	db "I'm sure that will", $4f
	db "make them happy.", $57
; 0x7ed4d

UnknownText_0x7ed4d: ; 0x7ed4d
	db $0, "There are other", $4f
	db "graves of #MON", $55
	db "here, I think.", $51
	db "There are many", $4f
	db "chambers that only", $55
	db "MR.FUJI may enter.", $57
; 0x7edb1

UnknownText_0x7edb1: ; 0x7edb1
	db $0, "I came with my mom", $4f
	db "to visit #MON", $55
	db "graves…", $57
; 0x7eddb

UnknownText_0x7eddb: ; 0x7eddb
	db $0, "The #MON that", $4f
	db "lived with me…", $51
	db "I loved them like", $4f
	db "my grandchildren…", $57
; 0x7ee1d

SoulHouse_MapEventHeader: ; 0x7ee1d
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $4, 6, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN
	warp_def $7, $5, 6, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $2f, 6, 8, $6, $0, 255, 255, $90, 0, UnknownScript_0x7ec47, $ffff
	person_event $29, 7, 11, $5, $1, 255, 255, $90, 0, UnknownScript_0x7ec4a, $ffff
	person_event $28, 9, 6, $7, $0, 255, 255, $90, 0, UnknownScript_0x7ec4d, $ffff
	person_event $30, 7, 5, $7, $0, 255, 255, $90, 0, UnknownScript_0x7ec50, $ffff
; 0x7ee61

LavRadioTower1F_MapScriptHeader: ; 0x7ee61
	; trigger count
	db 0

	; callback count
	db 0
; 0x7ee63

UnknownScript_0x7ee63: ; 0x7ee63
	jumptextfaceplayer UnknownText_0x7eebf
; 0x7ee66

UnknownScript_0x7ee66: ; 0x7ee66
	jumptextfaceplayer UnknownText_0x7eefa
; 0x7ee69

UnknownScript_0x7ee69: ; 0x7ee69
	jumptextfaceplayer UnknownText_0x7ef90
; 0x7ee6c

UnknownScript_0x7ee6c: ; 0x7ee6c
	faceplayer
	loadfont
	checkbit2 $0003
	iftrue UnknownScript_0x7ee8e
	checkbit1 $00c9
	iftrue UnknownScript_0x7ee80
	2writetext UnknownText_0x7effb
	closetext
	loadmovesprites
	end
; 0x7ee80

UnknownScript_0x7ee80: ; 0x7ee80
	2writetext UnknownText_0x7f0a1
	keeptextopen
	stringtotext $6e98, $1
	2call UnknownScript_0x7ee94
	setbit2 $0003
UnknownScript_0x7ee8e: ; 0x7ee8e
	2writetext UnknownText_0x7f141
	closetext
	loadmovesprites
	end
; 0x7ee94

UnknownScript_0x7ee94: ; 0x7ee94
	jumpstd $002f
	end
; 0x7ee98

UnknownRawText_0x7ee98: ; 0x7ee98
	db "EXPN CARD@"
; 0x7eea2

UnknownScript_0x7eea2: ; 0x7eea2
	faceplayer
	loadfont
	checkbit2 $0003
	iftrue UnknownScript_0x7eeb0
	2writetext UnknownText_0x7f193
	closetext
	loadmovesprites
	end
; 0x7eeb0

UnknownScript_0x7eeb0: ; 0x7eeb0
	2writetext UnknownText_0x7f248
	closetext
	loadmovesprites
	end
; 0x7eeb6

MapLavRadioTower1FSignpost0Script: ; 0x7eeb6
	jumptext UnknownText_0x7f2e3
; 0x7eeb9

MapLavRadioTower1FSignpost1Script: ; 0x7eeb9
	jumptext UnknownText_0x7f32d
; 0x7eebc

UnknownScript_0x7eebc: ; 0x7eebc
	jumptext UnknownText_0x7f36b
; 0x7eebf

UnknownText_0x7eebf: ; 0x7eebf
	db $0, "Welcome!", $4f
	db "Feel free to look", $51
	db "around anywhere on", $4f
	db "this floor.", $57
; 0x7eefa

UnknownText_0x7eefa: ; 0x7eefa
	db $0, "Sorry, but you can", $4f
	db "only tour the", $55
	db "ground floor.", $51
	db "Ever since JOHTO's", $4f
	db "RADIO TOWER was", $51
	db "taken over by a", $4f
	db "criminal gang, we", $51
	db "have had to step", $4f
	db "up our security.", $57
; 0x7ef90

UnknownText_0x7ef90: ; 0x7ef90
	db $0, "Many people are", $4f
	db "hard at work here", $51
	db "in the RADIO", $4f
	db "TOWER.", $51
	db "They must be doing", $4f
	db "their best to put", $55
	db "on good shows.", $57
; 0x7effb

UnknownText_0x7effb: ; 0x7effb
	db $0, "Oh, no, no, no!", $51
	db "We've been off the", $4f
	db "air ever since the", $51
	db "POWER PLANT shut", $4f
	db "down.", $51
	db "All my efforts to", $4f
	db "start this station", $51
	db "would be wasted if", $4f
	db "I can't broadcast.", $51
	db "I'll be ruined!", $57
; 0x7f0a1

UnknownText_0x7f0a1: ; 0x7f0a1
	db $0, "Ah! So you're the", $4f
	db $14, " who solved", $51
	db "the POWER PLANT's", $4f
	db "problem?", $51
	db "Thanks to you, I", $4f
	db "never lost my job.", $51
	db "I tell you, you're", $4f
	db "a real lifesaver!", $51
	db "Please take this", $4f
	db "as my thanks.", $57
; 0x7f141

UnknownText_0x7f141: ; 0x7f141
	db $0, "With that thing,", $4f
	db "you can tune into", $51
	db "the radio programs", $4f
	db "here in KANTO.", $51
	db "Gahahahaha!", $57
; 0x7f193

UnknownText_0x7f193: ; 0x7f193
	db $0, "Hey there!", $51
	db "I am the super", $4f
	db "MUSIC DIRECTOR!", $51
	db "Huh? Your #GEAR", $4f
	db "can't tune into my", $51
	db "music programs.", $4f
	db "How unfortunate!", $51
	db "If you get an EXPN", $4f
	db "CARD upgrade, you", $51
	db "can tune in. You'd", $4f
	db "better get one!", $57
; 0x7f248

UnknownText_0x7f248: ; 0x7f248
	db $0, "Hey there!", $51
	db "I am the super", $4f
	db "MUSIC DIRECTOR!", $51
	db "I'm responsible", $4f
	db "for the gorgeous", $51
	db "melodies that go", $4f
	db "out over the air.", $51
	db "Don't be square.", $4f
	db "Grab your music", $55
	db "off the air!", $57
; 0x7f2e3

UnknownText_0x7f2e3: ; 0x7f2e3
	db $0, "1F RECEPTION", $4f
	db "2F SALES", $51
	db "3F PERSONNEL", $4f
	db "4F PRODUCTION", $51
	db "5F DIRECTOR'S", $4f
	db "   OFFICE", $57
; 0x7f32d

UnknownText_0x7f32d: ; 0x7f32d
	db $0, "Perk Up #MON", $4f
	db "with Mellow Sounds", $51
	db "of the # FLUTE", $4f
	db "on CHANNEL 20", $57
; 0x7f36b

UnknownText_0x7f36b: ; 0x7f36b
	db $0, "Wow! A full rack", $4f
	db "of #MON CDs and", $55
	db "videos.", $51
	db "This must be the", $4f
	db "reference library.", $57
; 0x7f3b9

LavRadioTower1F_MapEventHeader: ; 0x7f3b9
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 7, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN
	warp_def $7, $3, 7, GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 11, $0, MapLavRadioTower1FSignpost0Script
	signpost 0, 5, $0, MapLavRadioTower1FSignpost1Script

	; people-events
	db 5
	person_event $42, 10, 10, $7, $0, 255, 255, $a0, 0, UnknownScript_0x7ee63, $ffff
	person_event $43, 5, 19, $6, $0, 255, 255, $a0, 0, UnknownScript_0x7ee66, $ffff
	person_event $2b, 7, 5, $2, $11, 255, 255, $80, 0, UnknownScript_0x7ee69, $ffff
	person_event $40, 5, 13, $7, $0, 255, 255, $0, 0, UnknownScript_0x7ee6c, $ffff
	person_event $2b, 10, 18, $9, $0, 255, 255, $0, 0, UnknownScript_0x7eea2, $ffff
; 0x7f414

Route8SaffronGate_MapScriptHeader: ; 0x7f414
	; trigger count
	db 0

	; callback count
	db 0
; 0x7f416

UnknownScript_0x7f416: ; 0x7f416
	jumptextfaceplayer UnknownText_0x7f419
; 0x7f419

UnknownText_0x7f419: ; 0x7f419
	db $0, "Have you been to", $4f
	db "LAVENDER TOWN?", $51
	db "There's a tall", $4f
	db "RADIO TOWER there.", $57
; 0x7f45b

Route8SaffronGate_MapEventHeader: ; 0x7f45b
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 14, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $5, $0, 15, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $4, $9, 1, GROUP_ROUTE_8, MAP_ROUTE_8
	warp_def $5, $9, 2, GROUP_ROUTE_8, MAP_ROUTE_8

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 6, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x7f416, $ffff
; 0x7f482

Route12SuperRodHouse_MapScriptHeader: ; 0x7f482
	; trigger count
	db 0

	; callback count
	db 0
; 0x7f484

UnknownScript_0x7f484: ; 0x7f484
	faceplayer
	loadfont
	checkbit1 $0019
	iftrue UnknownScript_0x7f4a0
	2writetext UnknownText_0x7f4af
	yesorno
	iffalse UnknownScript_0x7f4a6
	2writetext UnknownText_0x7f52f
	keeptextopen
	verbosegiveitem SUPER_ROD, 1
	iffalse UnknownScript_0x7f4aa
	setbit1 $0019
UnknownScript_0x7f4a0: ; 0x7f4a0
	2writetext UnknownText_0x7f57c
	closetext
	loadmovesprites
	end
; 0x7f4a6

UnknownScript_0x7f4a6: ; 0x7f4a6
	2writetext UnknownText_0x7f5ec
	closetext
UnknownScript_0x7f4aa: ; 0x7f4aa
	loadmovesprites
	end
; 0x7f4ac

UnknownScript_0x7f4ac: ; 0x7f4ac
	jumpstd $0002
; 0x7f4af

UnknownText_0x7f4af: ; 0x7f4af
	db $0, "I'm the FISHING", $4f
	db "GURU's younger", $55
	db "brother.", $51
	db "I can see that you", $4f
	db "like fishing.", $51
	db "There's no doubt", $4f
	db "in my mind at all!", $51
	db "So? I know I'm", $4f
	db "right.", $57
; 0x7f52f

UnknownText_0x7f52f: ; 0x7f52f
	db $0, "Yes, yes. Just as", $4f
	db "I thought!", $51
	db "Here, fishing fan!", $4f
	db "Take this--it's a", $55
	db "SUPER ROD.", $57
; 0x7f57c

UnknownText_0x7f57c: ; 0x7f57c
	db $0, "Try your hand at", $4f
	db "fishing wherever", $55
	db "there is water.", $51
	db "Remember--you can", $4f
	db "catch different", $51
	db "#MON using", $4f
	db "different RODS.", $57
; 0x7f5ec

UnknownText_0x7f5ec: ; 0x7f5ec
	db $0, "Huh? My own eyes", $4f
	db "deceived me?", $57
; 0x7f60b

Route12SuperRodHouse_MapEventHeader: ; 0x7f60b
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_ROUTE_12, MAP_ROUTE_12
	warp_def $7, $3, 1, GROUP_ROUTE_12, MAP_ROUTE_12

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $3b, 7, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x7f484, $ffff
; 0x7f628

SECTION "bank20",DATA,BANK[$20]

INCBIN "baserom.gbc",$80000,$80430-$80000

GetFlag2: ; 80430
; uses bittable2
; takes flag id in de, mode in b
; can either check, set or reset a flag
; check: stores flag in c
; set/reset: no output
;
;    b = 0: reset flag
;      = 1: set flag
;      > 1: check flag
;
	ld a, d
	cp $00 ; is the flag id > 256?
	jr z, .start ; no
	jr c, .read ; carry is never set
	jr .invalid ; yes
.start
	ld a, e
	cp $a2 ; $a2 flag ids
	jr c, .read
.invalid
; uses flag 0
	xor a
	ld e, a
	ld d, a
.read
	ld hl, Flags
	add hl, de ; skip three
	add hl, de ; bytes per
	add hl, de ; flag
	ld e, [hl]
	inc hl
	ld d, [hl]
	inc hl
	ld c, [hl] ; flag bit
	ld a, b
	cp $01
	jr c, .reset ; b = 0
	jr z, .set   ; b = 1
	ld a, [de]   ; b > 1
	and c
	ld c, a
	ret
.set
	ld a, [de]
	or c
	ld [de], a
	ret
.reset
	ld a, c
	cpl ; AND all bits except the one in question
	ld c, a
	ld a, [de]
	and c
	ld [de], a
	ret
; 80462
	
Flags: ; 80462
; bittable2
; location, bit

	; pokegear
	dwb $d957, %00000010 ; radio card
	dwb $d957, %00000001 ; map card
	dwb $d957, %00000100 ; phone card
	dwb $d957, %00001000 ; expn card
	dwb $d957, %10000000 ; on/off
	
	;   $def5  %10000000 ; daycare 1 on
	dwb $def5, %01000000 ; monster 1 and 2 are compatible
	;   $def5  %00100000 ; egg is ready
	dwb $def5, %00000001 ; monster 1 in daycare
	
	;   $df2c  %10000000 = daycare 2 on
	dwb $df2c, %00000001 ; monster 2 in daycare
	
	dwb $d854, %00000001 ; mom saving money
	dwb $d854, %10000000 ; dst
	
	dwb $dc39, %00000001
	
	dwb $d84c, %00000001 ; pokedex
	dwb $d84c, %00000010 ; unown dex
	dwb $d84c, %00001000 ; pokerus
	dwb $d84c, %00010000 ; rocket signal on ch20
	dwb $d84c, %01000000 ; credits skip
	dwb $d84c, %10000000 ; bug contest on
	dwb $d84d, %00000100 ; bug contest timer
	dwb $d84d, %00000010 ; rockets in radio tower
	dwb $d84d, %00000001 ; bike shop call enabled (1024 bike steps reqd)
	dwb $d84d, %00010000
	dwb $d84d, %00100000 ; give pokerus; berry -> berry juice when trading?
	dwb $d84d, %01000000
	dwb $d84d, %10000000 ; rockets in mahogany
	
	dwb $dbf5, %00000001 ; strength active
	dwb $dbf5, %00000010 ; always on bike (cant surf)
	dwb $dbf5, %00000100 ; downhill (cycling road)
	
	dwb JohtoBadges, %00000001 ; zephyrbadge
	dwb JohtoBadges, %00000010 ; hivebadge
	dwb JohtoBadges, %00000100 ; plainbadge
	dwb JohtoBadges, %00001000 ; fogbadge
	dwb JohtoBadges, %00010000 ; mineralbadge
	dwb JohtoBadges, %00100000 ; stormbadge
	dwb JohtoBadges, %01000000 ; glacierbadge
	dwb JohtoBadges, %10000000 ; risingbadge
	
	dwb KantoBadges, %00000001 ; boulderbadge
	dwb KantoBadges, %00000010 ; cascadebadge
	dwb KantoBadges, %00000100 ; thunderbadge
	dwb KantoBadges, %00001000 ; rainbowbadge
	dwb KantoBadges, %00010000 ; soulbadge
	dwb KantoBadges, %00100000 ; marshbadge
	dwb KantoBadges, %01000000 ; volcanobadge
	dwb KantoBadges, %10000000 ; earthbadge
	
	; unown sets
	dwb $def3, %00000001 ; 1
	dwb $def3, %00000010 ; 2
	dwb $def3, %00000100 ; 3
	dwb $def3, %00001000 ; 4
	dwb $def3, %00010000 ; 5
	dwb $def3, %00100000 ; 6
	dwb $def3, %01000000 ; 7
	dwb $def3, %10000000 ; 8
	
	; fly
	dwb $dca5, %00000001 ; your house
	dwb $dca5, %00000010 ; viridian pokecenter
	dwb $dca5, %00000100 ; pallet
	dwb $dca5, %00001000 ; viridian
	dwb $dca5, %00010000 ; pewter
	dwb $dca5, %00100000 ; cerulean
	dwb $dca5, %01000000 ; rock tunnel
	dwb $dca5, %10000000 ; vermilion
	dwb $dca6, %00000001 ; lavender
	dwb $dca6, %00000010 ; saffron
	dwb $dca6, %00000100 ; celadon
	dwb $dca6, %00001000 ; fuchsia
	dwb $dca6, %00010000 ; cinnabar
	dwb $dca6, %00100000 ; indigo plateau
	dwb $dca6, %01000000 ; new bark
	dwb $dca6, %10000000 ; cherrygrove
	dwb $dca7, %00000001 ; violet
	dwb $dca7, %00000100 ; azalea
	dwb $dca7, %00001000 ; cianwood
	dwb $dca7, %00010000 ; goldenrod
	dwb $dca7, %00100000 ; olivine
	dwb $dca7, %01000000 ; ecruteak
	dwb $dca7, %10000000 ; mahogany
	dwb $dca8, %00000001 ; lake of rage
	dwb $dca8, %00000010 ; blackthorn
	dwb $dca8, %00000100 ; silver cave
	dwb $dca8, %00010000 ; unused
	
	dwb $dc9d, %00000001 ; lucky number show
	dwb $d84d, %00001000
	
	dwb $dc1e, %00000001 ; kurt making balls
	dwb $dc1e, %00000010
	dwb $dc1e, %00000100 ; special wilddata?
	dwb $dc1e, %00001000 ; time capsule (24h wait)
	dwb $dc1e, %00010000 ; all fruit trees
	dwb $dc1e, %00100000 ; shuckle given
	dwb $dc1e, %01000000 ; goldenrod underground merchant closed
	dwb $dc1e, %10000000 ; fought in trainer hall today
	
	dwb $dc1f, %00000001 ; mt moon square clefairy
	dwb $dc1f, %00000010 ; union cave lapras
	dwb $dc1f, %00000100 ; goldenrod underground haircut used
	dwb $dc1f, %00001000 ; goldenrod mall happiness event floor05 person07
	dwb $dc1f, %00010000 ; tea in blues house
	dwb $dc1f, %00100000 ; indigo plateau rival fight
	dwb $dc1f, %01000000
	dwb $dc1f, %10000000
	
	dwb $dc20, %00000001 ; $60
	dwb $dc20, %00000010 ; goldenrod dept store sale is on
	
	dwb $cfbc, %10000000 ; $62
	
	dwb $d472, %00000001 ; player is female
	
	dwb $dbf3, %00000100 ; have gs ball after kurt examined it
	
	; rematches
	dwb $dc4c, %00000001 ; jack
	dwb $dc4c, %00000010 ; huey
	dwb $dc4c, %00000100 ; gaven
	dwb $dc4c, %00001000 ; beth
	dwb $dc4c, %00010000 ; jose
	dwb $dc4c, %00100000 ; reena
	dwb $dc4c, %01000000 ; joey
	dwb $dc4c, %10000000 ; wade
	dwb $dc4d, %00000001 ; ralph
	dwb $dc4d, %00000010 ; liz
	dwb $dc4d, %00000100 ; anthony
	dwb $dc4d, %00001000 ; todd
	dwb $dc4d, %00010000 ; gina
	dwb $dc4d, %00100000 ; arnie
	dwb $dc4d, %01000000 ; alan
	dwb $dc4d, %10000000 ; dana
	dwb $dc4e, %00000001 ; chad
	dwb $dc4e, %00000010 ; tully
	dwb $dc4e, %00000100 ; brent
	dwb $dc4e, %00001000 ; tiffany
	dwb $dc4e, %00010000 ; vance
	dwb $dc4e, %00100000 ; wilton
	dwb $dc4e, %01000000 ; parry
	dwb $dc4e, %10000000 ; erin
	
	dwb $dc50, %00000001 ; beverly has nugget
	dwb $dc50, %00000010 ; jose has star piece
	dwb $dc50, %00000100 ; wade has item (see bittable1 $032b-e)
	dwb $dc50, %00001000 ; gina has leaf stone
	dwb $dc50, %00010000 ; alan has fire stone
	dwb $dc50, %00100000 ; liz has thunderstone
	dwb $dc50, %01000000 ; derek has nugget
	dwb $dc50, %10000000 ; tully has water stone
	
	dwb $dc51, %00000001 ; tiffany has pink bow
	dwb $dc51, %00000010 ; wilton has item (see bittable1 $032f-31)
	
	dwb $dc54, %00000001
	dwb $dc54, %00000010
	dwb $dc54, %00000100
	dwb $dc54, %00001000
	dwb $dc54, %00010000
	dwb $dc54, %00100000
	dwb $dc54, %01000000
	dwb $dc54, %10000000
	
	dwb $dc55, %00000001
	dwb $dc55, %00000010
	dwb $dc55, %00000100
	dwb $dc55, %00001000
	dwb $dc55, %00010000
	dwb $dc55, %00100000
	dwb $dc55, %01000000
	dwb $dc55, %10000000
	
	dwb $dc56, %00000001
	dwb $dc56, %00000010
	dwb $dc56, %00000100
	dwb $dc56, %00001000
	dwb $dc56, %00010000
	dwb $dc56, %00100000
	dwb $dc56, %01000000
	dwb $dc56, %10000000
	
	dwb $d45b, %00000100 ; female player has been transformed into male
	
	dwb $dc20, %00000100 ; dunsparce swarm
	dwb $dc20, %00001000 ; yanma swarm
; 80648

INCBIN "baserom.gbc",$80648,$80730-$80648

BattleText_0x80730: ; 0x80730
	db $0, $52, " picked up", $4f
	db "¥@"
	deciram $c6ec, $36
	db $0, "!", $58
; 0x80746

WildPokemonAppearedText: ; 0x80746
	db $0, "Wild @"
	text_from_ram $c616
	db $0, $4f
	db "appeared!", $58
; 0x8075c

HookedPokemonAttackedText: ; 0x8075c
	db $0, "The hooked", $4f
	db "@"
	text_from_ram $c616
	db $0, $55
	db "attacked!", $58
; 0x80778

PokemonFellFromTreeText: ; 0x80778
	text_from_ram $c616
	db $0, " fell", $4f
	db "out of the tree!", $58
; 0x80793

WildPokemonAppearedText2: ; 0x80793
	db $0, "Wild @"
	text_from_ram $c616
	db $0, $4f
	db "appeared!", $58
; 0x807a9

BattleText_0x807a9: ; 0x807a9
	db $0, $3f, $4f
	db "wants to battle!", $58
; 0x807bd

BattleText_0x807bd: ; 0x807bd
	db $0, "Wild @"
	text_from_ram $c616
	db $0, $4f
	db "fled!", $58
; 0x807cf

BattleText_0x807cf: ; 0x807cf
	db $0, "Enemy @"
	text_from_ram $c616
	db $0, $4f
	db "fled!", $58
; 0x807e2

BattleText_0x807e2: ; 0x807e2
	db $0, $5a, $4f
	db "is hurt by poison!", $58
; 0x807f8

BattleText_0x807f8: ; 0x807f8
	db $0, $5a, "'s", $4f
	db "hurt by its burn!", $58
; 0x8080e

BattleText_0x8080e: ; 0x8080e
	db $0, "LEECH SEED saps", $4f
	db $5a, "!", $58
; 0x80822

BattleText_0x80822: ; 0x80822
	db $0, $5a, $4f
	db "has a NIGHTMARE!", $58
; 0x80836

BattleText_0x80836: ; 0x80836
	db $0, $5a, "'s", $4f
	db "hurt by the CURSE!", $58
; 0x8084d

BattleText_0x8084d: ; 0x8084d
	db $0, "The SANDSTORM hits", $4f
	db $5a, "!", $58
; 0x80864

BattleText_0x80864: ; 0x80864
	db $0, $5a, "'s", $4f
	db "PERISH count is @"
	deciram $d265, $11
	db $0, "!", $58
; 0x80880

BattleText_0x80880: ; 0x80880
	db $0, $59, $4f
	db "recovered with", $55
	db "@"
	text_from_ram $d073
	db $0, ".", $58
; 0x80899

BattleText_0x80899: ; 0x80899
	db $0, $5a, $4f
	db "recovered PP using", $55
	db "@"
	text_from_ram $d073
	db $0, ".", $58
; 0x808b6

BattleText_0x808b6: ; 0x808b6
	db $0, $59, $4f
	db "was hit by FUTURE", $55
	db "SIGHT!", $58
; 0x808d2

BattleText_0x808d2: ; 0x808d2
	db $0, $5a, "'s", $4f
	db "SAFEGUARD faded!", $58
; 0x808e7

BattleText_0x808e7: ; 0x808e7
	text_from_ram $d073
	db $0, " #MON's", $4f
	db "LIGHT SCREEN fell!", $58
; 0x80905

BattleText_0x80905: ; 0x80905
	text_from_ram $d073
	db $0, " #MON's", $4f
	db "REFLECT faded!", $58
; 0x8091f

BattleText_0x8091f: ; 0x8091f
	db $0, "Rain continues to", $4f
	db "fall.", $58
; 0x80938

BattleText_0x80938: ; 0x80938
	db $0, "The sunlight is", $4f
	db "strong.", $58
; 0x80951

BattleText_0x80951: ; 0x80951
	db $0, "The SANDSTORM", $4f
	db "rages.", $58
; 0x80967

BattleText_0x80967: ; 0x80967
	db $0, "The rain stopped.", $58
; 0x8097a

BattleText_0x8097a: ; 0x8097a
	db $0, "The sunlight", $4f
	db "faded.", $58
; 0x8098f

BattleText_0x8098f: ; 0x8098f
	db $0, "The SANDSTORM", $4f
	db "subsided.", $58
; 0x809a8

BattleText_0x809a8: ; 0x809a8
	db $0, "Enemy @"
	text_from_ram $c616
	db $0, $4f
	db "fainted!", $58
; 0x809be

BattleText_0x809be: ; 0x809be
	db $0, $52, " got ¥@"
	deciram $c686, $36
	db $0, $4f
	db "for winning!", $58
; 0x809da

BattleText_0x809da: ; 0x809da
	db $0, $3f, $4f
	db "was defeated!", $58
; 0x809eb

BattleText_0x809eb: ; 0x809eb
	db $0, "Tied against", $4f
	db $3f, "!", $58
; 0x809fc

BattleText_0x809fc: ; 0x809fc
	db $0, $52, " got ¥@"
	deciram $c686, $36
	db $0, $4f
	db "for winning!", $55
	db "Sent some to MOM!", $58
; 0x80a2a

BattleText_0x80a2a: ; 0x80a2a
	db $0, "Sent half to MOM!", $58
; 0x80a3d

BattleText_0x80a3d: ; 0x80a3d
	db $0, "Sent all to MOM!", $58
; 0x80a4f

BattleText_0x80a4f: ; 0x80a4f
	db $0, $53, ": Huh? I", $4f
	db "should've chosen", $55
	db "your #MON!", $58
; 0x80a75

BattleText_0x80a75: ; 0x80a75
	text_from_ram $c621
	db $0, $4f
	db "fainted!", $58
; 0x80a83

BattleText_0x80a83: ; 0x80a83
	db $0, "Use next #MON?", $57
; 0x80a93

BattleText_0x80a93: ; 0x80a93
	db $0, $53, ": Yes!", $4f
	db "I guess I chose a", $55
	db "good #MON!", $58
; 0x80ab9

BattleText_0x80ab9: ; 0x80ab9
	db $0, "Lost against", $4f
	db $3f, "!", $58
; 0x80aca

BattleText_0x80aca: ; 0x80aca
	db $0, $3f, $4f
	db "is about to use", $55
	db "@"
	text_from_ram $c616
	db $0, ".", $51
	db "Will ", $52, $4f
	db "change #MON?", $57
; 0x80af8

BattleText_0x80af8: ; 0x80af8
	db $0, $3f, $4f
	db "sent out", $55
	db "@"
	text_from_ram $c616
	db $0, "!", $57
; 0x80b0b

BattleText_0x80b0b: ; 0x80b0b
	db $0, "There's no will to", $4f
	db "battle!", $58
; 0x80b26

BattleText_0x80b26: ; 0x80b26
	db $0, "An EGG can't", $4f
	db "battle!", $58
; 0x80b3b

BattleText_0x80b3b: ; 0x80b3b
	db $0, "Can't escape!", $58
; 0x80b49

BattleText_0x80b49: ; 0x80b49
	db $0, "No! There's no", $4f
	db "running from a", $55
	db "trainer battle!", $58
; 0x80b77

BattleText_0x80b77: ; 0x80b77
	db $0, "Got away safely!", $58
; 0x80b89

BattleText_0x80b89: ; 0x80b89
	db $0, $5a, $4f
	db "fled using a", $55
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 0x80ba0

BattleText_0x80ba0: ; 0x80ba0
	db $0, "Can't escape!", $58
; 0x80bae

BattleText_0x80bae: ; 0x80bae
	db $0, $5a, "'s", $4f
	db "hurt by SPIKES!", $58
; 0x80bc2

RecoveredUsingText: ; 0x80bc2
	db $0, $59, $4f
	db "recovered using a", $55
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 0x80bde

BattleText_0x80bde: ; 0x80bde
	db $0, $5a, "'s", $4f
	db "@"
	text_from_ram $d073
	db $0, $55
	db "activated!", $58
; 0x80bf3

BattleText_0x80bf3: ; 0x80bf3
	db $0, "Items can't be", $4f
	db "used here.", $58
; 0x80c0d

BattleText_0x80c0d: ; 0x80c0d
	text_from_ram $c621
	db $0, $4f
	db "is already out.", $58
; 0x80c22

BattleText_0x80c22: ; 0x80c22
	text_from_ram $c621
	db $0, $4f
	db "can't be recalled!", $58
; 0x80c39

BattleText_0x80c39: ; 0x80c39
	db $0, "There's no PP left", $4f
	db "for this move!", $58
; 0x80c5b

BattleText_0x80c5b: ; 0x80c5b
	db $0, "The move is", $4f
	db "DISABLED!", $58
; 0x80c72

BattleText_0x80c72: ; 0x80c72
	text_from_ram $c621
	db $0, $4f
	db "has no moves left!", $57
; 0x80c8a

BattleText_0x80c8a: ; 0x80c8a
	db $0, $59, "'s", $4f
	db "ENCORE ended!", $58
; 0x80c9c

BattleText_0x80c9c: ; 0x80c9c
	text_from_ram $d073
	db $0, " grew to", $4f
	db "level @"
	deciram $d143, $13
	db $0, "!@"
	sound0
	db $50
; 0x80cb9

BattleText_0x80cb9: ; 0x80cb9
	db $50
; 0x80cba

BattleText_0x80cba: ; 0x80cba
	db $0, "Wild @"
	text_from_ram $c616
	db $0, $4f
	db "is eating!", $58
; 0x80cd1

BattleText_0x80cd1: ; 0x80cd1
	db $0, "Wild @"
	text_from_ram $c616
	db $0, $4f
	db "is angry!", $58
; 0x80ce7

BattleText_0x80ce7: ; 0x80ce7
	db $0, $5a, $4f
	db "is fast asleep!", $58
; 0x80cfa

BattleText_0x80cfa: ; 0x80cfa
	db $0, $5a, $4f
	db "woke up!", $58
; 0x80d06

BattleText_0x80d06: ; 0x80d06
	db $0, $5a, $4f
	db "is frozen solid!", $58
; 0x80d1a

BattleText_0x80d1a: ; 0x80d1a
	db $0, $5a, $4f
	db "flinched!", $58
; 0x80d27

BattleText_0x80d27: ; 0x80d27
	db $0, $5a, $4f
	db "must recharge!", $58
; 0x80d39

BattleText_0x80d39: ; 0x80d39
	db $0, $5a, "'s", $4f
	db "disabled no more!", $58
; 0x80d4f

BattleText_0x80d4f: ; 0x80d4f
	db $0, $5a, $4f
	db "is confused!", $58
; 0x80d5f

BattleText_0x80d5f: ; 0x80d5f
	db $0, "It hurt itself in", $4f
	db "its confusion!", $58
; 0x80d81

BattleText_0x80d81: ; 0x80d81
	db $0, $5a, "'s", $4f
	db "confused no more!", $58
; 0x80d97

BattleText_0x80d97: ; 0x80d97
	db $0, $59, $4f
	db "became confused!", $58
; 0x80dab

BattleText_0x80dab: ; 0x80dab
	db $0, "A @"
	text_from_ram $d073
	db $0, " rid", $4f
	db $59, $55
	db "of its confusion.", $58
; 0x80dcc

BattleText_0x80dcc: ; 0x80dcc
	db $0, $59, "'s", $4f
	db "already confused!", $58
; 0x80de2

BattleText_0x80de2: ; 0x80de2
	db $0, $5a, "'s", $4f
	db "hurt by", $55
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 0x80df5

BattleText_0x80df5: ; 0x80df5
	db $0, $5a, $4f
	db "was released from", $55
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 0x80e11

BattleText_0x80e11: ; 0x80e11
	db $0, $5a, $4f
	db "used BIND on", $55
	db $59, "!", $58
; 0x80e24

BattleText_0x80e24: ; 0x80e24
	db $0, $59, $4f
	db "was trapped!", $58
; 0x80e34

BattleText_0x80e34: ; 0x80e34
	db $0, $59, $4f
	db "was trapped!", $58
; 0x80e44

BattleText_0x80e44: ; 0x80e44
	db $0, $59, $4f
	db "was WRAPPED by", $55
	db $5a, "!", $58
; 0x80e59

BattleText_0x80e59: ; 0x80e59
	db $0, $59, $4f
	db "was CLAMPED by", $55
	db $5a, "!", $58
; 0x80e6e

BattleText_0x80e6e: ; 0x80e6e
	db $0, $5a, $4f
	db "is storing energy!", $58
; 0x80e84

BattleText_0x80e84: ; 0x80e84
	db $0, $5a, $4f
	db "unleashed energy!", $58
; 0x80e99

BattleText_0x80e99: ; 0x80e99
	db $0, $59, $4f
	db "hung on with", $55
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 0x80eb0

BattleText_0x80eb0: ; 0x80eb0
	db $0, $59, $4f
	db "ENDURED the hit!", $58
; 0x80ec4

BattleText_0x80ec4: ; 0x80ec4
	db $0, $5a, $4f
	db "is in love with", $55
	db $59, "!", $58
; 0x80eda

BattleText_0x80eda: ; 0x80eda
	db $0, $5a, "'s", $4f
	db "infatuation kept", $55
	db "it from attacking!", $58
; 0x80f02

BattleText_0x80f02: ; 0x80f02
	db $0, $5a, "'s", $4f
	db "@"
	text_from_ram $d073
	db $0, " is", $55
	db "DISABLED!", $58
; 0x80f19

BattleText_0x80f19: ; 0x80f19
	text_from_ram $c621
	db $0, " is", $4f
	db "loafing around.", $58
; 0x80f31

BattleText_0x80f31: ; 0x80f31
	text_from_ram $c621
	db $0, " began", $4f
	db "to nap!", $58
; 0x80f44

BattleText_0x80f44: ; 0x80f44
	text_from_ram $c621
	db $0, " won't", $4f
	db "obey!", $58
; 0x80f54

BattleText_0x80f54: ; 0x80f54
	text_from_ram $c621
	db $0, " turned", $4f
	db "away!", $58
; 0x80f66

BattleText_0x80f66: ; 0x80f66
	text_from_ram $c621
	db $0, " ignored", $4f
	db "orders!", $58
; 0x80f7b

BattleText_0x80f7b: ; 0x80f7b
	text_from_ram $c621
	db $0, " ignored", $4f
	db "orders…sleeping!", $58
; 0x80f99

BattleText_0x80f99: ; 0x80f99
	db $0, "But no PP is left", $4f
	db "for the move!", $58
; 0x80fba

BattleText_0x80fba: ; 0x80fba
	db $0, $5a, $4f
	db "has no PP left for", $55
	db "@"
	text_from_ram $d086
	db $0, "!", $58
; 0x80fd7

BattleText_0x80fd7: ; 0x80fd7
	db $0, $5a, $4f
	db "went to sleep!", $57
; 0x80fe9

BattleText_0x80fe9: ; 0x80fe9
	db $0, $5a, $4f
	db "fell asleep and", $55
	db "became healthy!", $57
; 0x8100c

BattleText_0x8100c: ; 0x8100c
	db $0, $5a, $4f
	db "regained health!", $58
; 0x81020

BattleText_0x81020: ; 0x81020
	db $0, $5a, "'s", $4f
	db "attack missed!", $58
; 0x81033

BattleText_0x81033: ; 0x81033
	db $0, $5a, "'s", $4f
	db "attack missed!", $58
; 0x81046

BattleText_0x81046: ; 0x81046
	db $0, $5a, $4f
	db "kept going and", $55
	db "crashed!", $58
; 0x81061

BattleText_0x81061: ; 0x81061
	db $0, $59, "'s", $4f
	db "unaffected!", $58
; 0x81071

BattleText_0x81071: ; 0x81071
	db $0, "It doesn't affect", $4f
	db $59, "!", $58
; 0x81086

BattleText_0x81086: ; 0x81086
	db $0, "A critical hit!", $58
; 0x81097

BattleText_0x81097: ; 0x81097
	db $0, "It's a one-hit KO!", $58
; 0x810aa

BattleText_0x810aa: ; 0x810aa
	db $0, "It's super-", $4f
	db "effective!", $58
; 0x810c1

BattleText_0x810c1: ; 0x810c1
	db $0, "It's not very", $4f
	db "effective…", $58
; 0x810da

BattleText_0x810da: ; 0x810da
	db $0, $59, $4f
	db "took down with it,", $55
	db $5a, "!", $58
; 0x810f3

BattleText_0x810f3: ; 0x810f3
	db $0, $5a, "'s", $4f
	db "RAGE is building!", $58
; 0x81109

BattleText_0x81109: ; 0x81109
	db $0, $59, $4f
	db "got an ENCORE!", $58
; 0x8111b

BattleText_0x8111b: ; 0x8111b
	db $0, "The battlers", $4f
	db "shared pain!", $58
; 0x81136

BattleText_0x81136: ; 0x81136
	db $0, $5a, $4f
	db "took aim!", $58
; 0x81143

BattleText_0x81143: ; 0x81143
	db $0, $5a, $4f
	db "SKETCHED", $55
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 0x81156

BattleText_0x81156: ; 0x81156
	db $0, $5a, "'s", $4f
	db "trying to take its", $55
	db "opponent with it!", $58
; 0x8117f

BattleText_0x8117f: ; 0x8117f
	db $0, $59, "'s", $4f
	db "@"
	text_from_ram $d073
	db $0, " was", $55
	db "reduced by @"
	deciram $d265, $11
	db $0, "!", $58
; 0x811a0

BattleText_0x811a0: ; 0x811a0
	db $0, "A bell chimed!", $4f
	db $58
; 0x811b1

BattleText_0x811b1: ; 0x811b1
	db $0, $59, $4f
	db "fell asleep!", $58
; 0x811c1

BattleText_0x811c1: ; 0x811c1
	db $0, $59, "'s", $4f
	db "already asleep!", $58
; 0x811d5

BattleText_0x811d5: ; 0x811d5
	db $0, $59, $4f
	db "was poisoned!", $58
; 0x811e6

BattleText_0x811e6: ; 0x811e6
	db $0, $59, "'s", $4f
	db "badly poisoned!", $58
; 0x811fa

BattleText_0x811fa: ; 0x811fa
	db $0, $59, "'s", $4f
	db "already poisoned!", $58
; 0x81210

BattleText_0x81210: ; 0x81210
	db $0, "Sucked health from", $4f
	db $59, "!", $58
; 0x81227

BattleText_0x81227: ; 0x81227
	db $0, $59, "'s", $4f
	db "dream was eaten!", $58
; 0x8123c

BattleText_0x8123c: ; 0x8123c
	db $0, $59, $4f
	db "was burned!", $58
; 0x8124b

BattleText_0x8124b: ; 0x8124b
	db $0, $59, $4f
	db "was defrosted!", $58
; 0x8125d

BattleText_0x8125d: ; 0x8125d
	db $0, $59, $4f
	db "was frozen solid!", $58
; 0x81272

BattleText_0x81272: ; 0x81272
	db $0, $5a, "'s", $4f
	db "@"
	text_from_ram $d086
	db $0, " won't", $55
	db "rise anymore!", $58
; 0x8128f

BattleText_0x8128f: ; 0x8128f
	db $0, $59, "'s", $4f
	db "@"
	text_from_ram $d086
	db $0, " won't", $55
	db "drop anymore!", $58
; 0x812ac

BattleText_0x812ac: ; 0x812ac
	db $0, $5a, $4f
	db "fled from battle!", $58
; 0x812c1

BattleText_0x812c1: ; 0x812c1
	db $0, $59, $4f
	db "fled in fear!", $58
; 0x812d2

BattleText_0x812d2: ; 0x812d2
	db $0, $59, $4f
	db "was blown away!", $58
; 0x812e5

BattleText_0x812e5: ; 0x812e5
	db $0, "Hit @"
	deciram $c682, $11
	db $0, " times!", $58
; 0x812f8

BattleText_0x812f8: ; 0x812f8
	db $0, "Hit @"
	deciram $c684, $11
	db $0, " times!", $58
; 0x8130b

BattleText_0x8130b: ; 0x8130b
	db $0, $5a, "'s", $4f
	db "shrouded in MIST!", $58
; 0x81321

BattleText_0x81321: ; 0x81321
	db $0, $59, "'s", $4f
	db "protected by MIST.", $58
; 0x81338

BattleText_0x81338: ; 0x81338
	interpret_data
	db $0, $5a, "'s", $4f
	db "getting pumped!", $58
; 0x8134d

BattleText_0x8134d: ; 0x8134d
	db $0, $5a, "'s", $4f
	db "hit with recoil!", $58
; 0x81362

BattleText_0x81362: ; 0x81362
	db $0, $5a, $4f
	db "made a SUBSTITUTE!", $58
; 0x81378

BattleText_0x81378: ; 0x81378
	db $0, $5a, $4f
	db "has a SUBSTITUTE!", $58
; 0x8138d

BattleText_0x8138d: ; 0x8138d
	db $0, "Too weak to make", $4f
	db "a SUBSTITUTE!", $58
; 0x813ad

BattleText_0x813ad: ; 0x813ad
	db $0, "The SUBSTITUTE", $4f
	db "took damage for", $55
	db $59, "!", $58
; 0x813d0

BattleText_0x813d0: ; 0x813d0
	db $0, $59, "'s", $4f
	db "SUBSTITUTE faded!", $58
; 0x813e6

BattleText_0x813e6: ; 0x813e6
	db $0, $5a, $4f
	db "learned", $55
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 0x813f8

BattleText_0x813f8: ; 0x813f8
	db $0, $59, $4f
	db "was seeded!", $58
; 0x81407

BattleText_0x81407: ; 0x81407
	db $0, $59, $4f
	db "evaded the attack!", $58
; 0x8141d

BattleText_0x8141d: ; 0x8141d
	db $0, $59, "'s", $4f
	db "@"
	text_from_ram $d073
	db $0, " was", $55
	db "DISABLED!", $58
; 0x81435

BattleText_0x81435: ; 0x81435
	db $0, "Coins scattered", $4f
	db "everywhere!", $58
; 0x81452

BattleText_0x81452: ; 0x81452
	db $0, $5a, $4f
	db "transformed into", $55
	db "the @"
	text_from_ram $d073
	db $0, "-type!", $58
; 0x81476

BattleText_0x81476: ; 0x81476
	db $0, "All stat changes", $4f
	db "were eliminated!", $58
; 0x81499

BattleText_0x81499: ; 0x81499
	db $0, $5a, $4f
	db "TRANSFORMED into", $55
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 0x814b4

BattleText_0x814b4: ; 0x814b4
	db $0, $5a, "'s", $4f
	db "SPCL.DEF rose!", $58
; 0x814c7

BattleText_0x814c7: ; 0x814c7
	db $0, $5a, "'s", $4f
	db "DEFENSE rose!", $58
; 0x814d9

BattleText_0x814d9: ; 0x814d9
	db $0, "But nothing", $4f
	db "happened.", $58
; 0x814f0

BattleText_0x814f0: ; 0x814f0
	db $0, "But it failed!", $58
; 0x81500

BattleText_0x81500: ; 0x81500
	db $0, "It failed!", $58
; 0x8150c

BattleText_0x8150c: ; 0x8150c
	db $0, "It didn't affect", $4f
	db $59, "!", $58
; 0x81520

BattleText_0x81520: ; 0x81520
	db $0, "It didn't affect", $4f
	db $59, "!", $58
; 0x81534

BattleText_0x81534: ; 0x81534
	db $0, $5a, "'s", $4f
	db "HP is full!", $58
; 0x81544

BattleText_0x81544: ; 0x81544
	db $0, $5a, $4f
	db "was dragged out!", $58
; 0x81558

BattleText_0x81558: ; 0x81558
	db $0, $59, "'s", $4f
	db "paralyzed! Maybe", $55
	db "it can't attack!", $58
; 0x8157d

BattleText_0x8157d: ; 0x8157d
	db $0, $5a, "'s", $4f
	db "fully paralyzed!", $58
; 0x81592

BattleText_0x81592: ; 0x81592
	db $0, $59, "'s", $4f
	db "already paralyzed!", $58
; 0x815a9

BattleText_0x815a9: ; 0x815a9
	db $0, $59, "'s", $4f
	db "protected by", $55
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 0x815c1

BattleText_0x815c1: ; 0x815c1
	db $0, "The MIRROR MOVE", $4e, "failed!", $58
; 0x815da

BattleText_0x815da: ; 0x815da
	db $0, $5a, $4f
	db "stole @"
	text_from_ram $d073
	db $0, $55
	db "from its foe!", $58
; 0x815f7

BattleText_0x815f7: ; 0x815f7
	db $0, $59, $4f
	db "can't escape now!", $58
; 0x8160b

BattleText_0x8160b: ; 0x8160b
	db $0, $59, $4f
	db "started to have a", $55
	db "NIGHTMARE!", $58
; 0x8162b

BattleText_0x8162b: ; 0x8162b
	db $0, $5a, $4f
	db "was defrosted!", $58
; 0x8163d

BattleText_0x8163d: ; 0x8163d
	db $0, $5a, $4f
	db "cut its own HP and", $51
	db "put a CURSE on", $4f
	db $59, "!", $58
; 0x81665

BattleText_0x81665: ; 0x81665
	db $0, $5a, $4f
	db "PROTECTED itself!", $58
; 0x8167a

BattleText_0x8167a: ; 0x8167a
	db $0, $59, "'s", $4f
	db "PROTECTING itself!", $57
; 0x81691

BattleText_0x81691: ; 0x81691
	db $0, "SPIKES scattered", $4f
	db "all around", $55
	db $59, "!", $58
; 0x816b1

BattleText_0x816b1: ; 0x816b1
	db $0, $5a, $4f
	db "identified", $55
	db $59, "!", $58
; 0x816c2

BattleText_0x816c2: ; 0x816c2
	db $0, "Both #MON will", $4f
	db "faint in 3 turns!", $58
; 0x816e4

BattleText_0x816e4: ; 0x816e4
	db $0, "A SANDSTORM", $4f
	db "brewed!", $58
; 0x816f9

BattleText_0x816f9: ; 0x816f9
	db $0, $5a, $4f
	db "braced itself!", $58
; 0x8170b

BattleText_0x8170b: ; 0x8170b
	db $0, $59, $4f
	db "fell in love!", $58
; 0x8171c

BattleText_0x8171c: ; 0x8171c
	db $0, $5a, "'s", $4f
	db "covered by a veil!", $58
; 0x81733

BattleText_0x81733: ; 0x81733
	db $0, $59, $4f
	db "is protected by", $55
	db "SAFEGUARD!", $58
; 0x81751

BattleText_0x81751: ; 0x81751
	db $0, "Magnitude @"
	deciram $d265, $11
	db $0, "!", $58
; 0x81764

BattleText_0x81764: ; 0x81764
	db $0, $5a, $4f
	db "was released by", $55
	db $59, "!", $58
; 0x8177a

BattleText_0x8177a: ; 0x8177a
	db $0, $5a, $4f
	db "shed LEECH SEED!", $58
; 0x8178e

BattleText_0x8178e: ; 0x8178e
	db $0, $5a, $4f
	db "blew away SPIKES!", $58
; 0x817a3

BattleText_0x817a3: ; 0x817a3
	db $0, "A downpour", $4f
	db "started!", $58
; 0x817b8

BattleText_0x817b8: ; 0x817b8
	db $0, "The sunlight got", $4f
	db "bright!", $58
; 0x817d2

BattleText_0x817d2: ; 0x817d2
	db $0, $5a, $4f
	db "cut its HP and", $55
	db "maximized ATTACK!", $58
; 0x817f6

BattleText_0x817f6: ; 0x817f6
	db $0, $5a, $4f
	db "copied the stat", $51
	db "changes of", $4f
	db $59, "!", $58
; 0x81817

BattleText_0x81817: ; 0x81817
	db $0, $5a, $4f
	db "foresaw an attack!", $58
; 0x8182d

BattleText_0x8182d: ; 0x8182d
	text_from_ram $d073
	db $0, "'s", $4f
	db "attack!", $57
; 0x8183b

BattleText_0x8183b: ; 0x8183b
	db $0, $59, $4f
	db "refused the gift!", $58
; 0x81850

BattleText_0x81850: ; 0x81850
	db $0, $5a, $4f
	db "ignored orders!", $58
; 0x81863

BattleText_0x81863: ; 0x81863
	db $0, "Link error…", $51
	db "The battle has", $4f
	db "been canceled…", $58
; 0x8188e

BattleText_0x8188e: ; 0x8188e
	db $0, "There is no time", $4f
	db "left today!", $57
; 0x818ac

INCBIN "baserom.gbc",$818ac,$84000-$818ac

SECTION "bank21",DATA,BANK[$21]

SECTION "bank21",DATA,BANK[$21]

INCBIN "baserom.gbc", $84000, $84a2e - $84000

FX00GFX:
FX01GFX: ; 84a2e
INCBIN "gfx/fx/lz/001.lz"
; 84b15

INCBIN "baserom.gbc", $84b15, $84b1e - $84b15

FX02GFX: ; 84b1e
INCBIN "gfx/fx/lz/002.lz"
; 84b7a

INCBIN "baserom.gbc", $84b7a, $84b7e - $84b7a

FX03GFX: ; 84b7e
INCBIN "gfx/fx/lz/003.lz"
; 84bd0

INCBIN "baserom.gbc", $84bd0, $84bde - $84bd0

FX04GFX: ; 84bde
INCBIN "gfx/fx/lz/004.lz"
; 84ca5

INCBIN "baserom.gbc", $84ca5, $84cae - $84ca5

FX05GFX: ; 84cae
INCBIN "gfx/fx/lz/005.lz"
; 84de2

INCBIN "baserom.gbc", $84de2, $84dee - $84de2

FX07GFX: ; 84dee
INCBIN "gfx/fx/lz/007.lz"
; 84e70

INCBIN "baserom.gbc", $84e70, $84e7e - $84e70

FX08GFX: ; 84e7e
INCBIN "gfx/fx/lz/008.lz"
; 84ed4

INCBIN "baserom.gbc", $84ed4, $84ede - $84ed4

FX10GFX: ; 84ede
INCBIN "gfx/fx/lz/010.lz"
; 84f13

INCBIN "baserom.gbc", $84f13, $84f1e - $84f13

FX09GFX: ; 84f1e
INCBIN "gfx/fx/lz/009.lz"
; 85009

INCBIN "baserom.gbc", $85009, $8500e - $85009

FX12GFX: ; 8500e
INCBIN "gfx/fx/lz/012.lz"
; 8506f

INCBIN "baserom.gbc", $8506f, $8507e - $8506f

FX06GFX: ; 8507e
INCBIN "gfx/fx/lz/006.lz"
; 8515c

INCBIN "baserom.gbc", $8515c, $8515e - $8515c

FX11GFX: ; 8515e
INCBIN "gfx/fx/lz/011.lz"
; 851ad

INCBIN "baserom.gbc", $851ad, $851ae - $851ad

FX13GFX: ; 851ae
INCBIN "gfx/fx/lz/013.lz"
; 85243

INCBIN "baserom.gbc", $85243, $8524e - $85243

FX14GFX: ; 8524e
INCBIN "gfx/fx/lz/014.lz"
; 852ff

INCBIN "baserom.gbc", $852ff, $8530e - $852ff

FX24GFX: ; 8530e
INCBIN "gfx/fx/lz/024.lz"
; 8537c

INCBIN "baserom.gbc", $8537c, $8537e - $8537c

FX15GFX: ; 8537e
INCBIN "gfx/fx/lz/015.lz"
; 8539a

INCBIN "baserom.gbc", $8539a, $8539e - $8539a

FX16GFX: ; 8539e
INCBIN "gfx/fx/lz/016.lz"
; 8542d

INCBIN "baserom.gbc", $8542d, $8542e - $8542d

FX17GFX: ; 8542e
INCBIN "gfx/fx/lz/017.lz"
; 85477

INCBIN "baserom.gbc", $85477, $8547e - $85477

FX18GFX: ; 8547e
INCBIN "gfx/fx/lz/018.lz"
; 854eb

INCBIN "baserom.gbc", $854eb, $854ee - $854eb

FX19GFX: ; 854ee
INCBIN "gfx/fx/lz/019.lz"
; 855a9

INCBIN "baserom.gbc", $855a9, $855ae - $855a9

FX20GFX: ; 855ae
INCBIN "gfx/fx/lz/020.lz"
; 85627

INCBIN "baserom.gbc", $85627, $8562e - $85627

FX22GFX: ; 8562e
INCBIN "gfx/fx/lz/022.lz"
; 856ec

INCBIN "baserom.gbc", $856ec, $856ee - $856ec

FX21GFX: ; 856ee
INCBIN "gfx/fx/lz/021.lz"
; 85767

INCBIN "baserom.gbc", $85767, $8576e - $85767

FX23GFX: ; 8576e
INCBIN "gfx/fx/lz/023.lz"
; 857d0

INCBIN "baserom.gbc", $857d0, $857de - $857d0

FX26GFX: ; 857de
INCBIN "gfx/fx/lz/026.lz"
; 85838

INCBIN "baserom.gbc", $85838, $8583e - $85838

FX27GFX: ; 8583e
INCBIN "gfx/fx/lz/027.lz"
; 858b0

INCBIN "baserom.gbc", $858b0, $858be - $858b0

FX28GFX: ; 858be
INCBIN "gfx/fx/lz/028.lz"
; 85948

INCBIN "baserom.gbc", $85948, $8594e - $85948

FX29GFX: ; 8594e
INCBIN "gfx/fx/lz/029.lz"
; 859a8

INCBIN "baserom.gbc", $859a8, $859ae - $859a8

FX30GFX: ; 859ae
INCBIN "gfx/fx/lz/030.lz"
; 859ff

INCBIN "baserom.gbc", $859ff, $85a0e - $859ff

FX31GFX: ; 85a0e
INCBIN "gfx/fx/lz/031.lz"
; 85ba1

INCBIN "baserom.gbc", $85ba1, $85bae - $85ba1

FX32GFX: ; 85bae
INCBIN "gfx/fx/lz/032.lz"
; 85d09

INCBIN "baserom.gbc", $85d09, $85d0e - $85d09

FX33GFX: ; 85d0e
INCBIN "gfx/fx/lz/033.lz"
; 85def

INCBIN "baserom.gbc", $85def, $85dfe - $85def

FX34GFX: ; 85dfe
INCBIN "gfx/fx/lz/034.lz"
; 85e96

INCBIN "baserom.gbc", $85e96, $85e9e - $85e96

FX25GFX: ; 85e9e
INCBIN "gfx/fx/lz/025.lz"
; 85fb8

INCBIN "baserom.gbc", $85fb8, $85fbe - $85fb8

FX35GFX: ; 85fbe
INCBIN "gfx/fx/lz/035.lz"
; 86099

INCBIN "baserom.gbc", $86099, $8609e - $86099

FX36GFX: ; 8609e
INCBIN "gfx/fx/lz/036.lz"
; 86174

INCBIN "baserom.gbc", $86174, $8617e - $86174

FX37GFX: ; 8617e
INCBIN "gfx/fx/lz/037.lz"
; 862eb

INCBIN "baserom.gbc", $862eb, $862ee - $862eb

FX38GFX: ; 862ee
INCBIN "gfx/fx/lz/038.lz"
; 8637f

INCBIN "baserom.gbc", $8637f, $8638e - $8637f

FX39GFX: ; 8638e
INCBIN "gfx/fx/lz/039.lz"
; 8640b

INCBIN "baserom.gbc", $8640b, $88000 - $8640b


SECTION "bank22",DATA,BANK[$22]

INCBIN "baserom.gbc",$88000,$896ff - $88000

ClearScreenArea: ; 0x896ff
; clears an area of the screen
; INPUT:
; hl = address of upper left corner of the area
; b = height
; c = width
	ld a,  $7f    ; blank tile
	ld de, 20     ; screen width
.loop\@
	push bc
	push hl
.innerLoop\@
	ld [hli], a
	dec c
	jr nz, .innerLoop\@
	pop hl
	pop bc
	add hl, de
	dec b
	jr nz, .loop\@
	dec hl
	inc c
	inc c
.asm_89713
	ld a, $36
	ld [hli], a
	dec c
	ret z
	ld a, $18
	ld [hli], a
	dec c
	jr nz, .asm_89713 ; 0x8971c $f5
	ret
; 0x8971f

INCBIN "baserom.gbc",$8971f,$8addb - $8971f

SpecialHoOhChamber: ; 0x8addb
	ld hl, PartySpecies
	ld a, [hl]
	cp HO_OH ; is Ho-oh the first Pokémon in the party?
	jr nz, .done ; if not, we're done
	call GetSecondaryMapHeaderPointer
	ld de, $0326
	ld b, $1
	call BitTable1Func
.done
	ret
; 0x8adef

INCBIN "baserom.gbc",$8adef,$8b170 - $8adef

SpecialDratini: ; 0x8b170
; if ScriptVar is 0 or 1, change the moveset of the last Dratini in the party.
;  0: give it a special moveset with Extremespeed.
;  1: give it the normal moveset of a level 15 Dratini.

	ld a, [ScriptVar]
	cp $2
	ret nc
	ld bc, PartyCount
	ld a, [bc]
	ld hl, 0
	call GetNthPartyMon
	ld a, [bc]
	ld c, a
	ld de, PartyMon2 - PartyMon1
.CheckForDratini
; start at the end of the party and search backwards for a Dratini
	ld a, [hl]
	cp DRATINI
	jr z, .GiveMoveset
	ld a, l
	sub e
	ld l, a
	ld a, h
	sbc d
	ld h, a
	dec c
	jr nz, .CheckForDratini
	ret

.GiveMoveset
	push hl
	ld a, [ScriptVar]
	ld hl, .Movesets
	ld bc, .Moveset1 - .Moveset0
	call AddNTimes

	; get address of mon's first move
	pop de
	inc de
	inc de

.GiveMoves
	ld a, [hl]
	and a ; is the move 00?
	ret z ; if so, we're done here

	push hl
	push de
	ld [de], a ; give the Pokémon the new move

	; get the PP of the new move
	dec a
	ld hl, Moves + 5
	ld bc, Move1 - Moves
	call AddNTimes
	ld a, BANK(Moves)
	call GetFarByte

	; get the address of the move's PP and update the PP
	ld hl, PartyMon1PP - PartyMon1Moves
	add hl, de
	ld [hl], a

	pop de
	pop hl
	inc de
	inc hl
	jr .GiveMoves

.Movesets
.Moveset0
; Dratini does not normally learn Extremespeed. This is a special gift.
	db WRAP
	db THUNDER_WAVE
	db TWISTER
	db EXTREMESPEED
	db 0
.Moveset1
; This is the normal moveset of a level 15 Dratini
	db WRAP
	db LEER
	db THUNDER_WAVE
	db TWISTER
	db 0

GetNthPartyMon: ; 0x8b1ce
; inputs:
; hl must be set to 0 before calling this function.
; a must be set to the number of Pokémon in the party.

; outputs:
; returns the address of the last Pokémon in the party in hl.
; sets carry if a is 0.

	ld de, PartyMon1
	add hl, de
	and a
	jr z, .EmptyParty
	dec a
	ret z
	ld de, PartyMon2 - PartyMon1
.loop
	add hl, de
	dec a
	jr nz, .loop
	ret
.EmptyParty
	scf
	ret

INCBIN "baserom.gbc",$8b1e1,$8c000-$8b1e1

SECTION "bank23",DATA,BANK[$23]

INCBIN "baserom.gbc",$8c000,$8c011 - $8c000

TimeOfDayPals: ; 8c011
; return carry if pals are changed

; forced pals?
	ld hl, $d846
	bit 7, [hl]
	jr nz, .dontchange
	
; do we need to bother updating?
	ld a, [TimeOfDay]
	ld hl, CurTimeOfDay
	cp [hl]
	jr z, .dontchange
	
; if so, the time of day has changed
	ld a, [TimeOfDay]
	ld [CurTimeOfDay], a
	
; get palette id
	call GetTimePalette
	
; same palette as before?
	ld hl, TimeOfDayPal
	cp [hl]
	jr z, .dontchange
	
; update palette id
	ld [TimeOfDayPal], a
	
	
; save bg palette 8
	ld hl, $d038 ; Unkn1Pals + 7 pals
	
; save wram bank
	ld a, [$ff70] ; wram bank
	ld b, a
; wram bank 5
	ld a, 5
	ld [$ff70], a ; wram bank
	
; push palette
	ld c, 4 ; NUM_PAL_COLORS
.push
	ld d, [hl]
	inc hl
	ld e, [hl]
	inc hl
	push de
	dec c
	jr nz, .push
	
; restore wram bank
	ld a, b
	ld [$ff70], a ; wram bank
	
	
; update sgb pals
	ld b, $9
	call GetSGBLayout
	
	
; restore bg palette 8
	ld hl, $d03f ; last byte in Unkn1Pals
	
; save wram bank
	ld a, [$ff70] ; wram bank
	ld d, a
; wram bank 5
	ld a, 5
	ld [$ff70], a ; wram bank
	
; pop palette
	ld e, 4 ; NUM_PAL_COLORS
.pop
	pop bc
	ld [hl], c
	dec hl
	ld [hl], b
	dec hl
	dec e
	jr nz, .pop
	
; restore wram bank
	ld a, d
	ld [$ff70], a ; wram bank
	
; update palettes
	call UpdateTimePals
	call DelayFrame
	
; successful change
	scf
	ret
	
.dontchange
; no change occurred
	and a
	ret
; 8c070


UpdateTimePals: ; 8c070
	ld c, $9 ; normal
	call GetTimePalFade
	call DmgToCgbTimePals
	ret
; 8c079

INCBIN "baserom.gbc",$8c079,$8c117 - $8c079

GetTimePalette: ; 8c117
; get time of day
	ld a, [TimeOfDay]
	ld e, a
	ld d, $0
; get fn ptr
	ld hl, .TimePalettes
	add hl, de
	add hl, de
	ld a, [hli]
	ld h, [hl]
	ld l, a
; go
	jp [hl]
; 8c126

.TimePalettes
	dw .MorningPalette
	dw .DayPalette
	dw .NitePalette
	dw .DarknessPalette

.MorningPalette ; 8c12e
	ld a, [$d847]
	and %00000011 ; 0
	ret
; 8c134

.DayPalette ; 8c134
	ld a, [$d847]
	and %00001100 ; 1
	srl a
	srl a
	ret
; 8c13e

.NitePalette ; 8c13e
	ld a, [$d847]
	and %00110000 ; 2
	swap a
	ret
; 8c146

.DarknessPalette ; 8c146
	ld a, [$d847]
	and %11000000 ; 3
	rlca
	rlca
	ret
; 8c14e


DmgToCgbTimePals: ; 8c14e
	push hl
	push de
	ld a, [hli]
	call DmgToCgbBGPals
	ld a, [hli]
	ld e, a
	ld a, [hli]
	ld d, a
	call DmgToCgbObjPals
	pop de
	pop hl
	ret
; 8c15e

INCBIN "baserom.gbc",$8c15e,$8c17c - $8c15e

GetTimePalFade: ; 8c17c
; check cgb
	ld a, [$ffe6]
	and a
	jr nz, .cgb
	
; else: dmg

; index
	ld a, [TimeOfDayPal]
	and %11
	
; get fade table
	push bc
	ld c, a
	ld b, $0
	ld hl, .dmgfades
	add hl, bc
	add hl, bc
	ld a, [hli]
	ld h, [hl]
	ld l, a
	pop bc
	
; get place in fade table
	ld b, $0
	add hl, bc
	ret
	
.cgb
	ld hl, .cgbfade
	ld b, $0
	add hl, bc
	ret
; 8c19e

.dmgfades ; 8c19e
	dw .morn
	dw .day
	dw .nite
	dw .darkness
; 8c1a6

.morn ; 8c1a6
	db %11111111
	db %11111111
	db %11111111
	
	db %11111110
	db %11111110
	db %11111110
	
	db %11111001
	db %11100100
	db %11100100
	
	db %11100100
	db %11010000
	db %11010000
	
	db %10010000
	db %10000000
	db %10000000
	
	db %01000000
	db %01000000
	db %01000000
	
	db %00000000
	db %00000000
	db %00000000
; 8c1bb

.day ; 8c1bb
	db %11111111
	db %11111111
	db %11111111
	
	db %11111110
	db %11111110
	db %11111110
	
	db %11111001
	db %11100100
	db %11100100
	
	db %11100100
	db %11010000
	db %11010000
	
	db %10010000
	db %10000000
	db %10000000
	
	db %01000000
	db %01000000
	db %01000000
	
	db %00000000
	db %00000000
	db %00000000
; 8c1d0

.nite ; 8c1d0
	db %11111111
	db %11111111
	db %11111111
	
	db %11111110
	db %11111110
	db %11111110
	
	db %11111001
	db %11100100
	db %11100100
	
	db %11101001
	db %11010000
	db %11010000
	
	db %10010000
	db %10000000
	db %10000000
	
	db %01000000
	db %01000000
	db %01000000
	
	db %00000000
	db %00000000
	db %00000000
; 8c1e5

.darkness ; 8c1e5
	db %11111111
	db %11111111
	db %11111111
	
	db %11111110
	db %11111110
	db %11111111
	
	db %11111110
	db %11100100
	db %11111111
	
	db %11111101
	db %11010000
	db %11111111
	
	db %11111101
	db %10000000
	db %11111111
	
	db %00000000
	db %01000000
	db %00000000
	
	db %00000000
	db %00000000
	db %00000000
; 8c1fa

.cgbfade ; 8c1fa
	db %11111111
	db %11111111
	db %11111111
	
	db %11111110
	db %11111110
	db %11111110
	
	db %11111001
	db %11111001
	db %11111001
	
	db %11100100
	db %11100100
	db %11100100
	
	db %10010000
	db %10010000
	db %10010000
	
	db %01000000
	db %01000000
	db %01000000
	
	db %00000000
	db %00000000
	db %00000000
; 8c20f

INCBIN "baserom.gbc",$8c20f,$8ff0d - $8c20f


SECTION "bank24",DATA,BANK[$24]

INCBIN "baserom.gbc",$90000,$909F2-$90000

dw Sunday
dw Monday
dw Tuesday
dw Wednesday
dw Thursday
dw Friday
dw Saturday
dw Sunday

Sunday:
	db " SUNDAY@"
Monday:
	db " MONDAY@"
Tuesday:
	db " TUESDAY@"
Wednesday:
	db "WEDNESDAY@"
Thursday:
	db "THURSDAY@"
Friday:
	db " FRIDAY@"
Saturday:
	db "SATURDAY@"


INCBIN "baserom.gbc", $90a3f, $914dd - $90a3f

PokegearSpritesGFX: ; 914dd
INCBIN "gfx/misc/lz/pokegear_sprites.lz"
; 91507

INCBIN "baserom.gbc", $91507, $93a31 - $91507


SECTION "bank25",DATA,BANK[$25]

MapHeaderPointers: ; 0x94000
; pointers to the first map header of each map group
	dw MapHeader_0x94034
	dw MahoganyRedGyaradosSpeechHouse_MapHeader
	dw SproutTower1F_MapHeader
	dw EcruteakHouse_MapHeader
	dw BlackthornGym1F_MapHeader
	dw CinnabarPokeCenter1F_MapHeader
	dw CeruleanGymBadgeSpeechHouse_MapHeader
	dw AzaleaPokeCenter1F_MapHeader
	dw LakeofRageHiddenPowerHouse_MapHeader
	dw Route32_MapHeader
	dw Route34_MapHeader
	dw Route6_MapHeader
	dw Route1_MapHeader
	dw Route3_MapHeader
	dw OlivinePort_MapHeader
	dw Route23_MapHeader
	dw Route13_MapHeader
	dw Route8_MapHeader
	dw Route28_MapHeader
	dw PokeCenter2F_MapHeader
	dw Route7_MapHeader
	dw Route40_MapHeader
	dw Route2_MapHeader
	dw Route26_MapHeader
	dw Route5_MapHeader
	dw Route30_MapHeader

MapHeader_0x94034: ; 0x94034
	; bank, tileset, permission
	db BANK(OlivinePokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw OlivinePokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $9, 1, 1
; had to increase the final size by 1
; had to convert 0x->$ (duh..)
; 0x9403d

OlivineGym_MapHeader: ; 0x9403d
	; bank, tileset, permission
	db BANK(OlivineGym_SecondMapHeader), $12, 3

	; second map header
	dw OlivineGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $1b, 17, 1
; 0x94046

OlivineVoltorbHouse_MapHeader: ; 0x94046
	; bank, tileset, permission
	db BANK(OlivineVoltorbHouse_SecondMapHeader), $5, 3

	; second map header
	dw OlivineVoltorbHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $2d, 1, 1
; 0x9404f

OlivineHouseBeta_MapHeader: ; 0x9404f
	; bank, tileset, permission
	db BANK(OlivineHouseBeta_SecondMapHeader), $5, 3

	; second map header
	dw OlivineHouseBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $2d, 1, 1
; 0x94058

OlivinePunishmentSpeechHouse_MapHeader: ; 0x94058
	; bank, tileset, permission
	db BANK(OlivinePunishmentSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw OlivinePunishmentSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $2d, 1, 1
; 0x94061

OlivineGoodRodHouse_MapHeader: ; 0x94061
	; bank, tileset, permission
	db BANK(OlivineGoodRodHouse_SecondMapHeader), $5, 3

	; second map header
	dw OlivineGoodRodHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $2d, 1, 1
; 0x9406a

OlivineCafe_MapHeader: ; 0x9406a
	; bank, tileset, permission
	db $25, $e, 3

	; second map header
	dw OlivineCafe_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $2d, 1, 1
; 0x94073

OlivineMart_MapHeader: ; 0x94073
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw OlivineMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $2d, 1, 1
; 0x9407c

Route38EcruteakGate_MapHeader: ; 0x9407c
	; bank, tileset, permission
	db BANK(Route38EcruteakGate_SecondMapHeader), $8, 6

	; second map header
	dw Route38EcruteakGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $19, $47, 1, 1
; 0x94085

Route39Barn_MapHeader: ; 0x94085
	; bank, tileset, permission
	db BANK(Route39Barn_SecondMapHeader), $10, 3

	; second map header
	dw Route39Barn_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1a, $2c, 1, 1
; 0x9408e

Route39Farmhouse_MapHeader: ; 0x9408e
	; bank, tileset, permission
	db BANK(Route39Farmhouse_SecondMapHeader), $5, 3

	; second map header
	dw Route39Farmhouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1a, $2c, 1, 1
; 0x94097

Route38_MapHeader: ; 0x94097
	; bank, tileset, permission
	db BANK(Route38_SecondMapHeader), $1, 2

	; second map header
	dw Route38_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $19, $47, 0, 1
; 0x940a0

Route39_MapHeader: ; 0x940a0
	; bank, tileset, permission
	db BANK(Route39_SecondMapHeader), $1, 2

	; second map header
	dw Route39_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1a, $47, 0, 1
; 0x940a9

OlivineCity_MapHeader: ; 0x940a9
	; bank, tileset, permission
	db BANK(OlivineCity_SecondMapHeader), $1, 1

	; second map header
	dw OlivineCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $2d, 0, 1
; 0x940b2

MahoganyRedGyaradosSpeechHouse_MapHeader: ; 0x940b2
	; bank, tileset, permission
	db BANK(MahoganyRedGyaradosSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw MahoganyRedGyaradosSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $24, $26, 1, 1
; 0x940bb

MahoganyGym_MapHeader: ; 0x940bb
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw MahoganyGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $24, $1b, 17, 1
; 0x940c4

MahoganyPokeCenter1F_MapHeader: ; 0x940c4
	; bank, tileset, permission
	db BANK(MahoganyPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw MahoganyPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $24, $9, 1, 1
; 0x940cd

Route42EcruteakGate_MapHeader: ; 0x940cd
	; bank, tileset, permission
	db BANK(Route42EcruteakGate_SecondMapHeader), $8, 6

	; second map header
	dw Route42EcruteakGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $22, $45, 1, 1
; 0x940d6

Route42_MapHeader: ; 0x940d6
	; bank, tileset, permission
	db BANK(Route42_SecondMapHeader), $1, 2

	; second map header
	dw Route42_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $22, $45, 0, 3
; 0x940df

Route44_MapHeader: ; 0x940df
	; bank, tileset, permission
	db BANK(Route44_SecondMapHeader), $1, 2

	; second map header
	dw Route44_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $27, $45, 0, 4
; 0x940e8

MahoganyTown_MapHeader: ; 0x940e8
	; bank, tileset, permission
	db BANK(MahoganyTown_SecondMapHeader), $1, 1

	; second map header
	dw MahoganyTown_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $24, $26, 0, 1
; 0x940f1

SproutTower1F_MapHeader: ; 0x940f1
	; bank, tileset, permission
	db BANK(SproutTower1F_SecondMapHeader), $17, 7

	; second map header
	dw SproutTower1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $7, $42, 1, 1
; 0x940fa

SproutTower2F_MapHeader: ; 0x940fa
	; bank, tileset, permission
	db BANK(SproutTower2F_SecondMapHeader), $17, 7

	; second map header
	dw SproutTower2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $7, $42, 1, 1
; 0x94103

SproutTower3F_MapHeader: ; 0x94103
	; bank, tileset, permission
	db BANK(SproutTower3F_SecondMapHeader), $17, 7

	; second map header
	dw SproutTower3F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $7, $42, 1, 1
; 0x9410c

TinTower1F_MapHeader: ; 0x9410c
	; bank, tileset, permission
	db BANK(TinTower1F_SecondMapHeader), $17, 7

	; second map header
	dw TinTower1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 1, 1
; 0x94115

TinTower2F_MapHeader: ; 0x94115
	; bank, tileset, permission
	db BANK(TinTower2F_SecondMapHeader), $17, 7

	; second map header
	dw TinTower2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 1, 1
; 0x9411e

TinTower3F_MapHeader: ; 0x9411e
	; bank, tileset, permission
	db BANK(TinTower3F_SecondMapHeader), $17, 7

	; second map header
	dw TinTower3F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 1, 1
; 0x94127

TinTower4F_MapHeader: ; 0x94127
	; bank, tileset, permission
	db BANK(TinTower4F_SecondMapHeader), $17, 7

	; second map header
	dw TinTower4F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 1, 1
; 0x94130

TinTower5F_MapHeader: ; 0x94130
	; bank, tileset, permission
	db BANK(TinTower5F_SecondMapHeader), $17, 7

	; second map header
	dw TinTower5F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 1, 1
; 0x94139

TinTower6F_MapHeader: ; 0x94139
	; bank, tileset, permission
	db BANK(TinTower6F_SecondMapHeader), $17, 7

	; second map header
	dw TinTower6F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 1, 1
; 0x94142

TinTower7F_MapHeader: ; 0x94142
	; bank, tileset, permission
	db BANK(TinTower7F_SecondMapHeader), $17, 7

	; second map header
	dw TinTower7F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 1, 1
; 0x9414b

TinTower8F_MapHeader: ; 0x9414b
	; bank, tileset, permission
	db BANK(TinTower8F_SecondMapHeader), $17, 7

	; second map header
	dw TinTower8F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 1, 1
; 0x94154

TinTower9F_MapHeader: ; 0x94154
	; bank, tileset, permission
	db BANK(TinTower9F_SecondMapHeader), $17, 7

	; second map header
	dw TinTower9F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 1, 1
; 0x9415d

BurnedTower1F_MapHeader: ; 0x9415d
	; bank, tileset, permission
	db BANK(BurnedTower1F_SecondMapHeader), $17, 7

	; second map header
	dw BurnedTower1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $18, $43, 18, 1
; 0x94166

BurnedTowerB1F_MapHeader: ; 0x94166
	; bank, tileset, permission
	db BANK(BurnedTowerB1F_SecondMapHeader), $18, 4

	; second map header
	dw BurnedTowerB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $18, $43, 18, 1
; 0x9416f

NationalPark_MapHeader: ; 0x9416f
	; bank, tileset, permission
	db BANK(NationalPark_SecondMapHeader), $19, 2

	; second map header
	dw NationalPark_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $13, $23, 0, 1
; 0x94178

NationalParkBugContest_MapHeader: ; 0x94178
	; bank, tileset, permission
	db BANK(NationalParkBugContest_SecondMapHeader), $19, 2

	; second map header
	dw NationalParkBugContest_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $13, $59, 0, 1
; 0x94181

RadioTower1F_MapHeader: ; 0x94181
	; bank, tileset, permission
	db $25, $1b, 3

	; second map header
	dw RadioTower1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $11, $bd, 17, 1
; 0x9418a

RadioTower2F_MapHeader: ; 0x9418a
	; bank, tileset, permission
	db $25, $1b, 3

	; second map header
	dw RadioTower2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $11, $bd, 17, 1
; 0x94193

RadioTower3F_MapHeader: ; 0x94193
	; bank, tileset, permission
	db $25, $1b, 3

	; second map header
	dw RadioTower3F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $11, $bd, 17, 1
; 0x9419c

RadioTower4F_MapHeader: ; 0x9419c
	; bank, tileset, permission
	db $25, $1b, 3

	; second map header
	dw RadioTower4F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $11, $bd, 17, 1
; 0x941a5

RadioTower5F_MapHeader: ; 0x941a5
	; bank, tileset, permission
	db $25, $1b, 3

	; second map header
	dw RadioTower5F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $11, $bd, 17, 1
; 0x941ae

RuinsofAlphOutside_MapHeader: ; 0x941ae
	; bank, tileset, permission
	db BANK(RuinsofAlphOutside_SecondMapHeader), $1, 2

	; second map header
	dw RuinsofAlphOutside_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 0, 4
; 0x941b7

RuinsofAlphHoOhChamber_MapHeader: ; 0x941b7
	; bank, tileset, permission
	db $25, $1a, 7

	; second map header
	dw RuinsofAlphHoOhChamber_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x941c0

RuinsofAlphKabutoChamber_MapHeader: ; 0x941c0
	; bank, tileset, permission
	db $25, $1a, 7

	; second map header
	dw RuinsofAlphKabutoChamber_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x941c9

RuinsofAlphOmanyteChamber_MapHeader: ; 0x941c9
	; bank, tileset, permission
	db $25, $1a, 7

	; second map header
	dw RuinsofAlphOmanyteChamber_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x941d2

RuinsofAlphAerodactylChamber_MapHeader: ; 0x941d2
	; bank, tileset, permission
	db $25, $1a, 7

	; second map header
	dw RuinsofAlphAerodactylChamber_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x941db

RuinsofAlphInnerChamber_MapHeader: ; 0x941db
	; bank, tileset, permission
	db $25, $1a, 7

	; second map header
	dw RuinsofAlphInnerChamber_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $55, 17, 1
; 0x941e4

RuinsofAlphResearchCenter_MapHeader: ; 0x941e4
	; bank, tileset, permission
	db $25, $b, 3

	; second map header
	dw RuinsofAlphResearchCenter_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 1, 1
; 0x941ed

RuinsofAlphHoOhItemRoom_MapHeader: ; 0x941ed
	; bank, tileset, permission
	db $25, $1a, 7

	; second map header
	dw RuinsofAlphHoOhItemRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x941f6

RuinsofAlphKabutoItemRoom_MapHeader: ; 0x941f6
	; bank, tileset, permission
	db $25, $1a, 7

	; second map header
	dw RuinsofAlphKabutoItemRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x941ff

RuinsofAlphOmanyteItemRoom_MapHeader: ; 0x941ff
	; bank, tileset, permission
	db $25, $1a, 7

	; second map header
	dw RuinsofAlphOmanyteItemRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x94208

RuinsofAlphAerodactylItemRoom_MapHeader: ; 0x94208
	; bank, tileset, permission
	db $25, $1a, 7

	; second map header
	dw RuinsofAlphAerodactylItemRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x94211

RuinsofAlphHoOhWordRoom_MapHeader: ; 0x94211
	; bank, tileset, permission
	db BANK(RuinsofAlphHoOhWordRoom_SecondMapHeader), $21, 7

	; second map header
	dw RuinsofAlphHoOhWordRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x9421a

RuinsofAlphKabutoWordRoom_MapHeader: ; 0x9421a
	; bank, tileset, permission
	db BANK(RuinsofAlphKabutoWordRoom_SecondMapHeader), $22, 7

	; second map header
	dw RuinsofAlphKabutoWordRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x94223

RuinsofAlphOmanyteWordRoom_MapHeader: ; 0x94223
	; bank, tileset, permission
	db BANK(RuinsofAlphOmanyteWordRoom_SecondMapHeader), $23, 7

	; second map header
	dw RuinsofAlphOmanyteWordRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x9422c

RuinsofAlphAerodactylWordRoom_MapHeader: ; 0x9422c
	; bank, tileset, permission
	db BANK(RuinsofAlphAerodactylWordRoom_SecondMapHeader), $24, 7

	; second map header
	dw RuinsofAlphAerodactylWordRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $9, $28, 17, 1
; 0x94235

UnionCave1F_MapHeader: ; 0x94235
	; bank, tileset, permission
	db BANK(UnionCave1F_SecondMapHeader), $18, 4

	; second map header
	dw UnionCave1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $a, $28, 18, 3
; 0x9423e

UnionCaveB1F_MapHeader: ; 0x9423e
	; bank, tileset, permission
	db BANK(UnionCaveB1F_SecondMapHeader), $18, 4

	; second map header
	dw UnionCaveB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $a, $28, 18, 3
; 0x94247

UnionCaveB2F_MapHeader: ; 0x94247
	; bank, tileset, permission
	db BANK(UnionCaveB2F_SecondMapHeader), $18, 4

	; second map header
	dw UnionCaveB2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $a, $28, 18, 1
; 0x94250

SlowpokeWellB1F_MapHeader: ; 0x94250
	; bank, tileset, permission
	db BANK(SlowpokeWellB1F_SecondMapHeader), $18, 4

	; second map header
	dw SlowpokeWellB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $d, $33, 18, 3
; 0x94259

SlowpokeWellB2F_MapHeader: ; 0x94259
	; bank, tileset, permission
	db BANK(SlowpokeWellB2F_SecondMapHeader), $18, 4

	; second map header
	dw SlowpokeWellB2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $d, $33, 18, 3
; 0x94262

OlivineLighthouse1F_MapHeader: ; 0x94262
	; bank, tileset, permission
	db BANK(OlivineLighthouse1F_SecondMapHeader), $13, 7

	; second map header
	dw OlivineLighthouse1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1c, $44, 1, 1
; 0x9426b

OlivineLighthouse2F_MapHeader: ; 0x9426b
	; bank, tileset, permission
	db BANK(OlivineLighthouse2F_SecondMapHeader), $13, 7

	; second map header
	dw OlivineLighthouse2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1c, $44, 1, 1
; 0x94274

OlivineLighthouse3F_MapHeader: ; 0x94274
	; bank, tileset, permission
	db BANK(OlivineLighthouse3F_SecondMapHeader), $13, 7

	; second map header
	dw OlivineLighthouse3F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1c, $44, 1, 1
; 0x9427d

OlivineLighthouse4F_MapHeader: ; 0x9427d
	; bank, tileset, permission
	db BANK(OlivineLighthouse4F_SecondMapHeader), $13, 7

	; second map header
	dw OlivineLighthouse4F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1c, $44, 1, 1
; 0x94286

OlivineLighthouse5F_MapHeader: ; 0x94286
	; bank, tileset, permission
	db BANK(OlivineLighthouse5F_SecondMapHeader), $13, 7

	; second map header
	dw OlivineLighthouse5F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1c, $44, 1, 1
; 0x9428f

OlivineLighthouse6F_MapHeader: ; 0x9428f
	; bank, tileset, permission
	db BANK(OlivineLighthouse6F_SecondMapHeader), $13, 7

	; second map header
	dw OlivineLighthouse6F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1c, $2d, 1, 1
; 0x94298

MahoganyMart1F_MapHeader: ; 0x94298
	; bank, tileset, permission
	db BANK(MahoganyMart1F_SecondMapHeader), $10, 3

	; second map header
	dw MahoganyMart1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $24, $64, 17, 1
; 0x942a1

TeamRocketBaseB1F_MapHeader: ; 0x942a1
	; bank, tileset, permission
	db $25, $1c, 7

	; second map header
	dw TeamRocketBaseB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $24, $48, 17, 1
; 0x942aa

TeamRocketBaseB2F_MapHeader: ; 0x942aa
	; bank, tileset, permission
	db $25, $b, 7

	; second map header
	dw TeamRocketBaseB2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $24, $48, 17, 1
; 0x942b3

TeamRocketBaseB3F_MapHeader: ; 0x942b3
	; bank, tileset, permission
	db $25, $b, 7

	; second map header
	dw TeamRocketBaseB3F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $24, $48, 17, 1
; 0x942bc

IlexForest_MapHeader: ; 0x942bc
	; bank, tileset, permission
	db $25, $1f, 4

	; second map header
	dw IlexForest_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $e, $28, 2, 4
; 0x942c5

WarehouseEntrance_MapHeader: ; 0x942c5
	; bank, tileset, permission
	db BANK(WarehouseEntrance_SecondMapHeader), $8, 7

	; second map header
	dw WarehouseEntrance_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $28, 17, 1
; 0x942ce

UndergroundPathSwitchRoomEntrances_MapHeader: ; 0x942ce
	; bank, tileset, permission
	db $25, $f, 7

	; second map header
	dw UndergroundPathSwitchRoomEntrances_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $28, 17, 1
; 0x942d7

GoldenrodDeptStoreB1F_MapHeader: ; 0x942d7
	; bank, tileset, permission
	db $25, $1c, 7

	; second map header
	dw GoldenrodDeptStoreB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 17, 1
; 0x942e0

UndergroundWarehouse_MapHeader: ; 0x942e0
	; bank, tileset, permission
	db $25, $1c, 7

	; second map header
	dw UndergroundWarehouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $28, 17, 1
; 0x942e9

MountMortar1FOutside_MapHeader: ; 0x942e9
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw MountMortar1FOutside_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $23, $28, 18, 3
; 0x942f2

MountMortar1FInside_MapHeader: ; 0x942f2
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw MountMortar1FInside_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $23, $28, 18, 3
; 0x942fb

MountMortar2FInside_MapHeader: ; 0x942fb
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw MountMortar2FInside_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $23, $28, 18, 3
; 0x94304

MountMortarB1F_MapHeader: ; 0x94304
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw MountMortarB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $23, $28, 18, 3
; 0x9430d

IcePath1F_MapHeader: ; 0x9430d
	; bank, tileset, permission
	db $25, $1d, 4

	; second map header
	dw IcePath1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $28, $33, 18, 5
; 0x94316

IcePathB1F_MapHeader: ; 0x94316
	; bank, tileset, permission
	db $25, $1d, 4

	; second map header
	dw IcePathB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $28, $33, 18, 5
; 0x9431f

IcePathB2FMahoganySide_MapHeader: ; 0x9431f
	; bank, tileset, permission
	db $25, $1d, 4

	; second map header
	dw IcePathB2FMahoganySide_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $28, $33, 18, 5
; 0x94328

IcePathB2FBlackthornSide_MapHeader: ; 0x94328
	; bank, tileset, permission
	db $25, $1d, 4

	; second map header
	dw IcePathB2FBlackthornSide_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $28, $33, 18, 5
; 0x94331

IcePathB3F_MapHeader: ; 0x94331
	; bank, tileset, permission
	db $25, $1d, 4

	; second map header
	dw IcePathB3F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $28, $33, 18, 5
; 0x9433a

WhirlIslandNW_MapHeader: ; 0x9433a
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw WhirlIslandNW_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1f, $28, 20, 10
; 0x94343

WhirlIslandNE_MapHeader: ; 0x94343
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw WhirlIslandNE_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1f, $28, 20, 10
; 0x9434c

WhirlIslandSW_MapHeader: ; 0x9434c
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw WhirlIslandSW_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1f, $28, 20, 10
; 0x94355

WhirlIslandCave_MapHeader: ; 0x94355
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw WhirlIslandCave_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1f, $28, 20, 10
; 0x9435e

WhirlIslandSE_MapHeader: ; 0x9435e
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw WhirlIslandSE_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1f, $28, 20, 10
; 0x94367

WhirlIslandB1F_MapHeader: ; 0x94367
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw WhirlIslandB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1f, $28, 20, 10
; 0x94370

WhirlIslandB2F_MapHeader: ; 0x94370
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw WhirlIslandB2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1f, $28, 20, 10
; 0x94379

WhirlIslandLugiaChamber_MapHeader: ; 0x94379
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw WhirlIslandLugiaChamber_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1f, $28, 20, 10
; 0x94382

SilverCaveRoom1_MapHeader: ; 0x94382
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw SilverCaveRoom1_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2e, $44, 20, 3
; 0x9438b

SilverCaveRoom2_MapHeader: ; 0x9438b
	; bank, tileset, permission
	db BANK(SilverCaveRoom2_SecondMapHeader), $18, 4

	; second map header
	dw SilverCaveRoom2_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2e, $44, 18, 3
; 0x94394

SilverCaveRoom3_MapHeader: ; 0x94394
	; bank, tileset, permission
	db BANK(SilverCaveRoom3_SecondMapHeader), $18, 4

	; second map header
	dw SilverCaveRoom3_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2e, $44, 17, 3
; 0x9439d

SilverCaveItemRooms_MapHeader: ; 0x9439d
	; bank, tileset, permission
	db BANK(SilverCaveItemRooms_SecondMapHeader), $18, 4

	; second map header
	dw SilverCaveItemRooms_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2e, $44, 18, 3
; 0x943a6

DarkCaveVioletEntrance_MapHeader: ; 0x943a6
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw DarkCaveVioletEntrance_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2c, $33, 20, 3
; 0x943af

DarkCaveBlackthornEntrance_MapHeader: ; 0x943af
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw DarkCaveBlackthornEntrance_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2c, $33, 20, 3
; 0x943b8

DragonsDen1F_MapHeader: ; 0x943b8
	; bank, tileset, permission
	db BANK(DragonsDen1F_SecondMapHeader), $18, 4

	; second map header
	dw DragonsDen1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2a, $49, 18, 5
; 0x943c1

DragonsDenB1F_MapHeader: ; 0x943c1
	; bank, tileset, permission
	db BANK(DragonsDenB1F_SecondMapHeader), $1, 4

	; second map header
	dw DragonsDenB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2a, $49, 18, 5
; 0x943ca

DragonShrine_MapHeader: ; 0x943ca
	; bank, tileset, permission
	db $25, $a, 3

	; second map header
	dw DragonShrine_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2a, $49, 18, 1
; 0x943d3

TohjoFalls_MapHeader: ; 0x943d3
	; bank, tileset, permission
	db BANK(TohjoFalls_SecondMapHeader), $18, 4

	; second map header
	dw TohjoFalls_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5d, $28, 18, 3
; 0x943dc

DiglettsCave_MapHeader: ; 0x943dc
	; bank, tileset, permission
	db BANK(DiglettsCave_SecondMapHeader), $18, 4

	; second map header
	dw DiglettsCave_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3e, $10, 18, 1
; 0x943e5

MountMoon_MapHeader: ; 0x943e5
	; bank, tileset, permission
	db BANK(MountMoon_SecondMapHeader), $18, 4

	; second map header
	dw MountMoon_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $35, $10, 18, 1
; 0x943ee

Underground_MapHeader: ; 0x943ee
	; bank, tileset, permission
	db $25, $1c, 6

	; second map header
	dw Underground_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3b, $10, 2, 1
; 0x943f7

RockTunnel1F_MapHeader: ; 0x943f7
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw RockTunnel1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $42, $10, 20, 1
; 0x94400

RockTunnelB1F_MapHeader: ; 0x94400
	; bank, tileset, permission
	db $25, $1e, 4

	; second map header
	dw RockTunnelB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $42, $10, 20, 1
; 0x94409

SafariZoneFuchsiaGateBeta_MapHeader: ; 0x94409
	; bank, tileset, permission
	db BANK(SafariZoneFuchsiaGateBeta_SecondMapHeader), $8, 3

	; second map header
	dw SafariZoneFuchsiaGateBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $15, 1, 1
; 0x94412

SafariZoneBeta_MapHeader: ; 0x94412
	; bank, tileset, permission
	db BANK(SafariZoneBeta_SecondMapHeader), $19, 4

	; second map header
	dw SafariZoneBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $22, 0, 1
; 0x9441b

VictoryRoad_MapHeader: ; 0x9441b
	; bank, tileset, permission
	db BANK(VictoryRoad_SecondMapHeader), $18, 4

	; second map header
	dw VictoryRoad_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $58, $4f, 18, 1
; 0x94424

EcruteakHouse_MapHeader: ; 0x94424
	; bank, tileset, permission
	db BANK(EcruteakHouse_SecondMapHeader), $17, 3

	; second map header
	dw EcruteakHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $16, $2c, 1, 1
; 0x9442d

WiseTriosRoom_MapHeader: ; 0x9442d
	; bank, tileset, permission
	db BANK(WiseTriosRoom_SecondMapHeader), $10, 3

	; second map header
	dw WiseTriosRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $16, $2c, 17, 1
; 0x94436

EcruteakPokeCenter1F_MapHeader: ; 0x94436
	; bank, tileset, permission
	db BANK(EcruteakPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw EcruteakPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $16, $9, 1, 1
; 0x9443f

EcruteakLugiaSpeechHouse_MapHeader: ; 0x9443f
	; bank, tileset, permission
	db BANK(EcruteakLugiaSpeechHouse_SecondMapHeader), $10, 3

	; second map header
	dw EcruteakLugiaSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $16, $2c, 1, 1
; 0x94448

DanceTheatre_MapHeader: ; 0x94448
	; bank, tileset, permission
	db BANK(DanceTheatre_SecondMapHeader), $10, 3

	; second map header
	dw DanceTheatre_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $16, $57, 1, 1
; 0x94451

EcruteakMart_MapHeader: ; 0x94451
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw EcruteakMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $16, $2c, 1, 1
; 0x9445a

EcruteakGym_MapHeader: ; 0x9445a
	; bank, tileset, permission
	db BANK(EcruteakGym_SecondMapHeader), $17, 3

	; second map header
	dw EcruteakGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $16, $1b, 17, 1
; 0x94463

EcruteakItemfinderHouse_MapHeader: ; 0x94463
	; bank, tileset, permission
	db BANK(EcruteakItemfinderHouse_SecondMapHeader), $10, 3

	; second map header
	dw EcruteakItemfinderHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $16, $2c, 1, 1
; 0x9446c

EcruteakCity_MapHeader: ; 0x9446c
	; bank, tileset, permission
	db BANK(EcruteakCity_SecondMapHeader), $1, 1

	; second map header
	dw EcruteakCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $16, $2c, 0, 4
; 0x94475

BlackthornGym1F_MapHeader: ; 0x94475
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw BlackthornGym1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $29, $1b, 17, 1
; 0x9447e

BlackthornGym2F_MapHeader: ; 0x9447e
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw BlackthornGym2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $29, $1b, 17, 1
; 0x94487

BlackthornDragonSpeechHouse_MapHeader: ; 0x94487
	; bank, tileset, permission
	db BANK(BlackthornDragonSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw BlackthornDragonSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $29, $25, 1, 1
; 0x94490

BlackthornDodrioTradeHouse_MapHeader: ; 0x94490
	; bank, tileset, permission
	db BANK(BlackthornDodrioTradeHouse_SecondMapHeader), $5, 3

	; second map header
	dw BlackthornDodrioTradeHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $29, $25, 1, 1
; 0x94499

BlackthornMart_MapHeader: ; 0x94499
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw BlackthornMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $29, $25, 1, 1
; 0x944a2

BlackthornPokeCenter1F_MapHeader: ; 0x944a2
	; bank, tileset, permission
	db BANK(BlackthornPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw BlackthornPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $29, $9, 1, 1
; 0x944ab

MoveDeletersHouse_MapHeader: ; 0x944ab
	; bank, tileset, permission
	db BANK(MoveDeletersHouse_SecondMapHeader), $5, 3

	; second map header
	dw MoveDeletersHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $29, $25, 1, 1
; 0x944b4

Route45_MapHeader: ; 0x944b4
	; bank, tileset, permission
	db BANK(Route45_SecondMapHeader), $1, 2

	; second map header
	dw Route45_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2b, $35, 0, 9
; 0x944bd

Route46_MapHeader: ; 0x944bd
	; bank, tileset, permission
	db BANK(Route46_SecondMapHeader), $1, 2

	; second map header
	dw Route46_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2d, $35, 0, 1
; 0x944c6

BlackthornCity_MapHeader: ; 0x944c6
	; bank, tileset, permission
	db BANK(BlackthornCity_SecondMapHeader), $1, 1

	; second map header
	dw BlackthornCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $29, $25, 0, 4
; 0x944cf

CinnabarPokeCenter1F_MapHeader: ; 0x944cf
	; bank, tileset, permission
	db BANK(CinnabarPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw CinnabarPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $55, $9, 1, 1
; 0x944d8

CinnabarPokeCenter2FBeta_MapHeader: ; 0x944d8
	; bank, tileset, permission
	db BANK(CinnabarPokeCenter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw CinnabarPokeCenter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $55, $9, 1, 1
; 0x944e1

Route19FuchsiaGate_MapHeader: ; 0x944e1
	; bank, tileset, permission
	db BANK(Route19FuchsiaGate_SecondMapHeader), $8, 6

	; second map header
	dw Route19FuchsiaGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $52, $3, 1, 1
; 0x944ea

SeafoamGym_MapHeader: ; 0x944ea
	; bank, tileset, permission
	db BANK(SeafoamGym_SecondMapHeader), $18, 3

	; second map header
	dw SeafoamGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $54, $1b, 17, 1
; 0x944f3

Route19_MapHeader: ; 0x944f3
	; bank, tileset, permission
	db BANK(Route19_SecondMapHeader), $3, 2

	; second map header
	dw Route19_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $52, $3, 0, 1
; 0x944fc

Route20_MapHeader: ; 0x944fc
	; bank, tileset, permission
	db BANK(Route20_SecondMapHeader), $3, 2

	; second map header
	dw Route20_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $53, $3, 0, 2
; 0x94505

Route21_MapHeader: ; 0x94505
	; bank, tileset, permission
	db BANK(Route21_SecondMapHeader), $3, 2

	; second map header
	dw Route21_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $56, $3, 0, 2
; 0x9450e

CinnabarIsland_MapHeader: ; 0x9450e
	; bank, tileset, permission
	db BANK(CinnabarIsland_SecondMapHeader), $3, 1

	; second map header
	dw CinnabarIsland_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $55, $15, 0, 2
; 0x94517

CeruleanGymBadgeSpeechHouse_MapHeader: ; 0x94517
	; bank, tileset, permission
	db BANK(CeruleanGymBadgeSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw CeruleanGymBadgeSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $37, $15, 1, 1
; 0x94520

CeruleanPoliceStation_MapHeader: ; 0x94520
	; bank, tileset, permission
	db BANK(CeruleanPoliceStation_SecondMapHeader), $5, 3

	; second map header
	dw CeruleanPoliceStation_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $37, $15, 1, 1
; 0x94529

CeruleanTradeSpeechHouse_MapHeader: ; 0x94529
	; bank, tileset, permission
	db BANK(CeruleanTradeSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw CeruleanTradeSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $37, $15, 1, 1
; 0x94532

CeruleanPokeCenter1F_MapHeader: ; 0x94532
	; bank, tileset, permission
	db BANK(CeruleanPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw CeruleanPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $37, $9, 1, 1
; 0x9453b

CeruleanPokeCenter2FBeta_MapHeader: ; 0x9453b
	; bank, tileset, permission
	db BANK(CeruleanPokeCenter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw CeruleanPokeCenter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $37, $9, 1, 1
; 0x94544

CeruleanGym_MapHeader: ; 0x94544
	; bank, tileset, permission
	db BANK(CeruleanGym_SecondMapHeader), $9, 3

	; second map header
	dw CeruleanGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $37, $1b, 17, 0
; 0x9454d

CeruleanMart_MapHeader: ; 0x9454d
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw CeruleanMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $37, $15, 1, 1
; 0x94556

Route10PokeCenter1F_MapHeader: ; 0x94556
	; bank, tileset, permission
	db BANK(Route10PokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw Route10PokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $43, $9, 1, 1
; 0x9455f

Route10PokeCenter2FBeta_MapHeader: ; 0x9455f
	; bank, tileset, permission
	db BANK(Route10PokeCenter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw Route10PokeCenter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $43, $9, 1, 1
; 0x94568

PowerPlant_MapHeader: ; 0x94568
	; bank, tileset, permission
	db $25, $b, 3

	; second map header
	dw PowerPlant_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $44, $15, 1, 1
; 0x94571

BillsHouse_MapHeader: ; 0x94571
	; bank, tileset, permission
	db BANK(BillsHouse_SecondMapHeader), $5, 3

	; second map header
	dw BillsHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $39, $15, 1, 1
; 0x9457a

Route4_MapHeader: ; 0x9457a
	; bank, tileset, permission
	db BANK(Route4_SecondMapHeader), $3, 2

	; second map header
	dw Route4_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $36, $3, 0, 0
; 0x94583

Route9_MapHeader: ; 0x94583
	; bank, tileset, permission
	db BANK(Route9_SecondMapHeader), $3, 2

	; second map header
	dw Route9_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $41, $3, 0, 3
; 0x9458c

Route10North_MapHeader: ; 0x9458c
	; bank, tileset, permission
	db BANK(Route10North_SecondMapHeader), $3, 2

	; second map header
	dw Route10North_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $43, $3, 0, 3
; 0x94595

Route24_MapHeader: ; 0x94595
	; bank, tileset, permission
	db BANK(Route24_SecondMapHeader), $3, 2

	; second map header
	dw Route24_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $38, $3, 0, 3
; 0x9459e

Route25_MapHeader: ; 0x9459e
	; bank, tileset, permission
	db BANK(Route25_SecondMapHeader), $3, 2

	; second map header
	dw Route25_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $39, $3, 0, 3
; 0x945a7

CeruleanCity_MapHeader: ; 0x945a7
	; bank, tileset, permission
	db BANK(CeruleanCity_SecondMapHeader), $3, 1

	; second map header
	dw CeruleanCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $37, $15, 0, 0
; 0x945b0

AzaleaPokeCenter1F_MapHeader: ; 0x945b0
	; bank, tileset, permission
	db BANK(AzaleaPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw AzaleaPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $c, $9, 1, 1
; 0x945b9

CharcoalKiln_MapHeader: ; 0x945b9
	; bank, tileset, permission
	db BANK(CharcoalKiln_SecondMapHeader), $5, 3

	; second map header
	dw CharcoalKiln_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $c, $25, 1, 1
; 0x945c2

AzaleaMart_MapHeader: ; 0x945c2
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw AzaleaMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $c, $25, 1, 1
; 0x945cb

KurtsHouse_MapHeader: ; 0x945cb
	; bank, tileset, permission
	db BANK(KurtsHouse_SecondMapHeader), $10, 3

	; second map header
	dw KurtsHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $c, $25, 1, 1
; 0x945d4

AzaleaGym_MapHeader: ; 0x945d4
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw AzaleaGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $c, $1b, 17, 1
; 0x945dd

Route33_MapHeader: ; 0x945dd
	; bank, tileset, permission
	db BANK(Route33_SecondMapHeader), $2, 2

	; second map header
	dw Route33_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $b, $2b, 0, 1
; 0x945e6

AzaleaTown_MapHeader: ; 0x945e6
	; bank, tileset, permission
	db BANK(AzaleaTown_SecondMapHeader), $2, 1

	; second map header
	dw AzaleaTown_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $c, $25, 0, 1
; 0x945ef

LakeofRageHiddenPowerHouse_MapHeader: ; 0x945ef
	; bank, tileset, permission
	db BANK(LakeofRageHiddenPowerHouse_SecondMapHeader), $5, 3

	; second map header
	dw LakeofRageHiddenPowerHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $26, $45, 1, 1
; 0x945f8

LakeofRageMagikarpHouse_MapHeader: ; 0x945f8
	; bank, tileset, permission
	db BANK(LakeofRageMagikarpHouse_SecondMapHeader), $5, 3

	; second map header
	dw LakeofRageMagikarpHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $26, $45, 1, 1
; 0x94601

Route43MahoganyGate_MapHeader: ; 0x94601
	; bank, tileset, permission
	db BANK(Route43MahoganyGate_SecondMapHeader), $8, 6

	; second map header
	dw Route43MahoganyGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $25, $45, 1, 1
; 0x9460a

Route43Gate_MapHeader: ; 0x9460a
	; bank, tileset, permission
	db BANK(Route43Gate_SecondMapHeader), $8, 6

	; second map header
	dw Route43Gate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $25, $45, 1, 1
; 0x94613

Route43_MapHeader: ; 0x94613
	; bank, tileset, permission
	db BANK(Route43_SecondMapHeader), $1, 2

	; second map header
	dw Route43_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $25, $45, 0, 4
; 0x9461c

LakeofRage_MapHeader: ; 0x9461c
	; bank, tileset, permission
	db BANK(LakeofRage_SecondMapHeader), $1, 1

	; second map header
	dw LakeofRage_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $26, $45, 0, 8
; 0x94625

Route32_MapHeader: ; 0x94625
	; bank, tileset, permission
	db BANK(Route32_SecondMapHeader), $1, 2

	; second map header
	dw Route32_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $8, $2b, 0, 11
; 0x9462e

Route35_MapHeader: ; 0x9462e
	; bank, tileset, permission
	db BANK(Route35_SecondMapHeader), $1, 2

	; second map header
	dw Route35_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $12, $35, 0, 4
; 0x94637

Route36_MapHeader: ; 0x94637
	; bank, tileset, permission
	db BANK(Route36_SecondMapHeader), $1, 2

	; second map header
	dw Route36_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $14, $35, 0, 1
; 0x94640

Route37_MapHeader: ; 0x94640
	; bank, tileset, permission
	db BANK(Route37_SecondMapHeader), $1, 2

	; second map header
	dw Route37_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $15, $35, 0, 1
; 0x94649

VioletCity_MapHeader: ; 0x94649
	; bank, tileset, permission
	db BANK(VioletCity_SecondMapHeader), $1, 1

	; second map header
	dw VioletCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $6, $2d, 0, 4
; 0x94652

VioletMart_MapHeader: ; 0x94652
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw VioletMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $6, $2d, 1, 1
; 0x9465b

VioletGym_MapHeader: ; 0x9465b
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw VioletGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $6, $1b, 17, 1
; 0x94664

EarlsPokemonAcademy_MapHeader: ; 0x94664
	; bank, tileset, permission
	db $25, $a, 3

	; second map header
	dw EarlsPokemonAcademy_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $6, $2d, 1, 1
; 0x9466d

VioletNicknameSpeechHouse_MapHeader: ; 0x9466d
	; bank, tileset, permission
	db BANK(VioletNicknameSpeechHouse_SecondMapHeader), $10, 3

	; second map header
	dw VioletNicknameSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $6, $2d, 1, 1
; 0x94676

VioletPokeCenter1F_MapHeader: ; 0x94676
	; bank, tileset, permission
	db BANK(VioletPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw VioletPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $6, $9, 1, 1
; 0x9467f

VioletOnixTradeHouse_MapHeader: ; 0x9467f
	; bank, tileset, permission
	db BANK(VioletOnixTradeHouse_SecondMapHeader), $10, 3

	; second map header
	dw VioletOnixTradeHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $6, $2d, 1, 1
; 0x94688

Route32RuinsofAlphGate_MapHeader: ; 0x94688
	; bank, tileset, permission
	db BANK(Route32RuinsofAlphGate_SecondMapHeader), $8, 6

	; second map header
	dw Route32RuinsofAlphGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $8, $2b, 1, 1
; 0x94691

Route32PokeCenter1F_MapHeader: ; 0x94691
	; bank, tileset, permission
	db BANK(Route32PokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw Route32PokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $8, $9, 1, 1
; 0x9469a

Route35Goldenrodgate_MapHeader: ; 0x9469a
	; bank, tileset, permission
	db BANK(Route35Goldenrodgate_SecondMapHeader), $8, 6

	; second map header
	dw Route35Goldenrodgate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $12, $35, 1, 1
; 0x946a3

Route35NationalParkgate_MapHeader: ; 0x946a3
	; bank, tileset, permission
	db BANK(Route35NationalParkgate_SecondMapHeader), $8, 3

	; second map header
	dw Route35NationalParkgate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $12, $3d, 1, 1
; 0x946ac

Route36RuinsofAlphgate_MapHeader: ; 0x946ac
	; bank, tileset, permission
	db BANK(Route36RuinsofAlphgate_SecondMapHeader), $8, 6

	; second map header
	dw Route36RuinsofAlphgate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $14, $35, 1, 1
; 0x946b5

Route36NationalParkgate_MapHeader: ; 0x946b5
	; bank, tileset, permission
	db BANK(Route36NationalParkgate_SecondMapHeader), $8, 3

	; second map header
	dw Route36NationalParkgate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $14, $3d, 1, 1
; 0x946be

Route34_MapHeader: ; 0x946be
	; bank, tileset, permission
	db BANK(Route34_SecondMapHeader), $2, 2

	; second map header
	dw Route34_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $f, $35, 0, 1
; 0x946c7

GoldenrodCity_MapHeader: ; 0x946c7
	; bank, tileset, permission
	db BANK(GoldenrodCity_SecondMapHeader), $2, 1

	; second map header
	dw GoldenrodCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 0, 1
; 0x946d0

GoldenrodGym_MapHeader: ; 0x946d0
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw GoldenrodGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $1b, 17, 1
; 0x946d9

GoldenrodBikeShop_MapHeader: ; 0x946d9
	; bank, tileset, permission
	db BANK(GoldenrodBikeShop_SecondMapHeader), $12, 3

	; second map header
	dw GoldenrodBikeShop_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x946e2

GoldenrodHappinessRater_MapHeader: ; 0x946e2
	; bank, tileset, permission
	db BANK(GoldenrodHappinessRater_SecondMapHeader), $5, 3

	; second map header
	dw GoldenrodHappinessRater_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x946eb

GoldenrodBillsHouse_MapHeader: ; 0x946eb
	; bank, tileset, permission
	db BANK(GoldenrodBillsHouse_SecondMapHeader), $5, 3

	; second map header
	dw GoldenrodBillsHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x946f4

GoldenrodMagnetTrainStation_MapHeader: ; 0x946f4
	; bank, tileset, permission
	db BANK(GoldenrodMagnetTrainStation_SecondMapHeader), $11, 3

	; second map header
	dw GoldenrodMagnetTrainStation_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x946fd

GoldenrodFlowerShop_MapHeader: ; 0x946fd
	; bank, tileset, permission
	db BANK(GoldenrodFlowerShop_SecondMapHeader), $5, 3

	; second map header
	dw GoldenrodFlowerShop_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x94706

GoldenrodPPSpeechHouse_MapHeader: ; 0x94706
	; bank, tileset, permission
	db BANK(GoldenrodPPSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw GoldenrodPPSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x9470f

GoldenrodNameRatersHouse_MapHeader: ; 0x9470f
	; bank, tileset, permission
	db BANK(GoldenrodNameRatersHouse_SecondMapHeader), $5, 3

	; second map header
	dw GoldenrodNameRatersHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x94718

GoldenrodDeptStore1F_MapHeader: ; 0x94718
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw GoldenrodDeptStore1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x94721

GoldenrodDeptStore2F_MapHeader: ; 0x94721
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw GoldenrodDeptStore2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x9472a

GoldenrodDeptStore3F_MapHeader: ; 0x9472a
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw GoldenrodDeptStore3F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x94733

GoldenrodDeptStore4F_MapHeader: ; 0x94733
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw GoldenrodDeptStore4F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x9473c

GoldenrodDeptStore5F_MapHeader: ; 0x9473c
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw GoldenrodDeptStore5F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x94745

GoldenrodDeptStore6F_MapHeader: ; 0x94745
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw GoldenrodDeptStore6F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x9474e

GoldenrodDeptStoreElevator_MapHeader: ; 0x9474e
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw GoldenrodDeptStoreElevator_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x94757

GoldenrodDeptStoreRoof_MapHeader: ; 0x94757
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw GoldenrodDeptStoreRoof_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $3d, 1, 1
; 0x94760

GoldenrodGameCorner_MapHeader: ; 0x94760
	; bank, tileset, permission
	db $25, $e, 3

	; second map header
	dw GoldenrodGameCorner_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $12, 1, 1
; 0x94769

GoldenrodPokeCenter1F_MapHeader: ; 0x94769
	; bank, tileset, permission
	db BANK(GoldenrodPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw GoldenrodPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $9, 1, 1
; 0x94772

GoldenrodPokeComCenter2FMobile_MapHeader: ; 0x94772
	; bank, tileset, permission
	db BANK(GoldenrodPokeComCenter2FMobile_SecondMapHeader), $15, 3

	; second map header
	dw GoldenrodPokeComCenter2FMobile_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $10, $9, 1, 1
; 0x9477b

IlexForestAzaleaGate_MapHeader: ; 0x9477b
	; bank, tileset, permission
	db BANK(IlexForestAzaleaGate_SecondMapHeader), $8, 6

	; second map header
	dw IlexForestAzaleaGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $f, $35, 1, 1
; 0x94784

Route34IlexForestGate_MapHeader: ; 0x94784
	; bank, tileset, permission
	db BANK(Route34IlexForestGate_SecondMapHeader), $8, 6

	; second map header
	dw Route34IlexForestGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $f, $35, 1, 1
; 0x9478d

DayCare_MapHeader: ; 0x9478d
	; bank, tileset, permission
	db BANK(DayCare_SecondMapHeader), $5, 3

	; second map header
	dw DayCare_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $f, $25, 1, 1
; 0x94796

Route6_MapHeader: ; 0x94796
	; bank, tileset, permission
	db BANK(Route6_SecondMapHeader), $3, 2

	; second map header
	dw Route6_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3c, $3, 0, 4
; 0x9479f

Route11_MapHeader: ; 0x9479f
	; bank, tileset, permission
	db BANK(Route11_SecondMapHeader), $3, 2

	; second map header
	dw Route11_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $49, $4, 0, 1
; 0x947a8

VermilionCity_MapHeader: ; 0x947a8
	; bank, tileset, permission
	db BANK(VermilionCity_SecondMapHeader), $3, 1

	; second map header
	dw VermilionCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $3e, 0, 2
; 0x947b1

VermilionHouseFishingSpeechHouse_MapHeader: ; 0x947b1
	; bank, tileset, permission
	db BANK(VermilionHouseFishingSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw VermilionHouseFishingSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $3e, 1, 1
; 0x947ba

VermilionPokeCenter1F_MapHeader: ; 0x947ba
	; bank, tileset, permission
	db BANK(VermilionPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw VermilionPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $9, 1, 1
; 0x947c3

VermilionPokeCenter2FBeta_MapHeader: ; 0x947c3
	; bank, tileset, permission
	db BANK(VermilionPokeCenter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw VermilionPokeCenter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $3e, 1, 1
; 0x947cc

PokemonFanClub_MapHeader: ; 0x947cc
	; bank, tileset, permission
	db BANK(PokemonFanClub_SecondMapHeader), $5, 3

	; second map header
	dw PokemonFanClub_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $3e, 1, 1
; 0x947d5

VermilionMagnetTrainSpeechHouse_MapHeader: ; 0x947d5
	; bank, tileset, permission
	db BANK(VermilionMagnetTrainSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw VermilionMagnetTrainSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $3e, 1, 1
; 0x947de

VermilionMart_MapHeader: ; 0x947de
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw VermilionMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $3e, 1, 1
; 0x947e7

VermilionHouseDiglettsCaveSpeechHouse_MapHeader: ; 0x947e7
	; bank, tileset, permission
	db BANK(VermilionHouseDiglettsCaveSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw VermilionHouseDiglettsCaveSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $3e, 1, 1
; 0x947f0

VermilionGym_MapHeader: ; 0x947f0
	; bank, tileset, permission
	db $25, $e, 3

	; second map header
	dw VermilionGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $1b, 17, 1
; 0x947f9

Route6SaffronGate_MapHeader: ; 0x947f9
	; bank, tileset, permission
	db BANK(Route6SaffronGate_SecondMapHeader), $8, 6

	; second map header
	dw Route6SaffronGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3c, $3, 1, 1
; 0x94802

Route6UndergroundEntrance_MapHeader: ; 0x94802
	; bank, tileset, permission
	db BANK(Route6UndergroundEntrance_SecondMapHeader), $8, 6

	; second map header
	dw Route6UndergroundEntrance_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3c, $3, 1, 1
; 0x9480b

Route1_MapHeader: ; 0x9480b
	; bank, tileset, permission
	db BANK(Route1_SecondMapHeader), $3, 2

	; second map header
	dw Route1_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $30, $2, 0, 1
; 0x94814

PalletTown_MapHeader: ; 0x94814
	; bank, tileset, permission
	db BANK(PalletTown_SecondMapHeader), $3, 1

	; second map header
	dw PalletTown_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2f, $1c, 0, 2
; 0x9481d

RedsHouse1F_MapHeader: ; 0x9481d
	; bank, tileset, permission
	db BANK(RedsHouse1F_SecondMapHeader), $6, 3

	; second map header
	dw RedsHouse1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2f, $1c, 1, 1
; 0x94826

RedsHouse2F_MapHeader: ; 0x94826
	; bank, tileset, permission
	db BANK(RedsHouse2F_SecondMapHeader), $6, 3

	; second map header
	dw RedsHouse2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2f, $1c, 1, 1
; 0x9482f

BluesHouse_MapHeader: ; 0x9482f
	; bank, tileset, permission
	db BANK(BluesHouse_SecondMapHeader), $5, 3

	; second map header
	dw BluesHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2f, $1c, 1, 1
; 0x94838

OaksLab_MapHeader: ; 0x94838
	; bank, tileset, permission
	db $25, $a, 3

	; second map header
	dw OaksLab_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2f, $1d, 1, 1
; 0x94841

Route3_MapHeader: ; 0x94841
	; bank, tileset, permission
	db BANK(Route3_SecondMapHeader), $3, 2

	; second map header
	dw Route3_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $34, $3, 0, 1
; 0x9484a

PewterCity_MapHeader: ; 0x9484a
	; bank, tileset, permission
	db BANK(PewterCity_SecondMapHeader), $3, 1

	; second map header
	dw PewterCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $33, $15, 0, 1
; 0x94853

PewterNidoranSpeechHouse_MapHeader: ; 0x94853
	; bank, tileset, permission
	db BANK(PewterNidoranSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw PewterNidoranSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $33, $15, 1, 1
; 0x9485c

PewterGym_MapHeader: ; 0x9485c
	; bank, tileset, permission
	db BANK(PewterGym_SecondMapHeader), $17, 3

	; second map header
	dw PewterGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $33, $1b, 17, 1
; 0x94865

PewterMart_MapHeader: ; 0x94865
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw PewterMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $33, $15, 1, 1
; 0x9486e

PewterPokeCenter1F_MapHeader: ; 0x9486e
	; bank, tileset, permission
	db BANK(PewterPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw PewterPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $33, $9, 1, 1
; 0x94877

PewterPokeCEnter2FBeta_MapHeader: ; 0x94877
	; bank, tileset, permission
	db BANK(PewterPokeCEnter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw PewterPokeCEnter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $33, $15, 1, 1
; 0x94880

PewterSnoozeSpeechHouse_MapHeader: ; 0x94880
	; bank, tileset, permission
	db BANK(PewterSnoozeSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw PewterSnoozeSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $33, $15, 1, 1
; 0x94889

OlivinePort_MapHeader: ; 0x94889
	; bank, tileset, permission
	db BANK(OlivinePort_SecondMapHeader), $9, 2

	; second map header
	dw OlivinePort_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $2d, 0, 2
; 0x94892

VermilionPort_MapHeader: ; 0x94892
	; bank, tileset, permission
	db BANK(VermilionPort_SecondMapHeader), $9, 2

	; second map header
	dw VermilionPort_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $3e, 0, 2
; 0x9489b

FastShip1F_MapHeader: ; 0x9489b
	; bank, tileset, permission
	db BANK(FastShip1F_SecondMapHeader), $13, 3

	; second map header
	dw FastShip1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5f, $36, 1, 1
; 0x948a4

FastShipCabins_NNW_NNE_NE_MapHeader: ; 0x948a4
	; bank, tileset, permission
	db BANK(FastShipCabins_NNW_NNE_NE_SecondMapHeader), $13, 3

	; second map header
	dw FastShipCabins_NNW_NNE_NE_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5f, $36, 1, 1
; 0x948ad

FastShipCabins_SW_SSW_NW_MapHeader: ; 0x948ad
	; bank, tileset, permission
	db BANK(FastShipCabins_SW_SSW_NW_SecondMapHeader), $13, 3

	; second map header
	dw FastShipCabins_SW_SSW_NW_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5f, $36, 1, 1
; 0x948b6

FastShipCabins_SE_SSE_CaptainsCabin_MapHeader: ; 0x948b6
	; bank, tileset, permission
	db BANK(FastShipCabins_SE_SSE_CaptainsCabin_SecondMapHeader), $13, 3

	; second map header
	dw FastShipCabins_SE_SSE_CaptainsCabin_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5f, $36, 1, 1
; 0x948bf

FastShipB1F_MapHeader: ; 0x948bf
	; bank, tileset, permission
	db BANK(FastShipB1F_SecondMapHeader), $13, 3

	; second map header
	dw FastShipB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5f, $36, 1, 1
; 0x948c8

OlivinePortPassage_MapHeader: ; 0x948c8
	; bank, tileset, permission
	db $25, $1c, 3

	; second map header
	dw OlivinePortPassage_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1b, $2d, 1, 1
; 0x948d1

VermilionPortPassage_MapHeader: ; 0x948d1
	; bank, tileset, permission
	db $25, $1c, 3

	; second map header
	dw VermilionPortPassage_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3d, $3e, 1, 1
; 0x948da

MountMoonSquare_MapHeader: ; 0x948da
	; bank, tileset, permission
	db BANK(MountMoonSquare_SecondMapHeader), $3, 2

	; second map header
	dw MountMoonSquare_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $35, $1a, 0, 1
; 0x948e3

MountMoonGiftShop_MapHeader: ; 0x948e3
	; bank, tileset, permission
	db BANK(MountMoonGiftShop_SecondMapHeader), $10, 3

	; second map header
	dw MountMoonGiftShop_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $35, $15, 1, 1
; 0x948ec

TinTowerRoof_MapHeader: ; 0x948ec
	; bank, tileset, permission
	db BANK(TinTowerRoof_SecondMapHeader), $17, 2

	; second map header
	dw TinTowerRoof_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $17, $41, 0, 1
; 0x948f5

Route23_MapHeader: ; 0x948f5
	; bank, tileset, permission
	db BANK(Route23_SecondMapHeader), $3, 1

	; second map header
	dw Route23_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $59, $46, 0, 1
; 0x948fe

IndigoPlateauPokeCenter1F_MapHeader: ; 0x948fe
	; bank, tileset, permission
	db BANK(IndigoPlateauPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw IndigoPlateauPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5a, $46, 1, 1
; 0x94907

WillsRoom_MapHeader: ; 0x94907
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw WillsRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5a, $46, 17, 1
; 0x94910

KogasRoom_MapHeader: ; 0x94910
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw KogasRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5a, $46, 17, 1
; 0x94919

BrunosRoom_MapHeader: ; 0x94919
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw BrunosRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5a, $46, 17, 1
; 0x94922

KarensRoom_MapHeader: ; 0x94922
	; bank, tileset, permission
	db $25, $f, 3

	; second map header
	dw KarensRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5a, $46, 17, 1
; 0x9492b

LancesRoom_MapHeader: ; 0x9492b
	; bank, tileset, permission
	db BANK(LancesRoom_SecondMapHeader), $12, 3

	; second map header
	dw LancesRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5a, $46, 17, 1
; 0x94934

HallOfFame_MapHeader: ; 0x94934
	; bank, tileset, permission
	db $25, $1d, 3

	; second map header
	dw HallOfFame_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5a, $3c, 17, 1
; 0x9493d

Route13_MapHeader: ; 0x9493d
	; bank, tileset, permission
	db BANK(Route13_SecondMapHeader), $3, 2

	; second map header
	dw Route13_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4b, $4, 0, 13
; 0x94946

Route14_MapHeader: ; 0x94946
	; bank, tileset, permission
	db BANK(Route14_SecondMapHeader), $3, 2

	; second map header
	dw Route14_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4c, $4, 0, 1
; 0x9494f

Route15_MapHeader: ; 0x9494f
	; bank, tileset, permission
	db BANK(Route15_SecondMapHeader), $3, 2

	; second map header
	dw Route15_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4d, $4, 0, 1
; 0x94958

Route18_MapHeader: ; 0x94958
	; bank, tileset, permission
	db BANK(Route18_SecondMapHeader), $3, 2

	; second map header
	dw Route18_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $50, $3, 0, 1
; 0x94961

FuchsiaCity_MapHeader: ; 0x94961
	; bank, tileset, permission
	db BANK(FuchsiaCity_SecondMapHeader), $3, 1

	; second map header
	dw FuchsiaCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $16, 0, 8
; 0x9496a

FuchsiaMart_MapHeader: ; 0x9496a
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw FuchsiaMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $16, 1, 1
; 0x94973

SafariZoneMainOffice_MapHeader: ; 0x94973
	; bank, tileset, permission
	db $25, $e, 3

	; second map header
	dw SafariZoneMainOffice_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $16, 1, 1
; 0x9497c

FuchsiaGym_MapHeader: ; 0x9497c
	; bank, tileset, permission
	db $25, $a, 3

	; second map header
	dw FuchsiaGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $1b, 17, 1
; 0x94985

FuchsiaBillSpeechHouse_MapHeader: ; 0x94985
	; bank, tileset, permission
	db BANK(FuchsiaBillSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw FuchsiaBillSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $16, 1, 1
; 0x9498e

FuchsiaPokeCenter1F_MapHeader: ; 0x9498e
	; bank, tileset, permission
	db BANK(FuchsiaPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw FuchsiaPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $9, 1, 1
; 0x94997

FuchsiaPokeCenter2FBeta_MapHeader: ; 0x94997
	; bank, tileset, permission
	db BANK(FuchsiaPokeCenter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw FuchsiaPokeCenter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $16, 1, 1
; 0x949a0

SafariZoneWardensHome_MapHeader: ; 0x949a0
	; bank, tileset, permission
	db BANK(SafariZoneWardensHome_SecondMapHeader), $5, 3

	; second map header
	dw SafariZoneWardensHome_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $51, $16, 1, 1
; 0x949a9

Route15FuchsiaGate_MapHeader: ; 0x949a9
	; bank, tileset, permission
	db BANK(Route15FuchsiaGate_SecondMapHeader), $8, 6

	; second map header
	dw Route15FuchsiaGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4d, $4, 1, 1
; 0x949b2

Route8_MapHeader: ; 0x949b2
	; bank, tileset, permission
	db BANK(Route8_SecondMapHeader), $3, 2

	; second map header
	dw Route8_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $40, $3, 0, 1
; 0x949bb

Route12_MapHeader: ; 0x949bb
	; bank, tileset, permission
	db BANK(Route12_SecondMapHeader), $3, 2

	; second map header
	dw Route12_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4a, $4, 0, 13
; 0x949c4

Route10South_MapHeader: ; 0x949c4
	; bank, tileset, permission
	db BANK(Route10South_SecondMapHeader), $3, 2

	; second map header
	dw Route10South_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $43, $3, 0, 3
; 0x949cd

LavenderTown_MapHeader: ; 0x949cd
	; bank, tileset, permission
	db BANK(LavenderTown_SecondMapHeader), $3, 1

	; second map header
	dw LavenderTown_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $45, $e, 0, 1
; 0x949d6

LavenderPokeCenter1F_MapHeader: ; 0x949d6
	; bank, tileset, permission
	db BANK(LavenderPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw LavenderPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $45, $9, 1, 1
; 0x949df

LavenderPokeCenter2FBeta_MapHeader: ; 0x949df
	; bank, tileset, permission
	db BANK(LavenderPokeCenter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw LavenderPokeCenter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $45, $9, 1, 1
; 0x949e8

MrFujisHouse_MapHeader: ; 0x949e8
	; bank, tileset, permission
	db BANK(MrFujisHouse_SecondMapHeader), $5, 3

	; second map header
	dw MrFujisHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $45, $e, 1, 1
; 0x949f1

LavenderTownSpeechHouse_MapHeader: ; 0x949f1
	; bank, tileset, permission
	db BANK(LavenderTownSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw LavenderTownSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $45, $e, 1, 1
; 0x949fa

LavenderNameRater_MapHeader: ; 0x949fa
	; bank, tileset, permission
	db BANK(LavenderNameRater_SecondMapHeader), $5, 3

	; second map header
	dw LavenderNameRater_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $45, $e, 1, 1
; 0x94a03

LavenderMart_MapHeader: ; 0x94a03
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw LavenderMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $45, $e, 1, 1
; 0x94a0c

SoulHouse_MapHeader: ; 0x94a0c
	; bank, tileset, permission
	db BANK(SoulHouse_SecondMapHeader), $5, 3

	; second map header
	dw SoulHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $45, $e, 1, 1
; 0x94a15

LavRadioTower1F_MapHeader: ; 0x94a15
	; bank, tileset, permission
	db $25, $1b, 3

	; second map header
	dw LavRadioTower1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $46, $e, 1, 1
; 0x94a1e

Route8SaffronGate_MapHeader: ; 0x94a1e
	; bank, tileset, permission
	db BANK(Route8SaffronGate_SecondMapHeader), $8, 6

	; second map header
	dw Route8SaffronGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $40, $3, 1, 1
; 0x94a27

Route12SuperRodHouse_MapHeader: ; 0x94a27
	; bank, tileset, permission
	db BANK(Route12SuperRodHouse_SecondMapHeader), $5, 3

	; second map header
	dw Route12SuperRodHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4a, $15, 1, 1
; 0x94a30

Route28_MapHeader: ; 0x94a30
	; bank, tileset, permission
	db BANK(Route28_SecondMapHeader), $3, 2

	; second map header
	dw Route28_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5e, $46, 0, 4
; 0x94a39

SilverCaveOutside_MapHeader: ; 0x94a39
	; bank, tileset, permission
	db BANK(SilverCaveOutside_SecondMapHeader), $3, 1

	; second map header
	dw SilverCaveOutside_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2e, $46, 0, 4
; 0x94a42

SilverCavePokeCenter1F_MapHeader: ; 0x94a42
	; bank, tileset, permission
	db BANK(SilverCavePokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw SilverCavePokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2e, $9, 1, 1
; 0x94a4b

Route28FamousSpeechHouse_MapHeader: ; 0x94a4b
	; bank, tileset, permission
	db BANK(Route28FamousSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw Route28FamousSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5e, $25, 1, 1
; 0x94a54

PokeCenter2F_MapHeader: ; 0x94a54
	; bank, tileset, permission
	db BANK(PokeCenter2F_SecondMapHeader), $7, 3

	; second map header
	dw PokeCenter2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $0, $9, 17, 1
; 0x94a5d

TradeCenter_MapHeader: ; 0x94a5d
	; bank, tileset, permission
	db BANK(TradeCenter_SecondMapHeader), $8, 3

	; second map header
	dw TradeCenter_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $0, $26, 17, 1
; 0x94a66

Colosseum_MapHeader: ; 0x94a66
	; bank, tileset, permission
	db BANK(Colosseum_SecondMapHeader), $8, 3

	; second map header
	dw Colosseum_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $0, $26, 17, 1
; 0x94a6f

TimeCapsule_MapHeader: ; 0x94a6f
	; bank, tileset, permission
	db BANK(TimeCapsule_SecondMapHeader), $8, 3

	; second map header
	dw TimeCapsule_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $0, $26, 17, 1
; 0x94a78

MobileTradeRoomMobile_MapHeader: ; 0x94a78
	; bank, tileset, permission
	db $25, $d, 3

	; second map header
	dw MobileTradeRoomMobile_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $0, $26, 17, 1
; 0x94a81

MobileBattleRoom_MapHeader: ; 0x94a81
	; bank, tileset, permission
	db $25, $d, 3

	; second map header
	dw MobileBattleRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $0, $26, 17, 1
; 0x94a8a

Route7_MapHeader: ; 0x94a8a
	; bank, tileset, permission
	db BANK(Route7_SecondMapHeader), $3, 2

	; second map header
	dw Route7_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3f, $3, 0, 1
; 0x94a93

Route16_MapHeader: ; 0x94a93
	; bank, tileset, permission
	db BANK(Route16_SecondMapHeader), $3, 2

	; second map header
	dw Route16_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4e, $3, 0, 1
; 0x94a9c

Route17_MapHeader: ; 0x94a9c
	; bank, tileset, permission
	db BANK(Route17_SecondMapHeader), $3, 2

	; second map header
	dw Route17_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4f, $3, 0, 0
; 0x94aa5

CeladonCity_MapHeader: ; 0x94aa5
	; bank, tileset, permission
	db BANK(CeladonCity_SecondMapHeader), $3, 1

	; second map header
	dw CeladonCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 0, 0
; 0x94aae

CeladonDeptStore1F_MapHeader: ; 0x94aae
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw CeladonDeptStore1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94ab7

CeladonDeptStore2F_MapHeader: ; 0x94ab7
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw CeladonDeptStore2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94ac0

CeladonDeptStore3F_MapHeader: ; 0x94ac0
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw CeladonDeptStore3F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94ac9

CeladonDeptStore4F_MapHeader: ; 0x94ac9
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw CeladonDeptStore4F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94ad2

CeladonDeptStore5F_MapHeader: ; 0x94ad2
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw CeladonDeptStore5F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94adb

CeladonDeptStore6F_MapHeader: ; 0x94adb
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw CeladonDeptStore6F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94ae4

CeladonDeptStoreElevator_MapHeader: ; 0x94ae4
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw CeladonDeptStoreElevator_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94aed

CeladonMansion1F_MapHeader: ; 0x94aed
	; bank, tileset, permission
	db $25, $d, 3

	; second map header
	dw CeladonMansion1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94af6

CeladonMansion2F_MapHeader: ; 0x94af6
	; bank, tileset, permission
	db $25, $d, 3

	; second map header
	dw CeladonMansion2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94aff

CeladonMansion3F_MapHeader: ; 0x94aff
	; bank, tileset, permission
	db $25, $d, 3

	; second map header
	dw CeladonMansion3F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94b08

CeladonMansionRoof_MapHeader: ; 0x94b08
	; bank, tileset, permission
	db $25, $d, 3

	; second map header
	dw CeladonMansionRoof_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94b11

CeladonMansionRoofHouse_MapHeader: ; 0x94b11
	; bank, tileset, permission
	db BANK(CeladonMansionRoofHouse_SecondMapHeader), $5, 3

	; second map header
	dw CeladonMansionRoofHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94b1a

CeladonPokeCenter1F_MapHeader: ; 0x94b1a
	; bank, tileset, permission
	db BANK(CeladonPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw CeladonPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $9, 1, 1
; 0x94b23

CeladonPokeCenter2FBeta_MapHeader: ; 0x94b23
	; bank, tileset, permission
	db BANK(CeladonPokeCenter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw CeladonPokeCenter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94b2c

CeladonGameCorner_MapHeader: ; 0x94b2c
	; bank, tileset, permission
	db $25, $e, 3

	; second map header
	dw CeladonGameCorner_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $12, 1, 1
; 0x94b35

CeladonGameCornerPrizeRoom_MapHeader: ; 0x94b35
	; bank, tileset, permission
	db $25, $e, 3

	; second map header
	dw CeladonGameCornerPrizeRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94b3e

CeladonGym_MapHeader: ; 0x94b3e
	; bank, tileset, permission
	db BANK(CeladonGym_SecondMapHeader), $11, 3

	; second map header
	dw CeladonGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $1b, 17, 1
; 0x94b47

CeladonCafe_MapHeader: ; 0x94b47
	; bank, tileset, permission
	db $25, $e, 3

	; second map header
	dw CeladonCafe_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $47, $16, 1, 1
; 0x94b50

Route16FuchsiaSpeechHouse_MapHeader: ; 0x94b50
	; bank, tileset, permission
	db BANK(Route16FuchsiaSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw Route16FuchsiaSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4e, $16, 1, 1
; 0x94b59

Route16Gate_MapHeader: ; 0x94b59
	; bank, tileset, permission
	db BANK(Route16Gate_SecondMapHeader), $8, 6

	; second map header
	dw Route16Gate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4e, $3, 1, 1
; 0x94b62

Route7SaffronGate_MapHeader: ; 0x94b62
	; bank, tileset, permission
	db BANK(Route7SaffronGate_SecondMapHeader), $8, 6

	; second map header
	dw Route7SaffronGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3f, $3, 1, 1
; 0x94b6b

Route1718Gate_MapHeader: ; 0x94b6b
	; bank, tileset, permission
	db BANK(Route1718Gate_SecondMapHeader), $8, 6

	; second map header
	dw Route1718Gate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4f, $3, 1, 1
; 0x94b74

Route40_MapHeader: ; 0x94b74
	; bank, tileset, permission
	db BANK(Route40_SecondMapHeader), $1, 2

	; second map header
	dw Route40_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1e, $35, 0, 1
; 0x94b7d

Route41_MapHeader: ; 0x94b7d
	; bank, tileset, permission
	db BANK(Route41_SecondMapHeader), $1, 2

	; second map header
	dw Route41_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $20, $35, 0, 2
; 0x94b86

CianwoodCity_MapHeader: ; 0x94b86
	; bank, tileset, permission
	db BANK(CianwoodCity_SecondMapHeader), $1, 1

	; second map header
	dw CianwoodCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $21, $2c, 0, 1
; 0x94b8f

ManiasHouse_MapHeader: ; 0x94b8f
	; bank, tileset, permission
	db BANK(ManiasHouse_SecondMapHeader), $5, 3

	; second map header
	dw ManiasHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $21, $2c, 1, 1
; 0x94b98

CianwoodGym_MapHeader: ; 0x94b98
	; bank, tileset, permission
	db BANK(CianwoodGym_SecondMapHeader), $17, 3

	; second map header
	dw CianwoodGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $21, $1b, 17, 1
; 0x94ba1

CianwoodPokeCenter1F_MapHeader: ; 0x94ba1
	; bank, tileset, permission
	db BANK(CianwoodPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw CianwoodPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $21, $9, 1, 1
; 0x94baa

CianwoodPharmacy_MapHeader: ; 0x94baa
	; bank, tileset, permission
	db BANK(CianwoodPharmacy_SecondMapHeader), $5, 3

	; second map header
	dw CianwoodPharmacy_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $21, $2c, 1, 1
; 0x94bb3

CianwoodCityPhotoStudio_MapHeader: ; 0x94bb3
	; bank, tileset, permission
	db BANK(CianwoodCityPhotoStudio_SecondMapHeader), $5, 3

	; second map header
	dw CianwoodCityPhotoStudio_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $21, $2c, 1, 1
; 0x94bbc

CianwoodLugiaSpeechHouse_MapHeader: ; 0x94bbc
	; bank, tileset, permission
	db BANK(CianwoodLugiaSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw CianwoodLugiaSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $21, $2c, 1, 1
; 0x94bc5

PokeSeersHouse_MapHeader: ; 0x94bc5
	; bank, tileset, permission
	db BANK(PokeSeersHouse_SecondMapHeader), $5, 3

	; second map header
	dw PokeSeersHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $21, $2c, 1, 1
; 0x94bce

BattleTower1F_MapHeader: ; 0x94bce
	; bank, tileset, permission
	db BANK(BattleTower1F_SecondMapHeader), $16, 3

	; second map header
	dw BattleTower1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1d, $65, 17, 1
; 0x94bd7

BattleTowerBattleRoom_MapHeader: ; 0x94bd7
	; bank, tileset, permission
	db BANK(BattleTowerBattleRoom_SecondMapHeader), $16, 3

	; second map header
	dw BattleTowerBattleRoom_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1d, $63, 17, 1
; 0x94be0

BattleTowerElevator_MapHeader: ; 0x94be0
	; bank, tileset, permission
	db BANK(BattleTowerElevator_SecondMapHeader), $16, 3

	; second map header
	dw BattleTowerElevator_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1d, $0, 17, 1
; 0x94be9

BattleTowerHallway_MapHeader: ; 0x94be9
	; bank, tileset, permission
	db BANK(BattleTowerHallway_SecondMapHeader), $16, 3

	; second map header
	dw BattleTowerHallway_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1d, $63, 17, 1
; 0x94bf2

Route40BattleTowerGate_MapHeader: ; 0x94bf2
	; bank, tileset, permission
	db BANK(Route40BattleTowerGate_SecondMapHeader), $8, 6

	; second map header
	dw Route40BattleTowerGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1d, $35, 1, 1
; 0x94bfb

BattleTowerOutside_MapHeader: ; 0x94bfb
	; bank, tileset, permission
	db BANK(BattleTowerOutside_SecondMapHeader), $4, 2

	; second map header
	dw BattleTowerOutside_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1d, $63, 0, 1
; 0x94c04

Route2_MapHeader: ; 0x94c04
	; bank, tileset, permission
	db BANK(Route2_SecondMapHeader), $3, 2

	; second map header
	dw Route2_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $32, $f, 0, 1
; 0x94c0d

Route22_MapHeader: ; 0x94c0d
	; bank, tileset, permission
	db BANK(Route22_SecondMapHeader), $3, 2

	; second map header
	dw Route22_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $57, $3, 0, 4
; 0x94c16

ViridianCity_MapHeader: ; 0x94c16
	; bank, tileset, permission
	db BANK(ViridianCity_SecondMapHeader), $3, 1

	; second map header
	dw ViridianCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $31, $15, 0, 4
; 0x94c1f

ViridianGym_MapHeader: ; 0x94c1f
	; bank, tileset, permission
	db BANK(ViridianGym_SecondMapHeader), $11, 3

	; second map header
	dw ViridianGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $31, $1b, 17, 1
; 0x94c28

ViridianNicknameSpeechHouse_MapHeader: ; 0x94c28
	; bank, tileset, permission
	db BANK(ViridianNicknameSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw ViridianNicknameSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $31, $15, 1, 1
; 0x94c31

TrainerHouse1F_MapHeader: ; 0x94c31
	; bank, tileset, permission
	db BANK(TrainerHouse1F_SecondMapHeader), $5, 3

	; second map header
	dw TrainerHouse1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $31, $15, 1, 1
; 0x94c3a

TrainerHouseB1F_MapHeader: ; 0x94c3a
	; bank, tileset, permission
	db $25, $b, 3

	; second map header
	dw TrainerHouseB1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $31, $15, 1, 1
; 0x94c43

ViridianMart_MapHeader: ; 0x94c43
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw ViridianMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $31, $15, 1, 1
; 0x94c4c

ViridianPokeCenter1F_MapHeader: ; 0x94c4c
	; bank, tileset, permission
	db BANK(ViridianPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw ViridianPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $31, $9, 1, 1
; 0x94c55

ViridianPokeCenter2FBeta_MapHeader: ; 0x94c55
	; bank, tileset, permission
	db BANK(ViridianPokeCenter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw ViridianPokeCenter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $31, $15, 1, 1
; 0x94c5e

Route2NuggetSpeechHouse_MapHeader: ; 0x94c5e
	; bank, tileset, permission
	db BANK(Route2NuggetSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw Route2NuggetSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $32, $15, 1, 1
; 0x94c67

Route2Gate_MapHeader: ; 0x94c67
	; bank, tileset, permission
	db BANK(Route2Gate_SecondMapHeader), $8, 6

	; second map header
	dw Route2Gate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $32, $f, 1, 1
; 0x94c70

VictoryRoadGate_MapHeader: ; 0x94c70
	; bank, tileset, permission
	db BANK(VictoryRoadGate_SecondMapHeader), $8, 6

	; second map header
	dw VictoryRoadGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5b, $46, 1, 1
; 0x94c79

Route26_MapHeader: ; 0x94c79
	; bank, tileset, permission
	db BANK(Route26_SecondMapHeader), $1, 2

	; second map header
	dw Route26_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5b, $4d, 0, 2
; 0x94c82

Route27_MapHeader: ; 0x94c82
	; bank, tileset, permission
	db BANK(Route27_SecondMapHeader), $1, 2

	; second map header
	dw Route27_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5c, $4d, 0, 2
; 0x94c8b

Route29_MapHeader: ; 0x94c8b
	; bank, tileset, permission
	db BANK(Route29_SecondMapHeader), $1, 2

	; second map header
	dw Route29_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2, $34, 0, 1
; 0x94c94

NewBarkTown_MapHeader: ; 0x94c94
	; bank, tileset, permission
	db BANK(NewBarkTown_SecondMapHeader), $1, 1

	; second map header
	dw NewBarkTown_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1, $3c, 0, 2
; 0x94c9d

ElmsLab_MapHeader: ; 0x94c9d
	; bank, tileset, permission
	db $25, $a, 3

	; second map header
	dw ElmsLab_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1, $32, 1, 1
; 0x94ca6

KrissHouse1F_MapHeader: ; 0x94ca6
	; bank, tileset, permission
	db BANK(KrissHouse1F_SecondMapHeader), $6, 3

	; second map header
	dw KrissHouse1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1, $3c, 1, 1
; 0x94caf

KrissHouse2F_MapHeader: ; 0x94caf
	; bank, tileset, permission
	db BANK(KrissHouse2F_SecondMapHeader), $14, 3

	; second map header
	dw KrissHouse2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1, $3c, 1, 1
; 0x94cb8

KrissNeighborsHouse_MapHeader: ; 0x94cb8
	; bank, tileset, permission
	db BANK(KrissNeighborsHouse_SecondMapHeader), $5, 3

	; second map header
	dw KrissNeighborsHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1, $3c, 1, 1
; 0x94cc1

ElmsHouse_MapHeader: ; 0x94cc1
	; bank, tileset, permission
	db BANK(ElmsHouse_SecondMapHeader), $6, 3

	; second map header
	dw ElmsHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $1, $3c, 1, 1
; 0x94cca

Route26HealSpeechHouse_MapHeader: ; 0x94cca
	; bank, tileset, permission
	db BANK(Route26HealSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw Route26HealSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5b, $25, 1, 1
; 0x94cd3

Route26DayofWeekSiblingsHouse_MapHeader: ; 0x94cd3
	; bank, tileset, permission
	db BANK(Route26DayofWeekSiblingsHouse_SecondMapHeader), $5, 3

	; second map header
	dw Route26DayofWeekSiblingsHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5b, $25, 1, 1
; 0x94cdc

Route27SandstormHouse_MapHeader: ; 0x94cdc
	; bank, tileset, permission
	db BANK(Route27SandstormHouse_SecondMapHeader), $5, 3

	; second map header
	dw Route27SandstormHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5c, $25, 1, 1
; 0x94ce5

Route2946Gate_MapHeader: ; 0x94ce5
	; bank, tileset, permission
	db BANK(Route2946Gate_SecondMapHeader), $8, 6

	; second map header
	dw Route2946Gate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $2, $34, 1, 1
; 0x94cee

Route5_MapHeader: ; 0x94cee
	; bank, tileset, permission
	db BANK(Route5_SecondMapHeader), $3, 2

	; second map header
	dw Route5_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3a, $3, 0, 1
; 0x94cf7

SaffronCity_MapHeader: ; 0x94cf7
	; bank, tileset, permission
	db BANK(SaffronCity_SecondMapHeader), $3, 1

	; second map header
	dw SaffronCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $15, 0, 1
; 0x94d00

FightingDojo_MapHeader: ; 0x94d00
	; bank, tileset, permission
	db BANK(FightingDojo_SecondMapHeader), $11, 3

	; second map header
	dw FightingDojo_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $15, 1, 1
; 0x94d09

SaffronGym_MapHeader: ; 0x94d09
	; bank, tileset, permission
	db $25, $1c, 3

	; second map header
	dw SaffronGym_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $1b, 17, 1
; 0x94d12

SaffronMart_MapHeader: ; 0x94d12
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw SaffronMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $15, 1, 1
; 0x94d1b

SaffronPokeCenter1F_MapHeader: ; 0x94d1b
	; bank, tileset, permission
	db BANK(SaffronPokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw SaffronPokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $9, 1, 1
; 0x94d24

SaffronPokeCenter2FBeta_MapHeader: ; 0x94d24
	; bank, tileset, permission
	db BANK(SaffronPokeCenter2FBeta_SecondMapHeader), $7, 3

	; second map header
	dw SaffronPokeCenter2FBeta_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $15, 1, 1
; 0x94d2d

MrPsychicsHouse_MapHeader: ; 0x94d2d
	; bank, tileset, permission
	db BANK(MrPsychicsHouse_SecondMapHeader), $5, 3

	; second map header
	dw MrPsychicsHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $15, 1, 1
; 0x94d36

SaffronTrainStation_MapHeader: ; 0x94d36
	; bank, tileset, permission
	db BANK(SaffronTrainStation_SecondMapHeader), $11, 3

	; second map header
	dw SaffronTrainStation_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $15, 1, 1
; 0x94d3f

SilphCo1F_MapHeader: ; 0x94d3f
	; bank, tileset, permission
	db $25, $b, 3

	; second map header
	dw SilphCo1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $15, 1, 1
; 0x94d48

CopycatsHouse1F_MapHeader: ; 0x94d48
	; bank, tileset, permission
	db BANK(CopycatsHouse1F_SecondMapHeader), $6, 3

	; second map header
	dw CopycatsHouse1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $15, 1, 1
; 0x94d51

CopycatsHouse2F_MapHeader: ; 0x94d51
	; bank, tileset, permission
	db BANK(CopycatsHouse2F_SecondMapHeader), $6, 3

	; second map header
	dw CopycatsHouse2F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $48, $15, 1, 1
; 0x94d5a

Route5UndergroundEntrance_MapHeader: ; 0x94d5a
	; bank, tileset, permission
	db BANK(Route5UndergroundEntrance_SecondMapHeader), $8, 6

	; second map header
	dw Route5UndergroundEntrance_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3a, $3, 1, 1
; 0x94d63

Route5SaffronCityGate_MapHeader: ; 0x94d63
	; bank, tileset, permission
	db BANK(Route5SaffronCityGate_SecondMapHeader), $8, 6

	; second map header
	dw Route5SaffronCityGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3a, $15, 1, 1
; 0x94d6c

Route5CleanseTagSpeechHouse_MapHeader: ; 0x94d6c
	; bank, tileset, permission
	db BANK(Route5CleanseTagSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw Route5CleanseTagSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3a, $15, 1, 1
; 0x94d75

Route30_MapHeader: ; 0x94d75
	; bank, tileset, permission
	db BANK(Route30_SecondMapHeader), $1, 2

	; second map header
	dw Route30_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4, $2b, 0, 4
; 0x94d7e

Route31_MapHeader: ; 0x94d7e
	; bank, tileset, permission
	db BANK(Route31_SecondMapHeader), $1, 2

	; second map header
	dw Route31_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5, $2b, 0, 4
; 0x94d87

CherrygroveCity_MapHeader: ; 0x94d87
	; bank, tileset, permission
	db BANK(CherrygroveCity_SecondMapHeader), $1, 1

	; second map header
	dw CherrygroveCity_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3, $26, 0, 1
; 0x94d90

CherrygroveMart_MapHeader: ; 0x94d90
	; bank, tileset, permission
	db $25, $c, 3

	; second map header
	dw CherrygroveMart_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3, $26, 1, 1
; 0x94d99

CherrygrovePokeCenter1F_MapHeader: ; 0x94d99
	; bank, tileset, permission
	db BANK(CherrygrovePokeCenter1F_SecondMapHeader), $7, 3

	; second map header
	dw CherrygrovePokeCenter1F_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3, $9, 1, 1
; 0x94da2

CherrygroveGymSpeechHouse_MapHeader: ; 0x94da2
	; bank, tileset, permission
	db BANK(CherrygroveGymSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw CherrygroveGymSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3, $26, 1, 1
; 0x94dab

GuideGentsHouse_MapHeader: ; 0x94dab
	; bank, tileset, permission
	db BANK(GuideGentsHouse_SecondMapHeader), $5, 3

	; second map header
	dw GuideGentsHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3, $26, 1, 1
; 0x94db4

CherrygroveEvolutionSpeechHouse_MapHeader: ; 0x94db4
	; bank, tileset, permission
	db BANK(CherrygroveEvolutionSpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw CherrygroveEvolutionSpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $3, $26, 1, 1
; 0x94dbd

Route30BerrySpeechHouse_MapHeader: ; 0x94dbd
	; bank, tileset, permission
	db BANK(Route30BerrySpeechHouse_SecondMapHeader), $5, 3

	; second map header
	dw Route30BerrySpeechHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4, $26, 1, 1
; 0x94dc6

MrPokemonsHouse_MapHeader: ; 0x94dc6
	; bank, tileset, permission
	db $25, $b, 3

	; second map header
	dw MrPokemonsHouse_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $4, $26, 1, 1
; 0x94dcf

Route31VioletGate_MapHeader: ; 0x94dcf
	; bank, tileset, permission
	db BANK(Route31VioletGate_SecondMapHeader), $8, 6

	; second map header
	dw Route31VioletGate_SecondMapHeader

	; location on world map, music, time of day, fishing group
	db $5, $2b, 1, 1
; 0x94dd8

NewBarkTown_SecondMapHeader: ; 0x94dd8
	; border block
	db $5

	; height, width
	db NEW_BARK_TOWN_HEIGHT, NEW_BARK_TOWN_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(NewBarkTown_BlockData), NewBarkTown_BlockData

	; script header (bank-then-pointer)
	dbw BANK(NewBarkTown_MapScriptHeader), NewBarkTown_MapScriptHeader

	; map event header (bank-then-pointer)
	dw NewBarkTown_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Route 29
	db GROUP_ROUTE_29, MAP_ROUTE_29 ; connected map (group, id)
	dw (Route29_BlockData + ROUTE_29_WIDTH - 3) ; strip pointer
	dw $c830 ; strip destination
	db 9, ROUTE_29_WIDTH ; (connection strip length, connected map width)
	db 0, ((ROUTE_29_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 59) ; window

	; EAST to Route 27
	db GROUP_ROUTE_27, MAP_ROUTE_27 ; connected map (group, id)
	dw (Route27_BlockData) ; strip pointer
	dw $c83d ; strip destination
	db 9, ROUTE_27_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_27_WIDTH) ; window
; 0x94dfc

CherrygroveCity_SecondMapHeader: ; 0x94dfc
	; border block
	db $35

	; height, width
	db CHERRYGROVE_CITY_HEIGHT, CHERRYGROVE_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CherrygroveCity_BlockData), CherrygroveCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CherrygroveCity_MapScriptHeader), CherrygroveCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CherrygroveCity_MapEventHeader

	; connections
	db NORTH | EAST

	; NORTH to Route 30
	db GROUP_ROUTE_30, MAP_ROUTE_30 ; connected map (group, id)
	dw (Route30_BlockData + (ROUTE_30_HEIGHT * ROUTE_30_WIDTH) - (ROUTE_30_WIDTH * 3)) ; strip pointer
	dw ($C703 + 261) ; strip destination
	db 10, ROUTE_30_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_30_HEIGHT * 2) - 1), 246 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_30_HEIGHT * 6) + (ROUTE_30_HEIGHT * ROUTE_30_WIDTH))) ; window

	; EAST to Route 29
	db GROUP_ROUTE_29, MAP_ROUTE_29 ; connected map (group, id)
	dw (Route29_BlockData) ; strip pointer
	dw $c865 ; strip destination
	db 9, ROUTE_29_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_29_WIDTH) ; window
; 0x94e20

VioletCity_SecondMapHeader: ; 0x94e20
	; border block
	db $5

	; height, width
	db VIOLET_CITY_HEIGHT, VIOLET_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(VioletCity_BlockData), VioletCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VioletCity_MapScriptHeader), VioletCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VioletCity_MapEventHeader

	; connections
	db SOUTH | WEST | EAST

	; SOUTH to Route 32
	db GROUP_ROUTE_32, MAP_ROUTE_32 ; connected map (group, id)
	dw (Route32_BlockData) ; strip pointer
	dw ($C703 + 256 + ((VIOLET_CITY_HEIGHT + 3) * (VIOLET_CITY_WIDTH + 6))) ; strip destination
	db 10, ROUTE_32_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_32_WIDTH) ; window

	; WEST to Route 36
	db GROUP_ROUTE_36, MAP_ROUTE_36 ; connected map (group, id)
	dw (Route36_BlockData + ROUTE_36_WIDTH - 3) ; strip pointer
	dw $c84e ; strip destination
	db 9, ROUTE_36_WIDTH ; (connection strip length, connected map width)
	db 0, ((ROUTE_36_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 59) ; window

	; EAST to Route 31
	db GROUP_ROUTE_31, MAP_ROUTE_31 ; connected map (group, id)
	dw (Route31_BlockData) ; strip pointer
	dw $c94f ; strip destination
	db 9, ROUTE_31_WIDTH ; (connection strip length, connected map width)
	db 238, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_31_WIDTH) ; window
; 0x94e50

AzaleaTown_SecondMapHeader: ; 0x94e50
	; border block
	db $5

	; height, width
	db AZALEA_TOWN_HEIGHT, AZALEA_TOWN_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(AzaleaTown_BlockData), AzaleaTown_BlockData

	; script header (bank-then-pointer)
	dbw BANK(AzaleaTown_MapScriptHeader), AzaleaTown_MapScriptHeader

	; map event header (bank-then-pointer)
	dw AzaleaTown_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Route 34
	db GROUP_ROUTE_34, MAP_ROUTE_34 ; connected map (group, id)
	dw (Route34_BlockData + (((ROUTE_34_HEIGHT - AZALEA_TOWN_HEIGHT) * ROUTE_34_WIDTH) - (ROUTE_34_WIDTH * 3) + (ROUTE_34_WIDTH - 1) - 2)) ; strip pointer
	dw $c800 ; strip destination
	db 12, ROUTE_34_WIDTH ; (connection strip length, connected map width)
	db 36, ((ROUTE_34_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window

	; EAST to Route 33
	db GROUP_ROUTE_33, MAP_ROUTE_33 ; connected map (group, id)
	dw (Route33_BlockData) ; strip pointer
	dw $c865 ; strip destination
	db 9, ROUTE_33_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_33_WIDTH) ; window
; 0x94e74

CianwoodCity_SecondMapHeader: ; 0x94e74
	; border block
	db $35

	; height, width
	db CIANWOOD_CITY_HEIGHT, CIANWOOD_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CianwoodCity_BlockData), CianwoodCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CianwoodCity_MapScriptHeader), CianwoodCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CianwoodCity_MapEventHeader

	; connections
	db EAST

	; EAST to Route 41
	db GROUP_ROUTE_41, MAP_ROUTE_41 ; connected map (group, id)
	dw (Route41_BlockData) ; strip pointer
	dw $c851 ; strip destination
	db 27, ROUTE_41_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_41_WIDTH) ; window
; 0x94e8c

GoldenrodCity_SecondMapHeader: ; 0x94e8c
	; border block
	db $35

	; height, width
	db GOLDENROD_CITY_HEIGHT, GOLDENROD_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodCity_BlockData), GoldenrodCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodCity_MapScriptHeader), GoldenrodCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodCity_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Route 35
	db GROUP_ROUTE_35, MAP_ROUTE_35 ; connected map (group, id)
	dw (Route35_BlockData + (ROUTE_35_HEIGHT * ROUTE_35_WIDTH) - (ROUTE_35_WIDTH * 3)) ; strip pointer
	dw ($C703 + 261) ; strip destination
	db 10, ROUTE_35_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_35_HEIGHT * 2) - 1), 246 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_35_HEIGHT * 6) + (ROUTE_35_HEIGHT * ROUTE_35_WIDTH))) ; window

	; SOUTH to Route 34
	db GROUP_ROUTE_34, MAP_ROUTE_34 ; connected map (group, id)
	dw (Route34_BlockData) ; strip pointer
	dw ($C703 + 261 + ((GOLDENROD_CITY_HEIGHT + 3) * (GOLDENROD_CITY_WIDTH + 6))) ; strip destination
	db 10, ROUTE_34_WIDTH ; (connection strip length, connected map width)
	db 0, 246 ; yoffset, xoffset
	dw ($C807 + ROUTE_34_WIDTH) ; window
; 0x94eb0

OlivineCity_SecondMapHeader: ; 0x94eb0
	; border block
	db $35

	; height, width
	db OLIVINE_CITY_HEIGHT, OLIVINE_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineCity_BlockData), OlivineCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineCity_MapScriptHeader), OlivineCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineCity_MapEventHeader

	; connections
	db NORTH | WEST

	; NORTH to Route 39
	db GROUP_ROUTE_39, MAP_ROUTE_39 ; connected map (group, id)
	dw (Route39_BlockData + (ROUTE_39_HEIGHT * ROUTE_39_WIDTH) - (ROUTE_39_WIDTH * 3)) ; strip pointer
	dw ($C703 + 261) ; strip destination
	db 10, ROUTE_39_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_39_HEIGHT * 2) - 1), 246 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_39_HEIGHT * 6) + (ROUTE_39_HEIGHT * ROUTE_39_WIDTH))) ; window

	; WEST to Route 40
	db GROUP_ROUTE_40, MAP_ROUTE_40 ; connected map (group, id)
	dw (Route40_BlockData + ROUTE_40_WIDTH - 3) ; strip pointer
	dw $c938 ; strip destination
	db 12, ROUTE_40_WIDTH ; (connection strip length, connected map width)
	db 238, ((ROUTE_40_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window
; 0x94ed4

EcruteakCity_SecondMapHeader: ; 0x94ed4
	; border block
	db $5

	; height, width
	db ECRUTEAK_CITY_HEIGHT, ECRUTEAK_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(EcruteakCity_BlockData), EcruteakCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(EcruteakCity_MapScriptHeader), EcruteakCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw EcruteakCity_MapEventHeader

	; connections
	db SOUTH | WEST | EAST

	; SOUTH to Route 37
	db GROUP_ROUTE_37, MAP_ROUTE_37 ; connected map (group, id)
	dw (Route37_BlockData) ; strip pointer
	dw ($C703 + 261 + ((ECRUTEAK_CITY_HEIGHT + 3) * (ECRUTEAK_CITY_WIDTH + 6))) ; strip destination
	db 10, ROUTE_37_WIDTH ; (connection strip length, connected map width)
	db 0, 246 ; yoffset, xoffset
	dw ($C807 + ROUTE_37_WIDTH) ; window

	; WEST to Route 38
	db GROUP_ROUTE_38, MAP_ROUTE_38 ; connected map (group, id)
	dw (Route38_BlockData + ROUTE_38_WIDTH - 3) ; strip pointer
	dw $c8d0 ; strip destination
	db 9, ROUTE_38_WIDTH ; (connection strip length, connected map width)
	db 246, ((ROUTE_38_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window

	; EAST to Route 42
	db GROUP_ROUTE_42, MAP_ROUTE_42 ; connected map (group, id)
	dw (Route42_BlockData) ; strip pointer
	dw $c94f ; strip destination
	db 9, ROUTE_42_WIDTH ; (connection strip length, connected map width)
	db 238, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_42_WIDTH) ; window
; 0x94f04

MahoganyTown_SecondMapHeader: ; 0x94f04
	; border block
	db $71

	; height, width
	db MAHOGANY_TOWN_HEIGHT, MAHOGANY_TOWN_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MahoganyTown_BlockData), MahoganyTown_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MahoganyTown_MapScriptHeader), MahoganyTown_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MahoganyTown_MapEventHeader

	; connections
	db NORTH | WEST | EAST

	; NORTH to Route 43
	db GROUP_ROUTE_43, MAP_ROUTE_43 ; connected map (group, id)
	dw (Route43_BlockData + (ROUTE_43_HEIGHT * ROUTE_43_WIDTH) - (ROUTE_43_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 10, ROUTE_43_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_43_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_43_HEIGHT * 6) + (ROUTE_43_HEIGHT * ROUTE_43_WIDTH))) ; window

	; WEST to Route 42
	db GROUP_ROUTE_42, MAP_ROUTE_42 ; connected map (group, id)
	dw (Route42_BlockData + ROUTE_42_WIDTH - 3) ; strip pointer
	dw $c830 ; strip destination
	db 9, ROUTE_42_WIDTH ; (connection strip length, connected map width)
	db 0, ((ROUTE_42_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 59) ; window

	; EAST to Route 44
	db GROUP_ROUTE_44, MAP_ROUTE_44 ; connected map (group, id)
	dw (Route44_BlockData) ; strip pointer
	dw $c83d ; strip destination
	db 9, ROUTE_44_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_44_WIDTH) ; window
; 0x94f34

LakeofRage_SecondMapHeader: ; 0x94f34
	; border block
	db $5

	; height, width
	db LAKE_OF_RAGE_HEIGHT, LAKE_OF_RAGE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(LakeofRage_BlockData), LakeofRage_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LakeofRage_MapScriptHeader), LakeofRage_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LakeofRage_MapEventHeader

	; connections
	db SOUTH

	; SOUTH to Route 43
	db GROUP_ROUTE_43, MAP_ROUTE_43 ; connected map (group, id)
	dw (Route43_BlockData) ; strip pointer
	dw ($C703 + 261 + ((LAKE_OF_RAGE_HEIGHT + 3) * (LAKE_OF_RAGE_WIDTH + 6))) ; strip destination
	db 10, ROUTE_43_WIDTH ; (connection strip length, connected map width)
	db 0, 246 ; yoffset, xoffset
	dw ($C807 + ROUTE_43_WIDTH) ; window
; 0x94f4c

BlackthornCity_SecondMapHeader: ; 0x94f4c
	; border block
	db $71

	; height, width
	db BLACKTHORN_CITY_HEIGHT, BLACKTHORN_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BlackthornCity_BlockData), BlackthornCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BlackthornCity_MapScriptHeader), BlackthornCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BlackthornCity_MapEventHeader

	; connections
	db SOUTH | WEST

	; SOUTH to Route 45
	db GROUP_ROUTE_45, MAP_ROUTE_45 ; connected map (group, id)
	dw (Route45_BlockData) ; strip pointer
	dw ($C703 + 256 + ((BLACKTHORN_CITY_HEIGHT + 3) * (BLACKTHORN_CITY_WIDTH + 6))) ; strip destination
	db 10, ROUTE_45_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_45_WIDTH) ; window

	; WEST to Route 44
	db GROUP_ROUTE_44, MAP_ROUTE_44 ; connected map (group, id)
	dw (Route44_BlockData + ROUTE_44_WIDTH - 3) ; strip pointer
	dw $c938 ; strip destination
	db 9, ROUTE_44_WIDTH ; (connection strip length, connected map width)
	db 238, ((ROUTE_44_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 59) ; window
; 0x94f70

SilverCaveOutside_SecondMapHeader: ; 0x94f70
	; border block
	db $2c

	; height, width
	db SILVER_CAVE_OUTSIDE_HEIGHT, SILVER_CAVE_OUTSIDE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SilverCaveOutside_BlockData), SilverCaveOutside_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SilverCaveOutside_MapScriptHeader), SilverCaveOutside_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SilverCaveOutside_MapEventHeader

	; connections
	db EAST

	; EAST to Route 28
	db GROUP_ROUTE_28, MAP_ROUTE_28 ; connected map (group, id)
	dw (Route28_BlockData) ; strip pointer
	dw $c94f ; strip destination
	db 9, ROUTE_28_WIDTH ; (connection strip length, connected map width)
	db 238, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_28_WIDTH) ; window
; 0x94f88

Route26_SecondMapHeader: ; 0x94f88
	; border block
	db $5

	; height, width
	db ROUTE_26_HEIGHT, ROUTE_26_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route26_BlockData), Route26_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route26_MapScriptHeader), Route26_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route26_MapEventHeader

	; connections
	db WEST

	; WEST to Route 27
	db GROUP_ROUTE_27, MAP_ROUTE_27 ; connected map (group, id)
	dw (Route27_BlockData + ROUTE_27_WIDTH - 3) ; strip pointer
	dw $cb00 ; strip destination
	db 9, ROUTE_27_WIDTH ; (connection strip length, connected map width)
	db 166, ((ROUTE_27_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 79) ; window
; 0x94fa0

Route27_SecondMapHeader: ; 0x94fa0
	; border block
	db $35

	; height, width
	db ROUTE_27_HEIGHT, ROUTE_27_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route27_BlockData), Route27_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route27_MapScriptHeader), Route27_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route27_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to New Bark Town
	db GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN ; connected map (group, id)
	dw (NewBarkTown_BlockData + NEW_BARK_TOWN_WIDTH - 3) ; strip pointer
	dw $c88a ; strip destination
	db 9, NEW_BARK_TOWN_WIDTH ; (connection strip length, connected map width)
	db 0, ((NEW_BARK_TOWN_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window

	; EAST to Route 26
	db GROUP_ROUTE_26, MAP_ROUTE_26 ; connected map (group, id)
	dw (Route26_BlockData + ((ROUTE_26_HEIGHT - 12) * ROUTE_26_WIDTH)) ; strip pointer
	dw $c82b ; strip destination
	db 12, ROUTE_26_WIDTH ; (connection strip length, connected map width)
	db 90, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_26_WIDTH) ; window
; 0x94fc4

Route28_SecondMapHeader: ; 0x94fc4
	; border block
	db $2c

	; height, width
	db ROUTE_28_HEIGHT, ROUTE_28_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route28_BlockData), Route28_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route28_MapScriptHeader), Route28_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route28_MapEventHeader

	; connections
	db WEST

	; WEST to Silver Cave Outside
	db GROUP_SILVER_CAVE_OUTSIDE, MAP_SILVER_CAVE_OUTSIDE ; connected map (group, id)
	dw (SilverCaveOutside_BlockData + (((SILVER_CAVE_OUTSIDE_HEIGHT - ROUTE_28_HEIGHT) * SILVER_CAVE_OUTSIDE_WIDTH) - (SILVER_CAVE_OUTSIDE_WIDTH * 3) + (SILVER_CAVE_OUTSIDE_WIDTH - 1) - 2)) ; strip pointer
	dw $c800 ; strip destination
	db 12, SILVER_CAVE_OUTSIDE_WIDTH ; (connection strip length, connected map width)
	db 18, ((SILVER_CAVE_OUTSIDE_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window
; 0x94fdc

Route29_SecondMapHeader: ; 0x94fdc
	; border block
	db $5

	; height, width
	db ROUTE_29_HEIGHT, ROUTE_29_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route29_BlockData), Route29_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route29_MapScriptHeader), Route29_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route29_MapEventHeader

	; connections
	db NORTH | WEST | EAST

	; NORTH to Route 46
	db GROUP_ROUTE_46, MAP_ROUTE_46 ; connected map (group, id)
	dw (Route46_BlockData + (ROUTE_46_HEIGHT * ROUTE_46_WIDTH) - (ROUTE_46_WIDTH * 3)) ; strip pointer
	dw ($C703 + 266) ; strip destination
	db 10, ROUTE_46_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_46_HEIGHT * 2) - 1), 236 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_46_HEIGHT * 6) + (ROUTE_46_HEIGHT * ROUTE_46_WIDTH))) ; window

	; WEST to Cherrygrove City
	db GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY ; connected map (group, id)
	dw (CherrygroveCity_BlockData + CHERRYGROVE_CITY_WIDTH - 3) ; strip pointer
	dw $c86c ; strip destination
	db 9, CHERRYGROVE_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, ((CHERRYGROVE_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window

	; EAST to New Bark Town
	db GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN ; connected map (group, id)
	dw (NewBarkTown_BlockData) ; strip pointer
	dw $c88d ; strip destination
	db 9, NEW_BARK_TOWN_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + NEW_BARK_TOWN_WIDTH) ; window
; 0x9500c

Route30_SecondMapHeader: ; 0x9500c
	; border block
	db $5

	; height, width
	db ROUTE_30_HEIGHT, ROUTE_30_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route30_BlockData), Route30_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route30_MapScriptHeader), Route30_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route30_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Route 31
	db GROUP_ROUTE_31, MAP_ROUTE_31 ; connected map (group, id)
	dw $7288 ; strip pointer
	dw ($C703 + 253) ; strip destination
	db 13, ROUTE_31_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_31_HEIGHT * 2) - 1), 20 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_31_HEIGHT * 6) + (ROUTE_31_HEIGHT * ROUTE_31_WIDTH))) ; window

	; SOUTH to Cherrygrove City
	db GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY ; connected map (group, id)
	dw (CherrygroveCity_BlockData + ((10 - 16 + ROUTE_30_WIDTH) / 2)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_30_HEIGHT + 3) * (ROUTE_30_WIDTH + 6))) ; strip destination
	db 16, CHERRYGROVE_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, 10 ; yoffset, xoffset
	dw ($C807 + CHERRYGROVE_CITY_WIDTH) ; window
; 0x95030

Route31_SecondMapHeader: ; 0x95030
	; border block
	db $5

	; height, width
	db ROUTE_31_HEIGHT, ROUTE_31_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route31_BlockData), Route31_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route31_MapScriptHeader), Route31_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route31_MapEventHeader

	; connections
	db SOUTH | WEST

	; SOUTH to Route 30
	db GROUP_ROUTE_30, MAP_ROUTE_30 ; connected map (group, id)
	dw (Route30_BlockData) ; strip pointer
	dw ($C703 + 266 + ((ROUTE_31_HEIGHT + 3) * (ROUTE_31_WIDTH + 6))) ; strip destination
	db 10, ROUTE_30_WIDTH ; (connection strip length, connected map width)
	db 0, 236 ; yoffset, xoffset
	dw ($C807 + ROUTE_30_WIDTH) ; window

	; WEST to Violet City
	db GROUP_VIOLET_CITY, MAP_VIOLET_CITY ; connected map (group, id)
	dw (VioletCity_BlockData + (((VIOLET_CITY_HEIGHT - ROUTE_31_HEIGHT) * VIOLET_CITY_WIDTH) - (VIOLET_CITY_WIDTH * 3) + (VIOLET_CITY_WIDTH - 1) - 2)) ; strip pointer
	dw $c800 ; strip destination
	db 12, VIOLET_CITY_WIDTH ; (connection strip length, connected map width)
	db 18, ((VIOLET_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window
; 0x95054

Route32_SecondMapHeader: ; 0x95054
	; border block
	db $5

	; height, width
	db ROUTE_32_HEIGHT, ROUTE_32_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route32_BlockData), Route32_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route32_MapScriptHeader), Route32_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route32_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Violet City
	db GROUP_VIOLET_CITY, MAP_VIOLET_CITY ; connected map (group, id)
	dw (VioletCity_BlockData + (VIOLET_CITY_HEIGHT * VIOLET_CITY_WIDTH) - (VIOLET_CITY_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 13, VIOLET_CITY_WIDTH ; (connection strip length, connected map width)
	db ((VIOLET_CITY_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((VIOLET_CITY_HEIGHT * 6) + (VIOLET_CITY_HEIGHT * VIOLET_CITY_WIDTH))) ; window

	; SOUTH to Route 33
	db GROUP_ROUTE_33, MAP_ROUTE_33 ; connected map (group, id)
	dw (Route33_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_32_HEIGHT + 3) * (ROUTE_32_WIDTH + 6))) ; strip destination
	db 10, ROUTE_33_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_33_WIDTH) ; window
; 0x95078

Route33_SecondMapHeader: ; 0x95078
	; border block
	db $5

	; height, width
	db ROUTE_33_HEIGHT, ROUTE_33_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route33_BlockData), Route33_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route33_MapScriptHeader), Route33_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route33_MapEventHeader

	; connections
	db NORTH | WEST

	; NORTH to Route 32
	db GROUP_ROUTE_32, MAP_ROUTE_32 ; connected map (group, id)
	dw (Route32_BlockData + (ROUTE_32_HEIGHT * ROUTE_32_WIDTH) - (ROUTE_32_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 10, ROUTE_32_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_32_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_32_HEIGHT * 6) + (ROUTE_32_HEIGHT * ROUTE_32_WIDTH))) ; window

	; WEST to Azalea Town
	db GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN ; connected map (group, id)
	dw (AzaleaTown_BlockData + AZALEA_TOWN_WIDTH - 3) ; strip pointer
	dw $c830 ; strip destination
	db 9, AZALEA_TOWN_WIDTH ; (connection strip length, connected map width)
	db 0, ((AZALEA_TOWN_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window
; 0x9509c

Route34_SecondMapHeader: ; 0x9509c
	; border block
	db $5

	; height, width
	db ROUTE_34_HEIGHT, ROUTE_34_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route34_BlockData), Route34_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route34_MapScriptHeader), Route34_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route34_MapEventHeader

	; connections
	db NORTH | EAST

	; NORTH to Goldenrod City
	db GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY ; connected map (group, id)
	dw (GoldenrodCity_BlockData + GOLDENROD_CITY_WIDTH + 10 + (16 * GOLDENROD_CITY_HEIGHT) - 16) ; strip pointer
	dw ($C703 + 253) ; strip destination
	db 16, GOLDENROD_CITY_WIDTH ; (connection strip length, connected map width)
	db ((GOLDENROD_CITY_HEIGHT * 2) - 1), 10 ; yoffset, xoffset
	dw ($C801 + ((GOLDENROD_CITY_HEIGHT * 6) + (GOLDENROD_CITY_HEIGHT * GOLDENROD_CITY_WIDTH))) ; window

	; EAST to Azalea Town
	db GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN ; connected map (group, id)
	dw (AzaleaTown_BlockData) ; strip pointer
	dw $c95d ; strip destination
	db 9, AZALEA_TOWN_WIDTH ; (connection strip length, connected map width)
	db 220, 0 ; yoffset, xoffset
	dw ($C807 + AZALEA_TOWN_WIDTH) ; window
; 0x950c0

Route35_SecondMapHeader: ; 0x950c0
	; border block
	db $5

	; height, width
	db ROUTE_35_HEIGHT, ROUTE_35_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route35_BlockData), Route35_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route35_MapScriptHeader), Route35_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route35_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Route 36
	db GROUP_ROUTE_36, MAP_ROUTE_36 ; connected map (group, id)
	dw (Route36_BlockData + (ROUTE_36_HEIGHT * ROUTE_36_WIDTH) - (ROUTE_36_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 13, ROUTE_36_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_36_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_36_HEIGHT * 6) + (ROUTE_36_HEIGHT * ROUTE_36_WIDTH))) ; window

	; SOUTH to Goldenrod City
	db GROUP_GOLDENROD_CITY, MAP_GOLDENROD_CITY ; connected map (group, id)
	dw (GoldenrodCity_BlockData + ((10 - 16 + ROUTE_35_WIDTH) / 2)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_35_HEIGHT + 3) * (ROUTE_35_WIDTH + 6))) ; strip destination
	db 16, GOLDENROD_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, 10 ; yoffset, xoffset
	dw ($C807 + GOLDENROD_CITY_WIDTH) ; window
; 0x950e4

Route36_SecondMapHeader: ; 0x950e4
	; border block
	db $5

	; height, width
	db ROUTE_36_HEIGHT, ROUTE_36_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route36_BlockData), Route36_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route36_MapScriptHeader), Route36_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route36_MapEventHeader

	; connections
	db NORTH | SOUTH | EAST

	; NORTH to Route 37
	db GROUP_ROUTE_37, MAP_ROUTE_37 ; connected map (group, id)
	dw (Route37_BlockData + (ROUTE_37_HEIGHT * ROUTE_37_WIDTH) - (ROUTE_37_WIDTH * 3)) ; strip pointer
	dw ($C703 + 266) ; strip destination
	db 10, ROUTE_37_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_37_HEIGHT * 2) - 1), 236 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_37_HEIGHT * 6) + (ROUTE_37_HEIGHT * ROUTE_37_WIDTH))) ; window

	; SOUTH to Route 35
	db GROUP_ROUTE_35, MAP_ROUTE_35 ; connected map (group, id)
	dw (Route35_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_36_HEIGHT + 3) * (ROUTE_36_WIDTH + 6))) ; strip destination
	db 10, ROUTE_35_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_35_WIDTH) ; window

	; EAST to Violet City
	db GROUP_VIOLET_CITY, MAP_VIOLET_CITY ; connected map (group, id)
	dw (VioletCity_BlockData) ; strip pointer
	dw $c88d ; strip destination
	db 12, VIOLET_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + VIOLET_CITY_WIDTH) ; window
; 0x95114

Route37_SecondMapHeader: ; 0x95114
	; border block
	db $5

	; height, width
	db ROUTE_37_HEIGHT, ROUTE_37_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route37_BlockData), Route37_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route37_MapScriptHeader), Route37_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route37_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Ecruteak City
	db GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY ; connected map (group, id)
	dw (EcruteakCity_BlockData + ECRUTEAK_CITY_WIDTH + 10 + (16 * ECRUTEAK_CITY_HEIGHT) - 16) ; strip pointer
	dw ($C703 + 253) ; strip destination
	db 16, ECRUTEAK_CITY_WIDTH ; (connection strip length, connected map width)
	db ((ECRUTEAK_CITY_HEIGHT * 2) - 1), 10 ; yoffset, xoffset
	dw ($C801 + ((ECRUTEAK_CITY_HEIGHT * 6) + (ECRUTEAK_CITY_HEIGHT * ECRUTEAK_CITY_WIDTH))) ; window

	; SOUTH to Route 36
	db GROUP_ROUTE_36, MAP_ROUTE_36 ; connected map (group, id)
	dw (Route36_BlockData + ((20 - 16 + ROUTE_37_WIDTH) / 2)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_37_HEIGHT + 3) * (ROUTE_37_WIDTH + 6))) ; strip destination
	db 16, ROUTE_36_WIDTH ; (connection strip length, connected map width)
	db 0, 20 ; yoffset, xoffset
	dw ($C807 + ROUTE_36_WIDTH) ; window
; 0x95138

Route38_SecondMapHeader: ; 0x95138
	; border block
	db $5

	; height, width
	db ROUTE_38_HEIGHT, ROUTE_38_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38_BlockData), Route38_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route38_MapScriptHeader), Route38_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route38_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Route 39
	db GROUP_ROUTE_39, MAP_ROUTE_39 ; connected map (group, id)
	dw (Route39_BlockData + ROUTE_39_WIDTH - 3) ; strip pointer
	dw $c84e ; strip destination
	db 12, ROUTE_39_WIDTH ; (connection strip length, connected map width)
	db 0, ((ROUTE_39_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window

	; EAST to Ecruteak City
	db GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY ; connected map (group, id)
	dw (EcruteakCity_BlockData + ((100 - (ECRUTEAK_CITY_WIDTH * 4)) * 2)) ; strip pointer
	dw $c817 ; strip destination
	db 15, ECRUTEAK_CITY_WIDTH ; (connection strip length, connected map width)
	db 10, 0 ; yoffset, xoffset
	dw ($C807 + ECRUTEAK_CITY_WIDTH) ; window
; 0x9515c

Route39_SecondMapHeader: ; 0x9515c
	; border block
	db $5

	; height, width
	db ROUTE_39_HEIGHT, ROUTE_39_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route39_BlockData), Route39_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route39_MapScriptHeader), Route39_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route39_MapEventHeader

	; connections
	db SOUTH | EAST

	; SOUTH to Olivine City
	db GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY ; connected map (group, id)
	dw (OlivineCity_BlockData + ((10 - 16 + ROUTE_39_WIDTH) / 2)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_39_HEIGHT + 3) * (ROUTE_39_WIDTH + 6))) ; strip destination
	db 16, OLIVINE_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, 10 ; yoffset, xoffset
	dw ($C807 + OLIVINE_CITY_WIDTH) ; window

	; EAST to Route 38
	db GROUP_ROUTE_38, MAP_ROUTE_38 ; connected map (group, id)
	dw (Route38_BlockData) ; strip pointer
	dw $c83d ; strip destination
	db 9, ROUTE_38_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_38_WIDTH) ; window
; 0x95180

Route40_SecondMapHeader: ; 0x95180
	; border block
	db $35

	; height, width
	db ROUTE_40_HEIGHT, ROUTE_40_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route40_BlockData), Route40_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route40_MapScriptHeader), Route40_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route40_MapEventHeader

	; connections
	db SOUTH | EAST

	; SOUTH to Route 41
	db GROUP_ROUTE_41, MAP_ROUTE_41 ; connected map (group, id)
	dw (Route41_BlockData + (((30 - 13 + ROUTE_40_WIDTH) / 2) - 1)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_40_HEIGHT + 3) * (ROUTE_40_WIDTH + 6))) ; strip destination
	db 13, ROUTE_41_WIDTH ; (connection strip length, connected map width)
	db 0, 30 ; yoffset, xoffset
	dw ($C807 + ROUTE_41_WIDTH) ; window

	; EAST to Olivine City
	db GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY ; connected map (group, id)
	dw (OlivineCity_BlockData + ((OLIVINE_CITY_HEIGHT - 12) * OLIVINE_CITY_WIDTH)) ; strip pointer
	dw $c80d ; strip destination
	db 12, OLIVINE_CITY_WIDTH ; (connection strip length, connected map width)
	db 18, 0 ; yoffset, xoffset
	dw ($C807 + OLIVINE_CITY_WIDTH) ; window
; 0x951a4

Route41_SecondMapHeader: ; 0x951a4
	; border block
	db $35

	; height, width
	db ROUTE_41_HEIGHT, ROUTE_41_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route41_BlockData), Route41_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route41_MapScriptHeader), Route41_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route41_MapEventHeader

	; connections
	db NORTH | WEST

	; NORTH to Route 40
	db GROUP_ROUTE_40, MAP_ROUTE_40 ; connected map (group, id)
	dw (Route40_BlockData + (ROUTE_40_HEIGHT * ROUTE_40_WIDTH) - (ROUTE_40_WIDTH * 3)) ; strip pointer
	dw ($C703 + 271) ; strip destination
	db 10, ROUTE_40_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_40_HEIGHT * 2) - 1), 226 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_40_HEIGHT * 6) + (ROUTE_40_HEIGHT * ROUTE_40_WIDTH))) ; window

	; WEST to Cianwood City
	db GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY ; connected map (group, id)
	dw (CianwoodCity_BlockData + CIANWOOD_CITY_WIDTH - 3) ; strip pointer
	dw $c85d ; strip destination
	db 27, CIANWOOD_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, ((CIANWOOD_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 29) ; window
; 0x951c8

Route42_SecondMapHeader: ; 0x951c8
	; border block
	db $5

	; height, width
	db ROUTE_42_HEIGHT, ROUTE_42_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route42_BlockData), Route42_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route42_MapScriptHeader), Route42_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route42_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Ecruteak City
	db GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY ; connected map (group, id)
	dw (EcruteakCity_BlockData + (((ECRUTEAK_CITY_HEIGHT - ROUTE_42_HEIGHT) * ECRUTEAK_CITY_WIDTH) - (ECRUTEAK_CITY_WIDTH * 3) + (ECRUTEAK_CITY_WIDTH - 1) - 2)) ; strip pointer
	dw $c800 ; strip destination
	db 12, ECRUTEAK_CITY_WIDTH ; (connection strip length, connected map width)
	db 18, ((ECRUTEAK_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window

	; EAST to Mahogany Town
	db GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN ; connected map (group, id)
	dw (MahoganyTown_BlockData) ; strip pointer
	dw $c88d ; strip destination
	db 9, MAHOGANY_TOWN_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + MAHOGANY_TOWN_WIDTH) ; window
; 0x951ec

Route43_SecondMapHeader: ; 0x951ec
	; border block
	db $5

	; height, width
	db ROUTE_43_HEIGHT, ROUTE_43_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route43_BlockData), Route43_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route43_MapScriptHeader), Route43_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route43_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Lake of Rage
	db GROUP_LAKE_OF_RAGE, MAP_LAKE_OF_RAGE ; connected map (group, id)
	dw (LakeofRage_BlockData + LAKE_OF_RAGE_WIDTH + 10 + (16 * LAKE_OF_RAGE_HEIGHT) - 16) ; strip pointer
	dw ($C703 + 253) ; strip destination
	db 16, LAKE_OF_RAGE_WIDTH ; (connection strip length, connected map width)
	db ((LAKE_OF_RAGE_HEIGHT * 2) - 1), 10 ; yoffset, xoffset
	dw ($C801 + ((LAKE_OF_RAGE_HEIGHT * 6) + (LAKE_OF_RAGE_HEIGHT * LAKE_OF_RAGE_WIDTH))) ; window

	; SOUTH to Mahogany Town
	db GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN ; connected map (group, id)
	dw (MahoganyTown_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_43_HEIGHT + 3) * (ROUTE_43_WIDTH + 6))) ; strip destination
	db 10, MAHOGANY_TOWN_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + MAHOGANY_TOWN_WIDTH) ; window
; 0x95210

Route44_SecondMapHeader: ; 0x95210
	; border block
	db $71

	; height, width
	db ROUTE_44_HEIGHT, ROUTE_44_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route44_BlockData), Route44_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route44_MapScriptHeader), Route44_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route44_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Mahogany Town
	db GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN ; connected map (group, id)
	dw (MahoganyTown_BlockData + MAHOGANY_TOWN_WIDTH - 3) ; strip pointer
	dw $c86c ; strip destination
	db 9, MAHOGANY_TOWN_WIDTH ; (connection strip length, connected map width)
	db 0, ((MAHOGANY_TOWN_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window

	; EAST to Blackthorn City
	db GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY ; connected map (group, id)
	dw (BlackthornCity_BlockData + ((BLACKTHORN_CITY_HEIGHT - 12) * BLACKTHORN_CITY_WIDTH)) ; strip pointer
	dw $c821 ; strip destination
	db 12, BLACKTHORN_CITY_WIDTH ; (connection strip length, connected map width)
	db 18, 0 ; yoffset, xoffset
	dw ($C807 + BLACKTHORN_CITY_WIDTH) ; window
; 0x95234

Route45_SecondMapHeader: ; 0x95234
	; border block
	db $71

	; height, width
	db ROUTE_45_HEIGHT, ROUTE_45_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route45_BlockData), Route45_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route45_MapScriptHeader), Route45_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route45_MapEventHeader

	; connections
	db NORTH | WEST

	; NORTH to Blackthorn City
	db GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY ; connected map (group, id)
	dw (BlackthornCity_BlockData + (BLACKTHORN_CITY_HEIGHT * BLACKTHORN_CITY_WIDTH) - (BLACKTHORN_CITY_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 13, BLACKTHORN_CITY_WIDTH ; (connection strip length, connected map width)
	db ((BLACKTHORN_CITY_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((BLACKTHORN_CITY_HEIGHT * 6) + (BLACKTHORN_CITY_HEIGHT * BLACKTHORN_CITY_WIDTH))) ; window

	; WEST to Route 46
	db GROUP_ROUTE_46, MAP_ROUTE_46 ; connected map (group, id)
	dw (Route46_BlockData + ROUTE_46_WIDTH - 3) ; strip pointer
	dw $ca70 ; strip destination
	db 12, ROUTE_46_WIDTH ; (connection strip length, connected map width)
	db 184, ((ROUTE_46_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window
; 0x95258

Route46_SecondMapHeader: ; 0x95258
	; border block
	db $5

	; height, width
	db ROUTE_46_HEIGHT, ROUTE_46_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route46_BlockData), Route46_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route46_MapScriptHeader), Route46_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route46_MapEventHeader

	; connections
	db SOUTH | EAST

	; SOUTH to Route 29
	db GROUP_ROUTE_29, MAP_ROUTE_29 ; connected map (group, id)
	dw (Route29_BlockData + ((20 - 16 + ROUTE_46_WIDTH) / 2)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_46_HEIGHT + 3) * (ROUTE_46_WIDTH + 6))) ; strip destination
	db 16, ROUTE_29_WIDTH ; (connection strip length, connected map width)
	db 0, 20 ; yoffset, xoffset
	dw ($C807 + ROUTE_29_WIDTH) ; window

	; EAST to Route 45
	db GROUP_ROUTE_45, MAP_ROUTE_45 ; connected map (group, id)
	dw (Route45_BlockData + ((ROUTE_45_HEIGHT - 12) * ROUTE_45_WIDTH)) ; strip pointer
	dw $c80d ; strip destination
	db 12, ROUTE_45_WIDTH ; (connection strip length, connected map width)
	db 72, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_45_WIDTH) ; window
; 0x9527c

PewterCity_SecondMapHeader: ; 0x9527c
	; border block
	db $f

	; height, width
	db PEWTER_CITY_HEIGHT, PEWTER_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(PewterCity_BlockData), PewterCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PewterCity_MapScriptHeader), PewterCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PewterCity_MapEventHeader

	; connections
	db SOUTH | EAST

	; SOUTH to Route 2
	db GROUP_ROUTE_2, MAP_ROUTE_2 ; connected map (group, id)
	dw (Route2_BlockData) ; strip pointer
	dw ($C703 + 261 + ((PEWTER_CITY_HEIGHT + 3) * (PEWTER_CITY_WIDTH + 6))) ; strip destination
	db 10, ROUTE_2_WIDTH ; (connection strip length, connected map width)
	db 0, 246 ; yoffset, xoffset
	dw ($C807 + ROUTE_2_WIDTH) ; window

	; EAST to Route 3
	db GROUP_ROUTE_3, MAP_ROUTE_3 ; connected map (group, id)
	dw (Route3_BlockData) ; strip pointer
	dw $c8e7 ; strip destination
	db 9, ROUTE_3_WIDTH ; (connection strip length, connected map width)
	db 246, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_3_WIDTH) ; window
; 0x952a0

Route2_SecondMapHeader: ; 0x952a0
	; border block
	db $f

	; height, width
	db ROUTE_2_HEIGHT, ROUTE_2_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route2_BlockData), Route2_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route2_MapScriptHeader), Route2_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route2_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Pewter City
	db GROUP_PEWTER_CITY, MAP_PEWTER_CITY ; connected map (group, id)
	dw (PewterCity_BlockData + PEWTER_CITY_WIDTH + 10 + (16 * PEWTER_CITY_HEIGHT) - 16) ; strip pointer
	dw ($C703 + 253) ; strip destination
	db 16, PEWTER_CITY_WIDTH ; (connection strip length, connected map width)
	db ((PEWTER_CITY_HEIGHT * 2) - 1), 10 ; yoffset, xoffset
	dw ($C801 + ((PEWTER_CITY_HEIGHT * 6) + (PEWTER_CITY_HEIGHT * PEWTER_CITY_WIDTH))) ; window

	; SOUTH to Viridian City
	db GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY ; connected map (group, id)
	dw (ViridianCity_BlockData + ((10 - 16 + ROUTE_2_WIDTH) / 2)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_2_HEIGHT + 3) * (ROUTE_2_WIDTH + 6))) ; strip destination
	db 16, VIRIDIAN_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, 10 ; yoffset, xoffset
	dw ($C807 + VIRIDIAN_CITY_WIDTH) ; window
; 0x952c4

ViridianCity_SecondMapHeader: ; 0x952c4
	; border block
	db $f

	; height, width
	db VIRIDIAN_CITY_HEIGHT, VIRIDIAN_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(ViridianCity_BlockData), ViridianCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(ViridianCity_MapScriptHeader), ViridianCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw ViridianCity_MapEventHeader

	; connections
	db NORTH | SOUTH | WEST

	; NORTH to Route 2
	db GROUP_ROUTE_2, MAP_ROUTE_2 ; connected map (group, id)
	dw (Route2_BlockData + (ROUTE_2_HEIGHT * ROUTE_2_WIDTH) - (ROUTE_2_WIDTH * 3)) ; strip pointer
	dw ($C703 + 261) ; strip destination
	db 10, ROUTE_2_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_2_HEIGHT * 2) - 1), 246 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_2_HEIGHT * 6) + (ROUTE_2_HEIGHT * ROUTE_2_WIDTH))) ; window

	; SOUTH to Route 1
	db GROUP_ROUTE_1, MAP_ROUTE_1 ; connected map (group, id)
	dw (Route1_BlockData) ; strip pointer
	dw ($C703 + 266 + ((VIRIDIAN_CITY_HEIGHT + 3) * (VIRIDIAN_CITY_WIDTH + 6))) ; strip destination
	db 10, ROUTE_1_WIDTH ; (connection strip length, connected map width)
	db 0, 236 ; yoffset, xoffset
	dw ($C807 + ROUTE_1_WIDTH) ; window

	; WEST to Route 22
	db GROUP_ROUTE_22, MAP_ROUTE_22 ; connected map (group, id)
	dw (Route22_BlockData + ROUTE_22_WIDTH - 3) ; strip pointer
	dw $c8b6 ; strip destination
	db 9, ROUTE_22_WIDTH ; (connection strip length, connected map width)
	db 248, ((ROUTE_22_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window
; 0x952f4

Route22_SecondMapHeader: ; 0x952f4
	; border block
	db $2c

	; height, width
	db ROUTE_22_HEIGHT, ROUTE_22_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route22_BlockData), Route22_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route22_MapScriptHeader), Route22_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route22_MapEventHeader

	; connections
	db EAST

	; EAST to Viridian City
	db GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY ; connected map (group, id)
	dw (ViridianCity_BlockData + 100 - (VIRIDIAN_CITY_WIDTH * 4)) ; strip pointer
	dw $c817 ; strip destination
	db 15, VIRIDIAN_CITY_WIDTH ; (connection strip length, connected map width)
	db 8, 0 ; yoffset, xoffset
	dw ($C807 + VIRIDIAN_CITY_WIDTH) ; window
; 0x9530c

Route1_SecondMapHeader: ; 0x9530c
	; border block
	db $f

	; height, width
	db ROUTE_1_HEIGHT, ROUTE_1_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route1_BlockData), Route1_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route1_MapScriptHeader), Route1_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route1_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Viridian City
	db GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY ; connected map (group, id)
	dw $6d9c ; strip pointer
	dw ($C703 + 253) ; strip destination
	db 13, VIRIDIAN_CITY_WIDTH ; (connection strip length, connected map width)
	db ((VIRIDIAN_CITY_HEIGHT * 2) - 1), 20 ; yoffset, xoffset
	dw ($C801 + ((VIRIDIAN_CITY_HEIGHT * 6) + (VIRIDIAN_CITY_HEIGHT * VIRIDIAN_CITY_WIDTH))) ; window

	; SOUTH to Pallet Town
	db GROUP_PALLET_TOWN, MAP_PALLET_TOWN ; connected map (group, id)
	dw (PalletTown_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_1_HEIGHT + 3) * (ROUTE_1_WIDTH + 6))) ; strip destination
	db 10, PALLET_TOWN_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + PALLET_TOWN_WIDTH) ; window
; 0x95330

PalletTown_SecondMapHeader: ; 0x95330
	; border block
	db $f

	; height, width
	db PALLET_TOWN_HEIGHT, PALLET_TOWN_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(PalletTown_BlockData), PalletTown_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PalletTown_MapScriptHeader), PalletTown_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PalletTown_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Route 1
	db GROUP_ROUTE_1, MAP_ROUTE_1 ; connected map (group, id)
	dw (Route1_BlockData + (ROUTE_1_HEIGHT * ROUTE_1_WIDTH) - (ROUTE_1_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 10, ROUTE_1_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_1_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_1_HEIGHT * 6) + (ROUTE_1_HEIGHT * ROUTE_1_WIDTH))) ; window

	; SOUTH to Route 21
	db GROUP_ROUTE_21, MAP_ROUTE_21 ; connected map (group, id)
	dw (Route21_BlockData) ; strip pointer
	dw ($C703 + 256 + ((PALLET_TOWN_HEIGHT + 3) * (PALLET_TOWN_WIDTH + 6))) ; strip destination
	db 10, ROUTE_21_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_21_WIDTH) ; window
; 0x95354

Route21_SecondMapHeader: ; 0x95354
	; border block
	db $43

	; height, width
	db ROUTE_21_HEIGHT, ROUTE_21_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route21_BlockData), Route21_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route21_MapScriptHeader), Route21_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route21_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Pallet Town
	db GROUP_PALLET_TOWN, MAP_PALLET_TOWN ; connected map (group, id)
	dw (PalletTown_BlockData + (PALLET_TOWN_HEIGHT * PALLET_TOWN_WIDTH) - (PALLET_TOWN_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 10, PALLET_TOWN_WIDTH ; (connection strip length, connected map width)
	db ((PALLET_TOWN_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((PALLET_TOWN_HEIGHT * 6) + (PALLET_TOWN_HEIGHT * PALLET_TOWN_WIDTH))) ; window

	; SOUTH to Cinnabar Island
	db GROUP_CINNABAR_ISLAND, MAP_CINNABAR_ISLAND ; connected map (group, id)
	dw (CinnabarIsland_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_21_HEIGHT + 3) * (ROUTE_21_WIDTH + 6))) ; strip destination
	db 10, CINNABAR_ISLAND_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + CINNABAR_ISLAND_WIDTH) ; window
; 0x95378

CinnabarIsland_SecondMapHeader: ; 0x95378
	; border block
	db $43

	; height, width
	db CINNABAR_ISLAND_HEIGHT, CINNABAR_ISLAND_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarIsland_BlockData), CinnabarIsland_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CinnabarIsland_MapScriptHeader), CinnabarIsland_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CinnabarIsland_MapEventHeader

	; connections
	db NORTH | EAST

	; NORTH to Route 21
	db GROUP_ROUTE_21, MAP_ROUTE_21 ; connected map (group, id)
	dw (Route21_BlockData + (ROUTE_21_HEIGHT * ROUTE_21_WIDTH) - (ROUTE_21_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 10, ROUTE_21_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_21_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_21_HEIGHT * 6) + (ROUTE_21_HEIGHT * ROUTE_21_WIDTH))) ; window

	; EAST to Route 20
	db GROUP_ROUTE_20, MAP_ROUTE_20 ; connected map (group, id)
	dw (Route20_BlockData) ; strip pointer
	dw $c83d ; strip destination
	db 9, ROUTE_20_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_20_WIDTH) ; window
; 0x9539c

Route20_SecondMapHeader: ; 0x9539c
	; border block
	db $43

	; height, width
	db ROUTE_20_HEIGHT, ROUTE_20_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route20_BlockData), Route20_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route20_MapScriptHeader), Route20_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route20_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Cinnabar Island
	db GROUP_CINNABAR_ISLAND, MAP_CINNABAR_ISLAND ; connected map (group, id)
	dw (CinnabarIsland_BlockData + CINNABAR_ISLAND_WIDTH - 3) ; strip pointer
	dw $c86c ; strip destination
	db 9, CINNABAR_ISLAND_WIDTH ; (connection strip length, connected map width)
	db 0, ((CINNABAR_ISLAND_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window

	; EAST to Route 19
	db GROUP_ROUTE_19, MAP_ROUTE_19 ; connected map (group, id)
	dw (Route19_BlockData + ((ROUTE_19_HEIGHT - 12) * ROUTE_19_WIDTH)) ; strip pointer
	dw $c821 ; strip destination
	db 12, ROUTE_19_WIDTH ; (connection strip length, connected map width)
	db 18, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_19_WIDTH) ; window
; 0x953c0

Route19_SecondMapHeader: ; 0x953c0
	; border block
	db $43

	; height, width
	db ROUTE_19_HEIGHT, ROUTE_19_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route19_BlockData), Route19_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route19_MapScriptHeader), Route19_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route19_MapEventHeader

	; connections
	db NORTH | WEST

	; NORTH to Fuchsia City
	db GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY ; connected map (group, id)
	dw (FuchsiaCity_BlockData + (FUCHSIA_CITY_HEIGHT * FUCHSIA_CITY_WIDTH) - (FUCHSIA_CITY_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 13, FUCHSIA_CITY_WIDTH ; (connection strip length, connected map width)
	db ((FUCHSIA_CITY_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((FUCHSIA_CITY_HEIGHT * 6) + (FUCHSIA_CITY_HEIGHT * FUCHSIA_CITY_WIDTH))) ; window

	; WEST to Route 20
	db GROUP_ROUTE_20, MAP_ROUTE_20 ; connected map (group, id)
	dw (Route20_BlockData + ROUTE_20_WIDTH - 3) ; strip pointer
	dw $c8c0 ; strip destination
	db 9, ROUTE_20_WIDTH ; (connection strip length, connected map width)
	db 238, ((ROUTE_20_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 59) ; window
; 0x953e4

FuchsiaCity_SecondMapHeader: ; 0x953e4
	; border block
	db $f

	; height, width
	db FUCHSIA_CITY_HEIGHT, FUCHSIA_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(FuchsiaCity_BlockData), FuchsiaCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FuchsiaCity_MapScriptHeader), FuchsiaCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FuchsiaCity_MapEventHeader

	; connections
	db SOUTH | WEST | EAST

	; SOUTH to Route 19
	db GROUP_ROUTE_19, MAP_ROUTE_19 ; connected map (group, id)
	dw (Route19_BlockData) ; strip pointer
	dw ($C703 + 256 + ((FUCHSIA_CITY_HEIGHT + 3) * (FUCHSIA_CITY_WIDTH + 6))) ; strip destination
	db 10, ROUTE_19_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_19_WIDTH) ; window

	; WEST to Route 18
	db GROUP_ROUTE_18, MAP_ROUTE_18 ; connected map (group, id)
	dw (Route18_BlockData + ROUTE_18_WIDTH - 3) ; strip pointer
	dw $c904 ; strip destination
	db 9, ROUTE_18_WIDTH ; (connection strip length, connected map width)
	db 242, ((ROUTE_18_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window

	; EAST to Route 15
	db GROUP_ROUTE_15, MAP_ROUTE_15 ; connected map (group, id)
	dw (Route15_BlockData) ; strip pointer
	dw $c94f ; strip destination
	db 9, ROUTE_15_WIDTH ; (connection strip length, connected map width)
	db 238, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_15_WIDTH) ; window
; 0x95414

Route18_SecondMapHeader: ; 0x95414
	; border block
	db $43

	; height, width
	db ROUTE_18_HEIGHT, ROUTE_18_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route18_BlockData), Route18_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route18_MapScriptHeader), Route18_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route18_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Route 17
	db GROUP_ROUTE_17, MAP_ROUTE_17 ; connected map (group, id)
	dw $7152 ; strip pointer
	dw $c800 ; strip destination
	db 10, ROUTE_17_WIDTH ; (connection strip length, connected map width)
	db 76, ((ROUTE_17_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window

	; EAST to Fuchsia City
	db GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY ; connected map (group, id)
	dw (FuchsiaCity_BlockData + ((FUCHSIA_CITY_HEIGHT - 14) * FUCHSIA_CITY_WIDTH)) ; strip pointer
	dw $c80d ; strip destination
	db 14, FUCHSIA_CITY_WIDTH ; (connection strip length, connected map width)
	db 14, 0 ; yoffset, xoffset
	dw ($C807 + FUCHSIA_CITY_WIDTH) ; window
; 0x95438

Route17_SecondMapHeader: ; 0x95438
	; border block
	db $43

	; height, width
	db ROUTE_17_HEIGHT, ROUTE_17_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route17_BlockData), Route17_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route17_MapScriptHeader), Route17_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route17_MapEventHeader

	; connections
	db NORTH | EAST

	; NORTH to Route 16
	db GROUP_ROUTE_16, MAP_ROUTE_16 ; connected map (group, id)
	dw (Route16_BlockData + (ROUTE_16_HEIGHT * ROUTE_16_WIDTH) - (ROUTE_16_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 10, ROUTE_16_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_16_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_16_HEIGHT * 6) + (ROUTE_16_HEIGHT * ROUTE_16_WIDTH))) ; window

	; EAST to Route 18
	db GROUP_ROUTE_18, MAP_ROUTE_18 ; connected map (group, id)
	dw (Route18_BlockData) ; strip pointer
	dw $ca9d ; strip destination
	db 9, ROUTE_18_WIDTH ; (connection strip length, connected map width)
	db 180, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_18_WIDTH) ; window
; 0x9545c

Route16_SecondMapHeader: ; 0x9545c
	; border block
	db $f

	; height, width
	db ROUTE_16_HEIGHT, ROUTE_16_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route16_BlockData), Route16_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route16_MapScriptHeader), Route16_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route16_MapEventHeader

	; connections
	db SOUTH | EAST

	; SOUTH to Route 17
	db GROUP_ROUTE_17, MAP_ROUTE_17 ; connected map (group, id)
	dw (Route17_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_16_HEIGHT + 3) * (ROUTE_16_WIDTH + 6))) ; strip destination
	db 10, ROUTE_17_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_17_WIDTH) ; window

	; EAST to Celadon City
	db GROUP_CELADON_CITY, MAP_CELADON_CITY ; connected map (group, id)
	dw (CeladonCity_BlockData + ((CELADON_CITY_HEIGHT - 12) * CELADON_CITY_WIDTH)) ; strip pointer
	dw $c80d ; strip destination
	db 12, CELADON_CITY_WIDTH ; (connection strip length, connected map width)
	db 18, 0 ; yoffset, xoffset
	dw ($C807 + CELADON_CITY_WIDTH) ; window
; 0x95480

CeladonCity_SecondMapHeader: ; 0x95480
	; border block
	db $f

	; height, width
	db CELADON_CITY_HEIGHT, CELADON_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeladonCity_BlockData), CeladonCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonCity_MapScriptHeader), CeladonCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonCity_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Route 16
	db GROUP_ROUTE_16, MAP_ROUTE_16 ; connected map (group, id)
	dw (Route16_BlockData + ROUTE_16_WIDTH - 3) ; strip pointer
	dw $c938 ; strip destination
	db 9, ROUTE_16_WIDTH ; (connection strip length, connected map width)
	db 238, ((ROUTE_16_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window

	; EAST to Route 7
	db GROUP_ROUTE_7, MAP_ROUTE_7 ; connected map (group, id)
	dw (Route7_BlockData) ; strip pointer
	dw $c8e7 ; strip destination
	db 9, ROUTE_7_WIDTH ; (connection strip length, connected map width)
	db 246, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_7_WIDTH) ; window
; 0x954a4

Route7_SecondMapHeader: ; 0x954a4
	; border block
	db $f

	; height, width
	db ROUTE_7_HEIGHT, ROUTE_7_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route7_BlockData), Route7_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route7_MapScriptHeader), Route7_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route7_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Celadon City
	db GROUP_CELADON_CITY, MAP_CELADON_CITY ; connected map (group, id)
	dw (CeladonCity_BlockData + 21 + (CELADON_CITY_HEIGHT * 2)) ; strip pointer
	dw $c800 ; strip destination
	db 15, CELADON_CITY_WIDTH ; (connection strip length, connected map width)
	db 10, ((CELADON_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window

	; EAST to Saffron City
	db GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY ; connected map (group, id)
	dw (SaffronCity_BlockData + ((SAFFRON_CITY_HEIGHT - 12) * SAFFRON_CITY_WIDTH)) ; strip pointer
	dw $c80d ; strip destination
	db 12, SAFFRON_CITY_WIDTH ; (connection strip length, connected map width)
	db 18, 0 ; yoffset, xoffset
	dw ($C807 + SAFFRON_CITY_WIDTH) ; window
; 0x954c8

Route15_SecondMapHeader: ; 0x954c8
	; border block
	db $f

	; height, width
	db ROUTE_15_HEIGHT, ROUTE_15_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route15_BlockData), Route15_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route15_MapScriptHeader), Route15_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route15_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Fuchsia City
	db GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY ; connected map (group, id)
	dw (FuchsiaCity_BlockData + (((FUCHSIA_CITY_HEIGHT - ROUTE_15_HEIGHT) * FUCHSIA_CITY_WIDTH) - (FUCHSIA_CITY_WIDTH * 3) + (FUCHSIA_CITY_WIDTH - 1) - 2)) ; strip pointer
	dw $c800 ; strip destination
	db 12, FUCHSIA_CITY_WIDTH ; (connection strip length, connected map width)
	db 18, ((FUCHSIA_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window

	; EAST to Route 14
	db GROUP_ROUTE_14, MAP_ROUTE_14 ; connected map (group, id)
	dw (Route14_BlockData + ((ROUTE_14_HEIGHT - 12) * ROUTE_14_WIDTH)) ; strip pointer
	dw $c817 ; strip destination
	db 12, ROUTE_14_WIDTH ; (connection strip length, connected map width)
	db 18, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_14_WIDTH) ; window
; 0x954ec

Route14_SecondMapHeader: ; 0x954ec
	; border block
	db $43

	; height, width
	db ROUTE_14_HEIGHT, ROUTE_14_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route14_BlockData), Route14_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route14_MapScriptHeader), Route14_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route14_MapEventHeader

	; connections
	db NORTH | WEST

	; NORTH to Route 13
	db GROUP_ROUTE_13, MAP_ROUTE_13 ; connected map (group, id)
	dw (Route13_BlockData + (ROUTE_13_HEIGHT * ROUTE_13_WIDTH) - (ROUTE_13_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 13, ROUTE_13_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_13_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_13_HEIGHT * 6) + (ROUTE_13_HEIGHT * ROUTE_13_WIDTH))) ; window

	; WEST to Route 15
	db GROUP_ROUTE_15, MAP_ROUTE_15 ; connected map (group, id)
	dw (Route15_BlockData + ROUTE_15_WIDTH - 3) ; strip pointer
	dw $c8c0 ; strip destination
	db 9, ROUTE_15_WIDTH ; (connection strip length, connected map width)
	db 238, ((ROUTE_15_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window
; 0x95510

Route13_SecondMapHeader: ; 0x95510
	; border block
	db $43

	; height, width
	db ROUTE_13_HEIGHT, ROUTE_13_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route13_BlockData), Route13_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route13_MapScriptHeader), Route13_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route13_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Route 12
	db GROUP_ROUTE_12, MAP_ROUTE_12 ; connected map (group, id)
	dw (Route12_BlockData + (ROUTE_12_HEIGHT * ROUTE_12_WIDTH) - (ROUTE_12_WIDTH * 3)) ; strip pointer
	dw ($C703 + 276) ; strip destination
	db 10, ROUTE_12_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_12_HEIGHT * 2) - 1), 216 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_12_HEIGHT * 6) + (ROUTE_12_HEIGHT * ROUTE_12_WIDTH))) ; window

	; SOUTH to Route 14
	db GROUP_ROUTE_14, MAP_ROUTE_14 ; connected map (group, id)
	dw (Route14_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_13_HEIGHT + 3) * (ROUTE_13_WIDTH + 6))) ; strip destination
	db 10, ROUTE_14_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_14_WIDTH) ; window
; 0x95534

Route12_SecondMapHeader: ; 0x95534
	; border block
	db $43

	; height, width
	db ROUTE_12_HEIGHT, ROUTE_12_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route12_BlockData), Route12_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route12_MapScriptHeader), Route12_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route12_MapEventHeader

	; connections
	db NORTH | SOUTH | WEST

	; NORTH to Lavender Town
	db GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN ; connected map (group, id)
	dw (LavenderTown_BlockData + (LAVENDER_TOWN_HEIGHT * LAVENDER_TOWN_WIDTH) - (LAVENDER_TOWN_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 10, LAVENDER_TOWN_WIDTH ; (connection strip length, connected map width)
	db ((LAVENDER_TOWN_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((LAVENDER_TOWN_HEIGHT * 6) + (LAVENDER_TOWN_HEIGHT * LAVENDER_TOWN_WIDTH))) ; window

	; SOUTH to Route 13
	db GROUP_ROUTE_13, MAP_ROUTE_13 ; connected map (group, id)
	dw (Route13_BlockData + (((40 - 13 + ROUTE_12_WIDTH) / 2) - 1)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_12_HEIGHT + 3) * (ROUTE_12_WIDTH + 6))) ; strip destination
	db 13, ROUTE_13_WIDTH ; (connection strip length, connected map width)
	db 0, 40 ; yoffset, xoffset
	dw ($C807 + ROUTE_13_WIDTH) ; window

	; WEST to Route 11
	db GROUP_ROUTE_11, MAP_ROUTE_11 ; connected map (group, id)
	dw (Route11_BlockData + ROUTE_11_WIDTH - 3) ; strip pointer
	dw $c8c0 ; strip destination
	db 9, ROUTE_11_WIDTH ; (connection strip length, connected map width)
	db 238, ((ROUTE_11_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window
; 0x95564

Route11_SecondMapHeader: ; 0x95564
	; border block
	db $f

	; height, width
	db ROUTE_11_HEIGHT, ROUTE_11_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route11_BlockData), Route11_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route11_MapScriptHeader), Route11_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route11_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Vermilion City
	db GROUP_VERMILION_CITY, MAP_VERMILION_CITY ; connected map (group, id)
	dw (VermilionCity_BlockData + VERMILION_CITY_WIDTH - 3) ; strip pointer
	dw $c84e ; strip destination
	db 12, VERMILION_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, ((VERMILION_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window

	; EAST to Route 12
	db GROUP_ROUTE_12, MAP_ROUTE_12 ; connected map (group, id)
	dw (Route12_BlockData + 100 - (ROUTE_12_WIDTH * 4)) ; strip pointer
	dw $c817 ; strip destination
	db 15, ROUTE_12_WIDTH ; (connection strip length, connected map width)
	db 18, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_12_WIDTH) ; window
; 0x95588

LavenderTown_SecondMapHeader: ; 0x95588
	; border block
	db $2c

	; height, width
	db LAVENDER_TOWN_HEIGHT, LAVENDER_TOWN_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(LavenderTown_BlockData), LavenderTown_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LavenderTown_MapScriptHeader), LavenderTown_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LavenderTown_MapEventHeader

	; connections
	db NORTH | SOUTH | WEST

	; NORTH to Route 10 South
	db GROUP_ROUTE_10_SOUTH, MAP_ROUTE_10_SOUTH ; connected map (group, id)
	dw (Route10South_BlockData + (ROUTE_10_SOUTH_HEIGHT * ROUTE_10_SOUTH_WIDTH) - (ROUTE_10_SOUTH_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 10, ROUTE_10_SOUTH_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_10_SOUTH_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_10_SOUTH_HEIGHT * 6) + (ROUTE_10_SOUTH_HEIGHT * ROUTE_10_SOUTH_WIDTH))) ; window

	; SOUTH to Route 12
	db GROUP_ROUTE_12, MAP_ROUTE_12 ; connected map (group, id)
	dw (Route12_BlockData) ; strip pointer
	dw ($C703 + 256 + ((LAVENDER_TOWN_HEIGHT + 3) * (LAVENDER_TOWN_WIDTH + 6))) ; strip destination
	db 10, ROUTE_12_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_12_WIDTH) ; window

	; WEST to Route 8
	db GROUP_ROUTE_8, MAP_ROUTE_8 ; connected map (group, id)
	dw (Route8_BlockData + ROUTE_8_WIDTH - 3) ; strip pointer
	dw $c830 ; strip destination
	db 9, ROUTE_8_WIDTH ; (connection strip length, connected map width)
	db 0, ((ROUTE_8_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window
; 0x955b8

VermilionCity_SecondMapHeader: ; 0x955b8
	; border block
	db $43

	; height, width
	db VERMILION_CITY_HEIGHT, VERMILION_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(VermilionCity_BlockData), VermilionCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionCity_MapScriptHeader), VermilionCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionCity_MapEventHeader

	; connections
	db NORTH | EAST

	; NORTH to Route 6
	db GROUP_ROUTE_6, MAP_ROUTE_6 ; connected map (group, id)
	dw (Route6_BlockData + (ROUTE_6_HEIGHT * ROUTE_6_WIDTH) - (ROUTE_6_WIDTH * 3)) ; strip pointer
	dw ($C703 + 261) ; strip destination
	db 10, ROUTE_6_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_6_HEIGHT * 2) - 1), 246 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_6_HEIGHT * 6) + (ROUTE_6_HEIGHT * ROUTE_6_WIDTH))) ; window

	; EAST to Route 11
	db GROUP_ROUTE_11, MAP_ROUTE_11 ; connected map (group, id)
	dw (Route11_BlockData) ; strip pointer
	dw $c865 ; strip destination
	db 9, ROUTE_11_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_11_WIDTH) ; window
; 0x955dc

Route6_SecondMapHeader: ; 0x955dc
	; border block
	db $f

	; height, width
	db ROUTE_6_HEIGHT, ROUTE_6_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route6_BlockData), Route6_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route6_MapScriptHeader), Route6_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route6_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Saffron City
	db GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY ; connected map (group, id)
	dw (SaffronCity_BlockData + SAFFRON_CITY_WIDTH + 10 + (16 * SAFFRON_CITY_HEIGHT) - 16) ; strip pointer
	dw ($C703 + 253) ; strip destination
	db 16, SAFFRON_CITY_WIDTH ; (connection strip length, connected map width)
	db ((SAFFRON_CITY_HEIGHT * 2) - 1), 10 ; yoffset, xoffset
	dw ($C801 + ((SAFFRON_CITY_HEIGHT * 6) + (SAFFRON_CITY_HEIGHT * SAFFRON_CITY_WIDTH))) ; window

	; SOUTH to Vermilion City
	db GROUP_VERMILION_CITY, MAP_VERMILION_CITY ; connected map (group, id)
	dw (VermilionCity_BlockData + ((10 - 16 + ROUTE_6_WIDTH) / 2)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_6_HEIGHT + 3) * (ROUTE_6_WIDTH + 6))) ; strip destination
	db 16, VERMILION_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, 10 ; yoffset, xoffset
	dw ($C807 + VERMILION_CITY_WIDTH) ; window
; 0x95600

SaffronCity_SecondMapHeader: ; 0x95600
	; border block
	db $f

	; height, width
	db SAFFRON_CITY_HEIGHT, SAFFRON_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SaffronCity_BlockData), SaffronCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SaffronCity_MapScriptHeader), SaffronCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SaffronCity_MapEventHeader

	; connections
	db NORTH | SOUTH | WEST | EAST

	; NORTH to Route 5
	db GROUP_ROUTE_5, MAP_ROUTE_5 ; connected map (group, id)
	dw (Route5_BlockData + (ROUTE_5_HEIGHT * ROUTE_5_WIDTH) - (ROUTE_5_WIDTH * 3)) ; strip pointer
	dw ($C703 + 261) ; strip destination
	db 10, ROUTE_5_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_5_HEIGHT * 2) - 1), 246 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_5_HEIGHT * 6) + (ROUTE_5_HEIGHT * ROUTE_5_WIDTH))) ; window

	; SOUTH to Route 6
	db GROUP_ROUTE_6, MAP_ROUTE_6 ; connected map (group, id)
	dw (Route6_BlockData) ; strip pointer
	dw ($C703 + 261 + ((SAFFRON_CITY_HEIGHT + 3) * (SAFFRON_CITY_WIDTH + 6))) ; strip destination
	db 10, ROUTE_6_WIDTH ; (connection strip length, connected map width)
	db 0, 246 ; yoffset, xoffset
	dw ($C807 + ROUTE_6_WIDTH) ; window

	; WEST to Route 7
	db GROUP_ROUTE_7, MAP_ROUTE_7 ; connected map (group, id)
	dw (Route7_BlockData + ROUTE_7_WIDTH - 3) ; strip pointer
	dw $c938 ; strip destination
	db 9, ROUTE_7_WIDTH ; (connection strip length, connected map width)
	db 238, ((ROUTE_7_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 19) ; window

	; EAST to Route 8
	db GROUP_ROUTE_8, MAP_ROUTE_8 ; connected map (group, id)
	dw (Route8_BlockData) ; strip pointer
	dw $c94f ; strip destination
	db 9, ROUTE_8_WIDTH ; (connection strip length, connected map width)
	db 238, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_8_WIDTH) ; window
; 0x9563c

Route5_SecondMapHeader: ; 0x9563c
	; border block
	db $f

	; height, width
	db ROUTE_5_HEIGHT, ROUTE_5_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route5_BlockData), Route5_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route5_MapScriptHeader), Route5_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route5_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Cerulean City
	db GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY ; connected map (group, id)
	dw (CeruleanCity_BlockData + CERULEAN_CITY_WIDTH + 10 + (16 * CERULEAN_CITY_HEIGHT) - 16) ; strip pointer
	dw ($C703 + 253) ; strip destination
	db 16, CERULEAN_CITY_WIDTH ; (connection strip length, connected map width)
	db ((CERULEAN_CITY_HEIGHT * 2) - 1), 10 ; yoffset, xoffset
	dw ($C801 + ((CERULEAN_CITY_HEIGHT * 6) + (CERULEAN_CITY_HEIGHT * CERULEAN_CITY_WIDTH))) ; window

	; SOUTH to Saffron City
	db GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY ; connected map (group, id)
	dw (SaffronCity_BlockData + ((10 - 16 + ROUTE_5_WIDTH) / 2)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_5_HEIGHT + 3) * (ROUTE_5_WIDTH + 6))) ; strip destination
	db 16, SAFFRON_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, 10 ; yoffset, xoffset
	dw ($C807 + SAFFRON_CITY_WIDTH) ; window
; 0x95660

CeruleanCity_SecondMapHeader: ; 0x95660
	; border block
	db $f

	; height, width
	db CERULEAN_CITY_HEIGHT, CERULEAN_CITY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeruleanCity_BlockData), CeruleanCity_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeruleanCity_MapScriptHeader), CeruleanCity_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeruleanCity_MapEventHeader

	; connections
	db NORTH | SOUTH | WEST | EAST

	; NORTH to Route 24
	db GROUP_ROUTE_24, MAP_ROUTE_24 ; connected map (group, id)
	dw (Route24_BlockData + (ROUTE_24_HEIGHT * ROUTE_24_WIDTH) - (ROUTE_24_WIDTH * 3)) ; strip pointer
	dw ($C703 + 262) ; strip destination
	db 10, ROUTE_24_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_24_HEIGHT * 2) - 1), 244 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_24_HEIGHT * 6) + (ROUTE_24_HEIGHT * ROUTE_24_WIDTH))) ; window

	; SOUTH to Route 5
	db GROUP_ROUTE_5, MAP_ROUTE_5 ; connected map (group, id)
	dw (Route5_BlockData) ; strip pointer
	dw ($C703 + 261 + ((CERULEAN_CITY_HEIGHT + 3) * (CERULEAN_CITY_WIDTH + 6))) ; strip destination
	db 10, ROUTE_5_WIDTH ; (connection strip length, connected map width)
	db 0, 246 ; yoffset, xoffset
	dw ($C807 + ROUTE_5_WIDTH) ; window

	; WEST to Route 4
	db GROUP_ROUTE_4, MAP_ROUTE_4 ; connected map (group, id)
	dw (Route4_BlockData + ROUTE_4_WIDTH - 3) ; strip pointer
	dw $c8d0 ; strip destination
	db 9, ROUTE_4_WIDTH ; (connection strip length, connected map width)
	db 246, ((ROUTE_4_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window

	; EAST to Route 9
	db GROUP_ROUTE_9, MAP_ROUTE_9 ; connected map (group, id)
	dw (Route9_BlockData) ; strip pointer
	dw $c94f ; strip destination
	db 9, ROUTE_9_WIDTH ; (connection strip length, connected map width)
	db 238, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_9_WIDTH) ; window
; 0x9569c

Route9_SecondMapHeader: ; 0x9569c
	; border block
	db $2c

	; height, width
	db ROUTE_9_HEIGHT, ROUTE_9_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route9_BlockData), Route9_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route9_MapScriptHeader), Route9_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route9_MapEventHeader

	; connections
	db SOUTH | WEST

	; SOUTH to Route 10 North
	db GROUP_ROUTE_10_NORTH, MAP_ROUTE_10_NORTH ; connected map (group, id)
	dw (Route10North_BlockData) ; strip pointer
	dw ($C703 + 276 + ((ROUTE_9_HEIGHT + 3) * (ROUTE_9_WIDTH + 6))) ; strip destination
	db 10, ROUTE_10_NORTH_WIDTH ; (connection strip length, connected map width)
	db 0, 216 ; yoffset, xoffset
	dw ($C807 + ROUTE_10_NORTH_WIDTH) ; window

	; WEST to Cerulean City
	db GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY ; connected map (group, id)
	dw (CeruleanCity_BlockData + (((CERULEAN_CITY_HEIGHT - ROUTE_9_HEIGHT) * CERULEAN_CITY_WIDTH) - (CERULEAN_CITY_WIDTH * 3) + (CERULEAN_CITY_WIDTH - 1) - 2)) ; strip pointer
	dw $c800 ; strip destination
	db 12, CERULEAN_CITY_WIDTH ; (connection strip length, connected map width)
	db 18, ((CERULEAN_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window
; 0x956c0

Route24_SecondMapHeader: ; 0x956c0
	; border block
	db $2c

	; height, width
	db ROUTE_24_HEIGHT, ROUTE_24_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route24_BlockData), Route24_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route24_MapScriptHeader), Route24_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route24_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Route 25
	db GROUP_ROUTE_25, MAP_ROUTE_25 ; connected map (group, id)
	dw (Route25_BlockData + (ROUTE_25_HEIGHT * ROUTE_25_WIDTH) - (ROUTE_25_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 13, ROUTE_25_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_25_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_25_HEIGHT * 6) + (ROUTE_25_HEIGHT * ROUTE_25_WIDTH))) ; window

	; SOUTH to Cerulean City
	db GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY ; connected map (group, id)
	dw (CeruleanCity_BlockData + ((12 - 16 + ROUTE_24_WIDTH) / 2)) ; strip pointer
	dw ($C703 + 253 + ((ROUTE_24_HEIGHT + 3) * (ROUTE_24_WIDTH + 6))) ; strip destination
	db 16, CERULEAN_CITY_WIDTH ; (connection strip length, connected map width)
	db 0, 12 ; yoffset, xoffset
	dw ($C807 + CERULEAN_CITY_WIDTH) ; window
; 0x956e4

Route25_SecondMapHeader: ; 0x956e4
	; border block
	db $2c

	; height, width
	db ROUTE_25_HEIGHT, ROUTE_25_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route25_BlockData), Route25_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route25_MapScriptHeader), Route25_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route25_MapEventHeader

	; connections
	db SOUTH

	; SOUTH to Route 24
	db GROUP_ROUTE_24, MAP_ROUTE_24 ; connected map (group, id)
	dw (Route24_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_25_HEIGHT + 3) * (ROUTE_25_WIDTH + 6))) ; strip destination
	db 10, ROUTE_24_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_24_WIDTH) ; window
; 0x956fc

Route3_SecondMapHeader: ; 0x956fc
	; border block
	db $2c

	; height, width
	db ROUTE_3_HEIGHT, ROUTE_3_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route3_BlockData), Route3_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route3_MapScriptHeader), Route3_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route3_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Pewter City
	db GROUP_PEWTER_CITY, MAP_PEWTER_CITY ; connected map (group, id)
	dw (PewterCity_BlockData + 21 + (PEWTER_CITY_HEIGHT * 2)) ; strip pointer
	dw $c800 ; strip destination
	db 15, PEWTER_CITY_WIDTH ; (connection strip length, connected map width)
	db 10, ((PEWTER_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window

	; EAST to Route 4
	db GROUP_ROUTE_4, MAP_ROUTE_4 ; connected map (group, id)
	dw (Route4_BlockData) ; strip pointer
	dw $c88d ; strip destination
	db 9, ROUTE_4_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_4_WIDTH) ; window
; 0x95720

Route4_SecondMapHeader: ; 0x95720
	; border block
	db $2c

	; height, width
	db ROUTE_4_HEIGHT, ROUTE_4_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route4_BlockData), Route4_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route4_MapScriptHeader), Route4_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route4_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Route 3
	db GROUP_ROUTE_3, MAP_ROUTE_3 ; connected map (group, id)
	dw (Route3_BlockData + ROUTE_3_WIDTH - 3) ; strip pointer
	dw $c84e ; strip destination
	db 9, ROUTE_3_WIDTH ; (connection strip length, connected map width)
	db 0, ((ROUTE_3_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 59) ; window

	; EAST to Cerulean City
	db GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY ; connected map (group, id)
	dw (CeruleanCity_BlockData + ((100 - (CERULEAN_CITY_WIDTH * 4)) * 2)) ; strip pointer
	dw $c817 ; strip destination
	db 15, CERULEAN_CITY_WIDTH ; (connection strip length, connected map width)
	db 10, 0 ; yoffset, xoffset
	dw ($C807 + CERULEAN_CITY_WIDTH) ; window
; 0x95744

Route8_SecondMapHeader: ; 0x95744
	; border block
	db $2c

	; height, width
	db ROUTE_8_HEIGHT, ROUTE_8_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route8_BlockData), Route8_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route8_MapScriptHeader), Route8_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route8_MapEventHeader

	; connections
	db WEST | EAST

	; WEST to Saffron City
	db GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY ; connected map (group, id)
	dw (SaffronCity_BlockData + (((SAFFRON_CITY_HEIGHT - ROUTE_8_HEIGHT) * SAFFRON_CITY_WIDTH) - (SAFFRON_CITY_WIDTH * 3) + (SAFFRON_CITY_WIDTH - 1) - 2)) ; strip pointer
	dw $c800 ; strip destination
	db 12, SAFFRON_CITY_WIDTH ; (connection strip length, connected map width)
	db 18, ((SAFFRON_CITY_WIDTH * 2) - 1) ; yoffset, xoffset
	dw ($C807 + 39) ; window

	; EAST to Lavender Town
	db GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN ; connected map (group, id)
	dw (LavenderTown_BlockData) ; strip pointer
	dw $c865 ; strip destination
	db 9, LAVENDER_TOWN_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + LAVENDER_TOWN_WIDTH) ; window
; 0x95768

Route10North_SecondMapHeader: ; 0x95768
	; border block
	db $2c

	; height, width
	db ROUTE_10_NORTH_HEIGHT, ROUTE_10_NORTH_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route10North_BlockData), Route10North_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route10North_MapScriptHeader), Route10North_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route10North_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Route 9
	db GROUP_ROUTE_9, MAP_ROUTE_9 ; connected map (group, id)
	dw $7eae ; strip pointer
	dw ($C703 + 253) ; strip destination
	db 13, ROUTE_9_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_9_HEIGHT * 2) - 1), 40 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_9_HEIGHT * 6) + (ROUTE_9_HEIGHT * ROUTE_9_WIDTH))) ; window

	; SOUTH to Route 10 South
	db GROUP_ROUTE_10_SOUTH, MAP_ROUTE_10_SOUTH ; connected map (group, id)
	dw (Route10South_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_10_NORTH_HEIGHT + 3) * (ROUTE_10_NORTH_WIDTH + 6))) ; strip destination
	db 10, ROUTE_10_SOUTH_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + ROUTE_10_SOUTH_WIDTH) ; window
; 0x9578c

Route10South_SecondMapHeader: ; 0x9578c
	; border block
	db $2c

	; height, width
	db ROUTE_10_SOUTH_HEIGHT, ROUTE_10_SOUTH_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route10South_BlockData), Route10South_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route10South_MapScriptHeader), Route10South_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route10South_MapEventHeader

	; connections
	db NORTH | SOUTH

	; NORTH to Route 10 North
	db GROUP_ROUTE_10_NORTH, MAP_ROUTE_10_NORTH ; connected map (group, id)
	dw (Route10North_BlockData + (ROUTE_10_NORTH_HEIGHT * ROUTE_10_NORTH_WIDTH) - (ROUTE_10_NORTH_WIDTH * 3)) ; strip pointer
	dw ($C703 + 256) ; strip destination
	db 10, ROUTE_10_NORTH_WIDTH ; (connection strip length, connected map width)
	db ((ROUTE_10_NORTH_HEIGHT * 2) - 1), 0 ; yoffset, xoffset
	dw ($C801 + ((ROUTE_10_NORTH_HEIGHT * 6) + (ROUTE_10_NORTH_HEIGHT * ROUTE_10_NORTH_WIDTH))) ; window

	; SOUTH to Lavender Town
	db GROUP_LAVENDER_TOWN, MAP_LAVENDER_TOWN ; connected map (group, id)
	dw (LavenderTown_BlockData) ; strip pointer
	dw ($C703 + 256 + ((ROUTE_10_SOUTH_HEIGHT + 3) * (ROUTE_10_SOUTH_WIDTH + 6))) ; strip destination
	db 10, LAVENDER_TOWN_WIDTH ; (connection strip length, connected map width)
	db 0, 0 ; yoffset, xoffset
	dw ($C807 + LAVENDER_TOWN_WIDTH) ; window
; 0x957b0

Route23_SecondMapHeader: ; 0x957b0
	; border block
	db $f

	; height, width
	db ROUTE_23_HEIGHT, ROUTE_23_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route23_BlockData), Route23_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route23_MapScriptHeader), Route23_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route23_MapEventHeader

	; connections
	db 0
; 0x957bc

SproutTower1F_SecondMapHeader: ; 0x957bc
	; border block
	db $0

	; height, width
	db SPROUT_TOWER_1F_HEIGHT, SPROUT_TOWER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SproutTower1F_BlockData), SproutTower1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SproutTower1F_MapScriptHeader), SproutTower1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SproutTower1F_MapEventHeader

	; connections
	db 0
; 0x957c8

SproutTower2F_SecondMapHeader: ; 0x957c8
	; border block
	db $0

	; height, width
	db SPROUT_TOWER_2F_HEIGHT, SPROUT_TOWER_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SproutTower2F_BlockData), SproutTower2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SproutTower2F_MapScriptHeader), SproutTower2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SproutTower2F_MapEventHeader

	; connections
	db 0
; 0x957d4

SproutTower3F_SecondMapHeader: ; 0x957d4
	; border block
	db $0

	; height, width
	db SPROUT_TOWER_3F_HEIGHT, SPROUT_TOWER_3F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SproutTower3F_BlockData), SproutTower3F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SproutTower3F_MapScriptHeader), SproutTower3F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SproutTower3F_MapEventHeader

	; connections
	db 0
; 0x957e0

TinTower1F_SecondMapHeader: ; 0x957e0
	; border block
	db $0

	; height, width
	db TIN_TOWER_1F_HEIGHT, TIN_TOWER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTower1F_BlockData), TinTower1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTower1F_MapScriptHeader), TinTower1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTower1F_MapEventHeader

	; connections
	db 0
; 0x957ec

TinTower2F_SecondMapHeader: ; 0x957ec
	; border block
	db $0

	; height, width
	db TIN_TOWER_2F_HEIGHT, TIN_TOWER_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTower2F_BlockData), TinTower2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTower2F_MapScriptHeader), TinTower2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTower2F_MapEventHeader

	; connections
	db 0
; 0x957f8

TinTower3F_SecondMapHeader: ; 0x957f8
	; border block
	db $0

	; height, width
	db TIN_TOWER_3F_HEIGHT, TIN_TOWER_3F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTower3F_BlockData), TinTower3F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTower3F_MapScriptHeader), TinTower3F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTower3F_MapEventHeader

	; connections
	db 0
; 0x95804

TinTower4F_SecondMapHeader: ; 0x95804
	; border block
	db $0

	; height, width
	db TIN_TOWER_4F_HEIGHT, TIN_TOWER_4F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTower4F_BlockData), TinTower4F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTower4F_MapScriptHeader), TinTower4F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTower4F_MapEventHeader

	; connections
	db 0
; 0x95810

TinTower5F_SecondMapHeader: ; 0x95810
	; border block
	db $0

	; height, width
	db TIN_TOWER_5F_HEIGHT, TIN_TOWER_5F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTower5F_BlockData), TinTower5F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTower5F_MapScriptHeader), TinTower5F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTower5F_MapEventHeader

	; connections
	db 0
; 0x9581c

TinTower6F_SecondMapHeader: ; 0x9581c
	; border block
	db $0

	; height, width
	db TIN_TOWER_6F_HEIGHT, TIN_TOWER_6F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTower6F_BlockData), TinTower6F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTower6F_MapScriptHeader), TinTower6F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTower6F_MapEventHeader

	; connections
	db 0
; 0x95828

TinTower7F_SecondMapHeader: ; 0x95828
	; border block
	db $0

	; height, width
	db TIN_TOWER_7F_HEIGHT, TIN_TOWER_7F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTower7F_BlockData), TinTower7F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTower7F_MapScriptHeader), TinTower7F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTower7F_MapEventHeader

	; connections
	db 0
; 0x95834

TinTower8F_SecondMapHeader: ; 0x95834
	; border block
	db $0

	; height, width
	db TIN_TOWER_8F_HEIGHT, TIN_TOWER_8F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTower8F_BlockData), TinTower8F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTower8F_MapScriptHeader), TinTower8F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTower8F_MapEventHeader

	; connections
	db 0
; 0x95840

TinTower9F_SecondMapHeader: ; 0x95840
	; border block
	db $0

	; height, width
	db TIN_TOWER_9F_HEIGHT, TIN_TOWER_9F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTower9F_BlockData), TinTower9F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTower9F_MapScriptHeader), TinTower9F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTower9F_MapEventHeader

	; connections
	db 0
; 0x9584c

BurnedTower1F_SecondMapHeader: ; 0x9584c
	; border block
	db $0

	; height, width
	db BURNED_TOWER_1F_HEIGHT, BURNED_TOWER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BurnedTower1F_BlockData), BurnedTower1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BurnedTower1F_MapScriptHeader), BurnedTower1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BurnedTower1F_MapEventHeader

	; connections
	db 0
; 0x95858

BurnedTowerB1F_SecondMapHeader: ; 0x95858
	; border block
	db $9

	; height, width
	db BURNED_TOWER_B1F_HEIGHT, BURNED_TOWER_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BurnedTowerB1F_BlockData), BurnedTowerB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BurnedTowerB1F_MapScriptHeader), BurnedTowerB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BurnedTowerB1F_MapEventHeader

	; connections
	db 0
; 0x95864

NationalPark_SecondMapHeader: ; 0x95864
	; border block
	db $0

	; height, width
	db NATIONAL_PARK_HEIGHT, NATIONAL_PARK_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(NationalPark_BlockData), NationalPark_BlockData

	; script header (bank-then-pointer)
	dbw BANK(NationalPark_MapScriptHeader), NationalPark_MapScriptHeader

	; map event header (bank-then-pointer)
	dw NationalPark_MapEventHeader

	; connections
	db 0
; 0x95870

NationalParkBugContest_SecondMapHeader: ; 0x95870
	; border block
	db $0

	; height, width
	db NATIONAL_PARK_BUG_CONTEST_HEIGHT, NATIONAL_PARK_BUG_CONTEST_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(NationalPark_BlockData), NationalPark_BlockData

	; script header (bank-then-pointer)
	dbw BANK(NationalParkBugContest_MapScriptHeader), NationalParkBugContest_MapScriptHeader

	; map event header (bank-then-pointer)
	dw NationalParkBugContest_MapEventHeader

	; connections
	db 0
; 0x9587c

RadioTower1F_SecondMapHeader: ; 0x9587c
	; border block
	db $0

	; height, width
	db RADIO_TOWER_1F_HEIGHT, RADIO_TOWER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RadioTower1F_BlockData), RadioTower1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RadioTower1F_MapScriptHeader), RadioTower1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RadioTower1F_MapEventHeader

	; connections
	db 0
; 0x95888

RadioTower2F_SecondMapHeader: ; 0x95888
	; border block
	db $0

	; height, width
	db RADIO_TOWER_2F_HEIGHT, RADIO_TOWER_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RadioTower2F_BlockData), RadioTower2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RadioTower2F_MapScriptHeader), RadioTower2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RadioTower2F_MapEventHeader

	; connections
	db 0
; 0x95894

RadioTower3F_SecondMapHeader: ; 0x95894
	; border block
	db $0

	; height, width
	db RADIO_TOWER_3F_HEIGHT, RADIO_TOWER_3F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RadioTower3F_BlockData), RadioTower3F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RadioTower3F_MapScriptHeader), RadioTower3F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RadioTower3F_MapEventHeader

	; connections
	db 0
; 0x958a0

RadioTower4F_SecondMapHeader: ; 0x958a0
	; border block
	db $0

	; height, width
	db RADIO_TOWER_4F_HEIGHT, RADIO_TOWER_4F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RadioTower4F_BlockData), RadioTower4F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RadioTower4F_MapScriptHeader), RadioTower4F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RadioTower4F_MapEventHeader

	; connections
	db 0
; 0x958ac

RadioTower5F_SecondMapHeader: ; 0x958ac
	; border block
	db $0

	; height, width
	db RADIO_TOWER_5F_HEIGHT, RADIO_TOWER_5F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RadioTower5F_BlockData), RadioTower5F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RadioTower5F_MapScriptHeader), RadioTower5F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RadioTower5F_MapEventHeader

	; connections
	db 0
; 0x958b8

RuinsofAlphOutside_SecondMapHeader: ; 0x958b8
	; border block
	db $5

	; height, width
	db RUINS_OF_ALPH_OUTSIDE_HEIGHT, RUINS_OF_ALPH_OUTSIDE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphOutside_BlockData), RuinsofAlphOutside_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphOutside_MapScriptHeader), RuinsofAlphOutside_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphOutside_MapEventHeader

	; connections
	db 0
; 0x958c4

RuinsofAlphHoOhChamber_SecondMapHeader: ; 0x958c4
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_HO_OH_CHAMBER_HEIGHT, RUINS_OF_ALPH_HO_OH_CHAMBER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhChamber_BlockData), RuinsofAlphHoOhChamber_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhChamber_MapScriptHeader), RuinsofAlphHoOhChamber_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphHoOhChamber_MapEventHeader

	; connections
	db 0
; 0x958d0

RuinsofAlphKabutoChamber_SecondMapHeader: ; 0x958d0
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_KABUTO_CHAMBER_HEIGHT, RUINS_OF_ALPH_KABUTO_CHAMBER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhChamber_BlockData), RuinsofAlphHoOhChamber_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphKabutoChamber_MapScriptHeader), RuinsofAlphKabutoChamber_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphKabutoChamber_MapEventHeader

	; connections
	db 0
; 0x958dc

RuinsofAlphOmanyteChamber_SecondMapHeader: ; 0x958dc
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_OMANYTE_CHAMBER_HEIGHT, RUINS_OF_ALPH_OMANYTE_CHAMBER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhChamber_BlockData), RuinsofAlphHoOhChamber_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphOmanyteChamber_MapScriptHeader), RuinsofAlphOmanyteChamber_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphOmanyteChamber_MapEventHeader

	; connections
	db 0
; 0x958e8

RuinsofAlphAerodactylChamber_SecondMapHeader: ; 0x958e8
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_AERODACTYL_CHAMBER_HEIGHT, RUINS_OF_ALPH_AERODACTYL_CHAMBER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhChamber_BlockData), RuinsofAlphHoOhChamber_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphAerodactylChamber_MapScriptHeader), RuinsofAlphAerodactylChamber_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphAerodactylChamber_MapEventHeader

	; connections
	db 0
; 0x958f4

RuinsofAlphInnerChamber_SecondMapHeader: ; 0x958f4
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_INNER_CHAMBER_HEIGHT, RUINS_OF_ALPH_INNER_CHAMBER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphInnerChamber_BlockData), RuinsofAlphInnerChamber_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphInnerChamber_MapScriptHeader), RuinsofAlphInnerChamber_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphInnerChamber_MapEventHeader

	; connections
	db 0
; 0x95900

RuinsofAlphResearchCenter_SecondMapHeader: ; 0x95900
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_RESEARCH_CENTER_HEIGHT, RUINS_OF_ALPH_RESEARCH_CENTER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphResearchCenter_BlockData), RuinsofAlphResearchCenter_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphResearchCenter_MapScriptHeader), RuinsofAlphResearchCenter_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphResearchCenter_MapEventHeader

	; connections
	db 0
; 0x9590c

RuinsofAlphHoOhItemRoom_SecondMapHeader: ; 0x9590c
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_HO_OH_ITEM_ROOM_HEIGHT, RUINS_OF_ALPH_HO_OH_ITEM_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhItemRoom_BlockData), RuinsofAlphHoOhItemRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhItemRoom_MapScriptHeader), RuinsofAlphHoOhItemRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphHoOhItemRoom_MapEventHeader

	; connections
	db 0
; 0x95918

RuinsofAlphKabutoItemRoom_SecondMapHeader: ; 0x95918
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_KABUTO_ITEM_ROOM_HEIGHT, RUINS_OF_ALPH_KABUTO_ITEM_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhItemRoom_BlockData), RuinsofAlphHoOhItemRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphKabutoItemRoom_MapScriptHeader), RuinsofAlphKabutoItemRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphKabutoItemRoom_MapEventHeader

	; connections
	db 0
; 0x95924

RuinsofAlphOmanyteItemRoom_SecondMapHeader: ; 0x95924
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_OMANYTE_ITEM_ROOM_HEIGHT, RUINS_OF_ALPH_OMANYTE_ITEM_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhItemRoom_BlockData), RuinsofAlphHoOhItemRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphOmanyteItemRoom_MapScriptHeader), RuinsofAlphOmanyteItemRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphOmanyteItemRoom_MapEventHeader

	; connections
	db 0
; 0x95930

RuinsofAlphAerodactylItemRoom_SecondMapHeader: ; 0x95930
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_AERODACTYL_ITEM_ROOM_HEIGHT, RUINS_OF_ALPH_AERODACTYL_ITEM_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhItemRoom_BlockData), RuinsofAlphHoOhItemRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphAerodactylItemRoom_MapScriptHeader), RuinsofAlphAerodactylItemRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphAerodactylItemRoom_MapEventHeader

	; connections
	db 0
; 0x9593c

RuinsofAlphHoOhWordRoom_SecondMapHeader: ; 0x9593c
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_HO_OH_WORD_ROOM_HEIGHT, RUINS_OF_ALPH_HO_OH_WORD_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhWordRoom_BlockData), RuinsofAlphHoOhWordRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphHoOhWordRoom_MapScriptHeader), RuinsofAlphHoOhWordRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphHoOhWordRoom_MapEventHeader

	; connections
	db 0
; 0x95948

RuinsofAlphKabutoWordRoom_SecondMapHeader: ; 0x95948
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_KABUTO_WORD_ROOM_HEIGHT, RUINS_OF_ALPH_KABUTO_WORD_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphKabutoWordRoom_BlockData), RuinsofAlphKabutoWordRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphKabutoWordRoom_MapScriptHeader), RuinsofAlphKabutoWordRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphKabutoWordRoom_MapEventHeader

	; connections
	db 0
; 0x95954

RuinsofAlphOmanyteWordRoom_SecondMapHeader: ; 0x95954
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_OMANYTE_WORD_ROOM_HEIGHT, RUINS_OF_ALPH_OMANYTE_WORD_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphOmanyteWordRoom_BlockData), RuinsofAlphOmanyteWordRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphOmanyteWordRoom_MapScriptHeader), RuinsofAlphOmanyteWordRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphOmanyteWordRoom_MapEventHeader

	; connections
	db 0
; 0x95960

RuinsofAlphAerodactylWordRoom_SecondMapHeader: ; 0x95960
	; border block
	db $0

	; height, width
	db RUINS_OF_ALPH_AERODACTYL_WORD_ROOM_HEIGHT, RUINS_OF_ALPH_AERODACTYL_WORD_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RuinsofAlphAerodactylWordRoom_BlockData), RuinsofAlphAerodactylWordRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RuinsofAlphAerodactylWordRoom_MapScriptHeader), RuinsofAlphAerodactylWordRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RuinsofAlphAerodactylWordRoom_MapEventHeader

	; connections
	db 0
; 0x9596c

UnionCave1F_SecondMapHeader: ; 0x9596c
	; border block
	db $9

	; height, width
	db UNION_CAVE_1F_HEIGHT, UNION_CAVE_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(UnionCave1F_BlockData), UnionCave1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(UnionCave1F_MapScriptHeader), UnionCave1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw UnionCave1F_MapEventHeader

	; connections
	db 0
; 0x95978

UnionCaveB1F_SecondMapHeader: ; 0x95978
	; border block
	db $9

	; height, width
	db UNION_CAVE_B1F_HEIGHT, UNION_CAVE_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(UnionCaveB1F_BlockData), UnionCaveB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(UnionCaveB1F_MapScriptHeader), UnionCaveB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw UnionCaveB1F_MapEventHeader

	; connections
	db 0
; 0x95984

UnionCaveB2F_SecondMapHeader: ; 0x95984
	; border block
	db $9

	; height, width
	db UNION_CAVE_B2F_HEIGHT, UNION_CAVE_B2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(UnionCaveB2F_BlockData), UnionCaveB2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(UnionCaveB2F_MapScriptHeader), UnionCaveB2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw UnionCaveB2F_MapEventHeader

	; connections
	db 0
; 0x95990

SlowpokeWellB1F_SecondMapHeader: ; 0x95990
	; border block
	db $9

	; height, width
	db SLOWPOKE_WELL_B1F_HEIGHT, SLOWPOKE_WELL_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SlowpokeWellB1F_BlockData), SlowpokeWellB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SlowpokeWellB1F_MapScriptHeader), SlowpokeWellB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SlowpokeWellB1F_MapEventHeader

	; connections
	db 0
; 0x9599c

SlowpokeWellB2F_SecondMapHeader: ; 0x9599c
	; border block
	db $9

	; height, width
	db SLOWPOKE_WELL_B2F_HEIGHT, SLOWPOKE_WELL_B2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SlowpokeWellB2F_BlockData), SlowpokeWellB2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SlowpokeWellB2F_MapScriptHeader), SlowpokeWellB2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SlowpokeWellB2F_MapEventHeader

	; connections
	db 0
; 0x959a8

OlivineLighthouse1F_SecondMapHeader: ; 0x959a8
	; border block
	db $0

	; height, width
	db OLIVINE_LIGHTHOUSE_1F_HEIGHT, OLIVINE_LIGHTHOUSE_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineLighthouse1F_BlockData), OlivineLighthouse1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineLighthouse1F_MapScriptHeader), OlivineLighthouse1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineLighthouse1F_MapEventHeader

	; connections
	db 0
; 0x959b4

OlivineLighthouse2F_SecondMapHeader: ; 0x959b4
	; border block
	db $0

	; height, width
	db OLIVINE_LIGHTHOUSE_2F_HEIGHT, OLIVINE_LIGHTHOUSE_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineLighthouse2F_BlockData), OlivineLighthouse2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineLighthouse2F_MapScriptHeader), OlivineLighthouse2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineLighthouse2F_MapEventHeader

	; connections
	db 0
; 0x959c0

OlivineLighthouse3F_SecondMapHeader: ; 0x959c0
	; border block
	db $0

	; height, width
	db OLIVINE_LIGHTHOUSE_3F_HEIGHT, OLIVINE_LIGHTHOUSE_3F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineLighthouse3F_BlockData), OlivineLighthouse3F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineLighthouse3F_MapScriptHeader), OlivineLighthouse3F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineLighthouse3F_MapEventHeader

	; connections
	db 0
; 0x959cc

OlivineLighthouse4F_SecondMapHeader: ; 0x959cc
	; border block
	db $0

	; height, width
	db OLIVINE_LIGHTHOUSE_4F_HEIGHT, OLIVINE_LIGHTHOUSE_4F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineLighthouse4F_BlockData), OlivineLighthouse4F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineLighthouse4F_MapScriptHeader), OlivineLighthouse4F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineLighthouse4F_MapEventHeader

	; connections
	db 0
; 0x959d8

OlivineLighthouse5F_SecondMapHeader: ; 0x959d8
	; border block
	db $0

	; height, width
	db OLIVINE_LIGHTHOUSE_5F_HEIGHT, OLIVINE_LIGHTHOUSE_5F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineLighthouse5F_BlockData), OlivineLighthouse5F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineLighthouse5F_MapScriptHeader), OlivineLighthouse5F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineLighthouse5F_MapEventHeader

	; connections
	db 0
; 0x959e4

OlivineLighthouse6F_SecondMapHeader: ; 0x959e4
	; border block
	db $0

	; height, width
	db OLIVINE_LIGHTHOUSE_6F_HEIGHT, OLIVINE_LIGHTHOUSE_6F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineLighthouse6F_BlockData), OlivineLighthouse6F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineLighthouse6F_MapScriptHeader), OlivineLighthouse6F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineLighthouse6F_MapEventHeader

	; connections
	db 0
; 0x959f0

MahoganyMart1F_SecondMapHeader: ; 0x959f0
	; border block
	db $0

	; height, width
	db MAHOGANY_MART_1F_HEIGHT, MAHOGANY_MART_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MahoganyMart1F_BlockData), MahoganyMart1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MahoganyMart1F_MapScriptHeader), MahoganyMart1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MahoganyMart1F_MapEventHeader

	; connections
	db 0
; 0x959fc

TeamRocketBaseB1F_SecondMapHeader: ; 0x959fc
	; border block
	db $0

	; height, width
	db TEAM_ROCKET_BASE_B1F_HEIGHT, TEAM_ROCKET_BASE_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TeamRocketBaseB1F_BlockData), TeamRocketBaseB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TeamRocketBaseB1F_MapScriptHeader), TeamRocketBaseB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TeamRocketBaseB1F_MapEventHeader

	; connections
	db 0
; 0x95a08

TeamRocketBaseB2F_SecondMapHeader: ; 0x95a08
	; border block
	db $0

	; height, width
	db TEAM_ROCKET_BASE_B2F_HEIGHT, TEAM_ROCKET_BASE_B2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TeamRocketBaseB2F_BlockData), TeamRocketBaseB2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TeamRocketBaseB2F_MapScriptHeader), TeamRocketBaseB2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TeamRocketBaseB2F_MapEventHeader

	; connections
	db 0
; 0x95a14

TeamRocketBaseB3F_SecondMapHeader: ; 0x95a14
	; border block
	db $0

	; height, width
	db TEAM_ROCKET_BASE_B3F_HEIGHT, TEAM_ROCKET_BASE_B3F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TeamRocketBaseB3F_BlockData), TeamRocketBaseB3F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TeamRocketBaseB3F_MapScriptHeader), TeamRocketBaseB3F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TeamRocketBaseB3F_MapEventHeader

	; connections
	db 0
; 0x95a20

IlexForest_SecondMapHeader: ; 0x95a20
	; border block
	db $5

	; height, width
	db ILEX_FOREST_HEIGHT, ILEX_FOREST_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(IlexForest_BlockData), IlexForest_BlockData

	; script header (bank-then-pointer)
	dbw BANK(IlexForest_MapScriptHeader), IlexForest_MapScriptHeader

	; map event header (bank-then-pointer)
	dw IlexForest_MapEventHeader

	; connections
	db 0
; 0x95a2c

WarehouseEntrance_SecondMapHeader: ; 0x95a2c
	; border block
	db $0

	; height, width
	db WAREHOUSE_ENTRANCE_HEIGHT, WAREHOUSE_ENTRANCE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WarehouseEntrance_BlockData), WarehouseEntrance_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WarehouseEntrance_MapScriptHeader), WarehouseEntrance_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WarehouseEntrance_MapEventHeader

	; connections
	db 0
; 0x95a38

UndergroundPathSwitchRoomEntrances_SecondMapHeader: ; 0x95a38
	; border block
	db $0

	; height, width
	db UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES_HEIGHT, UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(UndergroundPathSwitchRoomEntrances_BlockData), UndergroundPathSwitchRoomEntrances_BlockData

	; script header (bank-then-pointer)
	dbw BANK(UndergroundPathSwitchRoomEntrances_MapScriptHeader), UndergroundPathSwitchRoomEntrances_MapScriptHeader

	; map event header (bank-then-pointer)
	dw UndergroundPathSwitchRoomEntrances_MapEventHeader

	; connections
	db 0
; 0x95a44

GoldenrodDeptStoreB1F_SecondMapHeader: ; 0x95a44
	; border block
	db $0

	; height, width
	db GOLDENROD_DEPT_STORE_B1F_HEIGHT, GOLDENROD_DEPT_STORE_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStoreB1F_BlockData), GoldenrodDeptStoreB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodDeptStoreB1F_MapScriptHeader), GoldenrodDeptStoreB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodDeptStoreB1F_MapEventHeader

	; connections
	db 0
; 0x95a50

UndergroundWarehouse_SecondMapHeader: ; 0x95a50
	; border block
	db $0

	; height, width
	db UNDERGROUND_WAREHOUSE_HEIGHT, UNDERGROUND_WAREHOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(UndergroundWarehouse_BlockData), UndergroundWarehouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(UndergroundWarehouse_MapScriptHeader), UndergroundWarehouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw UndergroundWarehouse_MapEventHeader

	; connections
	db 0
; 0x95a5c

MountMortar1FOutside_SecondMapHeader: ; 0x95a5c
	; border block
	db $9

	; height, width
	db MOUNT_MORTAR_1F_OUTSIDE_HEIGHT, MOUNT_MORTAR_1F_OUTSIDE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MountMortar1FOutside_BlockData), MountMortar1FOutside_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MountMortar1FOutside_MapScriptHeader), MountMortar1FOutside_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MountMortar1FOutside_MapEventHeader

	; connections
	db 0
; 0x95a68

MountMortar1FInside_SecondMapHeader: ; 0x95a68
	; border block
	db $9

	; height, width
	db MOUNT_MORTAR_1F_INSIDE_HEIGHT, MOUNT_MORTAR_1F_INSIDE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MountMortar1FInside_BlockData), MountMortar1FInside_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MountMortar1FInside_MapScriptHeader), MountMortar1FInside_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MountMortar1FInside_MapEventHeader

	; connections
	db 0
; 0x95a74

MountMortar2FInside_SecondMapHeader: ; 0x95a74
	; border block
	db $9

	; height, width
	db MOUNT_MORTAR_2F_INSIDE_HEIGHT, MOUNT_MORTAR_2F_INSIDE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MountMortar2FInside_BlockData), MountMortar2FInside_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MountMortar2FInside_MapScriptHeader), MountMortar2FInside_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MountMortar2FInside_MapEventHeader

	; connections
	db 0
; 0x95a80

MountMortarB1F_SecondMapHeader: ; 0x95a80
	; border block
	db $9

	; height, width
	db MOUNT_MORTAR_B1F_HEIGHT, MOUNT_MORTAR_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MountMortarB1F_BlockData), MountMortarB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MountMortarB1F_MapScriptHeader), MountMortarB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MountMortarB1F_MapEventHeader

	; connections
	db 0
; 0x95a8c

IcePath1F_SecondMapHeader: ; 0x95a8c
	; border block
	db $9

	; height, width
	db ICE_PATH_1F_HEIGHT, ICE_PATH_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(IcePath1F_BlockData), IcePath1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(IcePath1F_MapScriptHeader), IcePath1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw IcePath1F_MapEventHeader

	; connections
	db 0
; 0x95a98

IcePathB1F_SecondMapHeader: ; 0x95a98
	; border block
	db $19

	; height, width
	db ICE_PATH_B1F_HEIGHT, ICE_PATH_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(IcePathB1F_BlockData), IcePathB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(IcePathB1F_MapScriptHeader), IcePathB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw IcePathB1F_MapEventHeader

	; connections
	db 0
; 0x95aa4

IcePathB2FMahoganySide_SecondMapHeader: ; 0x95aa4
	; border block
	db $19

	; height, width
	db ICE_PATH_B2F_MAHOGANY_SIDE_HEIGHT, ICE_PATH_B2F_MAHOGANY_SIDE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(IcePathB2FMahoganySide_BlockData), IcePathB2FMahoganySide_BlockData

	; script header (bank-then-pointer)
	dbw BANK(IcePathB2FMahoganySide_MapScriptHeader), IcePathB2FMahoganySide_MapScriptHeader

	; map event header (bank-then-pointer)
	dw IcePathB2FMahoganySide_MapEventHeader

	; connections
	db 0
; 0x95ab0

IcePathB2FBlackthornSide_SecondMapHeader: ; 0x95ab0
	; border block
	db $19

	; height, width
	db ICE_PATH_B2F_BLACKTHORN_SIDE_HEIGHT, ICE_PATH_B2F_BLACKTHORN_SIDE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(IcePathB2FBlackthornSide_BlockData), IcePathB2FBlackthornSide_BlockData

	; script header (bank-then-pointer)
	dbw BANK(IcePathB2FBlackthornSide_MapScriptHeader), IcePathB2FBlackthornSide_MapScriptHeader

	; map event header (bank-then-pointer)
	dw IcePathB2FBlackthornSide_MapEventHeader

	; connections
	db 0
; 0x95abc

IcePathB3F_SecondMapHeader: ; 0x95abc
	; border block
	db $19

	; height, width
	db ICE_PATH_B3F_HEIGHT, ICE_PATH_B3F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(IcePathB3F_BlockData), IcePathB3F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(IcePathB3F_MapScriptHeader), IcePathB3F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw IcePathB3F_MapEventHeader

	; connections
	db 0
; 0x95ac8

WhirlIslandNW_SecondMapHeader: ; 0x95ac8
	; border block
	db $9

	; height, width
	db WHIRL_ISLAND_NW_HEIGHT, WHIRL_ISLAND_NW_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WhirlIslandNW_BlockData), WhirlIslandNW_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WhirlIslandNW_MapScriptHeader), WhirlIslandNW_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WhirlIslandNW_MapEventHeader

	; connections
	db 0
; 0x95ad4

WhirlIslandNE_SecondMapHeader: ; 0x95ad4
	; border block
	db $9

	; height, width
	db WHIRL_ISLAND_NE_HEIGHT, WHIRL_ISLAND_NE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WhirlIslandNE_BlockData), WhirlIslandNE_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WhirlIslandNE_MapScriptHeader), WhirlIslandNE_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WhirlIslandNE_MapEventHeader

	; connections
	db 0
; 0x95ae0

WhirlIslandSW_SecondMapHeader: ; 0x95ae0
	; border block
	db $9

	; height, width
	db WHIRL_ISLAND_SW_HEIGHT, WHIRL_ISLAND_SW_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WhirlIslandSW_BlockData), WhirlIslandSW_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WhirlIslandSW_MapScriptHeader), WhirlIslandSW_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WhirlIslandSW_MapEventHeader

	; connections
	db 0
; 0x95aec

WhirlIslandCave_SecondMapHeader: ; 0x95aec
	; border block
	db $9

	; height, width
	db WHIRL_ISLAND_CAVE_HEIGHT, WHIRL_ISLAND_CAVE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WhirlIslandCave_BlockData), WhirlIslandCave_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WhirlIslandCave_MapScriptHeader), WhirlIslandCave_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WhirlIslandCave_MapEventHeader

	; connections
	db 0
; 0x95af8

WhirlIslandSE_SecondMapHeader: ; 0x95af8
	; border block
	db $f

	; height, width
	db WHIRL_ISLAND_SE_HEIGHT, WHIRL_ISLAND_SE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WhirlIslandSE_BlockData), WhirlIslandSE_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WhirlIslandSE_MapScriptHeader), WhirlIslandSE_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WhirlIslandSE_MapEventHeader

	; connections
	db 0
; 0x95b04

WhirlIslandB1F_SecondMapHeader: ; 0x95b04
	; border block
	db $9

	; height, width
	db WHIRL_ISLAND_B1F_HEIGHT, WHIRL_ISLAND_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WhirlIslandB1F_BlockData), WhirlIslandB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WhirlIslandB1F_MapScriptHeader), WhirlIslandB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WhirlIslandB1F_MapEventHeader

	; connections
	db 0
; 0x95b10

WhirlIslandB2F_SecondMapHeader: ; 0x95b10
	; border block
	db $2e

	; height, width
	db WHIRL_ISLAND_B2F_HEIGHT, WHIRL_ISLAND_B2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WhirlIslandB2F_BlockData), WhirlIslandB2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WhirlIslandB2F_MapScriptHeader), WhirlIslandB2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WhirlIslandB2F_MapEventHeader

	; connections
	db 0
; 0x95b1c

WhirlIslandLugiaChamber_SecondMapHeader: ; 0x95b1c
	; border block
	db $f

	; height, width
	db WHIRL_ISLAND_LUGIA_CHAMBER_HEIGHT, WHIRL_ISLAND_LUGIA_CHAMBER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WhirlIslandLugiaChamber_BlockData), WhirlIslandLugiaChamber_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WhirlIslandLugiaChamber_MapScriptHeader), WhirlIslandLugiaChamber_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WhirlIslandLugiaChamber_MapEventHeader

	; connections
	db 0
; 0x95b28

SilverCaveRoom1_SecondMapHeader: ; 0x95b28
	; border block
	db $9

	; height, width
	db SILVER_CAVE_ROOM_1_HEIGHT, SILVER_CAVE_ROOM_1_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SilverCaveRoom1_BlockData), SilverCaveRoom1_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SilverCaveRoom1_MapScriptHeader), SilverCaveRoom1_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SilverCaveRoom1_MapEventHeader

	; connections
	db 0
; 0x95b34

SilverCaveRoom2_SecondMapHeader: ; 0x95b34
	; border block
	db $9

	; height, width
	db SILVER_CAVE_ROOM_2_HEIGHT, SILVER_CAVE_ROOM_2_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SilverCaveRoom2_BlockData), SilverCaveRoom2_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SilverCaveRoom2_MapScriptHeader), SilverCaveRoom2_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SilverCaveRoom2_MapEventHeader

	; connections
	db 0
; 0x95b40

SilverCaveRoom3_SecondMapHeader: ; 0x95b40
	; border block
	db $9

	; height, width
	db SILVER_CAVE_ROOM_3_HEIGHT, SILVER_CAVE_ROOM_3_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SilverCaveRoom3_BlockData), SilverCaveRoom3_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SilverCaveRoom3_MapScriptHeader), SilverCaveRoom3_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SilverCaveRoom3_MapEventHeader

	; connections
	db 0
; 0x95b4c

SilverCaveItemRooms_SecondMapHeader: ; 0x95b4c
	; border block
	db $9

	; height, width
	db SILVER_CAVE_ITEM_ROOMS_HEIGHT, SILVER_CAVE_ITEM_ROOMS_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SilverCaveItemRooms_BlockData), SilverCaveItemRooms_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SilverCaveItemRooms_MapScriptHeader), SilverCaveItemRooms_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SilverCaveItemRooms_MapEventHeader

	; connections
	db 0
; 0x95b58

DarkCaveVioletEntrance_SecondMapHeader: ; 0x95b58
	; border block
	db $9

	; height, width
	db DARK_CAVE_VIOLET_ENTRANCE_HEIGHT, DARK_CAVE_VIOLET_ENTRANCE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(DarkCaveVioletEntrance_BlockData), DarkCaveVioletEntrance_BlockData

	; script header (bank-then-pointer)
	dbw BANK(DarkCaveVioletEntrance_MapScriptHeader), DarkCaveVioletEntrance_MapScriptHeader

	; map event header (bank-then-pointer)
	dw DarkCaveVioletEntrance_MapEventHeader

	; connections
	db 0
; 0x95b64

DarkCaveBlackthornEntrance_SecondMapHeader: ; 0x95b64
	; border block
	db $9

	; height, width
	db DARK_CAVE_BLACKTHORN_ENTRANCE_HEIGHT, DARK_CAVE_BLACKTHORN_ENTRANCE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(DarkCaveBlackthornEntrance_BlockData), DarkCaveBlackthornEntrance_BlockData

	; script header (bank-then-pointer)
	dbw BANK(DarkCaveBlackthornEntrance_MapScriptHeader), DarkCaveBlackthornEntrance_MapScriptHeader

	; map event header (bank-then-pointer)
	dw DarkCaveBlackthornEntrance_MapEventHeader

	; connections
	db 0
; 0x95b70

DragonsDen1F_SecondMapHeader: ; 0x95b70
	; border block
	db $9

	; height, width
	db DRAGONS_DEN_1F_HEIGHT, DRAGONS_DEN_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(DragonsDen1F_BlockData), DragonsDen1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(DragonsDen1F_MapScriptHeader), DragonsDen1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw DragonsDen1F_MapEventHeader

	; connections
	db 0
; 0x95b7c

DragonsDenB1F_SecondMapHeader: ; 0x95b7c
	; border block
	db $71

	; height, width
	db DRAGONS_DEN_B1F_HEIGHT, DRAGONS_DEN_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(DragonsDenB1F_BlockData), DragonsDenB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(DragonsDenB1F_MapScriptHeader), DragonsDenB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw DragonsDenB1F_MapEventHeader

	; connections
	db 0
; 0x95b88

DragonShrine_SecondMapHeader: ; 0x95b88
	; border block
	db $0

	; height, width
	db DRAGON_SHRINE_HEIGHT, DRAGON_SHRINE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(DragonShrine_BlockData), DragonShrine_BlockData

	; script header (bank-then-pointer)
	dbw BANK(DragonShrine_MapScriptHeader), DragonShrine_MapScriptHeader

	; map event header (bank-then-pointer)
	dw DragonShrine_MapEventHeader

	; connections
	db 0
; 0x95b94

TohjoFalls_SecondMapHeader: ; 0x95b94
	; border block
	db $9

	; height, width
	db TOHJO_FALLS_HEIGHT, TOHJO_FALLS_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TohjoFalls_BlockData), TohjoFalls_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TohjoFalls_MapScriptHeader), TohjoFalls_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TohjoFalls_MapEventHeader

	; connections
	db 0
; 0x95ba0

OlivinePokeCenter1F_SecondMapHeader: ; 0x95ba0
	; border block
	db $0

	; height, width
	db OLIVINE_POKECENTER_1F_HEIGHT, OLIVINE_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_MapScriptHeader), OlivinePokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivinePokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95bac

OlivineGym_SecondMapHeader: ; 0x95bac
	; border block
	db $0

	; height, width
	db OLIVINE_GYM_HEIGHT, OLIVINE_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineGym_BlockData), OlivineGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineGym_MapScriptHeader), OlivineGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineGym_MapEventHeader

	; connections
	db 0
; 0x95bb8

OlivineVoltorbHouse_SecondMapHeader: ; 0x95bb8
	; border block
	db $0

	; height, width
	db OLIVINE_VOLTORB_HOUSE_HEIGHT, OLIVINE_VOLTORB_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_MapScriptHeader), OlivineVoltorbHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineVoltorbHouse_MapEventHeader

	; connections
	db 0
; 0x95bc4

OlivineHouseBeta_SecondMapHeader: ; 0x95bc4
	; border block
	db $0

	; height, width
	db OLIVINE_HOUSE_BETA_HEIGHT, OLIVINE_HOUSE_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineHouseBeta_MapScriptHeader), OlivineHouseBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineHouseBeta_MapEventHeader

	; connections
	db 0
; 0x95bd0

OlivinePunishmentSpeechHouse_SecondMapHeader: ; 0x95bd0
	; border block
	db $0

	; height, width
	db OLIVINE_PUNISHMENT_SPEECH_HOUSE_HEIGHT, OLIVINE_PUNISHMENT_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivinePunishmentSpeechHouse_MapScriptHeader), OlivinePunishmentSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivinePunishmentSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x95bdc

OlivineGoodRodHouse_SecondMapHeader: ; 0x95bdc
	; border block
	db $0

	; height, width
	db OLIVINE_GOOD_ROD_HOUSE_HEIGHT, OLIVINE_GOOD_ROD_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineGoodRodHouse_MapScriptHeader), OlivineGoodRodHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineGoodRodHouse_MapEventHeader

	; connections
	db 0
; 0x95be8

OlivineCafe_SecondMapHeader: ; 0x95be8
	; border block
	db $0

	; height, width
	db OLIVINE_CAFE_HEIGHT, OLIVINE_CAFE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineCafe_BlockData), OlivineCafe_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineCafe_MapScriptHeader), OlivineCafe_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineCafe_MapEventHeader

	; connections
	db 0
; 0x95bf4

OlivineMart_SecondMapHeader: ; 0x95bf4
	; border block
	db $0

	; height, width
	db OLIVINE_MART_HEIGHT, OLIVINE_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivineMart_MapScriptHeader), OlivineMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivineMart_MapEventHeader

	; connections
	db 0
; 0x95c00

Route38EcruteakGate_SecondMapHeader: ; 0x95c00
	; border block
	db $0

	; height, width
	db ROUTE_38_ECRUTEAK_GATE_HEIGHT, ROUTE_38_ECRUTEAK_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_MapScriptHeader), Route38EcruteakGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route38EcruteakGate_MapEventHeader

	; connections
	db 0
; 0x95c0c

Route39Barn_SecondMapHeader: ; 0x95c0c
	; border block
	db $0

	; height, width
	db ROUTE_39_BARN_HEIGHT, ROUTE_39_BARN_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route39Barn_BlockData), Route39Barn_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route39Barn_MapScriptHeader), Route39Barn_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route39Barn_MapEventHeader

	; connections
	db 0
; 0x95c18

Route39Farmhouse_SecondMapHeader: ; 0x95c18
	; border block
	db $0

	; height, width
	db ROUTE_39_FARMHOUSE_HEIGHT, ROUTE_39_FARMHOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route39Farmhouse_MapScriptHeader), Route39Farmhouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route39Farmhouse_MapEventHeader

	; connections
	db 0
; 0x95c24

MahoganyRedGyaradosSpeechHouse_SecondMapHeader: ; 0x95c24
	; border block
	db $0

	; height, width
	db MAHOGANY_RED_GYARADOS_SPEECH_HOUSE_HEIGHT, MAHOGANY_RED_GYARADOS_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MahoganyRedGyaradosSpeechHouse_MapScriptHeader), MahoganyRedGyaradosSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MahoganyRedGyaradosSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x95c30

MahoganyGym_SecondMapHeader: ; 0x95c30
	; border block
	db $0

	; height, width
	db MAHOGANY_GYM_HEIGHT, MAHOGANY_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MahoganyGym_BlockData), MahoganyGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MahoganyGym_MapScriptHeader), MahoganyGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MahoganyGym_MapEventHeader

	; connections
	db 0
; 0x95c3c

MahoganyPokeCenter1F_SecondMapHeader: ; 0x95c3c
	; border block
	db $0

	; height, width
	db MAHOGANY_POKECENTER_1F_HEIGHT, MAHOGANY_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MahoganyPokeCenter1F_MapScriptHeader), MahoganyPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MahoganyPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95c48

Route42EcruteakGate_SecondMapHeader: ; 0x95c48
	; border block
	db $0

	; height, width
	db ROUTE_42_ECRUTEAK_GATE_HEIGHT, ROUTE_42_ECRUTEAK_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route42EcruteakGate_MapScriptHeader), Route42EcruteakGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route42EcruteakGate_MapEventHeader

	; connections
	db 0
; 0x95c54

DiglettsCave_SecondMapHeader: ; 0x95c54
	; border block
	db $9

	; height, width
	db DIGLETTS_CAVE_HEIGHT, DIGLETTS_CAVE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(DiglettsCave_BlockData), DiglettsCave_BlockData

	; script header (bank-then-pointer)
	dbw BANK(DiglettsCave_MapScriptHeader), DiglettsCave_MapScriptHeader

	; map event header (bank-then-pointer)
	dw DiglettsCave_MapEventHeader

	; connections
	db 0
; 0x95c60

MountMoon_SecondMapHeader: ; 0x95c60
	; border block
	db $9

	; height, width
	db MOUNT_MOON_HEIGHT, MOUNT_MOON_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MountMoon_BlockData), MountMoon_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MountMoon_MapScriptHeader), MountMoon_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MountMoon_MapEventHeader

	; connections
	db 0
; 0x95c6c

Underground_SecondMapHeader: ; 0x95c6c
	; border block
	db $0

	; height, width
	db UNDERGROUND_HEIGHT, UNDERGROUND_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Underground_BlockData), Underground_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Underground_MapScriptHeader), Underground_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Underground_MapEventHeader

	; connections
	db 0
; 0x95c78

RockTunnel1F_SecondMapHeader: ; 0x95c78
	; border block
	db $9

	; height, width
	db ROCK_TUNNEL_1F_HEIGHT, ROCK_TUNNEL_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RockTunnel1F_BlockData), RockTunnel1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RockTunnel1F_MapScriptHeader), RockTunnel1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RockTunnel1F_MapEventHeader

	; connections
	db 0
; 0x95c84

RockTunnelB1F_SecondMapHeader: ; 0x95c84
	; border block
	db $9

	; height, width
	db ROCK_TUNNEL_B1F_HEIGHT, ROCK_TUNNEL_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RockTunnelB1F_BlockData), RockTunnelB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RockTunnelB1F_MapScriptHeader), RockTunnelB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RockTunnelB1F_MapEventHeader

	; connections
	db 0
; 0x95c90

SafariZoneFuchsiaGateBeta_SecondMapHeader: ; 0x95c90
	; border block
	db $0

	; height, width
	db SAFARI_ZONE_FUCHSIA_GATE_BETA_HEIGHT, SAFARI_ZONE_FUCHSIA_GATE_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_MapScriptHeader), SafariZoneFuchsiaGateBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SafariZoneFuchsiaGateBeta_MapEventHeader

	; connections
	db 0
; 0x95c9c

SafariZoneBeta_SecondMapHeader: ; 0x95c9c
	; border block
	db $13

	; height, width
	db SAFARI_ZONE_BETA_HEIGHT, SAFARI_ZONE_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneBeta_BlockData), SafariZoneBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SafariZoneBeta_MapScriptHeader), SafariZoneBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SafariZoneBeta_MapEventHeader

	; connections
	db 0
; 0x95ca8

VictoryRoad_SecondMapHeader: ; 0x95ca8
	; border block
	db $1d

	; height, width
	db VICTORY_ROAD_HEIGHT, VICTORY_ROAD_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(VictoryRoad_BlockData), VictoryRoad_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VictoryRoad_MapScriptHeader), VictoryRoad_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VictoryRoad_MapEventHeader

	; connections
	db 0
; 0x95cb4

EcruteakHouse_SecondMapHeader: ; 0x95cb4
	; border block
	db $0

	; height, width
	db ECRUTEAK_HOUSE_HEIGHT, ECRUTEAK_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(EcruteakHouse_BlockData), EcruteakHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(EcruteakHouse_MapScriptHeader), EcruteakHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw EcruteakHouse_MapEventHeader

	; connections
	db 0
; 0x95cc0

WiseTriosRoom_SecondMapHeader: ; 0x95cc0
	; border block
	db $0

	; height, width
	db WISE_TRIOS_ROOM_HEIGHT, WISE_TRIOS_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WiseTriosRoom_BlockData), WiseTriosRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WiseTriosRoom_MapScriptHeader), WiseTriosRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WiseTriosRoom_MapEventHeader

	; connections
	db 0
; 0x95ccc

EcruteakPokeCenter1F_SecondMapHeader: ; 0x95ccc
	; border block
	db $0

	; height, width
	db ECRUTEAK_POKECENTER_1F_HEIGHT, ECRUTEAK_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(EcruteakPokeCenter1F_MapScriptHeader), EcruteakPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw EcruteakPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95cd8

EcruteakLugiaSpeechHouse_SecondMapHeader: ; 0x95cd8
	; border block
	db $0

	; height, width
	db ECRUTEAK_LUGIA_SPEECH_HOUSE_HEIGHT, ECRUTEAK_LUGIA_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(EcruteakLugiaSpeechHouse_BlockData), EcruteakLugiaSpeechHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(EcruteakLugiaSpeechHouse_MapScriptHeader), EcruteakLugiaSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw EcruteakLugiaSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x95ce4

DanceTheatre_SecondMapHeader: ; 0x95ce4
	; border block
	db $0

	; height, width
	db DANCE_THEATRE_HEIGHT, DANCE_THEATRE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(DanceTheatre_BlockData), DanceTheatre_BlockData

	; script header (bank-then-pointer)
	dbw BANK(DanceTheatre_MapScriptHeader), DanceTheatre_MapScriptHeader

	; map event header (bank-then-pointer)
	dw DanceTheatre_MapEventHeader

	; connections
	db 0
; 0x95cf0

EcruteakMart_SecondMapHeader: ; 0x95cf0
	; border block
	db $0

	; height, width
	db ECRUTEAK_MART_HEIGHT, ECRUTEAK_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(EcruteakMart_MapScriptHeader), EcruteakMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw EcruteakMart_MapEventHeader

	; connections
	db 0
; 0x95cfc

EcruteakGym_SecondMapHeader: ; 0x95cfc
	; border block
	db $0

	; height, width
	db ECRUTEAK_GYM_HEIGHT, ECRUTEAK_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(EcruteakGym_BlockData), EcruteakGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(EcruteakGym_MapScriptHeader), EcruteakGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw EcruteakGym_MapEventHeader

	; connections
	db 0
; 0x95d08

EcruteakItemfinderHouse_SecondMapHeader: ; 0x95d08
	; border block
	db $0

	; height, width
	db ECRUTEAK_ITEMFINDER_HOUSE_HEIGHT, ECRUTEAK_ITEMFINDER_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(EcruteakLugiaSpeechHouse_BlockData), EcruteakLugiaSpeechHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(EcruteakItemfinderHouse_MapScriptHeader), EcruteakItemfinderHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw EcruteakItemfinderHouse_MapEventHeader

	; connections
	db 0
; 0x95d14

BlackthornGym1F_SecondMapHeader: ; 0x95d14
	; border block
	db $0

	; height, width
	db BLACKTHORN_GYM_1F_HEIGHT, BLACKTHORN_GYM_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BlackthornGym1F_BlockData), BlackthornGym1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BlackthornGym1F_MapScriptHeader), BlackthornGym1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BlackthornGym1F_MapEventHeader

	; connections
	db 0
; 0x95d20

BlackthornGym2F_SecondMapHeader: ; 0x95d20
	; border block
	db $0

	; height, width
	db BLACKTHORN_GYM_2F_HEIGHT, BLACKTHORN_GYM_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BlackthornGym2F_BlockData), BlackthornGym2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BlackthornGym2F_MapScriptHeader), BlackthornGym2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BlackthornGym2F_MapEventHeader

	; connections
	db 0
; 0x95d2c

BlackthornDragonSpeechHouse_SecondMapHeader: ; 0x95d2c
	; border block
	db $0

	; height, width
	db BLACKTHORN_DRAGON_SPEECH_HOUSE_HEIGHT, BLACKTHORN_DRAGON_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BlackthornDragonSpeechHouse_MapScriptHeader), BlackthornDragonSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BlackthornDragonSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x95d38

BlackthornDodrioTradeHouse_SecondMapHeader: ; 0x95d38
	; border block
	db $0

	; height, width
	db BLACKTHORN_DODRIO_TRADE_HOUSE_HEIGHT, BLACKTHORN_DODRIO_TRADE_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BlackthornDodrioTradeHouse_MapScriptHeader), BlackthornDodrioTradeHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BlackthornDodrioTradeHouse_MapEventHeader

	; connections
	db 0
; 0x95d44

BlackthornMart_SecondMapHeader: ; 0x95d44
	; border block
	db $0

	; height, width
	db BLACKTHORN_MART_HEIGHT, BLACKTHORN_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BlackthornMart_MapScriptHeader), BlackthornMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BlackthornMart_MapEventHeader

	; connections
	db 0
; 0x95d50

BlackthornPokeCenter1F_SecondMapHeader: ; 0x95d50
	; border block
	db $0

	; height, width
	db BLACKTHORN_POKECENTER_1F_HEIGHT, BLACKTHORN_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BlackthornPokeCenter1F_MapScriptHeader), BlackthornPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BlackthornPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95d5c

MoveDeletersHouse_SecondMapHeader: ; 0x95d5c
	; border block
	db $0

	; height, width
	db MOVE_DELETERS_HOUSE_HEIGHT, MOVE_DELETERS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MoveDeletersHouse_MapScriptHeader), MoveDeletersHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MoveDeletersHouse_MapEventHeader

	; connections
	db 0
; 0x95d68

CinnabarPokeCenter1F_SecondMapHeader: ; 0x95d68
	; border block
	db $0

	; height, width
	db CINNABAR_POKECENTER_1F_HEIGHT, CINNABAR_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter1F_MapScriptHeader), CinnabarPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CinnabarPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95d74

CinnabarPokeCenter2FBeta_SecondMapHeader: ; 0x95d74
	; border block
	db $0

	; height, width
	db CINNABAR_POKECENTER_2F_BETA_HEIGHT, CINNABAR_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_MapScriptHeader), CinnabarPokeCenter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CinnabarPokeCenter2FBeta_MapEventHeader

	; connections
	db 0
; 0x95d80

Route19FuchsiaGate_SecondMapHeader: ; 0x95d80
	; border block
	db $0

	; height, width
	db ROUTE_19___FUCHSIA_GATE_HEIGHT, ROUTE_19___FUCHSIA_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route19FuchsiaGate_MapScriptHeader), Route19FuchsiaGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route19FuchsiaGate_MapEventHeader

	; connections
	db 0
; 0x95d8c

SeafoamGym_SecondMapHeader: ; 0x95d8c
	; border block
	db $9

	; height, width
	db SEAFOAM_GYM_HEIGHT, SEAFOAM_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SeafoamGym_BlockData), SeafoamGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SeafoamGym_MapScriptHeader), SeafoamGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SeafoamGym_MapEventHeader

	; connections
	db 0
; 0x95d98

CeruleanGymBadgeSpeechHouse_SecondMapHeader: ; 0x95d98
	; border block
	db $0

	; height, width
	db CERULEAN_GYM_BADGE_SPEECH_HOUSE_HEIGHT, CERULEAN_GYM_BADGE_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeruleanGymBadgeSpeechHouse_MapScriptHeader), CeruleanGymBadgeSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeruleanGymBadgeSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x95da4

CeruleanPoliceStation_SecondMapHeader: ; 0x95da4
	; border block
	db $0

	; height, width
	db CERULEAN_POLICE_STATION_HEIGHT, CERULEAN_POLICE_STATION_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeruleanPoliceStation_MapScriptHeader), CeruleanPoliceStation_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeruleanPoliceStation_MapEventHeader

	; connections
	db 0
; 0x95db0

CeruleanTradeSpeechHouse_SecondMapHeader: ; 0x95db0
	; border block
	db $0

	; height, width
	db CERULEAN_TRADE_SPEECH_HOUSE_HEIGHT, CERULEAN_TRADE_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeruleanTradeSpeechHouse_MapScriptHeader), CeruleanTradeSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeruleanTradeSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x95dbc

CeruleanPokeCenter1F_SecondMapHeader: ; 0x95dbc
	; border block
	db $0

	; height, width
	db CERULEAN_POKECENTER_1F_HEIGHT, CERULEAN_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeruleanPokeCenter1F_MapScriptHeader), CeruleanPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeruleanPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95dc8

CeruleanPokeCenter2FBeta_SecondMapHeader: ; 0x95dc8
	; border block
	db $0

	; height, width
	db CERULEAN_POKECENTER_2F_BETA_HEIGHT, CERULEAN_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeruleanPokeCenter2FBeta_MapScriptHeader), CeruleanPokeCenter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeruleanPokeCenter2FBeta_MapEventHeader

	; connections
	db 0
; 0x95dd4

CeruleanGym_SecondMapHeader: ; 0x95dd4
	; border block
	db $0

	; height, width
	db CERULEAN_GYM_HEIGHT, CERULEAN_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeruleanGym_BlockData), CeruleanGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeruleanGym_MapScriptHeader), CeruleanGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeruleanGym_MapEventHeader

	; connections
	db 0
; 0x95de0

CeruleanMart_SecondMapHeader: ; 0x95de0
	; border block
	db $0

	; height, width
	db CERULEAN_MART_HEIGHT, CERULEAN_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeruleanMart_MapScriptHeader), CeruleanMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeruleanMart_MapEventHeader

	; connections
	db 0
; 0x95dec

Route10PokeCenter1F_SecondMapHeader: ; 0x95dec
	; border block
	db $0

	; height, width
	db ROUTE_10_POKECENTER_1F_HEIGHT, ROUTE_10_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route10PokeCenter1F_MapScriptHeader), Route10PokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route10PokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95df8

Route10PokeCenter2FBeta_SecondMapHeader: ; 0x95df8
	; border block
	db $0

	; height, width
	db ROUTE_10_POKECENTER_2F_BETA_HEIGHT, ROUTE_10_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route10PokeCenter2FBeta_MapScriptHeader), Route10PokeCenter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route10PokeCenter2FBeta_MapEventHeader

	; connections
	db 0
; 0x95e04

PowerPlant_SecondMapHeader: ; 0x95e04
	; border block
	db $0

	; height, width
	db POWER_PLANT_HEIGHT, POWER_PLANT_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(PowerPlant_BlockData), PowerPlant_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PowerPlant_MapScriptHeader), PowerPlant_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PowerPlant_MapEventHeader

	; connections
	db 0
; 0x95e10

BillsHouse_SecondMapHeader: ; 0x95e10
	; border block
	db $0

	; height, width
	db BILLS_HOUSE_HEIGHT, BILLS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BillsHouse_MapScriptHeader), BillsHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BillsHouse_MapEventHeader

	; connections
	db 0
; 0x95e1c

AzaleaPokeCenter1F_SecondMapHeader: ; 0x95e1c
	; border block
	db $0

	; height, width
	db AZALEA_POKECENTER_1F_HEIGHT, AZALEA_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(AzaleaPokeCenter1F_MapScriptHeader), AzaleaPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw AzaleaPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95e28

CharcoalKiln_SecondMapHeader: ; 0x95e28
	; border block
	db $0

	; height, width
	db CHARCOAL_KILN_HEIGHT, CHARCOAL_KILN_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CharcoalKiln_MapScriptHeader), CharcoalKiln_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CharcoalKiln_MapEventHeader

	; connections
	db 0
; 0x95e34

AzaleaMart_SecondMapHeader: ; 0x95e34
	; border block
	db $0

	; height, width
	db AZALEA_MART_HEIGHT, AZALEA_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(AzaleaMart_MapScriptHeader), AzaleaMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw AzaleaMart_MapEventHeader

	; connections
	db 0
; 0x95e40

KurtsHouse_SecondMapHeader: ; 0x95e40
	; border block
	db $0

	; height, width
	db KURTS_HOUSE_HEIGHT, KURTS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(KurtsHouse_BlockData), KurtsHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(KurtsHouse_MapScriptHeader), KurtsHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw KurtsHouse_MapEventHeader

	; connections
	db 0
; 0x95e4c

AzaleaGym_SecondMapHeader: ; 0x95e4c
	; border block
	db $0

	; height, width
	db AZALEA_GYM_HEIGHT, AZALEA_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(AzaleaGym_BlockData), AzaleaGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(AzaleaGym_MapScriptHeader), AzaleaGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw AzaleaGym_MapEventHeader

	; connections
	db 0
; 0x95e58

LakeofRageHiddenPowerHouse_SecondMapHeader: ; 0x95e58
	; border block
	db $0

	; height, width
	db LAKE_OF_RAGE_HIDDEN_POWER_HOUSE_HEIGHT, LAKE_OF_RAGE_HIDDEN_POWER_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LakeofRageHiddenPowerHouse_MapScriptHeader), LakeofRageHiddenPowerHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LakeofRageHiddenPowerHouse_MapEventHeader

	; connections
	db 0
; 0x95e64

LakeofRageMagikarpHouse_SecondMapHeader: ; 0x95e64
	; border block
	db $0

	; height, width
	db LAKE_OF_RAGE_MAGIKARP_HOUSE_HEIGHT, LAKE_OF_RAGE_MAGIKARP_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LakeofRageMagikarpHouse_MapScriptHeader), LakeofRageMagikarpHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LakeofRageMagikarpHouse_MapEventHeader

	; connections
	db 0
; 0x95e70

Route43MahoganyGate_SecondMapHeader: ; 0x95e70
	; border block
	db $0

	; height, width
	db ROUTE_43_MAHOGANY_GATE_HEIGHT, ROUTE_43_MAHOGANY_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route43MahoganyGate_MapScriptHeader), Route43MahoganyGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route43MahoganyGate_MapEventHeader

	; connections
	db 0
; 0x95e7c

Route43Gate_SecondMapHeader: ; 0x95e7c
	; border block
	db $0

	; height, width
	db ROUTE_43_GATE_HEIGHT, ROUTE_43_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route43Gate_MapScriptHeader), Route43Gate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route43Gate_MapEventHeader

	; connections
	db 0
; 0x95e88

VioletMart_SecondMapHeader: ; 0x95e88
	; border block
	db $0

	; height, width
	db VIOLET_MART_HEIGHT, VIOLET_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VioletMart_MapScriptHeader), VioletMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VioletMart_MapEventHeader

	; connections
	db 0
; 0x95e94

VioletGym_SecondMapHeader: ; 0x95e94
	; border block
	db $0

	; height, width
	db VIOLET_GYM_HEIGHT, VIOLET_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(VioletGym_BlockData), VioletGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VioletGym_MapScriptHeader), VioletGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VioletGym_MapEventHeader

	; connections
	db 0
; 0x95ea0

EarlsPokemonAcademy_SecondMapHeader: ; 0x95ea0
	; border block
	db $0

	; height, width
	db EARLS_POKEMON_ACADEMY_HEIGHT, EARLS_POKEMON_ACADEMY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(EarlsPokemonAcademy_BlockData), EarlsPokemonAcademy_BlockData

	; script header (bank-then-pointer)
	dbw BANK(EarlsPokemonAcademy_MapScriptHeader), EarlsPokemonAcademy_MapScriptHeader

	; map event header (bank-then-pointer)
	dw EarlsPokemonAcademy_MapEventHeader

	; connections
	db 0
; 0x95eac

VioletNicknameSpeechHouse_SecondMapHeader: ; 0x95eac
	; border block
	db $0

	; height, width
	db VIOLET_NICKNAME_SPEECH_HOUSE_HEIGHT, VIOLET_NICKNAME_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(EcruteakLugiaSpeechHouse_BlockData), EcruteakLugiaSpeechHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VioletNicknameSpeechHouse_MapScriptHeader), VioletNicknameSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VioletNicknameSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x95eb8

VioletPokeCenter1F_SecondMapHeader: ; 0x95eb8
	; border block
	db $0

	; height, width
	db VIOLET_POKECENTER_1F_HEIGHT, VIOLET_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VioletPokeCenter1F_MapScriptHeader), VioletPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VioletPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95ec4

VioletOnixTradeHouse_SecondMapHeader: ; 0x95ec4
	; border block
	db $0

	; height, width
	db VIOLET_ONIX_TRADE_HOUSE_HEIGHT, VIOLET_ONIX_TRADE_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(EcruteakLugiaSpeechHouse_BlockData), EcruteakLugiaSpeechHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VioletOnixTradeHouse_MapScriptHeader), VioletOnixTradeHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VioletOnixTradeHouse_MapEventHeader

	; connections
	db 0
; 0x95ed0

Route32RuinsofAlphGate_SecondMapHeader: ; 0x95ed0
	; border block
	db $0

	; height, width
	db ROUTE_32_RUINS_OF_ALPH_GATE_HEIGHT, ROUTE_32_RUINS_OF_ALPH_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route32RuinsofAlphGate_MapScriptHeader), Route32RuinsofAlphGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route32RuinsofAlphGate_MapEventHeader

	; connections
	db 0
; 0x95edc

Route32PokeCenter1F_SecondMapHeader: ; 0x95edc
	; border block
	db $0

	; height, width
	db ROUTE_32_POKECENTER_1F_HEIGHT, ROUTE_32_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route32PokeCenter1F_MapScriptHeader), Route32PokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route32PokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95ee8

Route35Goldenrodgate_SecondMapHeader: ; 0x95ee8
	; border block
	db $0

	; height, width
	db ROUTE_35_GOLDENROD_GATE_HEIGHT, ROUTE_35_GOLDENROD_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route35Goldenrodgate_MapScriptHeader), Route35Goldenrodgate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route35Goldenrodgate_MapEventHeader

	; connections
	db 0
; 0x95ef4

Route35NationalParkgate_SecondMapHeader: ; 0x95ef4
	; border block
	db $0

	; height, width
	db ROUTE_35_NATIONAL_PARK_GATE_HEIGHT, ROUTE_35_NATIONAL_PARK_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route35NationalParkgate_BlockData), Route35NationalParkgate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route35NationalParkgate_MapScriptHeader), Route35NationalParkgate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route35NationalParkgate_MapEventHeader

	; connections
	db 0
; 0x95f00

Route36RuinsofAlphgate_SecondMapHeader: ; 0x95f00
	; border block
	db $0

	; height, width
	db ROUTE_36_RUINS_OF_ALPH_GATE_HEIGHT, ROUTE_36_RUINS_OF_ALPH_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route36RuinsofAlphgate_MapScriptHeader), Route36RuinsofAlphgate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route36RuinsofAlphgate_MapEventHeader

	; connections
	db 0
; 0x95f0c

Route36NationalParkgate_SecondMapHeader: ; 0x95f0c
	; border block
	db $0

	; height, width
	db ROUTE_36_NATIONAL_PARK_GATE_HEIGHT, ROUTE_36_NATIONAL_PARK_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route36NationalParkgate_BlockData), Route36NationalParkgate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route36NationalParkgate_MapScriptHeader), Route36NationalParkgate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route36NationalParkgate_MapEventHeader

	; connections
	db 0
; 0x95f18

GoldenrodGym_SecondMapHeader: ; 0x95f18
	; border block
	db $0

	; height, width
	db GOLDENROD_GYM_HEIGHT, GOLDENROD_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodGym_BlockData), GoldenrodGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodGym_MapScriptHeader), GoldenrodGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodGym_MapEventHeader

	; connections
	db 0
; 0x95f24

GoldenrodBikeShop_SecondMapHeader: ; 0x95f24
	; border block
	db $0

	; height, width
	db GOLDENROD_BIKE_SHOP_HEIGHT, GOLDENROD_BIKE_SHOP_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodBikeShop_BlockData), GoldenrodBikeShop_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodBikeShop_MapScriptHeader), GoldenrodBikeShop_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodBikeShop_MapEventHeader

	; connections
	db 0
; 0x95f30

GoldenrodHappinessRater_SecondMapHeader: ; 0x95f30
	; border block
	db $0

	; height, width
	db GOLDENROD_HAPPINESS_RATER_HEIGHT, GOLDENROD_HAPPINESS_RATER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodHappinessRater_MapScriptHeader), GoldenrodHappinessRater_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodHappinessRater_MapEventHeader

	; connections
	db 0
; 0x95f3c

GoldenrodBillsHouse_SecondMapHeader: ; 0x95f3c
	; border block
	db $0

	; height, width
	db GOLDENROD_BILLS_HOUSE_HEIGHT, GOLDENROD_BILLS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodBillsHouse_MapScriptHeader), GoldenrodBillsHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodBillsHouse_MapEventHeader

	; connections
	db 0
; 0x95f48

GoldenrodMagnetTrainStation_SecondMapHeader: ; 0x95f48
	; border block
	db $0

	; height, width
	db GOLDENROD_MAGNET_TRAIN_STATION_HEIGHT, GOLDENROD_MAGNET_TRAIN_STATION_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodMagnetTrainStation_BlockData), GoldenrodMagnetTrainStation_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodMagnetTrainStation_MapScriptHeader), GoldenrodMagnetTrainStation_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodMagnetTrainStation_MapEventHeader

	; connections
	db 0
; 0x95f54

GoldenrodFlowerShop_SecondMapHeader: ; 0x95f54
	; border block
	db $0

	; height, width
	db GOLDENROD_FLOWER_SHOP_HEIGHT, GOLDENROD_FLOWER_SHOP_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodFlowerShop_BlockData), GoldenrodFlowerShop_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodFlowerShop_MapScriptHeader), GoldenrodFlowerShop_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodFlowerShop_MapEventHeader

	; connections
	db 0
; 0x95f60

GoldenrodPPSpeechHouse_SecondMapHeader: ; 0x95f60
	; border block
	db $0

	; height, width
	db GOLDENROD_PP_SPEECH_HOUSE_HEIGHT, GOLDENROD_PP_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodPPSpeechHouse_MapScriptHeader), GoldenrodPPSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodPPSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x95f6c

GoldenrodNameRatersHouse_SecondMapHeader: ; 0x95f6c
	; border block
	db $0

	; height, width
	db GOLDENROD_NAME_RATERS_HOUSE_HEIGHT, GOLDENROD_NAME_RATERS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodNameRatersHouse_MapScriptHeader), GoldenrodNameRatersHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodNameRatersHouse_MapEventHeader

	; connections
	db 0
; 0x95f78

GoldenrodDeptStore1F_SecondMapHeader: ; 0x95f78
	; border block
	db $0

	; height, width
	db GOLDENROD_DEPT_STORE_1F_HEIGHT, GOLDENROD_DEPT_STORE_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore1F_BlockData), GoldenrodDeptStore1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore1F_MapScriptHeader), GoldenrodDeptStore1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodDeptStore1F_MapEventHeader

	; connections
	db 0
; 0x95f84

GoldenrodDeptStore2F_SecondMapHeader: ; 0x95f84
	; border block
	db $0

	; height, width
	db GOLDENROD_DEPT_STORE_2F_HEIGHT, GOLDENROD_DEPT_STORE_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore2F_BlockData), GoldenrodDeptStore2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore2F_MapScriptHeader), GoldenrodDeptStore2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodDeptStore2F_MapEventHeader

	; connections
	db 0
; 0x95f90

GoldenrodDeptStore3F_SecondMapHeader: ; 0x95f90
	; border block
	db $0

	; height, width
	db GOLDENROD_DEPT_STORE_3F_HEIGHT, GOLDENROD_DEPT_STORE_3F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore3F_BlockData), GoldenrodDeptStore3F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore3F_MapScriptHeader), GoldenrodDeptStore3F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodDeptStore3F_MapEventHeader

	; connections
	db 0
; 0x95f9c

GoldenrodDeptStore4F_SecondMapHeader: ; 0x95f9c
	; border block
	db $0

	; height, width
	db GOLDENROD_DEPT_STORE_4F_HEIGHT, GOLDENROD_DEPT_STORE_4F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore4F_BlockData), GoldenrodDeptStore4F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore4F_MapScriptHeader), GoldenrodDeptStore4F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodDeptStore4F_MapEventHeader

	; connections
	db 0
; 0x95fa8

GoldenrodDeptStore5F_SecondMapHeader: ; 0x95fa8
	; border block
	db $0

	; height, width
	db GOLDENROD_DEPT_STORE_5F_HEIGHT, GOLDENROD_DEPT_STORE_5F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore5F_BlockData), GoldenrodDeptStore5F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore5F_MapScriptHeader), GoldenrodDeptStore5F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodDeptStore5F_MapEventHeader

	; connections
	db 0
; 0x95fb4

GoldenrodDeptStore6F_SecondMapHeader: ; 0x95fb4
	; border block
	db $0

	; height, width
	db GOLDENROD_DEPT_STORE_6F_HEIGHT, GOLDENROD_DEPT_STORE_6F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore6F_BlockData), GoldenrodDeptStore6F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore6F_MapScriptHeader), GoldenrodDeptStore6F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodDeptStore6F_MapEventHeader

	; connections
	db 0
; 0x95fc0

GoldenrodDeptStoreElevator_SecondMapHeader: ; 0x95fc0
	; border block
	db $0

	; height, width
	db GOLDENROD_DEPT_STORE_ELEVATOR_HEIGHT, GOLDENROD_DEPT_STORE_ELEVATOR_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStoreElevator_BlockData), GoldenrodDeptStoreElevator_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodDeptStoreElevator_MapScriptHeader), GoldenrodDeptStoreElevator_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodDeptStoreElevator_MapEventHeader

	; connections
	db 0
; 0x95fcc

GoldenrodDeptStoreRoof_SecondMapHeader: ; 0x95fcc
	; border block
	db $24

	; height, width
	db GOLDENROD_DEPT_STORE_ROOF_HEIGHT, GOLDENROD_DEPT_STORE_ROOF_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStoreRoof_BlockData), GoldenrodDeptStoreRoof_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodDeptStoreRoof_MapScriptHeader), GoldenrodDeptStoreRoof_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodDeptStoreRoof_MapEventHeader

	; connections
	db 0
; 0x95fd8

GoldenrodGameCorner_SecondMapHeader: ; 0x95fd8
	; border block
	db $0

	; height, width
	db GOLDENROD_GAME_CORNER_HEIGHT, GOLDENROD_GAME_CORNER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodGameCorner_BlockData), GoldenrodGameCorner_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodGameCorner_MapScriptHeader), GoldenrodGameCorner_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodGameCorner_MapEventHeader

	; connections
	db 0
; 0x95fe4

GoldenrodPokeCenter1F_SecondMapHeader: ; 0x95fe4
	; border block
	db $0

	; height, width
	db GOLDENROD_POKECENTER_1F_HEIGHT, GOLDENROD_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodPokeCenter1F_MapScriptHeader), GoldenrodPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x95ff0

GoldenrodPokeComCenter2FMobile_SecondMapHeader: ; 0x95ff0
	; border block
	db $0

	; height, width
	db GOLDENROD_POKECOM_CENTER_2F_MOBILE_HEIGHT, GOLDENROD_POKECOM_CENTER_2F_MOBILE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodPokeComCenter2FMobile_BlockData), GoldenrodPokeComCenter2FMobile_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GoldenrodPokeComCenter2FMobile_MapScriptHeader), GoldenrodPokeComCenter2FMobile_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GoldenrodPokeComCenter2FMobile_MapEventHeader

	; connections
	db 0
; 0x95ffc

IlexForestAzaleaGate_SecondMapHeader: ; 0x95ffc
	; border block
	db $0

	; height, width
	db ILEX_FOREST_AZALEA_GATE_HEIGHT, ILEX_FOREST_AZALEA_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(IlexForestAzaleaGate_MapScriptHeader), IlexForestAzaleaGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw IlexForestAzaleaGate_MapEventHeader

	; connections
	db 0
; 0x96008

Route34IlexForestGate_SecondMapHeader: ; 0x96008
	; border block
	db $0

	; height, width
	db ROUTE_34_ILEX_FOREST_GATE_HEIGHT, ROUTE_34_ILEX_FOREST_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route34IlexForestGate_MapScriptHeader), Route34IlexForestGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route34IlexForestGate_MapEventHeader

	; connections
	db 0
; 0x96014

DayCare_SecondMapHeader: ; 0x96014
	; border block
	db $0

	; height, width
	db DAY_CARE_HEIGHT, DAY_CARE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(DayCare_BlockData), DayCare_BlockData

	; script header (bank-then-pointer)
	dbw BANK(DayCare_MapScriptHeader), DayCare_MapScriptHeader

	; map event header (bank-then-pointer)
	dw DayCare_MapEventHeader

	; connections
	db 0
; 0x96020

VermilionHouseFishingSpeechHouse_SecondMapHeader: ; 0x96020
	; border block
	db $0

	; height, width
	db VERMILION_HOUSE_FISHING_SPEECH_HOUSE_HEIGHT, VERMILION_HOUSE_FISHING_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionHouseFishingSpeechHouse_MapScriptHeader), VermilionHouseFishingSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionHouseFishingSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x9602c

VermilionPokeCenter1F_SecondMapHeader: ; 0x9602c
	; border block
	db $0

	; height, width
	db VERMILION_POKECENTER_1F_HEIGHT, VERMILION_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionPokeCenter1F_MapScriptHeader), VermilionPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x96038

VermilionPokeCenter2FBeta_SecondMapHeader: ; 0x96038
	; border block
	db $0

	; height, width
	db VERMILION_POKECENTER_2F_BETA_HEIGHT, VERMILION_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionPokeCenter2FBeta_MapScriptHeader), VermilionPokeCenter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionPokeCenter2FBeta_MapEventHeader

	; connections
	db 0
; 0x96044

PokemonFanClub_SecondMapHeader: ; 0x96044
	; border block
	db $0

	; height, width
	db POKEMON_FAN_CLUB_HEIGHT, POKEMON_FAN_CLUB_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(PokemonFanClub_BlockData), PokemonFanClub_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PokemonFanClub_MapScriptHeader), PokemonFanClub_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PokemonFanClub_MapEventHeader

	; connections
	db 0
; 0x96050

VermilionMagnetTrainSpeechHouse_SecondMapHeader: ; 0x96050
	; border block
	db $0

	; height, width
	db VERMILION_MAGNET_TRAIN_SPEECH_HOUSE_HEIGHT, VERMILION_MAGNET_TRAIN_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionMagnetTrainSpeechHouse_MapScriptHeader), VermilionMagnetTrainSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionMagnetTrainSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x9605c

VermilionMart_SecondMapHeader: ; 0x9605c
	; border block
	db $0

	; height, width
	db VERMILION_MART_HEIGHT, VERMILION_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionMart_MapScriptHeader), VermilionMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionMart_MapEventHeader

	; connections
	db 0
; 0x96068

VermilionHouseDiglettsCaveSpeechHouse_SecondMapHeader: ; 0x96068
	; border block
	db $0

	; height, width
	db VERMILION_HOUSE_DIGLETTS_CAVE_SPEECH_HOUSE_HEIGHT, VERMILION_HOUSE_DIGLETTS_CAVE_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionHouseDiglettsCaveSpeechHouse_MapScriptHeader), VermilionHouseDiglettsCaveSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionHouseDiglettsCaveSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96074

VermilionGym_SecondMapHeader: ; 0x96074
	; border block
	db $0

	; height, width
	db VERMILION_GYM_HEIGHT, VERMILION_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(VermilionGym_BlockData), VermilionGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionGym_MapScriptHeader), VermilionGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionGym_MapEventHeader

	; connections
	db 0
; 0x96080

Route6SaffronGate_SecondMapHeader: ; 0x96080
	; border block
	db $0

	; height, width
	db ROUTE_6_SAFFRON_GATE_HEIGHT, ROUTE_6_SAFFRON_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route6SaffronGate_MapScriptHeader), Route6SaffronGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route6SaffronGate_MapEventHeader

	; connections
	db 0
; 0x9608c

Route6UndergroundEntrance_SecondMapHeader: ; 0x9608c
	; border block
	db $0

	; height, width
	db ROUTE_6_UNDERGROUND_ENTRANCE_HEIGHT, ROUTE_6_UNDERGROUND_ENTRANCE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route6UndergroundEntrance_BlockData), Route6UndergroundEntrance_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route6UndergroundEntrance_MapScriptHeader), Route6UndergroundEntrance_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route6UndergroundEntrance_MapEventHeader

	; connections
	db 0
; 0x96098

RedsHouse1F_SecondMapHeader: ; 0x96098
	; border block
	db $0

	; height, width
	db REDS_HOUSE_1F_HEIGHT, REDS_HOUSE_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RedsHouse1F_BlockData), RedsHouse1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RedsHouse1F_MapScriptHeader), RedsHouse1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RedsHouse1F_MapEventHeader

	; connections
	db 0
; 0x960a4

RedsHouse2F_SecondMapHeader: ; 0x960a4
	; border block
	db $0

	; height, width
	db REDS_HOUSE_2F_HEIGHT, REDS_HOUSE_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(RedsHouse2F_BlockData), RedsHouse2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(RedsHouse2F_MapScriptHeader), RedsHouse2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw RedsHouse2F_MapEventHeader

	; connections
	db 0
; 0x960b0

BluesHouse_SecondMapHeader: ; 0x960b0
	; border block
	db $0

	; height, width
	db BLUES_HOUSE_HEIGHT, BLUES_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BluesHouse_MapScriptHeader), BluesHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BluesHouse_MapEventHeader

	; connections
	db 0
; 0x960bc

OaksLab_SecondMapHeader: ; 0x960bc
	; border block
	db $0

	; height, width
	db OAKS_LAB_HEIGHT, OAKS_LAB_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OaksLab_BlockData), OaksLab_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OaksLab_MapScriptHeader), OaksLab_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OaksLab_MapEventHeader

	; connections
	db 0
; 0x960c8

PewterNidoranSpeechHouse_SecondMapHeader: ; 0x960c8
	; border block
	db $0

	; height, width
	db PEWTER_NIDORAN_SPEECH_HOUSE_HEIGHT, PEWTER_NIDORAN_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PewterNidoranSpeechHouse_MapScriptHeader), PewterNidoranSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PewterNidoranSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x960d4

PewterGym_SecondMapHeader: ; 0x960d4
	; border block
	db $0

	; height, width
	db PEWTER_GYM_HEIGHT, PEWTER_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(PewterGym_BlockData), PewterGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PewterGym_MapScriptHeader), PewterGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PewterGym_MapEventHeader

	; connections
	db 0
; 0x960e0

PewterMart_SecondMapHeader: ; 0x960e0
	; border block
	db $0

	; height, width
	db PEWTER_MART_HEIGHT, PEWTER_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PewterMart_MapScriptHeader), PewterMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PewterMart_MapEventHeader

	; connections
	db 0
; 0x960ec

PewterPokeCenter1F_SecondMapHeader: ; 0x960ec
	; border block
	db $0

	; height, width
	db PEWTER_POKECENTER_1F_HEIGHT, PEWTER_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PewterPokeCenter1F_MapScriptHeader), PewterPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PewterPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x960f8

PewterPokeCEnter2FBeta_SecondMapHeader: ; 0x960f8
	; border block
	db $0

	; height, width
	db PEWTER_POKECENTER_2F_BETA_HEIGHT, PEWTER_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PewterPokeCEnter2FBeta_MapScriptHeader), PewterPokeCEnter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PewterPokeCEnter2FBeta_MapEventHeader

	; connections
	db 0
; 0x96104

PewterSnoozeSpeechHouse_SecondMapHeader: ; 0x96104
	; border block
	db $0

	; height, width
	db PEWTER_SNOOZE_SPEECH_HOUSE_HEIGHT, PEWTER_SNOOZE_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PewterSnoozeSpeechHouse_MapScriptHeader), PewterSnoozeSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PewterSnoozeSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96110

OlivinePort_SecondMapHeader: ; 0x96110
	; border block
	db $a

	; height, width
	db OLIVINE_PORT_HEIGHT, OLIVINE_PORT_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePort_BlockData), OlivinePort_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivinePort_MapScriptHeader), OlivinePort_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivinePort_MapEventHeader

	; connections
	db 0
; 0x9611c

VermilionPort_SecondMapHeader: ; 0x9611c
	; border block
	db $a

	; height, width
	db VERMILION_PORT_HEIGHT, VERMILION_PORT_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(VermilionPort_BlockData), VermilionPort_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionPort_MapScriptHeader), VermilionPort_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionPort_MapEventHeader

	; connections
	db 0
; 0x96128

FastShip1F_SecondMapHeader: ; 0x96128
	; border block
	db $0

	; height, width
	db FAST_SHIP_1F_HEIGHT, FAST_SHIP_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(FastShip1F_BlockData), FastShip1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FastShip1F_MapScriptHeader), FastShip1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FastShip1F_MapEventHeader

	; connections
	db 0
; 0x96134

FastShipCabins_NNW_NNE_NE_SecondMapHeader: ; 0x96134
	; border block
	db $0

	; height, width
	db FAST_SHIP_CABINS_NNW_NNE_NE_HEIGHT, FAST_SHIP_CABINS_NNW_NNE_NE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(FastShipCabins_NNW_NNE_NE_BlockData), FastShipCabins_NNW_NNE_NE_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FastShipCabins_NNW_NNE_NE_MapScriptHeader), FastShipCabins_NNW_NNE_NE_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FastShipCabins_NNW_NNE_NE_MapEventHeader

	; connections
	db 0
; 0x96140

FastShipCabins_SW_SSW_NW_SecondMapHeader: ; 0x96140
	; border block
	db $0

	; height, width
	db FAST_SHIP_CABINS_SW_SSW_NW_HEIGHT, FAST_SHIP_CABINS_SW_SSW_NW_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(FastShipCabins_SW_SSW_NW_BlockData), FastShipCabins_SW_SSW_NW_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FastShipCabins_SW_SSW_NW_MapScriptHeader), FastShipCabins_SW_SSW_NW_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FastShipCabins_SW_SSW_NW_MapEventHeader

	; connections
	db 0
; 0x9614c

FastShipCabins_SE_SSE_CaptainsCabin_SecondMapHeader: ; 0x9614c
	; border block
	db $0

	; height, width
	db FAST_SHIP_CABINS_SE_SSE_CAPTAINS_CABIN_HEIGHT, FAST_SHIP_CABINS_SE_SSE_CAPTAINS_CABIN_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(FastShipCabins_SE_SSE_CaptainsCabin_BlockData), FastShipCabins_SE_SSE_CaptainsCabin_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FastShipCabins_SE_SSE_CaptainsCabin_MapScriptHeader), FastShipCabins_SE_SSE_CaptainsCabin_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FastShipCabins_SE_SSE_CaptainsCabin_MapEventHeader

	; connections
	db 0
; 0x96158

FastShipB1F_SecondMapHeader: ; 0x96158
	; border block
	db $0

	; height, width
	db FAST_SHIP_B1F_HEIGHT, FAST_SHIP_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(FastShipB1F_BlockData), FastShipB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FastShipB1F_MapScriptHeader), FastShipB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FastShipB1F_MapEventHeader

	; connections
	db 0
; 0x96164

OlivinePortPassage_SecondMapHeader: ; 0x96164
	; border block
	db $0

	; height, width
	db OLIVINE_PORT_PASSAGE_HEIGHT, OLIVINE_PORT_PASSAGE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePortPassage_BlockData), OlivinePortPassage_BlockData

	; script header (bank-then-pointer)
	dbw BANK(OlivinePortPassage_MapScriptHeader), OlivinePortPassage_MapScriptHeader

	; map event header (bank-then-pointer)
	dw OlivinePortPassage_MapEventHeader

	; connections
	db 0
; 0x96170

VermilionPortPassage_SecondMapHeader: ; 0x96170
	; border block
	db $0

	; height, width
	db VERMILION_PORT_PASSAGE_HEIGHT, VERMILION_PORT_PASSAGE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePortPassage_BlockData), OlivinePortPassage_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VermilionPortPassage_MapScriptHeader), VermilionPortPassage_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VermilionPortPassage_MapEventHeader

	; connections
	db 0
; 0x9617c

MountMoonSquare_SecondMapHeader: ; 0x9617c
	; border block
	db $2d

	; height, width
	db MOUNT_MOON_SQUARE_HEIGHT, MOUNT_MOON_SQUARE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MountMoonSquare_BlockData), MountMoonSquare_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MountMoonSquare_MapScriptHeader), MountMoonSquare_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MountMoonSquare_MapEventHeader

	; connections
	db 0
; 0x96188

MountMoonGiftShop_SecondMapHeader: ; 0x96188
	; border block
	db $0

	; height, width
	db MOUNT_MOON_GIFT_SHOP_HEIGHT, MOUNT_MOON_GIFT_SHOP_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MahoganyMart1F_BlockData), MahoganyMart1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MountMoonGiftShop_MapScriptHeader), MountMoonGiftShop_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MountMoonGiftShop_MapEventHeader

	; connections
	db 0
; 0x96194

TinTowerRoof_SecondMapHeader: ; 0x96194
	; border block
	db $0

	; height, width
	db TIN_TOWER_ROOF_HEIGHT, TIN_TOWER_ROOF_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TinTowerRoof_BlockData), TinTowerRoof_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TinTowerRoof_MapScriptHeader), TinTowerRoof_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TinTowerRoof_MapEventHeader

	; connections
	db 0
; 0x961a0

IndigoPlateauPokeCenter1F_SecondMapHeader: ; 0x961a0
	; border block
	db $0

	; height, width
	db INDIGO_PLATEAU_POKECENTER_1F_HEIGHT, INDIGO_PLATEAU_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(IndigoPlateauPokeCenter1F_BlockData), IndigoPlateauPokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(IndigoPlateauPokeCenter1F_MapScriptHeader), IndigoPlateauPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw IndigoPlateauPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x961ac

WillsRoom_SecondMapHeader: ; 0x961ac
	; border block
	db $0

	; height, width
	db WILLS_ROOM_HEIGHT, WILLS_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(WillsRoom_BlockData), WillsRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(WillsRoom_MapScriptHeader), WillsRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw WillsRoom_MapEventHeader

	; connections
	db 0
; 0x961b8

KogasRoom_SecondMapHeader: ; 0x961b8
	; border block
	db $0

	; height, width
	db KOGAS_ROOM_HEIGHT, KOGAS_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(KogasRoom_BlockData), KogasRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(KogasRoom_MapScriptHeader), KogasRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw KogasRoom_MapEventHeader

	; connections
	db 0
; 0x961c4

BrunosRoom_SecondMapHeader: ; 0x961c4
	; border block
	db $0

	; height, width
	db BRUNOS_ROOM_HEIGHT, BRUNOS_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BrunosRoom_BlockData), BrunosRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BrunosRoom_MapScriptHeader), BrunosRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BrunosRoom_MapEventHeader

	; connections
	db 0
; 0x961d0

KarensRoom_SecondMapHeader: ; 0x961d0
	; border block
	db $0

	; height, width
	db KARENS_ROOM_HEIGHT, KARENS_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(KarensRoom_BlockData), KarensRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(KarensRoom_MapScriptHeader), KarensRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw KarensRoom_MapEventHeader

	; connections
	db 0
; 0x961dc

LancesRoom_SecondMapHeader: ; 0x961dc
	; border block
	db $0

	; height, width
	db LANCES_ROOM_HEIGHT, LANCES_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(LancesRoom_BlockData), LancesRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LancesRoom_MapScriptHeader), LancesRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LancesRoom_MapEventHeader

	; connections
	db 0
; 0x961e8

HallOfFame_SecondMapHeader: ; 0x961e8
	; border block
	db $0

	; height, width
	db HALL_OF_FAME_HEIGHT, HALL_OF_FAME_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(HallOfFame_BlockData), HallOfFame_BlockData

	; script header (bank-then-pointer)
	dbw BANK(HallOfFame_MapScriptHeader), HallOfFame_MapScriptHeader

	; map event header (bank-then-pointer)
	dw HallOfFame_MapEventHeader

	; connections
	db 0
; 0x961f4

FuchsiaMart_SecondMapHeader: ; 0x961f4
	; border block
	db $0

	; height, width
	db FUCHSIA_MART_HEIGHT, FUCHSIA_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FuchsiaMart_MapScriptHeader), FuchsiaMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FuchsiaMart_MapEventHeader

	; connections
	db 0
; 0x96200

SafariZoneMainOffice_SecondMapHeader: ; 0x96200
	; border block
	db $0

	; height, width
	db SAFARI_ZONE_MAIN_OFFICE_HEIGHT, SAFARI_ZONE_MAIN_OFFICE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineCafe_BlockData), OlivineCafe_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SafariZoneMainOffice_MapScriptHeader), SafariZoneMainOffice_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SafariZoneMainOffice_MapEventHeader

	; connections
	db 0
; 0x9620c

FuchsiaGym_SecondMapHeader: ; 0x9620c
	; border block
	db $0

	; height, width
	db FUCHSIA_GYM_HEIGHT, FUCHSIA_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(FuchsiaGym_BlockData), FuchsiaGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FuchsiaGym_MapScriptHeader), FuchsiaGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FuchsiaGym_MapEventHeader

	; connections
	db 0
; 0x96218

FuchsiaBillSpeechHouse_SecondMapHeader: ; 0x96218
	; border block
	db $0

	; height, width
	db FUCHSIA_BILL_SPEECH_HOUSE_HEIGHT, FUCHSIA_BILL_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FuchsiaBillSpeechHouse_MapScriptHeader), FuchsiaBillSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FuchsiaBillSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96224

FuchsiaPokeCenter1F_SecondMapHeader: ; 0x96224
	; border block
	db $0

	; height, width
	db FUCHSIA_POKECENTER_1F_HEIGHT, FUCHSIA_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FuchsiaPokeCenter1F_MapScriptHeader), FuchsiaPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FuchsiaPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x96230

FuchsiaPokeCenter2FBeta_SecondMapHeader: ; 0x96230
	; border block
	db $0

	; height, width
	db FUCHSIA_POKECENTER_2F_BETA_HEIGHT, FUCHSIA_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FuchsiaPokeCenter2FBeta_MapScriptHeader), FuchsiaPokeCenter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FuchsiaPokeCenter2FBeta_MapEventHeader

	; connections
	db 0
; 0x9623c

SafariZoneWardensHome_SecondMapHeader: ; 0x9623c
	; border block
	db $0

	; height, width
	db SAFARI_ZONE_WARDENS_HOME_HEIGHT, SAFARI_ZONE_WARDENS_HOME_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(PokemonFanClub_BlockData), PokemonFanClub_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SafariZoneWardensHome_MapScriptHeader), SafariZoneWardensHome_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SafariZoneWardensHome_MapEventHeader

	; connections
	db 0
; 0x96248

Route15FuchsiaGate_SecondMapHeader: ; 0x96248
	; border block
	db $0

	; height, width
	db ROUTE_15_FUCHSIA_GATE_HEIGHT, ROUTE_15_FUCHSIA_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route15FuchsiaGate_MapScriptHeader), Route15FuchsiaGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route15FuchsiaGate_MapEventHeader

	; connections
	db 0
; 0x96254

LavenderPokeCenter1F_SecondMapHeader: ; 0x96254
	; border block
	db $0

	; height, width
	db LAVENDER_POKECENTER_1F_HEIGHT, LAVENDER_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LavenderPokeCenter1F_MapScriptHeader), LavenderPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LavenderPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x96260

LavenderPokeCenter2FBeta_SecondMapHeader: ; 0x96260
	; border block
	db $0

	; height, width
	db LAVENDER_POKECENTER_2F_BETA_HEIGHT, LAVENDER_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LavenderPokeCenter2FBeta_MapScriptHeader), LavenderPokeCenter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LavenderPokeCenter2FBeta_MapEventHeader

	; connections
	db 0
; 0x9626c

MrFujisHouse_SecondMapHeader: ; 0x9626c
	; border block
	db $0

	; height, width
	db MR_FUJIS_HOUSE_HEIGHT, MR_FUJIS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MrFujisHouse_BlockData), MrFujisHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MrFujisHouse_MapScriptHeader), MrFujisHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MrFujisHouse_MapEventHeader

	; connections
	db 0
; 0x96278

LavenderTownSpeechHouse_SecondMapHeader: ; 0x96278
	; border block
	db $0

	; height, width
	db LAVENDER_TOWN_SPEECH_HOUSE_HEIGHT, LAVENDER_TOWN_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LavenderTownSpeechHouse_MapScriptHeader), LavenderTownSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LavenderTownSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96284

LavenderNameRater_SecondMapHeader: ; 0x96284
	; border block
	db $0

	; height, width
	db LAVENDER_NAME_RATER_HEIGHT, LAVENDER_NAME_RATER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LavenderNameRater_MapScriptHeader), LavenderNameRater_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LavenderNameRater_MapEventHeader

	; connections
	db 0
; 0x96290

LavenderMart_SecondMapHeader: ; 0x96290
	; border block
	db $0

	; height, width
	db LAVENDER_MART_HEIGHT, LAVENDER_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LavenderMart_MapScriptHeader), LavenderMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LavenderMart_MapEventHeader

	; connections
	db 0
; 0x9629c

SoulHouse_SecondMapHeader: ; 0x9629c
	; border block
	db $0

	; height, width
	db SOUL_HOUSE_HEIGHT, SOUL_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SoulHouse_BlockData), SoulHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SoulHouse_MapScriptHeader), SoulHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SoulHouse_MapEventHeader

	; connections
	db 0
; 0x962a8

LavRadioTower1F_SecondMapHeader: ; 0x962a8
	; border block
	db $0

	; height, width
	db LAV_RADIO_TOWER_1F_HEIGHT, LAV_RADIO_TOWER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(LavRadioTower1F_BlockData), LavRadioTower1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(LavRadioTower1F_MapScriptHeader), LavRadioTower1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw LavRadioTower1F_MapEventHeader

	; connections
	db 0
; 0x962b4

Route8SaffronGate_SecondMapHeader: ; 0x962b4
	; border block
	db $0

	; height, width
	db ROUTE_8_SAFFRON_GATE_HEIGHT, ROUTE_8_SAFFRON_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route8SaffronGate_MapScriptHeader), Route8SaffronGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route8SaffronGate_MapEventHeader

	; connections
	db 0
; 0x962c0

Route12SuperRodHouse_SecondMapHeader: ; 0x962c0
	; border block
	db $0

	; height, width
	db ROUTE_12_SUPER_ROD_HOUSE_HEIGHT, ROUTE_12_SUPER_ROD_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route12SuperRodHouse_MapScriptHeader), Route12SuperRodHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route12SuperRodHouse_MapEventHeader

	; connections
	db 0
; 0x962cc

SilverCavePokeCenter1F_SecondMapHeader: ; 0x962cc
	; border block
	db $0

	; height, width
	db SILVER_CAVE_POKECENTER_1F_HEIGHT, SILVER_CAVE_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SilverCavePokeCenter1F_MapScriptHeader), SilverCavePokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SilverCavePokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x962d8

Route28FamousSpeechHouse_SecondMapHeader: ; 0x962d8
	; border block
	db $0

	; height, width
	db ROUTE_28_FAMOUS_SPEECH_HOUSE_HEIGHT, ROUTE_28_FAMOUS_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route28FamousSpeechHouse_MapScriptHeader), Route28FamousSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route28FamousSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x962e4

PokeCenter2F_SecondMapHeader: ; 0x962e4
	; border block
	db $0

	; height, width
	db POKECENTER_2F_HEIGHT, POKECENTER_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PokeCenter2F_MapScriptHeader), PokeCenter2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PokeCenter2F_MapEventHeader

	; connections
	db 0
; 0x962f0

TradeCenter_SecondMapHeader: ; 0x962f0
	; border block
	db $0

	; height, width
	db TRADE_CENTER_HEIGHT, TRADE_CENTER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TradeCenter_BlockData), TradeCenter_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TradeCenter_MapScriptHeader), TradeCenter_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TradeCenter_MapEventHeader

	; connections
	db 0
; 0x962fc

Colosseum_SecondMapHeader: ; 0x962fc
	; border block
	db $0

	; height, width
	db COLOSSEUM_HEIGHT, COLOSSEUM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Colosseum_BlockData), Colosseum_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Colosseum_MapScriptHeader), Colosseum_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Colosseum_MapEventHeader

	; connections
	db 0
; 0x96308

TimeCapsule_SecondMapHeader: ; 0x96308
	; border block
	db $0

	; height, width
	db TIME_CAPSULE_HEIGHT, TIME_CAPSULE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TradeCenter_BlockData), TradeCenter_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TimeCapsule_MapScriptHeader), TimeCapsule_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TimeCapsule_MapEventHeader

	; connections
	db 0
; 0x96314

MobileTradeRoomMobile_SecondMapHeader: ; 0x96314
	; border block
	db $0

	; height, width
	db MOBILE_TRADE_ROOM_MOBILE_HEIGHT, MOBILE_TRADE_ROOM_MOBILE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MobileTradeRoomMobile_BlockData), MobileTradeRoomMobile_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MobileTradeRoomMobile_MapScriptHeader), MobileTradeRoomMobile_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MobileTradeRoomMobile_MapEventHeader

	; connections
	db 0
; 0x96320

MobileBattleRoom_SecondMapHeader: ; 0x96320
	; border block
	db $0

	; height, width
	db MOBILE_BATTLE_ROOM_HEIGHT, MOBILE_BATTLE_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MobileBattleRoom_BlockData), MobileBattleRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MobileBattleRoom_MapScriptHeader), MobileBattleRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MobileBattleRoom_MapEventHeader

	; connections
	db 0
; 0x9632c

CeladonDeptStore1F_SecondMapHeader: ; 0x9632c
	; border block
	db $0

	; height, width
	db CELADON_DEPT_STORE_1F_HEIGHT, CELADON_DEPT_STORE_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore1F_BlockData), GoldenrodDeptStore1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonDeptStore1F_MapScriptHeader), CeladonDeptStore1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonDeptStore1F_MapEventHeader

	; connections
	db 0
; 0x96338

CeladonDeptStore2F_SecondMapHeader: ; 0x96338
	; border block
	db $0

	; height, width
	db CELADON_DEPT_STORE_2F_HEIGHT, CELADON_DEPT_STORE_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore2F_BlockData), GoldenrodDeptStore2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonDeptStore2F_MapScriptHeader), CeladonDeptStore2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonDeptStore2F_MapEventHeader

	; connections
	db 0
; 0x96344

CeladonDeptStore3F_SecondMapHeader: ; 0x96344
	; border block
	db $0

	; height, width
	db CELADON_DEPT_STORE_3F_HEIGHT, CELADON_DEPT_STORE_3F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore3F_BlockData), GoldenrodDeptStore3F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonDeptStore3F_MapScriptHeader), CeladonDeptStore3F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonDeptStore3F_MapEventHeader

	; connections
	db 0
; 0x96350

CeladonDeptStore4F_SecondMapHeader: ; 0x96350
	; border block
	db $0

	; height, width
	db CELADON_DEPT_STORE_4F_HEIGHT, CELADON_DEPT_STORE_4F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore4F_BlockData), GoldenrodDeptStore4F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonDeptStore4F_MapScriptHeader), CeladonDeptStore4F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonDeptStore4F_MapEventHeader

	; connections
	db 0
; 0x9635c

CeladonDeptStore5F_SecondMapHeader: ; 0x9635c
	; border block
	db $0

	; height, width
	db CELADON_DEPT_STORE_5F_HEIGHT, CELADON_DEPT_STORE_5F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore5F_BlockData), GoldenrodDeptStore5F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonDeptStore5F_MapScriptHeader), CeladonDeptStore5F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonDeptStore5F_MapEventHeader

	; connections
	db 0
; 0x96368

CeladonDeptStore6F_SecondMapHeader: ; 0x96368
	; border block
	db $0

	; height, width
	db CELADON_DEPT_STORE_6F_HEIGHT, CELADON_DEPT_STORE_6F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStore6F_BlockData), GoldenrodDeptStore6F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonDeptStore6F_MapScriptHeader), CeladonDeptStore6F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonDeptStore6F_MapEventHeader

	; connections
	db 0
; 0x96374

CeladonDeptStoreElevator_SecondMapHeader: ; 0x96374
	; border block
	db $0

	; height, width
	db CELADON_DEPT_STORE_ELEVATOR_HEIGHT, CELADON_DEPT_STORE_ELEVATOR_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(GoldenrodDeptStoreElevator_BlockData), GoldenrodDeptStoreElevator_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonDeptStoreElevator_MapScriptHeader), CeladonDeptStoreElevator_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonDeptStoreElevator_MapEventHeader

	; connections
	db 0
; 0x96380

CeladonMansion1F_SecondMapHeader: ; 0x96380
	; border block
	db $0

	; height, width
	db CELADON_MANSION_1F_HEIGHT, CELADON_MANSION_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeladonMansion1F_BlockData), CeladonMansion1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonMansion1F_MapScriptHeader), CeladonMansion1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonMansion1F_MapEventHeader

	; connections
	db 0
; 0x9638c

CeladonMansion2F_SecondMapHeader: ; 0x9638c
	; border block
	db $0

	; height, width
	db CELADON_MANSION_2F_HEIGHT, CELADON_MANSION_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeladonMansion2F_BlockData), CeladonMansion2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonMansion2F_MapScriptHeader), CeladonMansion2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonMansion2F_MapEventHeader

	; connections
	db 0
; 0x96398

CeladonMansion3F_SecondMapHeader: ; 0x96398
	; border block
	db $0

	; height, width
	db CELADON_MANSION_3F_HEIGHT, CELADON_MANSION_3F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeladonMansion3F_BlockData), CeladonMansion3F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonMansion3F_MapScriptHeader), CeladonMansion3F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonMansion3F_MapEventHeader

	; connections
	db 0
; 0x963a4

CeladonMansionRoof_SecondMapHeader: ; 0x963a4
	; border block
	db $1

	; height, width
	db CELADON_MANSION_ROOF_HEIGHT, CELADON_MANSION_ROOF_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeladonMansionRoof_BlockData), CeladonMansionRoof_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonMansionRoof_MapScriptHeader), CeladonMansionRoof_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonMansionRoof_MapEventHeader

	; connections
	db 0
; 0x963b0

CeladonMansionRoofHouse_SecondMapHeader: ; 0x963b0
	; border block
	db $0

	; height, width
	db CELADON_MANSION_ROOF_HOUSE_HEIGHT, CELADON_MANSION_ROOF_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonMansionRoofHouse_MapScriptHeader), CeladonMansionRoofHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonMansionRoofHouse_MapEventHeader

	; connections
	db 0
; 0x963bc

CeladonPokeCenter1F_SecondMapHeader: ; 0x963bc
	; border block
	db $0

	; height, width
	db CELADON_POKECENTER_1F_HEIGHT, CELADON_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonPokeCenter1F_MapScriptHeader), CeladonPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x963c8

CeladonPokeCenter2FBeta_SecondMapHeader: ; 0x963c8
	; border block
	db $0

	; height, width
	db CELADON_POKECENTER_2F_BETA_HEIGHT, CELADON_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonPokeCenter2FBeta_MapScriptHeader), CeladonPokeCenter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonPokeCenter2FBeta_MapEventHeader

	; connections
	db 0
; 0x963d4

CeladonGameCorner_SecondMapHeader: ; 0x963d4
	; border block
	db $0

	; height, width
	db CELADON_GAME_CORNER_HEIGHT, CELADON_GAME_CORNER_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeladonGameCorner_BlockData), CeladonGameCorner_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonGameCorner_MapScriptHeader), CeladonGameCorner_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonGameCorner_MapEventHeader

	; connections
	db 0
; 0x963e0

CeladonGameCornerPrizeRoom_SecondMapHeader: ; 0x963e0
	; border block
	db $0

	; height, width
	db CELADON_GAME_CORNER_PRIZE_ROOM_HEIGHT, CELADON_GAME_CORNER_PRIZE_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeladonGameCornerPrizeRoom_BlockData), CeladonGameCornerPrizeRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonGameCornerPrizeRoom_MapScriptHeader), CeladonGameCornerPrizeRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonGameCornerPrizeRoom_MapEventHeader

	; connections
	db 0
; 0x963ec

CeladonGym_SecondMapHeader: ; 0x963ec
	; border block
	db $0

	; height, width
	db CELADON_GYM_HEIGHT, CELADON_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeladonGym_BlockData), CeladonGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonGym_MapScriptHeader), CeladonGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonGym_MapEventHeader

	; connections
	db 0
; 0x963f8

CeladonCafe_SecondMapHeader: ; 0x963f8
	; border block
	db $0

	; height, width
	db CELADON_CAFE_HEIGHT, CELADON_CAFE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CeladonCafe_BlockData), CeladonCafe_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CeladonCafe_MapScriptHeader), CeladonCafe_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CeladonCafe_MapEventHeader

	; connections
	db 0
; 0x96404

Route16FuchsiaSpeechHouse_SecondMapHeader: ; 0x96404
	; border block
	db $0

	; height, width
	db ROUTE_16_FUCHSIA_SPEECH_HOUSE_HEIGHT, ROUTE_16_FUCHSIA_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route16FuchsiaSpeechHouse_MapScriptHeader), Route16FuchsiaSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route16FuchsiaSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96410

Route16Gate_SecondMapHeader: ; 0x96410
	; border block
	db $0

	; height, width
	db ROUTE_16_GATE_HEIGHT, ROUTE_16_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route16Gate_MapScriptHeader), Route16Gate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route16Gate_MapEventHeader

	; connections
	db 0
; 0x9641c

Route7SaffronGate_SecondMapHeader: ; 0x9641c
	; border block
	db $0

	; height, width
	db ROUTE_7_SAFFRON_GATE_HEIGHT, ROUTE_7_SAFFRON_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route7SaffronGate_MapScriptHeader), Route7SaffronGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route7SaffronGate_MapEventHeader

	; connections
	db 0
; 0x96428

Route1718Gate_SecondMapHeader: ; 0x96428
	; border block
	db $0

	; height, width
	db ROUTE_17_18_GATE_HEIGHT, ROUTE_17_18_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route1718Gate_MapScriptHeader), Route1718Gate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route1718Gate_MapEventHeader

	; connections
	db 0
; 0x96434

ManiasHouse_SecondMapHeader: ; 0x96434
	; border block
	db $0

	; height, width
	db MANIAS_HOUSE_HEIGHT, MANIAS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(ManiasHouse_MapScriptHeader), ManiasHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw ManiasHouse_MapEventHeader

	; connections
	db 0
; 0x96440

CianwoodGym_SecondMapHeader: ; 0x96440
	; border block
	db $0

	; height, width
	db CIANWOOD_GYM_HEIGHT, CIANWOOD_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CianwoodGym_BlockData), CianwoodGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CianwoodGym_MapScriptHeader), CianwoodGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CianwoodGym_MapEventHeader

	; connections
	db 0
; 0x9644c

CianwoodPokeCenter1F_SecondMapHeader: ; 0x9644c
	; border block
	db $0

	; height, width
	db CIANWOOD_POKECENTER_1F_HEIGHT, CIANWOOD_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CianwoodPokeCenter1F_MapScriptHeader), CianwoodPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CianwoodPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x96458

CianwoodPharmacy_SecondMapHeader: ; 0x96458
	; border block
	db $0

	; height, width
	db CIANWOOD_PHARMACY_HEIGHT, CIANWOOD_PHARMACY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CianwoodPharmacy_MapScriptHeader), CianwoodPharmacy_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CianwoodPharmacy_MapEventHeader

	; connections
	db 0
; 0x96464

CianwoodCityPhotoStudio_SecondMapHeader: ; 0x96464
	; border block
	db $0

	; height, width
	db CIANWOOD_CITY_PHOTO_STUDIO_HEIGHT, CIANWOOD_CITY_PHOTO_STUDIO_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CianwoodCityPhotoStudio_MapScriptHeader), CianwoodCityPhotoStudio_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CianwoodCityPhotoStudio_MapEventHeader

	; connections
	db 0
; 0x96470

CianwoodLugiaSpeechHouse_SecondMapHeader: ; 0x96470
	; border block
	db $0

	; height, width
	db CIANWOOD_LUGIA_SPEECH_HOUSE_HEIGHT, CIANWOOD_LUGIA_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CianwoodLugiaSpeechHouse_MapScriptHeader), CianwoodLugiaSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CianwoodLugiaSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x9647c

PokeSeersHouse_SecondMapHeader: ; 0x9647c
	; border block
	db $0

	; height, width
	db POKE_SEERS_HOUSE_HEIGHT, POKE_SEERS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(PokeSeersHouse_MapScriptHeader), PokeSeersHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw PokeSeersHouse_MapEventHeader

	; connections
	db 0
; 0x96488

BattleTower1F_SecondMapHeader: ; 0x96488
	; border block
	db $0

	; height, width
	db BATTLE_TOWER_1F_HEIGHT, BATTLE_TOWER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BattleTower1F_BlockData), BattleTower1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BattleTower1F_MapScriptHeader), BattleTower1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BattleTower1F_MapEventHeader

	; connections
	db 0
; 0x96494

BattleTowerBattleRoom_SecondMapHeader: ; 0x96494
	; border block
	db $0

	; height, width
	db BATTLE_TOWER_BATTLE_ROOM_HEIGHT, BATTLE_TOWER_BATTLE_ROOM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BattleTowerBattleRoom_BlockData), BattleTowerBattleRoom_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BattleTowerBattleRoom_MapScriptHeader), BattleTowerBattleRoom_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BattleTowerBattleRoom_MapEventHeader

	; connections
	db 0
; 0x964a0

BattleTowerElevator_SecondMapHeader: ; 0x964a0
	; border block
	db $0

	; height, width
	db BATTLE_TOWER_ELEVATOR_HEIGHT, BATTLE_TOWER_ELEVATOR_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BattleTowerElevator_BlockData), BattleTowerElevator_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BattleTowerElevator_MapScriptHeader), BattleTowerElevator_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BattleTowerElevator_MapEventHeader

	; connections
	db 0
; 0x964ac

BattleTowerHallway_SecondMapHeader: ; 0x964ac
	; border block
	db $0

	; height, width
	db BATTLE_TOWER_HALLWAY_HEIGHT, BATTLE_TOWER_HALLWAY_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BattleTowerHallway_BlockData), BattleTowerHallway_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BattleTowerHallway_MapScriptHeader), BattleTowerHallway_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BattleTowerHallway_MapEventHeader

	; connections
	db 0
; 0x964b8

Route40BattleTowerGate_SecondMapHeader: ; 0x964b8
	; border block
	db $0

	; height, width
	db ROUTE_40_BATTLE_TOWER_GATE_HEIGHT, ROUTE_40_BATTLE_TOWER_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route40BattleTowerGate_MapScriptHeader), Route40BattleTowerGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route40BattleTowerGate_MapEventHeader

	; connections
	db 0
; 0x964c4

BattleTowerOutside_SecondMapHeader: ; 0x964c4
	; border block
	db $5

	; height, width
	db BATTLE_TOWER_OUTSIDE_HEIGHT, BATTLE_TOWER_OUTSIDE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(BattleTowerOutside_BlockData), BattleTowerOutside_BlockData

	; script header (bank-then-pointer)
	dbw BANK(BattleTowerOutside_MapScriptHeader), BattleTowerOutside_MapScriptHeader

	; map event header (bank-then-pointer)
	dw BattleTowerOutside_MapEventHeader

	; connections
	db 0
; 0x964d0

ViridianGym_SecondMapHeader: ; 0x964d0
	; border block
	db $0

	; height, width
	db VIRIDIAN_GYM_HEIGHT, VIRIDIAN_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(ViridianGym_BlockData), ViridianGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(ViridianGym_MapScriptHeader), ViridianGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw ViridianGym_MapEventHeader

	; connections
	db 0
; 0x964dc

ViridianNicknameSpeechHouse_SecondMapHeader: ; 0x964dc
	; border block
	db $0

	; height, width
	db VIRIDIAN_NICKNAME_SPEECH_HOUSE_HEIGHT, VIRIDIAN_NICKNAME_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(ViridianNicknameSpeechHouse_MapScriptHeader), ViridianNicknameSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw ViridianNicknameSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x964e8

TrainerHouse1F_SecondMapHeader: ; 0x964e8
	; border block
	db $0

	; height, width
	db TRAINER_HOUSE_1F_HEIGHT, TRAINER_HOUSE_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TrainerHouse1F_BlockData), TrainerHouse1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TrainerHouse1F_MapScriptHeader), TrainerHouse1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TrainerHouse1F_MapEventHeader

	; connections
	db 0
; 0x964f4

TrainerHouseB1F_SecondMapHeader: ; 0x964f4
	; border block
	db $0

	; height, width
	db TRAINER_HOUSE_B1F_HEIGHT, TRAINER_HOUSE_B1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(TrainerHouseB1F_BlockData), TrainerHouseB1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(TrainerHouseB1F_MapScriptHeader), TrainerHouseB1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw TrainerHouseB1F_MapEventHeader

	; connections
	db 0
; 0x96500

ViridianMart_SecondMapHeader: ; 0x96500
	; border block
	db $0

	; height, width
	db VIRIDIAN_MART_HEIGHT, VIRIDIAN_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(ViridianMart_MapScriptHeader), ViridianMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw ViridianMart_MapEventHeader

	; connections
	db 0
; 0x9650c

ViridianPokeCenter1F_SecondMapHeader: ; 0x9650c
	; border block
	db $0

	; height, width
	db VIRIDIAN_POKECENTER_1F_HEIGHT, VIRIDIAN_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(ViridianPokeCenter1F_MapScriptHeader), ViridianPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw ViridianPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x96518

ViridianPokeCenter2FBeta_SecondMapHeader: ; 0x96518
	; border block
	db $0

	; height, width
	db VIRIDIAN_POKECENTER_2F_BETA_HEIGHT, VIRIDIAN_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(ViridianPokeCenter2FBeta_MapScriptHeader), ViridianPokeCenter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw ViridianPokeCenter2FBeta_MapEventHeader

	; connections
	db 0
; 0x96524

Route2NuggetSpeechHouse_SecondMapHeader: ; 0x96524
	; border block
	db $0

	; height, width
	db ROUTE_2_NUGGET_SPEECH_HOUSE_HEIGHT, ROUTE_2_NUGGET_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route2NuggetSpeechHouse_MapScriptHeader), Route2NuggetSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route2NuggetSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96530

Route2Gate_SecondMapHeader: ; 0x96530
	; border block
	db $0

	; height, width
	db ROUTE_2_GATE_HEIGHT, ROUTE_2_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route2Gate_MapScriptHeader), Route2Gate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route2Gate_MapEventHeader

	; connections
	db 0
; 0x9653c

VictoryRoadGate_SecondMapHeader: ; 0x9653c
	; border block
	db $0

	; height, width
	db VICTORY_ROAD_GATE_HEIGHT, VICTORY_ROAD_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(VictoryRoadGate_BlockData), VictoryRoadGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(VictoryRoadGate_MapScriptHeader), VictoryRoadGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw VictoryRoadGate_MapEventHeader

	; connections
	db 0
; 0x96548

ElmsLab_SecondMapHeader: ; 0x96548
	; border block
	db $0

	; height, width
	db ELMS_LAB_HEIGHT, ELMS_LAB_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(ElmsLab_BlockData), ElmsLab_BlockData

	; script header (bank-then-pointer)
	dbw BANK(ElmsLab_MapScriptHeader), ElmsLab_MapScriptHeader

	; map event header (bank-then-pointer)
	dw ElmsLab_MapEventHeader

	; connections
	db 0
; 0x96554

KrissHouse1F_SecondMapHeader: ; 0x96554
	; border block
	db $0

	; height, width
	db KRISS_HOUSE_1F_HEIGHT, KRISS_HOUSE_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(KrissHouse1F_BlockData), KrissHouse1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(KrissHouse1F_MapScriptHeader), KrissHouse1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw KrissHouse1F_MapEventHeader

	; connections
	db 0
; 0x96560

KrissHouse2F_SecondMapHeader: ; 0x96560
	; border block
	db $0

	; height, width
	db KRISS_HOUSE_2F_HEIGHT, KRISS_HOUSE_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(KrissHouse2F_BlockData), KrissHouse2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(KrissHouse2F_MapScriptHeader), KrissHouse2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw KrissHouse2F_MapEventHeader

	; connections
	db 0
; 0x9656c

KrissNeighborsHouse_SecondMapHeader: ; 0x9656c
	; border block
	db $0

	; height, width
	db KRISS_NEIGHBORS_HOUSE_HEIGHT, KRISS_NEIGHBORS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(KrissNeighborsHouse_MapScriptHeader), KrissNeighborsHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw KrissNeighborsHouse_MapEventHeader

	; connections
	db 0
; 0x96578

ElmsHouse_SecondMapHeader: ; 0x96578
	; border block
	db $0

	; height, width
	db ELMS_HOUSE_HEIGHT, ELMS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(ElmsHouse_BlockData), ElmsHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(ElmsHouse_MapScriptHeader), ElmsHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw ElmsHouse_MapEventHeader

	; connections
	db 0
; 0x96584

Route26HealSpeechHouse_SecondMapHeader: ; 0x96584
	; border block
	db $0

	; height, width
	db ROUTE_26_HEAL_SPEECH_HOUSE_HEIGHT, ROUTE_26_HEAL_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route26HealSpeechHouse_MapScriptHeader), Route26HealSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route26HealSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96590

Route26DayofWeekSiblingsHouse_SecondMapHeader: ; 0x96590
	; border block
	db $0

	; height, width
	db ROUTE_26_DAY_OF_WEEK_SIBLINGS_HOUSE_HEIGHT, ROUTE_26_DAY_OF_WEEK_SIBLINGS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route26DayofWeekSiblingsHouse_MapScriptHeader), Route26DayofWeekSiblingsHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route26DayofWeekSiblingsHouse_MapEventHeader

	; connections
	db 0
; 0x9659c

Route27SandstormHouse_SecondMapHeader: ; 0x9659c
	; border block
	db $0

	; height, width
	db ROUTE_27_SANDSTORM_HOUSE_HEIGHT, ROUTE_27_SANDSTORM_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route27SandstormHouse_MapScriptHeader), Route27SandstormHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route27SandstormHouse_MapEventHeader

	; connections
	db 0
; 0x965a8

Route2946Gate_SecondMapHeader: ; 0x965a8
	; border block
	db $0

	; height, width
	db ROUTE_29_46_GATE_HEIGHT, ROUTE_29_46_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route2946Gate_MapScriptHeader), Route2946Gate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route2946Gate_MapEventHeader

	; connections
	db 0
; 0x965b4

FightingDojo_SecondMapHeader: ; 0x965b4
	; border block
	db $0

	; height, width
	db FIGHTING_DOJO_HEIGHT, FIGHTING_DOJO_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(FightingDojo_BlockData), FightingDojo_BlockData

	; script header (bank-then-pointer)
	dbw BANK(FightingDojo_MapScriptHeader), FightingDojo_MapScriptHeader

	; map event header (bank-then-pointer)
	dw FightingDojo_MapEventHeader

	; connections
	db 0
; 0x965c0

SaffronGym_SecondMapHeader: ; 0x965c0
	; border block
	db $0

	; height, width
	db SAFFRON_GYM_HEIGHT, SAFFRON_GYM_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SaffronGym_BlockData), SaffronGym_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SaffronGym_MapScriptHeader), SaffronGym_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SaffronGym_MapEventHeader

	; connections
	db 0
; 0x965cc

SaffronMart_SecondMapHeader: ; 0x965cc
	; border block
	db $0

	; height, width
	db SAFFRON_MART_HEIGHT, SAFFRON_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SaffronMart_MapScriptHeader), SaffronMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SaffronMart_MapEventHeader

	; connections
	db 0
; 0x965d8

SaffronPokeCenter1F_SecondMapHeader: ; 0x965d8
	; border block
	db $0

	; height, width
	db SAFFRON_POKECENTER_1F_HEIGHT, SAFFRON_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SaffronPokeCenter1F_MapScriptHeader), SaffronPokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SaffronPokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x965e4

SaffronPokeCenter2FBeta_SecondMapHeader: ; 0x965e4
	; border block
	db $0

	; height, width
	db SAFFRON_POKECENTER_2F_BETA_HEIGHT, SAFFRON_POKECENTER_2F_BETA_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CinnabarPokeCenter2FBeta_BlockData), CinnabarPokeCenter2FBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SaffronPokeCenter2FBeta_MapScriptHeader), SaffronPokeCenter2FBeta_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SaffronPokeCenter2FBeta_MapEventHeader

	; connections
	db 0
; 0x965f0

MrPsychicsHouse_SecondMapHeader: ; 0x965f0
	; border block
	db $0

	; height, width
	db MR_PSYCHICS_HOUSE_HEIGHT, MR_PSYCHICS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MrPsychicsHouse_MapScriptHeader), MrPsychicsHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MrPsychicsHouse_MapEventHeader

	; connections
	db 0
; 0x965fc

SaffronTrainStation_SecondMapHeader: ; 0x965fc
	; border block
	db $0

	; height, width
	db SAFFRON_TRAIN_STATION_HEIGHT, SAFFRON_TRAIN_STATION_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SaffronTrainStation_BlockData), SaffronTrainStation_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SaffronTrainStation_MapScriptHeader), SaffronTrainStation_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SaffronTrainStation_MapEventHeader

	; connections
	db 0
; 0x96608

SilphCo1F_SecondMapHeader: ; 0x96608
	; border block
	db $0

	; height, width
	db SILPH_CO_1F_HEIGHT, SILPH_CO_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SilphCo1F_BlockData), SilphCo1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(SilphCo1F_MapScriptHeader), SilphCo1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw SilphCo1F_MapEventHeader

	; connections
	db 0
; 0x96614

CopycatsHouse1F_SecondMapHeader: ; 0x96614
	; border block
	db $0

	; height, width
	db COPYCATS_HOUSE_1F_HEIGHT, COPYCATS_HOUSE_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CopycatsHouse1F_BlockData), CopycatsHouse1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CopycatsHouse1F_MapScriptHeader), CopycatsHouse1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CopycatsHouse1F_MapEventHeader

	; connections
	db 0
; 0x96620

CopycatsHouse2F_SecondMapHeader: ; 0x96620
	; border block
	db $0

	; height, width
	db COPYCATS_HOUSE_2F_HEIGHT, COPYCATS_HOUSE_2F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(CopycatsHouse2F_BlockData), CopycatsHouse2F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CopycatsHouse2F_MapScriptHeader), CopycatsHouse2F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CopycatsHouse2F_MapEventHeader

	; connections
	db 0
; 0x9662c

Route5UndergroundEntrance_SecondMapHeader: ; 0x9662c
	; border block
	db $0

	; height, width
	db ROUTE_5_UNDERGROUND_ENTRANCE_HEIGHT, ROUTE_5_UNDERGROUND_ENTRANCE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route6UndergroundEntrance_BlockData), Route6UndergroundEntrance_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route5UndergroundEntrance_MapScriptHeader), Route5UndergroundEntrance_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route5UndergroundEntrance_MapEventHeader

	; connections
	db 0
; 0x96638

Route5SaffronCityGate_SecondMapHeader: ; 0x96638
	; border block
	db $0

	; height, width
	db ROUTE_5_SAFFRON_CITY_GATE_HEIGHT, ROUTE_5_SAFFRON_CITY_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(SafariZoneFuchsiaGateBeta_BlockData), SafariZoneFuchsiaGateBeta_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route5SaffronCityGate_MapScriptHeader), Route5SaffronCityGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route5SaffronCityGate_MapEventHeader

	; connections
	db 0
; 0x96644

Route5CleanseTagSpeechHouse_SecondMapHeader: ; 0x96644
	; border block
	db $0

	; height, width
	db ROUTE_5_CLEANSE_TAG_SPEECH_HOUSE_HEIGHT, ROUTE_5_CLEANSE_TAG_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route5CleanseTagSpeechHouse_MapScriptHeader), Route5CleanseTagSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route5CleanseTagSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96650

CherrygroveMart_SecondMapHeader: ; 0x96650
	; border block
	db $0

	; height, width
	db CHERRYGROVE_MART_HEIGHT, CHERRYGROVE_MART_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineMart_BlockData), OlivineMart_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CherrygroveMart_MapScriptHeader), CherrygroveMart_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CherrygroveMart_MapEventHeader

	; connections
	db 0
; 0x9665c

CherrygrovePokeCenter1F_SecondMapHeader: ; 0x9665c
	; border block
	db $0

	; height, width
	db CHERRYGROVE_POKECENTER_1F_HEIGHT, CHERRYGROVE_POKECENTER_1F_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivinePokeCenter1F_BlockData), OlivinePokeCenter1F_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CherrygrovePokeCenter1F_MapScriptHeader), CherrygrovePokeCenter1F_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CherrygrovePokeCenter1F_MapEventHeader

	; connections
	db 0
; 0x96668

CherrygroveGymSpeechHouse_SecondMapHeader: ; 0x96668
	; border block
	db $0

	; height, width
	db CHERRYGROVE_GYM_SPEECH_HOUSE_HEIGHT, CHERRYGROVE_GYM_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CherrygroveGymSpeechHouse_MapScriptHeader), CherrygroveGymSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CherrygroveGymSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96674

GuideGentsHouse_SecondMapHeader: ; 0x96674
	; border block
	db $0

	; height, width
	db GUIDE_GENTS_HOUSE_HEIGHT, GUIDE_GENTS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(GuideGentsHouse_MapScriptHeader), GuideGentsHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw GuideGentsHouse_MapEventHeader

	; connections
	db 0
; 0x96680

CherrygroveEvolutionSpeechHouse_SecondMapHeader: ; 0x96680
	; border block
	db $0

	; height, width
	db CHERRYGROVE_EVOLUTION_SPEECH_HOUSE_HEIGHT, CHERRYGROVE_EVOLUTION_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(CherrygroveEvolutionSpeechHouse_MapScriptHeader), CherrygroveEvolutionSpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw CherrygroveEvolutionSpeechHouse_MapEventHeader

	; connections
	db 0
; 0x9668c

Route30BerrySpeechHouse_SecondMapHeader: ; 0x9668c
	; border block
	db $0

	; height, width
	db ROUTE_30_BERRY_SPEECH_HOUSE_HEIGHT, ROUTE_30_BERRY_SPEECH_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(OlivineVoltorbHouse_BlockData), OlivineVoltorbHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route30BerrySpeechHouse_MapScriptHeader), Route30BerrySpeechHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route30BerrySpeechHouse_MapEventHeader

	; connections
	db 0
; 0x96698

MrPokemonsHouse_SecondMapHeader: ; 0x96698
	; border block
	db $0

	; height, width
	db MR_POKEMONS_HOUSE_HEIGHT, MR_POKEMONS_HOUSE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(MrPokemonsHouse_BlockData), MrPokemonsHouse_BlockData

	; script header (bank-then-pointer)
	dbw BANK(MrPokemonsHouse_MapScriptHeader), MrPokemonsHouse_MapScriptHeader

	; map event header (bank-then-pointer)
	dw MrPokemonsHouse_MapEventHeader

	; connections
	db 0
; 0x966a4

Route31VioletGate_SecondMapHeader: ; 0x966a4
	; border block
	db $0

	; height, width
	db ROUTE_31_VIOLET_GATE_HEIGHT, ROUTE_31_VIOLET_GATE_WIDTH

	; blockdata (bank-then-pointer)
	dbw BANK(Route38EcruteakGate_BlockData), Route38EcruteakGate_BlockData

	; script header (bank-then-pointer)
	dbw BANK(Route31VioletGate_MapScriptHeader), Route31VioletGate_MapScriptHeader

	; map event header (bank-then-pointer)
	dw Route31VioletGate_MapEventHeader

	; connections
	db 0
; 0x966b0

INCBIN "baserom.gbc",$966b0,$1950

SECTION "bank26",DATA,BANK[$26]

EcruteakHouse_MapScriptHeader: ; 0x98000
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x9800d, $0000
	dw UnknownScript_0x9800e, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x9800f
; 0x9800d

UnknownScript_0x9800d: ; 0x9800d
	end
; 0x9800e

UnknownScript_0x9800e: ; 0x9800e
	end
; 0x9800f

UnknownScript_0x9800f: ; 0x9800f
	checkbit1 $0335
	iftrue UnknownScript_0x98033
	checkbit1 $0334
	iftrue UnknownScript_0x98033
	checkbit1 $0021
	iftrue UnknownScript_0x98022
	return
; 0x98022

UnknownScript_0x98022: ; 0x98022
	clearbit1 $0766
	setbit1 $0767
	setbit1 $07b1
	checkitem CLEAR_BELL
	iftrue UnknownScript_0x98032
	dotrigger $0
UnknownScript_0x98032: ; 0x98032
	return
; 0x98033

UnknownScript_0x98033: ; 0x98033
	clearbit1 $07b1
	return
; 0x98037

UnknownScript_0x98037: ; 0x98037
	checkbit1 $0767
	iftrue UnknownScript_0x98061
	applymovement $3, MovementData_0x980c7
	moveperson $2, $4, $6
	appear $2
	pause 5
	disappear $3
	end
; 0x9804c

UnknownScript_0x9804c: ; 0x9804c
	checkbit1 $0766
	iftrue UnknownScript_0x98061
	applymovement $2, MovementData_0x980cc
	moveperson $3, $5, $6
	appear $3
	pause 5
	disappear $2
	end
; 0x98061

UnknownScript_0x98061: ; 0x98061
	end
; 0x98062

UnknownScript_0x98062: ; 0x98062
	faceplayer
	loadfont
	checkbit1 $0021
	iftrue UnknownScript_0x9807c
	checkbit2 $001e
	iftrue UnknownScript_0x98076
	2writetext UnknownText_0x980d1
	closetext
	loadmovesprites
	end
; 0x98076

UnknownScript_0x98076: ; 0x98076
	2writetext UnknownText_0x98131
	closetext
	loadmovesprites
	end
; 0x9807c

UnknownScript_0x9807c: ; 0x9807c
	checkbit1 $0334
	iftrue UnknownScript_0x980a4
	checkbit1 $0000
	iftrue UnknownScript_0x980aa
	checkitem CLEAR_BELL
	iftrue UnknownScript_0x98093
	2writetext UnknownText_0x981a4
	closetext
	loadmovesprites
	end
; 0x98093

UnknownScript_0x98093: ; 0x98093
	2writetext UnknownText_0x98250
	closetext
	loadmovesprites
	dotrigger $1
	setbit1 $0767
	clearbit1 $0766
	setbit1 $0000
	end
; 0x980a4

UnknownScript_0x980a4: ; 0x980a4
	2writetext UnknownText_0x9837e
	closetext
	loadmovesprites
	end
; 0x980aa

UnknownScript_0x980aa: ; 0x980aa
	2writetext UnknownText_0x98391
	closetext
	loadmovesprites
	end
; 0x980b0

UnknownScript_0x980b0: ; 0x980b0
	faceplayer
	loadfont
	checkbit1 $0078
	iftrue UnknownScript_0x980be
	2writetext UnknownText_0x9840b
	closetext
	loadmovesprites
	end
; 0x980be

UnknownScript_0x980be: ; 0x980be
	2writetext UnknownText_0x9846f
	closetext
	loadmovesprites
	end
; 0x980c4

UnknownScript_0x980c4: ; 0x980c4
	jumptextfaceplayer UnknownText_0x984ab
; 0x980c7

MovementData_0x980c7: ; 0x980c7
	fix_facing
	big_step_left
	remove_fixed_facing
	turn_head_down
	step_end
; 0x980cc

MovementData_0x980cc: ; 0x980cc
	fix_facing
	big_step_right
	remove_fixed_facing
	turn_head_down
	step_end
; 0x980d1

UnknownText_0x980d1: ; 0x980d1
	db $0, "TIN TOWER is off", $4f
	db "limits to anyone", $51
	db "without ECRUTEAK", $4f
	db "GYM's BADGE.", $51
	db "Sorry, but you'll", $4f
	db "have to leave.", $57
; 0x98131

UnknownText_0x98131: ; 0x98131
	db $0, "TIN TOWER is off", $4f
	db "limits to anyone", $51
	db "without ECRUTEAK", $4f
	db "GYM's BADGE.", $51
	db "Ah!", $51
	db "ECRUTEAK's GYM", $4f
	db "BADGE! Please, go", $55
	db "right through.", $57
; 0x981a4

UnknownText_0x981a4: ; 0x981a4
	db $0, "A momentous event", $4f
	db "has occurred.", $51
	db "I beg your pardon,", $4f
	db "but I must ask you", $55
	db "to leave.", $51
	db "…What soothes the", $4f
	db "soul…", $51
	db "The WISE TRIO say", $4f
	db "things that are so", $51
	db "very difficult to", $4f
	db "understand…", $57
; 0x98250

UnknownText_0x98250: ; 0x98250
	db $0, "A momentous event", $4f
	db "has occurred.", $51
	db "I beg your pardon,", $4f
	db "but I must ask you", $55
	db "to leave.", $51
	db $56, $56, $56, $51
	db "Ah!", $51
	db "The sound of that", $4f
	db "CLEAR BELL!", $51
	db "It… It's sublime!", $51
	db "I've never heard", $4f
	db "so beautiful a", $55
	db "sound before!", $51
	db "That bell's chime", $4f
	db "is indicative of", $55
	db "the bearer's soul.", $51
	db "You…", $51
	db "You may be able to", $4f
	db "make it through", $55
	db "TIN TOWER.", $51
	db "Please, do go on.", $57
; 0x9837e

UnknownText_0x9837e: ; 0x9837e
	db $0, "Please, do go on.", $57
; 0x98391

UnknownText_0x98391: ; 0x98391
	db $0, "That bell's chime", $4f
	db "is indicative of", $55
	db "the bearer's soul.", $51
	db "You…", $51
	db "You may be able to", $4f
	db "make it through", $55
	db "TIN TOWER.", $51
	db "Please, do go on.", $57
; 0x9840b

UnknownText_0x9840b: ; 0x9840b
	db $0, "The TIN TOWER", $4f
	db "ahead is a nine-", $51
	db "tier tower of", $4f
	db "divine beauty.", $51
	db "It soothes the", $4f
	db "soul of all who", $55
	db "see it.", $57
; 0x9846f

UnknownText_0x9846f: ; 0x9846f
	db $0, "The TIN TOWER", $4f
	db "shook! A #MON", $51
	db "must have returned", $4f
	db "to the top!", $57
; 0x984ab

UnknownText_0x984ab: ; 0x984ab
	db $0, "Two towers…", $4f
	db "Two #MON…", $51
	db "But when one", $4f
	db "burned down, both", $51
	db "#MON flew away,", $4f
	db "never to return.", $57
; 0x98502

EcruteakHouse_MapEventHeader: ; 0x98502
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $11, $4, 3, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $11, $5, 3, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $3, $5, 4, GROUP_ECRUTEAK_HOUSE, MAP_ECRUTEAK_HOUSE
	warp_def $f, $11, 3, GROUP_ECRUTEAK_HOUSE, MAP_ECRUTEAK_HOUSE
	warp_def $3, $11, 3, GROUP_WISE_TRIOS_ROOM, MAP_WISE_TRIOS_ROOM

	; xy triggers
	db 2
	xy_trigger 0, $7, $4, $0, UnknownScript_0x98037, $0, $0
	xy_trigger 0, $7, $5, $0, UnknownScript_0x9804c, $0, $0

	; signposts
	db 0

	; people-events
	db 4
	person_event $3e, 10, 8, $6, $0, 255, 255, $0, 0, UnknownScript_0x98062, $0766
	person_event $3e, 10, 9, $6, $0, 255, 255, $0, 0, UnknownScript_0x98062, $0767
	person_event $3e, 13, 10, $2, $11, 255, 255, $0, 0, UnknownScript_0x980b0, $07b1
	person_event $2f, 15, 7, $2, $11, 255, 255, $0, 0, UnknownScript_0x980c4, $07b1
; 0x98565

WiseTriosRoom_MapScriptHeader: ; 0x98565
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x98572, $0000
	dw UnknownScript_0x98573, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x98574
; 0x98572

UnknownScript_0x98572: ; 0x98572
	end
; 0x98573

UnknownScript_0x98573: ; 0x98573
	end
; 0x98574

UnknownScript_0x98574: ; 0x98574
	checkbit1 $0335
	iftrue UnknownScript_0x98593
	checkbit1 $0334
	iftrue UnknownScript_0x9858c
	checkitem CLEAR_BELL
	iftrue UnknownScript_0x9858c
	clearbit1 $07ab
	setbit1 $07ac
	return
; 0x9858c

UnknownScript_0x9858c: ; 0x9858c
	setbit1 $07ab
	clearbit1 $07ac
	return
; 0x98593

UnknownScript_0x98593: ; 0x98593
	setbit1 $07ab
	setbit1 $07ac
	return
; 0x9859a

UnknownScript_0x9859a: ; 0x9859a
	jumptextfaceplayer UnknownText_0x9862b
; 0x9859d

UnknownScript_0x9859d: ; 0x9859d
	jumptextfaceplayer UnknownText_0x9868b
; 0x985a0

UnknownScript_0x985a0: ; 0x985a0
	jumptextfaceplayer UnknownText_0x987af
; 0x985a3

UnknownScript_0x985a3: ; 0x985a3
	spriteface $4, $1
	spriteface $0, $0
	showemote $0, $4, 20
	follow $0, $4
	applymovement $0, MovementData_0x98622
	stopfollow
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x98712
	closetext
	loadmovesprites
	applymovement $4, MovementData_0x98625
	spriteface $4, $2
	end
; 0x985c6

TrainerSageGaku: ; 0x985c6
	; bit/flag number
	dw $5c9

	; trainer group && trainer id
	db SAGE, GAKU

	; text when seen
	dw SageGakuSeenText

	; text when trainer beaten
	dw SageGakuBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageGakuScript
; 0x985d2

SageGakuScript: ; 0x985d2
	loadfont
	2writetext UnknownText_0x98938
	closetext
	loadmovesprites
	end
; 0x985d9

TrainerSageMasa: ; 0x985d9
	; bit/flag number
	dw $5ca

	; trainer group && trainer id
	db SAGE, MASA

	; text when seen
	dw SageMasaSeenText

	; text when trainer beaten
	dw SageMasaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageMasaScript
; 0x985e5

SageMasaScript: ; 0x985e5
	loadfont
	2writetext UnknownText_0x98a35
	closetext
	loadmovesprites
	end
; 0x985ec

TrainerSageKoji: ; 0x985ec
	; bit/flag number
	dw $5cb

	; trainer group && trainer id
	db SAGE, KOJI

	; text when seen
	dw SageKojiSeenText

	; text when trainer beaten
	dw SageKojiBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageKojiScript
; 0x985f8

SageKojiScript: ; 0x985f8
	checkbit1 $0334
	iftrue UnknownScript_0x9861b
	pause 10
	showemote $0, $7, 20
	loadfont
	2writetext UnknownText_0x98c6c
	keeptextopen
	2writetext UnknownText_0x98cac
	closetext
	loadmovesprites
	applymovement $7, MovementData_0x98628
	spriteface $7, $1
	setbit1 $0334
	dotrigger $1
	end
; 0x9861b

UnknownScript_0x9861b: ; 0x9861b
	loadfont
	2writetext UnknownText_0x98db5
	closetext
	loadmovesprites
	end
; 0x98622

MovementData_0x98622: ; 0x98622
	step_left
	step_left
	step_end
; 0x98625

MovementData_0x98625: ; 0x98625
	step_right
	step_down
	step_end
; 0x98628

MovementData_0x98628: ; 0x98628
	step_right
	step_down
	step_end
; 0x9862b

UnknownText_0x9862b: ; 0x9862b
	db $0, "Astounding…", $51
	db "SUICUNE, ENTEI and", $4f
	db "RAIKOU have arisen", $55
	db "from their sleep…", $51
	db "Is the legend", $4f
	db "coming true?", $57
; 0x9868b

UnknownText_0x9868b: ; 0x9868b
	db $0, "We train at the", $4f
	db "BURNED TOWER, but", $51
	db "we've never heard", $4f
	db "of a hole opening", $51
	db "up there before.", $4f
	db "It must have been", $51
	db "deliberately made", $4f
	db "by someone.", $57
; 0x98712

UnknownText_0x98712: ; 0x98712
	db $0, "TIN TOWER may be", $4f
	db "entered by those", $51
	db "bearing ECRUTEAK's", $4f
	db "GYM BADGE.", $51
	db "However, now that", $4f
	db "SUICUNE, RAIKOU", $51
	db "and ENTEI have", $4f
	db "arisen, I ask you", $51
	db "to refrain from", $4f
	db "entering!", $57
; 0x987af

UnknownText_0x987af: ; 0x987af
	db $0, "We, the WISE TRIO,", $4f
	db "are the protectors", $51
	db "of the legendary", $4f
	db "#MON.", $57
; 0x987ed

SageGakuSeenText: ; 0x987ed
	db $0, "Legend has it that", $4f
	db "upon the emergence", $51
	db "of a trainer who", $4f
	db "has the ability to", $51
	db "touch the souls of", $4f
	db "#MON, a #MON", $51
	db "will come forth to", $4f
	db "put that trainer", $51
	db "to test at the TIN", $4f
	db "TOWER.", $51
	db "The legend has", $4f
	db "come true!", $51
	db "The legendary", $4f
	db "#MON SUICUNE", $55
	db "has arrived!", $51
	db "We, the WISE TRIO,", $4f
	db "shall test your", $51
	db "worthiness to go", $4f
	db "inside!", $57
; 0x98914

SageGakuBeatenText: ; 0x98914
	db $0, "Stronger than we", $4f
	db "thought? Perhaps…", $57
; 0x98938

UnknownText_0x98938: ; 0x98938
	db $0, "Ah, so it is you", $4f
	db "who claim to have", $51
	db "seen SUICUNE,", $4f
	db "ENTEI and RAIKOU", $55
	db "while they slept?", $51
	db "Unbelievable!", $51
	db "Legend has it that", $4f
	db "they can't be seen", $55
	db "while they sleep…", $57
; 0x989d2

SageMasaSeenText: ; 0x989d2
	db $0, "Can you be trusted", $4f
	db "with the truth?", $51
	db "I must ascertain", $4f
	db "your worthiness.", $57
; 0x98a18

SageMasaBeatenText: ; 0x98a18
	db $0, "…I will tell you", $4f
	db "the truth…", $57
; 0x98a35

UnknownText_0x98a35: ; 0x98a35
	db $0, "In the past, there", $4f
	db "were two nine-tier", $55
	db "towers here.", $51
	db "The BRASS TOWER,", $4f
	db "which was said to", $51
	db "awaken #MON,", $4f
	db "and the TIN TOWER,", $51
	db "where #MON were", $4f
	db "said to rest.", $51
	db "The view from the", $4f
	db "tops of the TOWERS", $51
	db "must have been", $4f
	db "magnificent.", $51
	db "At the time, an", $4f
	db "immense, silver-", $51
	db "colored #MON", $4f
	db "was said to make", $51
	db "its roost atop the", $4f
	db "BRASS TOWER.", $51
	db "However…", $51
	db "About 150 years", $4f
	db "ago, a lightning", $51
	db "bolt struck one of", $4f
	db "the TOWERS.", $51
	db "It was engulfed in", $4f
	db "flames that raged", $55
	db "for three days.", $51
	db "A sudden downpour", $4f
	db "finally put out", $55
	db "the blaze.", $51
	db "And that is how", $4f
	db "the BURNED TOWER", $55
	db "came to be.", $57
; 0x98c42

SageKojiSeenText: ; 0x98c42
	db $0, "Let me see your", $4f
	db "power!", $57
; 0x98c5a

SageKojiBeatenText: ; 0x98c5a
	db $0, "Too strong!", $4f
	db "Why?", $57
; 0x98c6c

UnknownText_0x98c6c: ; 0x98c6c
	db $0, "You… Are you the", $4f
	db "trainer who is", $51
	db "awaited by the", $4f
	db "legendary #MON?", $57
; 0x98cac

UnknownText_0x98cac: ; 0x98cac
	db $0, "I see…", $51
	db "We, the WISE TRIO,", $4f
	db "have been given ", $51
	db "the responsibility", $4f
	db "of protecting the", $51
	db "legendary #MON.", $4f
	db "We are to allow", $51
	db "passage only to", $4f
	db "those people who", $51
	db "possess the power", $4f
	db "and soul of truth.", $51
	db "Please, do go on", $4f
	db "and enter the TIN", $55
	db "TOWER ahead.", $51
	db "SUICUNE will put", $4f
	db "you to the test.", $57
; 0x98db5

UnknownText_0x98db5: ; 0x98db5
	db $0, "Please, do go on.", $51
	db "SUICUNE will put", $4f
	db "you to the test.", $57
; 0x98dea

WiseTriosRoom_MapEventHeader: ; 0x98dea
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $4, $7, 4, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $5, $7, 5, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $4, $1, 5, GROUP_ECRUTEAK_HOUSE, MAP_ECRUTEAK_HOUSE

	; xy triggers
	db 1
	xy_trigger 0, $4, $7, $0, UnknownScript_0x985a3, $0, $0

	; signposts
	db 0

	; people-events
	db 6
	person_event $3e, 6, 10, $3, $0, 255, 255, $0, 0, UnknownScript_0x9859a, $07ab
	person_event $3e, 11, 10, $5, $1, 255, 255, $0, 0, UnknownScript_0x9859d, $07ab
	person_event $3e, 9, 11, $8, $0, 255, 255, $0, 0, UnknownScript_0x985a0, $07ab
	person_event $3e, 6, 8, $6, $0, 255, 255, $2, 2, TrainerSageGaku, $07ac
	person_event $3e, 10, 8, $7, $0, 255, 255, $2, 2, TrainerSageMasa, $07ac
	person_event $3e, 8, 10, $8, $0, 255, 255, $2, 2, TrainerSageKoji, $07ac
; 0x98e55

EcruteakPokeCenter1F_MapScriptHeader: ; 0x98e55
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x98e5f, $0000
	dw UnknownScript_0x98e63, $0000

	; callback count
	db 0
; 0x98e5f

UnknownScript_0x98e5f: ; 0x98e5f
	priorityjump UnknownScript_0x98e64
	end
; 0x98e63

UnknownScript_0x98e63: ; 0x98e63
	end
; 0x98e64

UnknownScript_0x98e64: ; 0x98e64
	pause 30
	playsound $0023
	appear $6
	waitbutton
	applymovement $6, MovementData_0x98ec5
	applymovement $0, MovementData_0x98ed4
	spriteface $2, $1
	pause 10
	spriteface $2, $0
	pause 30
	spriteface $2, $1
	pause 10
	spriteface $2, $0
	pause 20
	spriteface $6, $0
	pause 10
	loadfont
	2writetext UnknownText_0x98ed8
	keeptextopen
	2jump UnknownScript_0x98e95
; 0x98e95

UnknownScript_0x98e95: ; 0x98e95
	2writetext UnknownText_0x98f22
	closetext
	loadmovesprites
	spriteface $0, $0
	applymovement $6, MovementData_0x98ece
	playsound $0023
	disappear $6
	clearbit1 $0712
	setbit2 $0053
	dotrigger $1
	waitbutton
	end
; 0x98eb0

UnknownScript_0x98eb0: ; 0x98eb0
	jumpstd $0000
; 0x98eb3

UnknownScript_0x98eb3: ; 0x98eb3
	special $00a0
	iftrue UnknownScript_0x98ebc
	jumptextfaceplayer UnknownText_0x99155
; 0x98ebc

UnknownScript_0x98ebc: ; 0x98ebc
	jumptextfaceplayer UnknownText_0x991aa
; 0x98ebf

UnknownScript_0x98ebf: ; 0x98ebf
	jumptextfaceplayer UnknownText_0x99240
; 0x98ec2

UnknownScript_0x98ec2: ; 0x98ec2
	jumptextfaceplayer UnknownText_0x99286
; 0x98ec5

MovementData_0x98ec5: ; 0x98ec5
	step_up
	step_up
	step_up
	step_up
	step_right
	step_right
	step_right
	turn_head_up
	step_end
; 0x98ece

MovementData_0x98ece: ; 0x98ece
	step_right
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x98ed4

MovementData_0x98ed4: ; 0x98ed4
	step_up
	step_up
	step_up
	step_end
; 0x98ed8

UnknownText_0x98ed8: ; 0x98ed8
	db $0, "Hi, I'm BILL. And", $4f
	db "who are you?", $51
	db "Hmm, ", $52, ", huh?", $4f
	db "You've come at the", $55
	db "right time.", $57
; 0x98f22

UnknownText_0x98f22: ; 0x98f22
	db $0, "I just finished", $4f
	db "adjustments on my", $55
	db "TIME CAPSULE.", $51
	db "You know that", $4f
	db "#MON can be", $55
	db "traded, right?", $51
	db "My TIME CAPSULE", $4f
	db "was developed to", $51
	db "enable trades with", $4f
	db "the past.", $51
	db "But you can't send", $4f
	db "anything that", $51
	db "didn't exist in", $4f
	db "the past.", $51
	db "If you did, the PC", $4f
	db "in the past would", $55
	db "have a breakdown.", $51
	db "So you have to", $4f
	db "remove anything", $51
	db "that wasn't around", $4f
	db "in the past.", $51
	db "Put simply, no", $4f
	db "sending new moves", $51
	db "or new #MON in", $4f
	db "the TIME CAPSULE.", $51
	db "Don't you worry.", $4f
	db "I'm done with the", $55
	db "adjustments.", $51
	db "Tomorrow, TIME", $4f
	db "CAPSULES will be", $51
	db "running at all", $4f
	db "#MON CENTERS.", $51
	db "I have to hurry on", $4f
	db "back to GOLDENROD", $55
	db "and see my folks.", $51
	db "Buh-bye!", $57
; 0x99155

UnknownText_0x99155: ; 0x99155
	db $0, "The way the KIMONO", $4f
	db "GIRLS dance is", $51
	db "marvelous. Just", $4f
	db "like the way they", $55
	db "use their #MON.", $57
; 0x991aa

UnknownText_0x991aa: ; 0x991aa
	db $0, "You must be hoping", $4f
	db "to battle more", $51
	db "people, right?", $4f
	db "There's apparently", $51
	db "some place where", $4f
	db "trainers gather.", $51
	db "Where, you ask?", $51
	db "It's a little past", $4f
	db "OLIVINE CITY.", $57
; 0x99240

UnknownText_0x99240: ; 0x99240
	db $0, "MORTY, the GYM", $4f
	db "LEADER, is soooo", $55
	db "cool.", $51
	db "His #MON are", $4f
	db "really tough too.", $57
; 0x99286

UnknownText_0x99286: ; 0x99286
	db $0, "LAKE OF RAGE…", $51
	db "The appearance of", $4f
	db "a GYARADOS swarm…", $51
	db "I smell a conspir-", $4f
	db "acy. I know it!", $57
; 0x992dc

EcruteakPokeCenter1F_MapEventHeader: ; 0x992dc
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 6, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $7, $4, 6, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 5
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x98eb0, $ffff
	person_event $2d, 10, 11, $a, $0, 255, 255, $0, 0, UnknownScript_0x98eb3, $ffff
	person_event $24, 8, 5, $3, $0, 255, 255, $0, 0, UnknownScript_0x98ebf, $ffff
	person_event $48, 5, 11, $6, $0, 255, 255, $a0, 0, UnknownScript_0x98ec2, $ffff
	person_event $8, 11, 4, $9, $0, 255, 255, $0, 0, ObjectEvent, $0713
; 0x99332

EcruteakLugiaSpeechHouse_MapScriptHeader: ; 0x99332
	; trigger count
	db 0

	; callback count
	db 0
; 0x99334

UnknownScript_0x99334: ; 0x99334
	jumptextfaceplayer UnknownText_0x9933d
; 0x99337

UnknownScript_0x99337: ; 0x99337
	jumptextfaceplayer UnknownText_0x993ec
; 0x9933a

MapEcruteakLugiaSpeechHouseSignpost0Script: ; 0x9933a
	jumpstd $000c
; 0x9933d

UnknownText_0x9933d: ; 0x9933d
	db $0, "This happened when", $4f
	db "I was young.", $51
	db "The sky suddenly", $4f
	db "turned black. A", $51
	db "giant flying #-", $4f
	db "MON was blocking", $55
	db "out the sun.", $51
	db "I wonder what that", $4f
	db "#MON was? ", $51
	db "It was like a bird", $4f
	db "and a dragon.", $57
; 0x993ec

UnknownText_0x993ec: ; 0x993ec
	db $0, "Is there really a", $4f
	db "#MON that big?", $51
	db "If it exists, it", $4f
	db "must be powerful.", $57
; 0x99431

EcruteakLugiaSpeechHouse_MapEventHeader: ; 0x99431
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $3, 7, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $7, $4, 7, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 1, 2, $0, MapEcruteakLugiaSpeechHouseSignpost0Script

	; people-events
	db 2
	person_event $2f, 7, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x99334, $ffff
	person_event $27, 8, 9, $8, $0, 255, 255, $0, 0, UnknownScript_0x99337, $ffff
; 0x99460

DanceTheatre_MapScriptHeader: ; 0x99460
	; trigger count
	db 0

	; callback count
	db 0
; 0x99462

TrainerKimono_girlNaoko2: ; 0x99462
	; bit/flag number
	dw $4df

	; trainer group && trainer id
	db KIMONO_GIRL, NAOKO2

	; text when seen
	dw Kimono_girlNaoko2SeenText

	; text when trainer beaten
	dw Kimono_girlNaoko2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Kimono_girlNaoko2Script
; 0x9946e

Kimono_girlNaoko2Script: ; 0x9946e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x99579
	closetext
	loadmovesprites
	end
; 0x99476

TrainerKimono_girlSayo: ; 0x99476
	; bit/flag number
	dw $4e0

	; trainer group && trainer id
	db KIMONO_GIRL, SAYO

	; text when seen
	dw Kimono_girlSayoSeenText

	; text when trainer beaten
	dw Kimono_girlSayoBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Kimono_girlSayoScript
; 0x99482

Kimono_girlSayoScript: ; 0x99482
	talkaftercancel
	loadfont
	2writetext UnknownText_0x9960b
	closetext
	loadmovesprites
	end
; 0x9948a

TrainerKimono_girlZuki: ; 0x9948a
	; bit/flag number
	dw $4e1

	; trainer group && trainer id
	db KIMONO_GIRL, ZUKI

	; text when seen
	dw Kimono_girlZukiSeenText

	; text when trainer beaten
	dw Kimono_girlZukiBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Kimono_girlZukiScript
; 0x99496

Kimono_girlZukiScript: ; 0x99496
	talkaftercancel
	loadfont
	2writetext UnknownText_0x99688
	closetext
	loadmovesprites
	end
; 0x9949e

TrainerKimono_girlKuni: ; 0x9949e
	; bit/flag number
	dw $4e2

	; trainer group && trainer id
	db KIMONO_GIRL, KUNI

	; text when seen
	dw Kimono_girlKuniSeenText

	; text when trainer beaten
	dw Kimono_girlKuniBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Kimono_girlKuniScript
; 0x994aa

Kimono_girlKuniScript: ; 0x994aa
	talkaftercancel
	loadfont
	2writetext UnknownText_0x99714
	closetext
	loadmovesprites
	end
; 0x994b2

TrainerKimono_girlMiki: ; 0x994b2
	; bit/flag number
	dw $4e3

	; trainer group && trainer id
	db KIMONO_GIRL, MIKI

	; text when seen
	dw Kimono_girlMikiSeenText

	; text when trainer beaten
	dw Kimono_girlMikiBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Kimono_girlMikiScript
; 0x994be

Kimono_girlMikiScript: ; 0x994be
	talkaftercancel
	loadfont
	2writetext UnknownText_0x997a8
	closetext
	loadmovesprites
	end
; 0x994c6

UnknownScript_0x994c6: ; 0x994c6
	faceplayer
	loadfont
	2writetext UnknownText_0x9980a
	keeptextopen
	checkbit1 $0012
	iftrue UnknownScript_0x99515
	checkbit1 $04df
	iffalse UnknownScript_0x994f3
	checkbit1 $04e0
	iffalse UnknownScript_0x994f3
	checkbit1 $04e1
	iffalse UnknownScript_0x994f3
	checkbit1 $04e2
	iffalse UnknownScript_0x994f3
	checkbit1 $04e3
	iffalse UnknownScript_0x994f3
	2jump UnknownScript_0x99505
; 0x994f3

UnknownScript_0x994f3: ; 0x994f3
	checkbit2 $0063
	iftrue UnknownScript_0x994ff
	2writetext UnknownText_0x99891
	closetext
	loadmovesprites
	end
; 0x994ff

UnknownScript_0x994ff: ; 0x994ff
	2writetext UnknownText_0x998d4
	closetext
	loadmovesprites
	end
; 0x99505

UnknownScript_0x99505: ; 0x99505
	2writetext UnknownText_0x9991a
	keeptextopen
	verbosegiveitem HM_03, 1
	setbit1 $0012
	2writetext UnknownText_0x9999b
	closetext
	loadmovesprites
	end
; 0x99515

UnknownScript_0x99515: ; 0x99515
	2writetext UnknownText_0x999d5
	closetext
	loadmovesprites
	end
; 0x9951b

UnknownScript_0x9951b: ; 0x9951b
	loadfont
	2writetext UnknownText_0x99a0a
	cry RHYDON
	closetext
	loadmovesprites
	end
; 0x99525

UnknownScript_0x99525: ; 0x99525
	jumptextfaceplayer UnknownText_0x99a24
; 0x99528

UnknownScript_0x99528: ; 0x99528
	jumptextfaceplayer UnknownText_0x99aaa
; 0x9952b

MapDanceTheatreSignpost1Script: ; 0x9952b
	jumptext UnknownText_0x99b79
; 0x9952e

Kimono_girlNaoko2SeenText: ; 0x9952e
	db $0, "You have lovely", $4f
	db "#MON. May I see", $55
	db "them in battle?", $57
; 0x9955f

Kimono_girlNaoko2BeatenText: ; 0x9955f
	db $0, "Oh, you are very", $4f
	db "strong.", $57
; 0x99579

UnknownText_0x99579: ; 0x99579
	db $0, "I enjoyed that", $4f
	db "bout. I would like", $55
	db "to see you again.", $57
; 0x995ae

Kimono_girlSayoSeenText: ; 0x995ae
	db $0, "I always dance", $4f
	db "with my #MON.", $51
	db "Of course, I also", $4f
	db "train them.", $57
; 0x995ea

Kimono_girlSayoBeatenText: ; 0x995ea
	db $0, "Oh, so close!", $4f
	db "I almost had you.", $57
; 0x9960b

UnknownText_0x9960b: ; 0x9960b
	db $0, "Rhythm is impor-", $4f
	db "tant for both", $51
	db "dancing and #-", $4f
	db "MON.", $57
; 0x9963f

Kimono_girlZukiSeenText: ; 0x9963f
	db $0, "Isn't my barrette", $4f
	db "pretty?", $51
	db "Oh. A #MON", $4f
	db "battle?", $57
; 0x9966c

Kimono_girlZukiBeatenText: ; 0x9966c
	db $0, "I don't have any", $4f
	db "#MON left…", $57
; 0x99688

UnknownText_0x99688: ; 0x99688
	db $0, "I put a different", $4f
	db "flower in my bar-", $55
	db "rette every month.", $57
; 0x996c0

Kimono_girlKuniSeenText: ; 0x996c0
	db $0, "Oh, you're a cute", $4f
	db "trainer. Would you", $55
	db "like to battle?", $57
; 0x996f5

Kimono_girlKuniBeatenText: ; 0x996f5
	db $0, "You're stronger", $4f
	db "than you look.", $57
; 0x99714

UnknownText_0x99714: ; 0x99714
	db $0, "I trained a lot,", $4f
	db "so I thought I was", $51
	db "a capable trainer.", $4f
	db "I guess I'm not.", $57
; 0x9975c

Kimono_girlMikiSeenText: ; 0x9975c
	db $0, "Do you like my", $4f
	db "dancing? I'm good", $55
	db "at #MON too.", $57
; 0x9978a

Kimono_girlMikiBeatenText: ; 0x9978a
	db $0, "Ooh, you're good", $4f
	db "at #MON too.", $57
; 0x997a8

UnknownText_0x997a8: ; 0x997a8
	db $0, "I can keep dancing", $4f
	db "because there are", $51
	db "people who enjoy", $4f
	db "what I do.", $51
	db "My #MON keep my", $4f
	db "spirits up too.", $57
; 0x9980a

UnknownText_0x9980a: ; 0x9980a
	db $0, "Not only are the", $4f
	db "KIMONO GIRLS great", $51
	db "dancers, they're", $4f
	db "also skilled at", $55
	db "#MON.", $51
	db "I always challenge", $4f
	db "them, but I've", $51
	db "never even left a", $4f
	db "scratch…", $57
; 0x99891

UnknownText_0x99891: ; 0x99891
	db $0, "Lad! If you can", $4f
	db "defeat all the", $51
	db "KIMONO GIRLS, I'll", $4f
	db "give you a gift.", $57
; 0x998d4

UnknownText_0x998d4: ; 0x998d4
	db $0, "Lassie, if you can", $4f
	db "defeat all the", $51
	db "KIMONO GIRLS, I'll", $4f
	db "give you a gift.", $57
; 0x9991a

UnknownText_0x9991a: ; 0x9991a
	db $0, "The way you bat-", $4f
	db "tled, it was like", $55
	db "watching a dance.", $51
	db "It was a rare", $4f
	db "treat to see!", $51
	db "I want you to have", $4f
	db "this. Don't worry", $55
	db "--take it!", $57
; 0x9999b

UnknownText_0x9999b: ; 0x9999b
	db $0, "That's SURF.", $51
	db "It's a move that", $4f
	db "lets #MON swim", $55
	db "across water.", $57
; 0x999d5

UnknownText_0x999d5: ; 0x999d5
	db $0, "I wish my #MON", $4f
	db "were as elegant as", $55
	db "the KIMONO GIRLS…", $57
; 0x99a0a

UnknownText_0x99a0a: ; 0x99a0a
	db $0, "RHYDON: Gugooh", $4f
	db "gugogooh!", $57
; 0x99a24

UnknownText_0x99a24: ; 0x99a24
	db $0, "That man's always", $4f
	db "with his RHYDON.", $51
	db "Says he wants a", $4f
	db "#MON that can", $55
	db "SURF and dance.", $51
	db "Is he trying to", $4f
	db "make a synchro-", $55
	db "nized swimming", $55
	db "#MON?", $57
; 0x99aaa

UnknownText_0x99aaa: ; 0x99aaa
	db $0, "The KIMONO GIRLS", $4f
	db "are so beautiful…", $51
	db "But they have to", $4f
	db "go through rigor-", $55
	db "ous training.", $51
	db "And they have to", $4f
	db "learn to follow", $51
	db "customs before ap-", $4f
	db "pearing in public.", $51
	db "But if you love", $4f
	db "something, any-", $55
	db "thing is possible.", $57
; 0x99b79

UnknownText_0x99b79: ; 0x99b79
	db $0, "It's a fancy panel", $4f
	db "that's decorated", $55
	db "with flowers.", $57
; 0x99baa

DanceTheatre_MapEventHeader: ; 0x99baa
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $d, $5, 8, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $d, $6, 8, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 6, 5, $1, MapDanceTheatreSignpost1Script
	signpost 6, 6, $1, MapDanceTheatreSignpost1Script

	; people-events
	db 9
	person_event $3d, 6, 4, $1e, $0, 255, 255, $a2, 0, TrainerKimono_girlNaoko2, $ffff
	person_event $3d, 5, 6, $a, $0, 255, 255, $92, 0, TrainerKimono_girlSayo, $ffff
	person_event $3d, 6, 10, $3, $0, 255, 255, $82, 0, TrainerKimono_girlZuki, $ffff
	person_event $3d, 5, 13, $a, $0, 255, 255, $92, 0, TrainerKimono_girlKuni, $ffff
	person_event $3d, 6, 15, $1f, $0, 255, 255, $a2, 0, TrainerKimono_girlMiki, $ffff
	person_event $40, 14, 11, $7, $0, 255, 255, $0, 0, UnknownScript_0x994c6, $ffff
	person_event $9d, 12, 10, $16, $0, 255, 255, $90, 0, UnknownScript_0x9951b, $ffff
	person_event $23, 14, 14, $8, $0, 255, 255, $80, 0, UnknownScript_0x99525, $ffff
	person_event $30, 10, 7, $7, $0, 255, 255, $0, 0, UnknownScript_0x99528, $ffff
; 0x99c39

EcruteakMart_MapScriptHeader: ; 0x99c39
	; trigger count
	db 0

	; callback count
	db 0
; 0x99c3b

UnknownScript_0x99c3b: ; 0x99c3b
	loadfont
	pokemart $0, $000e
	loadmovesprites
	end
; 0x99c42

UnknownScript_0x99c42: ; 0x99c42
	jumptextfaceplayer UnknownText_0x99c48
; 0x99c45

UnknownScript_0x99c45: ; 0x99c45
	jumptextfaceplayer UnknownText_0x99cd5
; 0x99c48

UnknownText_0x99c48: ; 0x99c48
	db $0, "My EEVEE evolved", $4f
	db "into an ESPEON.", $51
	db "But my friend's", $4f
	db "EEVEE turned into", $55
	db "an UMBREON.", $51
	db "I wonder why? We", $4f
	db "both were raising", $51
	db "our EEVEE in the", $4f
	db "same way…", $57
; 0x99cd5

UnknownText_0x99cd5: ; 0x99cd5
	db $0, "If you use REVIVE,", $4f
	db "a #MON that's", $51
	db "fainted will wake", $4f
	db "right up.", $57
; 0x99d12

EcruteakMart_MapEventHeader: ; 0x99d12
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 9, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $7, $3, 9, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x99c3b, $ffff
	person_event $2b, 6, 9, $5, $1, 255, 255, $a0, 0, UnknownScript_0x99c42, $ffff
	person_event $30, 10, 10, $7, $0, 255, 255, $0, 0, UnknownScript_0x99c45, $ffff
; 0x99d49

EcruteakGym_MapScriptHeader: ; 0x99d49
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x99d53, $0000
	dw UnknownScript_0x99d57, $0000

	; callback count
	db 0
; 0x99d53

UnknownScript_0x99d53: ; 0x99d53
	priorityjump UnknownScript_0x99dc6
	end
; 0x99d57

UnknownScript_0x99d57: ; 0x99d57
	end
; 0x99d58

UnknownScript_0x99d58: ; 0x99d58
	faceplayer
	loadfont
	checkbit1 $04c0
	iftrue UnknownScript_0x99d8c
	2writetext UnknownText_0x99e65
	closetext
	loadmovesprites
	winlosstext UnknownText_0x9a00a, $0000
	loadtrainer MORTY, 1
	startbattle
	returnafterbattle
	setbit1 $04c0
	loadfont
	2writetext UnknownText_0x9a043
	playsound $009c
	waitbutton
	setbit2 $001e
	checkcode $7
	2call UnknownScript_0x99db7
	domaptrigger GROUP_ECRUTEAK_HOUSE, MAP_ECRUTEAK_HOUSE, $1
	setbit1 $0766
	setbit1 $0767
UnknownScript_0x99d8c: ; 0x99d8c	
	checkbit1 $000c
	iftrue UnknownScript_0x99db1
	setbit1 $0415
	setbit1 $0416
	setbit1 $058b
	setbit1 $058c
	2writetext UnknownText_0x9a059
	keeptextopen
	verbosegiveitem TM_30, 1
	iffalse UnknownScript_0x99db5
	setbit1 $000c
	2writetext UnknownText_0x9a0ec
	closetext
	loadmovesprites
	end
; 0x99db1

UnknownScript_0x99db1: ; 0x99db1
	2writetext UnknownText_0x9a145
	closetext
UnknownScript_0x99db5: ; 0x99db5
	loadmovesprites
	end
; 0x99db7

UnknownScript_0x99db7: ; 0x99db7
	if_equal $7, UnknownScript_0x99dc3
	if_equal $6, UnknownScript_0x99dc0
	end
; 0x99dc0

UnknownScript_0x99dc0: ; 0x99dc0
	jumpstd $0012
; 0x99dc3

UnknownScript_0x99dc3: ; 0x99dc3
	jumpstd $0013
; 0x99dc6

UnknownScript_0x99dc6: ; 0x99dc6
	applymovement $0, MovementData_0x99e5d
	applymovement $8, MovementData_0x99e63
	loadfont
	2writetext UnknownText_0x9a49c
	closetext
	loadmovesprites
	follow $0, $8
	applymovement $0, MovementData_0x99e5f
	stopfollow
	special $002e
	playsound $001f
	waitbutton
	warp GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY, $6, $1b
	end
; 0x99de9

TrainerSageJeffrey: ; 0x99de9
	; bit/flag number
	dw $415

	; trainer group && trainer id
	db SAGE, JEFFREY

	; text when seen
	dw SageJeffreySeenText

	; text when trainer beaten
	dw SageJeffreyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageJeffreyScript
; 0x99df5

SageJeffreyScript: ; 0x99df5
	talkaftercancel
	loadfont
	2writetext UnknownText_0x9a263
	closetext
	loadmovesprites
	end
; 0x99dfd

TrainerSagePing: ; 0x99dfd
	; bit/flag number
	dw $416

	; trainer group && trainer id
	db SAGE, PING

	; text when seen
	dw SagePingSeenText

	; text when trainer beaten
	dw SagePingBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SagePingScript
; 0x99e09

SagePingScript: ; 0x99e09
	talkaftercancel
	loadfont
	2writetext UnknownText_0x9a2b7
	closetext
	loadmovesprites
	end
; 0x99e11

TrainerMediumMartha: ; 0x99e11
	; bit/flag number
	dw $58b

	; trainer group && trainer id
	db MEDIUM, MARTHA

	; text when seen
	dw MediumMarthaSeenText

	; text when trainer beaten
	dw MediumMarthaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw MediumMarthaScript
; 0x99e1d

MediumMarthaScript: ; 0x99e1d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x9a318
	closetext
	loadmovesprites
	end
; 0x99e25

TrainerMediumGrace: ; 0x99e25
	; bit/flag number
	dw $58c

	; trainer group && trainer id
	db MEDIUM, GRACE

	; text when seen
	dw MediumGraceSeenText

	; text when trainer beaten
	dw MediumGraceBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw MediumGraceScript
; 0x99e31

MediumGraceScript: ; 0x99e31
	talkaftercancel
	loadfont
	2writetext UnknownText_0x9a38a
	closetext
	loadmovesprites
	end
; 0x99e39

EcruteakGymGuyScript: ; 0x99e39
	faceplayer
	loadfont
	checkbit1 $04c0
	iftrue .EcruteakGymGuyWinScript
	2writetext EcruteakGymGuyText
	closetext
	loadmovesprites
	end

.EcruteakGymGuyWinScript
	2writetext EcruteakGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x99e4d

MapEcruteakGymSignpost1Script: ; 0x99e4d
	checkbit2 $001e
	iftrue UnknownScript_0x99e56
	jumpstd $002d
; 0x99e56

UnknownScript_0x99e56: ; 0x99e56
	trainertotext MORTY, 1, $1
	jumpstd $002e
; 0x99e5d

MovementData_0x99e5d: ; 0x99e5d
	step_up
	step_end
; 0x99e5f

MovementData_0x99e5f: ; 0x99e5f
	fix_facing
	slow_step_down
	remove_fixed_facing
	step_end
; 0x99e63

MovementData_0x99e63: ; 0x99e63
	slow_step_down
	step_end
; 0x99e65

UnknownText_0x99e65: ; 0x99e65
	db $0, "Good of you to", $4f
	db "have come.", $51
	db "Here in ECRUTEAK,", $4f
	db "#MON have been", $55
	db "revered.", $51
	db "It's said that a", $4f
	db "rainbow-colored", $51
	db "#MON will come", $4f
	db "down to appear", $51
	db "before a truly", $4f
	db "powerful trainer.", $51
	db "I believed that", $4f
	db "tale, so I have", $51
	db "secretly trained", $4f
	db "here all my life.", $51
	db "As a result, I can", $4f
	db "now see what", $55
	db "others cannot.", $51
	db "Just a bit more…", $51
	db "With a little", $4f
	db "more, I could see", $51
	db "a future in which", $4f
	db "I meet the #MON", $55
	db "of rainbow colors.", $51
	db "You're going to", $4f
	db "help me reach that", $55
	db "level!", $57
; 0x9a00a

UnknownText_0x9a00a: ; 0x9a00a
	db $0, "I'm not good", $4f
	db "enough yet…", $51
	db "All right. This", $4f
	db "BADGE is yours.", $57
; 0x9a043

UnknownText_0x9a043: ; 0x9a043
	db $0, $52, " received", $4f
	db "FOGBADGE.", $57
; 0x9a059

UnknownText_0x9a059: ; 0x9a059
	db $0, "By having FOG-", $4f
	db "BADGE, #MON up", $51
	db "to L50 will obey", $4f
	db "you.", $51
	db "Also, #MON that", $4f
	db "know SURF will be", $51
	db "able to use that", $4f
	db "move anytime.", $51
	db "I want you to have", $4f
	db "this too.", $57
; 0x9a0ec

UnknownText_0x9a0ec: ; 0x9a0ec
	db $0, "It's SHADOW BALL.", $4f
	db "It causes damage", $51
	db "and may reduce", $4f
	db "SPCL.DEF.", $51
	db "Use it if it", $4f
	db "appeals to you.", $57
; 0x9a145

UnknownText_0x9a145: ; 0x9a145
	db $0, "I see…", $51
	db "Your journey has", $4f
	db "taken you to far-", $55
	db "away places.", $51
	db "And you have wit-", $4f
	db "nessed much more", $55
	db "than I.", $51
	db "I envy you for", $4f
	db "that…", $57
; 0x9a1bd

SageJeffreySeenText: ; 0x9a1bd
	db $0, "I spent the spring", $4f
	db "with my #MON.", $51
	db "Then summer, fall", $4f
	db "and winter…", $51
	db "Then spring came", $4f
	db "again. We have", $51
	db "lived together", $4f
	db "for a long time.", $57
; 0x9a23d

SageJeffreyBeatenText: ; 0x9a23d
	db $0, "Wins and losses, I", $4f
	db "experienced both.", $57
; 0x9a263

UnknownText_0x9a263: ; 0x9a263
	db $0, "Where did #MON", $4f
	db "come from?", $57
; 0x9a27e

SagePingSeenText: ; 0x9a27e
	db $0, "Can you inflict", $4f
	db "any damage on our", $55
	db "#MON?", $57
; 0x9a2a7

SagePingBeatenText: ; 0x9a2a7
	db $0, "Ah! Well done!", $57
; 0x9a2b7

UnknownText_0x9a2b7: ; 0x9a2b7
	db $0, "We use only ghost-", $4f
	db "type #MON.", $51
	db "No normal-type", $4f
	db "attack can harm", $55
	db "them!", $57
; 0x9a2fb

MediumMarthaSeenText: ; 0x9a2fb
	db $0, "I shall win!", $57
; 0x9a309

MediumMarthaBeatenText: ; 0x9a309
	db $0, "I, I, I lost!", $57
; 0x9a318

UnknownText_0x9a318: ; 0x9a318
	db $0, "The one who wants", $4f
	db "to win most--will!", $57
; 0x9a33e

MediumGraceSeenText: ; 0x9a33e
	db $0, "Stumped by our in-", $4f
	db "visible floor?", $51
	db "Defeat me if you", $4f
	db "want a hint!", $57
; 0x9a37f

MediumGraceBeatenText: ; 0x9a37f
	db $0, "Wha-what?", $57
; 0x9a38a

UnknownText_0x9a38a: ; 0x9a38a
	db $0, "Fine. I shall tell", $4f
	db "you the secret of", $51
	db "the invisible", $4f
	db "floor.", $51
	db "The path is right", $4f
	db "before our eyes!", $57
; 0x9a3e8

EcruteakGymGuyText: ; 0x9a3e8
	db $0, "The trainers here", $4f
	db "have secret mo-", $55
	db "tives.", $51
	db "If you win, they", $4f
	db "may tell you some", $51
	db "deep secrets about", $4f
	db "ECRUTEAK.", $57
; 0x9a452

EcruteakGymGuyWinText: ; 0x9a452
	db $0, "Whew, ", $52, ".", $4f
	db "You did great!", $51
	db "I was cowering in", $4f
	db "the corner out of", $55
	db "pure terror!", $57
; 0x9a49c

UnknownText_0x9a49c: ; 0x9a49c
	db $0, "MORTY, the GYM", $4f
	db "LEADER, is absent.", $51
	db "Sorry, but you'll", $4f
	db "have to leave.", $51
	db "Hohohoho.", $57
; 0x9a4e9

EcruteakGym_MapEventHeader: ; 0x9a4e9
	; filler
	db 0, 0

	; warps
	db 33
	warp_def $11, $4, 10, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $11, $5, 10, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $e, $4, 4, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $4, $2, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $4, $3, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $4, $4, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $5, $4, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $7, $6, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $4, $7, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $6, $2, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $6, $3, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $6, $4, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $6, $5, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $6, $7, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $7, $7, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $8, $4, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $8, $5, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $8, $6, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $8, $7, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $8, $2, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $9, $2, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $a, $2, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $b, $2, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $a, $4, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $a, $5, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $c, $2, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $c, $3, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $c, $4, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $c, $5, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $a, $7, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $b, $7, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $c, $7, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $d, $7, 3, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 15, 3, $0, MapEcruteakGymSignpost1Script
	signpost 15, 6, $0, MapEcruteakGymSignpost1Script

	; people-events
	db 7
	person_event $15, 5, 9, $6, $0, 255, 255, $b0, 0, UnknownScript_0x99d58, $ffff
	person_event $3e, 11, 6, $9, $0, 255, 255, $92, 1, TrainerSageJeffrey, $ffff
	person_event $3e, 17, 7, $9, $0, 255, 255, $92, 3, TrainerSagePing, $ffff
	person_event $30, 9, 11, $8, $0, 255, 255, $b2, 1, TrainerMediumMartha, $ffff
	person_event $30, 13, 11, $8, $0, 255, 255, $b2, 1, TrainerMediumGrace, $ffff
	person_event $48, 19, 11, $6, $0, 255, 255, $80, 0, EcruteakGymGuyScript, $ffff
	person_event $2f, 18, 8, $6, $0, 255, 255, $a0, 0, ObjectEvent, $07a8
; 0x9a5f9

EcruteakItemfinderHouse_MapScriptHeader: ; 0x9a5f9
	; trigger count
	db 0

	; callback count
	db 0
; 0x9a5fb

UnknownScript_0x9a5fb: ; 0x9a5fb
	faceplayer
	loadfont
	checkbit1 $005a
	iftrue UnknownScript_0x9a614
	2writetext UnknownText_0x9a63c
	yesorno
	iffalse UnknownScript_0x9a61a
	2writetext UnknownText_0x9a6b5
	keeptextopen
	verbosegiveitem ITEMFINDER, 1
	setbit1 $005a
UnknownScript_0x9a614: ; 0x9a614
	2writetext UnknownText_0x9a70e
	closetext
	loadmovesprites
	end
; 0x9a61a

UnknownScript_0x9a61a: ; 0x9a61a
	2writetext UnknownText_0x9a805
	closetext
	loadmovesprites
	end
; 0x9a620

UnknownScript_0x9a620: ; 0x9a620
	loadfont
	2writetext UnknownText_0x9a826
	yesorno
	iftrue UnknownScript_0x9a62a
	loadmovesprites
	end
; 0x9a62a

UnknownScript_0x9a62a: ; 0x9a62a
	2writetext UnknownText_0x9a84c
	yesorno
	iftrue UnknownScript_0x9a633
	loadmovesprites
	end
; 0x9a633

UnknownScript_0x9a633: ; 0x9a633
	2writetext UnknownText_0x9a902
	closetext
	loadmovesprites
	end
; 0x9a639

MapEcruteakItemfinderHouseSignpost0Script: ; 0x9a639
	jumpstd $000c
; 0x9a63c

UnknownText_0x9a63c: ; 0x9a63c
	db $0, "Ah. You're on an", $4f
	db "adventure with", $55
	db "your #MON?", $51
	db "Well, what's an", $4f
	db "adventure without", $55
	db "treasure hunting?", $51
	db "Am I right, or am", $4f
	db "I right?", $57
; 0x9a6b5

UnknownText_0x9a6b5: ; 0x9a6b5
	db $0, "Good! You under-", $4f
	db "stand the true", $51
	db "spirit of adven-", $4f
	db "ture.", $51
	db "I like that! Take", $4f
	db "this with you.", $57
; 0x9a70e

UnknownText_0x9a70e: ; 0x9a70e
	db $0, "There are many", $4f
	db "items lying about", $51
	db "that aren't ob-", $4f
	db "vious.", $51
	db "Use ITEMFINDER to", $4f
	db "check if there is", $51
	db "an item on the", $4f
	db "ground near you.", $51
	db "It doesn't show", $4f
	db "the exact spot,", $51
	db "so you'll have to", $4f
	db "look yourself.", $51
	db "Oh yeah--I heard", $4f
	db "there are items", $51
	db "in ECRUTEAK's", $4f
	db "BURNED TOWER.", $57
; 0x9a805

UnknownText_0x9a805: ; 0x9a805
	db $0, "Oh… To each his", $4f
	db "own, I suppose…", $57
; 0x9a826

UnknownText_0x9a826: ; 0x9a826
	db $0, "HISTORY OF", $4f
	db "ECRUTEAK", $51
	db "Want to read it?", $57
; 0x9a84c

UnknownText_0x9a84c: ; 0x9a84c
	db $0, "In ECRUTEAK, there", $4f
	db "were two towers.", $51
	db "Each tower was the", $4f
	db "roost of powerful", $55
	db "flying #MON.", $51
	db "But one of the", $4f
	db "towers burned to", $55
	db "the ground.", $51
	db "The two #MON", $4f
	db "haven't been seen", $55
	db "since…", $51
	db "Keep reading?", $57
; 0x9a902

UnknownText_0x9a902: ; 0x9a902
	db $0, "ECRUTEAK was also", $4f
	db "home to three", $51
	db "#MON that raced", $4f
	db "around the town.", $51
	db "They were said to", $4f
	db "have been born of", $51
	db "water, lightning", $4f
	db "and fire.", $51
	db "But they could not", $4f
	db "contain their", $55
	db "excessive power.", $51
	db "So they say the", $4f
	db "three ran like the", $51
	db "wind off into the", $4f
	db "grassland.", $57
; 0x9a9f5

EcruteakItemfinderHouse_MapEventHeader: ; 0x9a9f5
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $3, 11, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $7, $4, 11, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 1, 2, $0, MapEcruteakItemfinderHouseSignpost0Script

	; people-events
	db 2
	person_event $23, 7, 6, $6, $0, 255, 255, $80, 0, UnknownScript_0x9a5fb, $ffff
	person_event $55, 7, 7, $1, $0, 255, 255, $0, 0, UnknownScript_0x9a620, $ffff
; 0x9aa24

ViridianGym_MapScriptHeader: ; 0x9aa24
	; trigger count
	db 0

	; callback count
	db 0
; 0x9aa26

UnknownScript_0x9aa26: ; 0x9aa26
	faceplayer
	loadfont
	checkbit2 $002a
	iftrue UnknownScript_0x9aa51
	2writetext UnknownText_0x9aa7b
	closetext
	loadmovesprites
	winlosstext UnknownText_0x9abae, $0000
	loadtrainer BLUE, 1
	startbattle
	returnafterbattle
	setbit1 $04cc
	loadfont
	2writetext UnknownText_0x9ac0f
	playsound $009c
	waitbutton
	setbit2 $002a
	2writetext UnknownText_0x9ac27
	closetext
	loadmovesprites
	end
; 0x9aa51

UnknownScript_0x9aa51: ; 0x9aa51
	2writetext UnknownText_0x9acab
	closetext
	loadmovesprites
	end
; 0x9aa57

ViridianGymGuyScript: ; 0x9aa57
	faceplayer
	loadfont
	checkbit1 $04cc
	iftrue .ViridianGymGuyWinScript
	2writetext ViridianGymGuyText
	closetext
	loadmovesprites
	end

.ViridianGymGuyWinScript
	2writetext ViridianGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x9aa6b

MapViridianGymSignpost1Script: ; 0x9aa6b
	checkbit2 $002a
	iftrue UnknownScript_0x9aa74
	jumpstd $002d
; 0x9aa74

UnknownScript_0x9aa74: ; 0x9aa74
	trainertotext BLUE, 1, $1
	jumpstd $002e
; 0x9aa7b

UnknownText_0x9aa7b: ; 0x9aa7b
	db $0, "BLUE: Yo! Finally", $4f
	db "got here, huh?", $51
	db "I wasn't in the", $4f
	db "mood at CINNABAR,", $51
	db "but now I'm ready", $4f
	db "to battle you.", $51
	db "…", $51
	db "You're telling me", $4f
	db "you conquered all", $55
	db "the GYMS in JOHTO?", $51
	db "Heh! JOHTO's GYMS", $4f
	db "must be pretty", $55
	db "pathetic then.", $51
	db "Hey, don't worry", $4f
	db "about it.", $51
	db "I'll know if you", $4f
	db "are good or not by", $51
	db "battling you right", $4f
	db "now.", $51
	db "Ready, JOHTO", $4f
	db "CHAMP?", $57
; 0x9abae

UnknownText_0x9abae: ; 0x9abae
	db $0, "BLUE: What?", $51
	db "How the heck did I", $4f
	db "lose to you?", $51
	db "…", $51
	db "Tch, all right…", $4f
	db "Here, take this--", $55
	db "it's EARTHBADGE.", $57
; 0x9ac0f

UnknownText_0x9ac0f: ; 0x9ac0f
	db $0, $52, " received", $4f
	db "EARTHBADGE.", $57
; 0x9ac27

UnknownText_0x9ac27: ; 0x9ac27
	db $0, "BLUE: …", $51
	db "All right, I was", $4f
	db "wrong. You're the", $51
	db "real deal. You are", $4f
	db "a good trainer.", $51
	db "But I'm going to", $4f
	db "beat you someday.", $51
	db "Don't you forget", $4f
	db "it!", $57
; 0x9acab

UnknownText_0x9acab: ; 0x9acab
	db $0, "BLUE: Listen, you.", $51
	db "You'd better not", $4f
	db "lose until I beat", $55
	db "you. Got it?", $57
; 0x9acee

ViridianGymGuyText: ; 0x9acee
	db $0, "Yo, CHAMP in", $4f
	db "making!", $51
	db "How's it going?", $4f
	db "Looks like you're", $55
	db "on a roll.", $51
	db "The GYM LEADER is", $4f
	db "a guy who battled", $51
	db "the CHAMPION three", $4f
	db "years ago.", $51
	db "He's no pushover.", $51
	db "Give it everything", $4f
	db "you've got!", $57
; 0x9ada0

ViridianGymGuyWinText: ; 0x9ada0
	db $0, "Man, you are truly", $4f
	db "tough…", $51
	db "That was a heck of", $4f
	db "an inspirational", $51
	db "battle. It brought", $4f
	db "tears to my eyes.", $57
; 0x9ae04

ViridianGym_MapEventHeader: ; 0x9ae04
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $11, $4, 1, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY
	warp_def $11, $5, 1, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 13, 3, $0, MapViridianGymSignpost1Script
	signpost 13, 6, $0, MapViridianGymSignpost1Script

	; people-events
	db 2
	person_event $7, 7, 9, $6, $0, 255, 255, $0, 0, UnknownScript_0x9aa26, $0776
	person_event $48, 17, 11, $6, $0, 255, 255, $90, 0, ViridianGymGuyScript, $0776
; 0x9ae38

ViridianNicknameSpeechHouse_MapScriptHeader: ; 0x9ae38
	; trigger count
	db 0

	; callback count
	db 0
; 0x9ae3a

UnknownScript_0x9ae3a: ; 0x9ae3a
	jumptextfaceplayer UnknownText_0x9ae54
; 0x9ae3d

UnknownScript_0x9ae3d: ; 0x9ae3d
	jumptextfaceplayer UnknownText_0x9aecb
; 0x9ae40

UnknownScript_0x9ae40: ; 0x9ae40
	loadfont
	2writetext UnknownText_0x9aefe
	cry SPEAROW
	closetext
	loadmovesprites
	end
; 0x9ae4a

UnknownScript_0x9ae4a: ; 0x9ae4a
	loadfont
	2writetext UnknownText_0x9af10
	cry RATTATA
	closetext
	loadmovesprites
	end
; 0x9ae54

UnknownText_0x9ae54: ; 0x9ae54
	db $0, "Do you put a lot", $4f
	db "of thought into", $51
	db "naming your", $4f
	db "#MON?", $51
	db "Giving them good", $4f
	db "nicknames adds to", $51
	db "the fun of trading", $4f
	db "with others.", $57
; 0x9aecb

UnknownText_0x9aecb: ; 0x9aecb
	db $0, "They're SPEARY--", $4f
	db "a SPEAROW--and", $55
	db "RATTEY--a RATTATA.", $57
; 0x9aefe

UnknownText_0x9aefe: ; 0x9aefe
	db $0, "SPEARY: Ch-chun!", $57
; 0x9af10

UnknownText_0x9af10: ; 0x9af10
	db $0, "RATTEY: Kikiii!", $57
; 0x9af21

ViridianNicknameSpeechHouse_MapEventHeader: ; 0x9af21
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY
	warp_def $7, $3, 2, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $2d, 8, 6, $9, $0, 255, 255, $80, 0, UnknownScript_0x9ae3a, $ffff
	person_event $28, 8, 9, $7, $0, 255, 255, $a0, 0, UnknownScript_0x9ae3d, $ffff
	person_event $9e, 6, 9, $16, $2, 255, 255, $b0, 0, UnknownScript_0x9ae40, $ffff
	person_event $82, 7, 10, $16, $2, 255, 255, $90, 0, UnknownScript_0x9ae4a, $ffff
; 0x9af65

TrainerHouse1F_MapScriptHeader: ; 0x9af65
	; trigger count
	db 0

	; callback count
	db 0
; 0x9af67

UnknownScript_0x9af67: ; 0x9af67
	jumptextfaceplayer UnknownText_0x9af7f
; 0x9af6a

UnknownScript_0x9af6a: ; 0x9af6a
	jumptextfaceplayer UnknownText_0x9b025
; 0x9af6d

UnknownScript_0x9af6d: ; 0x9af6d
	jumptextfaceplayer UnknownText_0x9b0b5
; 0x9af70

UnknownScript_0x9af70: ; 0x9af70
	jumptextfaceplayer UnknownText_0x9b11d
; 0x9af73

UnknownScript_0x9af73: ; 0x9af73
	jumptextfaceplayer UnknownText_0x9b1c9
; 0x9af76

MapTrainerHouse1FSignpost0Script: ; 0x9af76
	jumptext UnknownText_0x9b1f4
; 0x9af79

MapTrainerHouse1FSignpost1Script: ; 0x9af79
	jumptext UnknownText_0x9b25d
; 0x9af7c

MapTrainerHouse1FSignpost2Script: ; 0x9af7c
	jumptext UnknownText_0x9b2c1
; 0x9af7f

UnknownText_0x9af7f: ; 0x9af7f
	db $0, "Welcome to TRAINER", $4f
	db "HOUSE, the newest", $51
	db "and most happening", $4f
	db "place in VIRIDIAN.", $51
	db "We're open to", $4f
	db "trainers only.", $51
	db "You can battle", $4f
	db "against the best", $51
	db "of the best right", $4f
	db "downstairs.", $57
; 0x9b025

UnknownText_0x9b025: ; 0x9b025
	db $0, "VIRIDIAN is the", $4f
	db "town closest to", $55
	db "INDIGO PLATEAU.", $51
	db "They built this", $4f
	db "place because so", $51
	db "many trainers pass", $4f
	db "through on their", $51
	db "way up to INDIGO", $4f
	db "PLATEAU.", $57
; 0x9b0b5

UnknownText_0x9b0b5: ; 0x9b0b5
	db $0, "They hold practice", $4f
	db "battles downstairs", $55
	db "here.", $51
	db "I would love to", $4f
	db "see how well a", $51
	db "trainer from JOHTO", $4f
	db "battles.", $57
; 0x9b11d

UnknownText_0x9b11d: ; 0x9b11d
	db $0, "I guess you can't", $4f
	db "become the CHAMP", $51
	db "unless you go all", $4f
	db "over the place and", $51
	db "battle all kinds", $4f
	db "of people.", $51
	db "The CHAMPION from", $4f
	db "PALLET traveled to", $51
	db "all the cities and", $4f
	db "towns in KANTO.", $57
; 0x9b1c9

UnknownText_0x9b1c9: ; 0x9b1c9
	db $0, "Whew… I'm taking a", $4f
	db "rest from #MON", $55
	db "battles.", $57
; 0x9b1f4

UnknownText_0x9b1f4: ; 0x9b1f4
	db $0, "Practice battles", $4f
	db "are held in the", $51
	db "TRAINING HALL", $4f
	db "downstairs.", $51
	db "Skilled trainers", $4f
	db "are invited to", $55
	db "participate.", $57
; 0x9b25d

UnknownText_0x9b25d: ; 0x9b25d
	db $0, "There are no rules", $4f
	db "or regulations for", $51
	db "practice matches.", $4f
	db "Just like in field", $51
	db "battles, anything", $4f
	db "goes!", $57
; 0x9b2c1

UnknownText_0x9b2c1: ; 0x9b2c1
	db $0, "…What's this?", $4f
	db "A strategy memo?", $51
	db "This writing looks", $4f
	db "like ONIX tracks…", $51
	db "It's completely", $4f
	db "illegible…", $57
; 0x9b31f

TrainerHouse1F_MapEventHeader: ; 0x9b31f
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $d, $2, 3, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY
	warp_def $d, $3, 3, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY
	warp_def $2, $8, 1, GROUP_TRAINER_HOUSE_B1F, MAP_TRAINER_HOUSE_B1F

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 0, 5, $0, MapTrainerHouse1FSignpost0Script
	signpost 0, 7, $0, MapTrainerHouse1FSignpost1Script
	signpost 10, 7, $0, MapTrainerHouse1FSignpost2Script

	; people-events
	db 5
	person_event $42, 15, 4, $9, $0, 255, 255, $a0, 0, UnknownScript_0x9af67, $ffff
	person_event $23, 15, 11, $7, $0, 255, 255, $0, 0, UnknownScript_0x9af6a, $ffff
	person_event $24, 6, 10, $6, $2, 255, 255, $80, 0, UnknownScript_0x9af6d, $ffff
	person_event $27, 12, 8, $5, $2, 255, 255, $80, 0, UnknownScript_0x9af70, $ffff
	person_event $40, 8, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x9af73, $ffff
; 0x9b384

TrainerHouseB1F_MapScriptHeader: ; 0x9b384
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x9b38a, $0000

	; callback count
	db 0
; 0x9b38a

UnknownScript_0x9b38a: ; 0x9b38a
	end
; 0x9b38b

UnknownScript_0x9b38b: ; 0x9b38b
	spriteface $0, $1
	loadfont
	checkbit2 $0057
	iftrue UnknownScript_0x9b3f7
	2writetext UnknownText_0x9b420
	keeptextopen
	special $0067
	iffalse UnknownScript_0x9b3a6
	trainertotext CAL, CAL2, $0
	2jump UnknownScript_0x9b3aa
; 0x9b3a6

UnknownScript_0x9b3a6: ; 0x9b3a6
	trainertotext CAL, CAL3, $0
UnknownScript_0x9b3aa: ; 0x9b3aa
	2writetext UnknownText_0x9b46a
	keeptextopen
	2writetext UnknownText_0x9b487
	yesorno
	iffalse UnknownScript_0x9b3ed
	setbit2 $0057
	2writetext UnknownText_0x9b4a2
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x9b401
	loadfont
	2writetext UnknownText_0x9b587
	closetext
	loadmovesprites
	special $0067
	iffalse UnknownScript_0x9b3dc
	winlosstext UnknownText_0x9b578, $0000
	setlasttalked $3
	loadtrainer CAL, CAL2
	startbattle
	returnafterbattle
	iffalse UnknownScript_0x9b3e8
UnknownScript_0x9b3dc: ; 0x9b3dc
	winlosstext UnknownText_0x9b578, $0000
	setlasttalked $3
	loadtrainer CAL, CAL3
	startbattle
	returnafterbattle
UnknownScript_0x9b3e8: ; 0x9b3e8
	applymovement $0, MovementData_0x9b40f
	end
; 0x9b3ed

UnknownScript_0x9b3ed: ; 0x9b3ed
	2writetext UnknownText_0x9b4d6
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x9b41d
	end
; 0x9b3f7

UnknownScript_0x9b3f7: ; 0x9b3f7
	2writetext UnknownText_0x9b51d
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x9b41d
	end
; 0x9b401

MovementData_0x9b401: ; 0x9b401
	step_left
	step_left
	step_left
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_left
	turn_head_right
	step_end
; 0x9b40f

MovementData_0x9b40f: ; 0x9b40f
	step_up
	step_up
	step_up
	step_right
	step_up
	step_up
	step_up
	step_up
	step_up
	step_right
	step_right
	step_right
	step_right
	step_end
; 0x9b41d

MovementData_0x9b41d: ; 0x9b41d
	step_right
	turn_head_left
	step_end
; 0x9b420

UnknownText_0x9b420: ; 0x9b420
	db $0, "Hi. Welcome to our", $4f
	db "TRAINING HALL.", $51
	db "You may battle a", $4f
	db "trainer once per", $55
	db "day.", $57
; 0x9b46a

UnknownText_0x9b46a: ; 0x9b46a
	text_from_ram $d099
	db $0, " is your", $4f
	db "opponent today.", $57
; 0x9b487

UnknownText_0x9b487: ; 0x9b487
	db $0, "Would you like to", $4f
	db "battle?", $57
; 0x9b4a2

UnknownText_0x9b4a2: ; 0x9b4a2
	db $0, "Please go right", $4f
	db "through.", $51
	db "You may begin", $4f
	db "right away.", $57
; 0x9b4d6

UnknownText_0x9b4d6: ; 0x9b4d6
	db $0, "Sorry. Only those", $4f
	db "trainers who will", $51
	db "be battling are", $4f
	db "allowed to go in.", $57
; 0x9b51d

UnknownText_0x9b51d: ; 0x9b51d
	db $0, "I'm sorry.", $4f
	db "This would be your", $51
	db "second time today.", $4f
	db "You're permitted", $51
	db "to enter just once", $4f
	db "a day.", $57
; 0x9b578

UnknownText_0x9b578: ; 0x9b578
	db $0, "I lost…", $4f
	db "Darn…", $57
; 0x9b587

UnknownText_0x9b587: ; 0x9b587
	db $0, "I traveled out", $4f
	db "here just so I", $55
	db "could battle you.", $57
; 0x9b5b8

TrainerHouseB1F_MapEventHeader: ; 0x9b5b8
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $4, $9, 3, GROUP_TRAINER_HOUSE_1F, MAP_TRAINER_HOUSE_1F

	; xy triggers
	db 1
	xy_trigger 0, $3, $7, $0, UnknownScript_0x9b38b, $0, $0

	; signposts
	db 0

	; people-events
	db 2
	person_event $42, 5, 11, $6, $0, 255, 255, $a0, 0, ObjectEvent, $ffff
	person_event $1, 15, 10, $8, $0, 255, 255, $80, 0, ObjectEvent, $ffff
; 0x9b5e5

ViridianMart_MapScriptHeader: ; 0x9b5e5
	; trigger count
	db 0

	; callback count
	db 0
; 0x9b5e7

UnknownScript_0x9b5e7: ; 0x9b5e7
	loadfont
	pokemart $0, $0012
	loadmovesprites
	end
; 0x9b5ee

UnknownScript_0x9b5ee: ; 0x9b5ee
	jumptextfaceplayer UnknownText_0x9b5f4
; 0x9b5f1

UnknownScript_0x9b5f1: ; 0x9b5f1
	jumptextfaceplayer UnknownText_0x9b61a
; 0x9b5f4

UnknownText_0x9b5f4: ; 0x9b5f4
	db $0, "The GYM LEADER", $4f
	db "here is totally", $55
	db "cool.", $57
; 0x9b61a

UnknownText_0x9b61a: ; 0x9b61a
	db $0, "Have you been to", $4f
	db "CINNABAR?", $51
	db "It's an island way", $4f
	db "south of here.", $57
; 0x9b657

ViridianMart_MapEventHeader: ; 0x9b657
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY
	warp_def $7, $3, 4, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x9b5e7, $ffff
	person_event $28, 6, 11, $5, $2, 255, 255, $0, 0, UnknownScript_0x9b5ee, $ffff
	person_event $23, 10, 5, $7, $0, 255, 255, $0, 0, UnknownScript_0x9b5f1, $ffff
; 0x9b68e

ViridianPokeCenter1F_MapScriptHeader: ; 0x9b68e
	; trigger count
	db 0

	; callback count
	db 0
; 0x9b690

UnknownScript_0x9b690: ; 0x9b690
	jumpstd $0000
; 0x9b693

UnknownScript_0x9b693: ; 0x9b693
	faceplayer
	loadfont
	checkbit1 $0775
	iftrue UnknownScript_0x9b6a1
	2writetext UnknownText_0x9b6ad
	closetext
	loadmovesprites
	end
; 0x9b6a1

UnknownScript_0x9b6a1: ; 0x9b6a1
	2writetext UnknownText_0x9b6f5
	closetext
	loadmovesprites
	end
; 0x9b6a7

UnknownScript_0x9b6a7: ; 0x9b6a7
	jumptextfaceplayer UnknownText_0x9b76b
; 0x9b6aa

UnknownScript_0x9b6aa: ; 0x9b6aa
	jumptextfaceplayer UnknownText_0x9b7c8
; 0x9b6ad

UnknownText_0x9b6ad: ; 0x9b6ad
	db $0, "Where in the world", $4f
	db "is VIRIDIAN's GYM", $51
	db "LEADER? I wanted", $4f
	db "to challenge him.", $57
; 0x9b6f5

UnknownText_0x9b6f5: ; 0x9b6f5
	db $0, "There are no GYM", $4f
	db "TRAINERS at the", $55
	db "VIRIDIAN GYM.", $51
	db "The LEADER claims", $4f
	db "his policy is to", $51
	db "win without having", $4f
	db "any underlings.", $57
; 0x9b76b

UnknownText_0x9b76b: ; 0x9b76b
	db $0, "I heard that the", $4f
	db "GYM in CINNABAR is", $55
	db "gone.", $51
	db "I wonder what be-", $4f
	db "came of BLAINE,", $55
	db "the GYM LEADER.", $57
; 0x9b7c8

UnknownText_0x9b7c8: ; 0x9b7c8
	db $0, "My dream is to be-", $4f
	db "come a GYM LEADER.", $57
; 0x9b7ef

ViridianPokeCenter1F_MapEventHeader: ; 0x9b7ef
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 5, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY
	warp_def $7, $4, 5, GROUP_VIRIDIAN_CITY, MAP_VIRIDIAN_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x9b690, $ffff
	person_event $23, 8, 12, $5, $1, 255, 255, $80, 0, UnknownScript_0x9b693, $ffff
	person_event $24, 7, 9, $7, $0, 255, 255, $90, 0, UnknownScript_0x9b6a7, $ffff
	person_event $25, 10, 5, $9, $0, 255, 255, $a0, 0, UnknownScript_0x9b6aa, $ffff
; 0x9b838

ViridianPokeCenter2FBeta_MapScriptHeader: ; 0x9b838
	; trigger count
	db 0

	; callback count
	db 0
; 0x9b83a

ViridianPokeCenter2FBeta_MapEventHeader: ; 0x9b83a
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 3, GROUP_VIRIDIAN_POKECENTER_1F, MAP_VIRIDIAN_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x9b845

Route2NuggetSpeechHouse_MapScriptHeader: ; 0x9b845
	; trigger count
	db 0

	; callback count
	db 0
; 0x9b847

UnknownScript_0x9b847: ; 0x9b847
	faceplayer
	loadfont
	checkbit1 $00c8
	iftrue UnknownScript_0x9b85c
	2writetext UnknownText_0x9b865
	keeptextopen
	verbosegiveitem NUGGET, 1
	iffalse UnknownScript_0x9b860
	setbit1 $00c8
UnknownScript_0x9b85c: ; 0x9b85c
	2writetext UnknownText_0x9b8e5
	closetext
UnknownScript_0x9b860: ; 0x9b860
	loadmovesprites
	end
; 0x9b862

UnknownScript_0x9b862: ; 0x9b862
	jumpstd $0001
; 0x9b865

UnknownText_0x9b865: ; 0x9b865
	db $0, "Hi! Wow, I'm glad", $4f
	db "to see you.", $51
	db "You're the first", $4f
	db "visitor I've had", $55
	db "in a long time.", $51
	db "I'm super-happy!", $4f
	db "Let me give you a", $55
	db "little present.", $57
; 0x9b8e5

UnknownText_0x9b8e5: ; 0x9b8e5
	db $0, "That's a NUGGET.", $51
	db "I can't give you", $4f
	db "any nuggets of", $51
	db "wisdom, so that'll", $4f
	db "have to do!", $57
; 0x9b933

Route2NuggetSpeechHouse_MapEventHeader: ; 0x9b933
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_ROUTE_2, MAP_ROUTE_2
	warp_def $7, $3, 1, GROUP_ROUTE_2, MAP_ROUTE_2

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $3a, 8, 6, $4, $20, 255, 255, $90, 0, UnknownScript_0x9b847, $ffff
; 0x9b950

Route2Gate_MapScriptHeader: ; 0x9b950
	; trigger count
	db 0

	; callback count
	db 0
; 0x9b952

UnknownScript_0x9b952: ; 0x9b952
	jumptextfaceplayer UnknownText_0x9b955
; 0x9b955

UnknownText_0x9b955: ; 0x9b955
	db $0, "Are you ", $14, "?", $51
	db "I work as PROF.", $4f
	db "OAK's AIDE.", $51
	db "I had no idea that", $4f
	db "you were out here.", $51
	db "PROF.OAK's LAB is", $4f
	db "nearby in PALLET", $55
	db "TOWN.", $57
; 0x9b9ca

Route2Gate_MapEventHeader: ; 0x9b9ca
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 3, GROUP_ROUTE_2, MAP_ROUTE_2
	warp_def $0, $5, 4, GROUP_ROUTE_2, MAP_ROUTE_2
	warp_def $7, $4, 2, GROUP_ROUTE_2, MAP_ROUTE_2
	warp_def $7, $5, 2, GROUP_ROUTE_2, MAP_ROUTE_2

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $3c, 8, 10, $4, $20, 255, 255, $90, 0, UnknownScript_0x9b952, $ffff
; 0x9b9f1

VictoryRoadGate_MapScriptHeader: ; 0x9b9f1
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x9b9fb, $0000
	dw UnknownScript_0x9b9fc, $0000

	; callback count
	db 0
; 0x9b9fb

UnknownScript_0x9b9fb: ; 0x9b9fb
	end
; 0x9b9fc

UnknownScript_0x9b9fc: ; 0x9b9fc
	end
; 0x9b9fd

UnknownScript_0x9b9fd: ; 0x9b9fd
	spriteface $0, $2
	2jump UnknownScript_0x9ba04
; 0x9ba03

UnknownScript_0x9ba03: ; 0x9ba03
	faceplayer
UnknownScript_0x9ba04: ; 0x9ba04
	loadfont
	2writetext UnknownText_0x9ba29
	keeptextopen
	checkcode $7
	if_less_than $7, UnknownScript_0x9ba19
	2writetext UnknownText_0x9ba5f
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x9ba27
	end
; 0x9ba19

UnknownScript_0x9ba19: ; 0x9ba19
	2writetext UnknownText_0x9bab4
	closetext
	loadmovesprites
	dotrigger $1
	end
; 0x9ba21

UnknownScript_0x9ba21: ; 0x9ba21
	jumptextfaceplayer UnknownText_0x9baf1
; 0x9ba24

UnknownScript_0x9ba24: ; 0x9ba24
	jumptextfaceplayer UnknownText_0x9bb37
; 0x9ba27

MovementData_0x9ba27: ; 0x9ba27
	step_down
	step_end
; 0x9ba29

UnknownText_0x9ba29: ; 0x9ba29
	db $0, "Only trainers who", $4f
	db "have proven them-", $55
	db "selves may pass.", $57
; 0x9ba5f

UnknownText_0x9ba5f: ; 0x9ba5f
	db $0, "You don't have all", $4f
	db "the GYM BADGES of", $55
	db "JOHTO.", $51
	db "I'm sorry, but I", $4f
	db "can't let you go", $55
	db "through.", $57
; 0x9bab4

UnknownText_0x9bab4: ; 0x9bab4
	db $0, "Oh! The eight", $4f
	db "BADGES of JOHTO!", $51
	db "Please, go right", $4f
	db "on through!", $57
; 0x9baf1

UnknownText_0x9baf1: ; 0x9baf1
	db $0, "This way leads to", $4f
	db "MT.SILVER.", $51
	db "You'll see scary-", $4f
	db "strong #MON out", $55
	db "there.", $57
; 0x9bb37

UnknownText_0x9bb37: ; 0x9bb37
	db $0, "Off to the #MON", $4f
	db "LEAGUE, are you?", $51
	db "The ELITE FOUR are", $4f
	db "so strong it's", $51
	db "scary, and they're", $4f
	db "ready for you!", $57
; 0x9bb9b

VictoryRoadGate_MapEventHeader: ; 0x9bb9b
	; filler
	db 0, 0

	; warps
	db 8
	warp_def $7, $11, 1, GROUP_ROUTE_22, MAP_ROUTE_22
	warp_def $7, $12, 1, GROUP_ROUTE_22, MAP_ROUTE_22
	warp_def $11, $9, 1, GROUP_ROUTE_26, MAP_ROUTE_26
	warp_def $11, $a, 1, GROUP_ROUTE_26, MAP_ROUTE_26
	warp_def $0, $9, 1, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $0, $a, 1, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $7, $1, 2, GROUP_ROUTE_28, MAP_ROUTE_28
	warp_def $7, $2, 2, GROUP_ROUTE_28, MAP_ROUTE_28

	; xy triggers
	db 1
	xy_trigger 0, $b, $a, $0, UnknownScript_0x9b9fd, $0, $0

	; signposts
	db 0

	; people-events
	db 3
	person_event $43, 15, 12, $9, $0, 255, 255, $0, 0, UnknownScript_0x9ba03, $ffff
	person_event $41, 9, 11, $9, $0, 255, 255, $0, 0, UnknownScript_0x9ba21, $074f
	person_event $41, 9, 16, $8, $0, 255, 255, $0, 0, UnknownScript_0x9ba24, $0750
; 0x9bbf8

SECTION "bank27",DATA,BANK[$27]

OlivinePokeCenter1F_MapScriptHeader: ; 0x9c000
	; trigger count
	db 0

	; callback count
	db 0
; 0x9c002

UnknownScript_0x9c002: ; 0x9c002
	jumpstd $0000
; 0x9c005

UnknownScript_0x9c005: ; 0x9c005
	jumpstd $0033
; 0x9c008

UnknownScript_0x9c008: ; 0x9c008
	jumptextfaceplayer UnknownText_0x9c00e
; 0x9c00b

UnknownScript_0x9c00b: ; 0x9c00b
	jumptextfaceplayer UnknownText_0x9c086
; 0x9c00e

UnknownText_0x9c00e: ; 0x9c00e
	db $0, "The SAILOR in the", $4f
	db "OLIVINE CAFE next", $51
	db "door is really", $4f
	db "generous.", $51
	db "He taught my", $4f
	db "#MON STRENGTH.", $51
	db "Now it can move", $4f
	db "big boulders.", $57
; 0x9c086

UnknownText_0x9c086: ; 0x9c086
	db $0, "There's a person", $4f
	db "in CIANWOOD CITY", $55
	db "across the sea.", $51
	db "I heard him brag-", $4f
	db "ging about his", $55
	db "rare #MON.", $57
; 0x9c0e4

OlivinePokeCenter1F_MapEventHeader: ; 0x9c0e4
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $7, $4, 1, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x9c002, $ffff
	person_event $3b, 8, 12, $5, $1, 255, 255, $0, 0, UnknownScript_0x9c005, $ffff
	person_event $3a, 7, 6, $6, $0, 255, 255, $a0, 0, UnknownScript_0x9c008, $ffff
	person_event $29, 5, 11, $6, $0, 255, 255, $0, 0, UnknownScript_0x9c00b, $ffff
; 0x9c12d

OlivineGym_MapScriptHeader: ; 0x9c12d
	; trigger count
	db 0

	; callback count
	db 0
; 0x9c12f

UnknownScript_0x9c12f: ; 0x9c12f
	faceplayer
	loadfont
	checkbit1 $04c1
	iftrue UnknownScript_0x9c159
	2writetext UnknownText_0x9c1b9
	closetext
	loadmovesprites
	winlosstext UnknownText_0x9c2bb, $0000
	loadtrainer JASMINE, 1
	startbattle
	returnafterbattle
	setbit1 $04c1
	loadfont
	2writetext UnknownText_0x9c33a
	playsound $009c
	waitbutton
	setbit2 $001f
	checkcode $7
	2call UnknownScript_0x9c178
UnknownScript_0x9c159: ; 0x9c159
	checkbit1 $000d
	iftrue UnknownScript_0x9c172
	2writetext UnknownText_0x9c354
	keeptextopen
	verbosegiveitem TM_23, 1
	iffalse UnknownScript_0x9c176
	setbit1 $000d
	2writetext UnknownText_0x9c3a5
	closetext
	loadmovesprites
	end
; 0x9c172

UnknownScript_0x9c172: ; 0x9c172
	2writetext UnknownText_0x9c3d1
	closetext
UnknownScript_0x9c176: ; 0x9c176
	loadmovesprites
	end
; 0x9c178

UnknownScript_0x9c178: ; 0x9c178
	if_equal $7, UnknownScript_0x9c184
	if_equal $6, UnknownScript_0x9c181
	end
; 0x9c181

UnknownScript_0x9c181: ; 0x9c181
	jumpstd $0012
; 0x9c184

UnknownScript_0x9c184: ; 0x9c184
	jumpstd $0013
; 0x9c187

OlivineGymGuyScript: ; 0x9c187
	faceplayer
	checkbit1 $04c1
	iftrue .OlivineGymGuyWinScript
	checkbit1 $0020
	iffalse .OlivineGymGuyPreScript
	loadfont
	2writetext OlivineGymGuyText
	closetext
	loadmovesprites
	end
; 0x9c19b

.OlivineGymGuyWinScript
	loadfont
	2writetext OlivineGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x9c1a2

.OlivineGymGuyPreScript
	loadfont
	2writetext OlivineGymGuyPreText
	closetext
	loadmovesprites
	end
; 0x9c1a9

MapOlivineGymSignpost1Script: ; 0x9c1a9
	checkbit2 $001f
	iftrue UnknownScript_0x9c1b2
	jumpstd $002d
; 0x9c1b2

UnknownScript_0x9c1b2: ; 0x9c1b2
	trainertotext JASMINE, 1, $1
	jumpstd $002e
; 0x9c1b9

UnknownText_0x9c1b9: ; 0x9c1b9
	db $0, "…Thank you for", $4f
	db "your help at the", $55
	db "LIGHTHOUSE…", $51
	db "But this is dif-", $4f
	db "ferent. Please", $51
	db "allow me to intro-", $4f
	db "duce myself.", $51
	db "I am JASMINE, a", $4f
	db "GYM LEADER. I use", $55
	db "the steel-type.", $51
	db "…Do you know about", $4f
	db "the steel-type?", $51
	db "It's a type that", $4f
	db "was only recently", $55
	db "discovered.", $51
	db "…Um… May I begin?", $57
; 0x9c2bb

UnknownText_0x9c2bb: ; 0x9c2bb
	db $0, "…You are a better", $4f
	db "trainer than me,", $51
	db "in both skill and", $4f
	db "kindness.", $51
	db "In accordance with", $4f
	db "LEAGUE rules, I", $51
	db "confer upon you", $4f
	db "this BADGE.", $57
; 0x9c33a

UnknownText_0x9c33a: ; 0x9c33a
	db $0, $52, " received", $4f
	db "MINERALBADGE.", $57
; 0x9c354

UnknownText_0x9c354: ; 0x9c354
	db $0, "MINERALBADGE", $4f
	db "raises #MON's", $55
	db "DEFENSE.", $51
	db "…Um… Please take", $4f
	db "this too…", $57
; 0x9c393

UnknownText_0x9c393: ; 0x9c393
	db $0, $52, " received", $4f
	db "TM09.", $57
; 0x9c3a5

UnknownText_0x9c3a5: ; 0x9c3a5
	db $0, "…You could use", $4f
	db "that TM to teach", $55
	db "IRON TAIL.", $57
; 0x9c3d1

UnknownText_0x9c3d1: ; 0x9c3d1
	db $0, "Um… I don't know", $4f
	db "how to say this,", $55
	db "but good luck…", $57
; 0x9c402

OlivineGymGuyText: ; 0x9c402
	db $0, "JASMINE uses the", $4f
	db "newly discovered", $55
	db "steel-type.", $51
	db "I don't know very", $4f
	db "much about it.", $57
; 0x9c451

OlivineGymGuyWinText: ; 0x9c451
	db $0, "That was awesome.", $51
	db "The steel-type,", $4f
	db "huh?", $51
	db "That was a close", $4f
	db "encounter of an", $55
	db "unknown kind!", $57
; 0x9c4a8

OlivineGymGuyPreText: ; 0x9c4a8
	db $0, "JASMINE, the GYM", $4f
	db "LEADER, is at the", $55
	db "LIGHTHOUSE.", $51
	db "She's been tending", $4f
	db "to a sick #MON.", $51
	db "A strong trainer", $4f
	db "has to be compas-", $55
	db "sionate.", $57
; 0x9c526

OlivineGym_MapEventHeader: ; 0x9c526
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $f, $4, 2, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $f, $5, 2, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 13, 3, $0, MapOlivineGymSignpost1Script
	signpost 13, 6, $0, MapOlivineGymSignpost1Script

	; people-events
	db 2
	person_event $17, 7, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x9c12f, $06d3
	person_event $48, 17, 11, $6, $0, 255, 255, $80, 0, OlivineGymGuyScript, $ffff
; 0x9c55a

OlivineVoltorbHouse_MapScriptHeader: ; 0x9c55a
	; trigger count
	db 0

	; callback count
	db 0
; 0x9c55c

UnknownScript_0x9c55c: ; 0x9c55c
	faceplayer
	loadfont
	trade $2
	closetext
	loadmovesprites
	end
; 0x9c563

MapOlivineVoltorbHouseSignpost1Script: ; 0x9c563
	jumpstd $0003
; 0x9c566

OlivineVoltorbHouse_MapEventHeader: ; 0x9c566
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $7, $3, 3, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapOlivineVoltorbHouseSignpost1Script
	signpost 1, 1, $0, MapOlivineVoltorbHouseSignpost1Script

	; people-events
	db 1
	person_event $3b, 7, 6, $3, $0, 255, 255, $80, 0, UnknownScript_0x9c55c, $ffff
; 0x9c58d

OlivineHouseBeta_MapScriptHeader: ; 0x9c58d
	; trigger count
	db 0

	; callback count
	db 0
; 0x9c58f

UnknownScript_0x9c58f: ; 0x9c58f
	jumptextfaceplayer UnknownText_0x9c5a2
; 0x9c592

UnknownScript_0x9c592: ; 0x9c592
	loadfont
	2writetext UnknownText_0x9c5f0
	cry RHYDON
	closetext
	loadmovesprites
	end
; 0x9c59c

MapOlivineHouseBetaSignpost0Script: ; 0x9c59c
	jumpstd $0002
; 0x9c59f

MapOlivineHouseBetaSignpost1Script: ; 0x9c59f
	jumpstd $0003
; 0x9c5a2

UnknownText_0x9c5a2: ; 0x9c5a2
	db $0, "When my #MON", $4f
	db "got sick, the", $51
	db "PHARMACIST in", $4f
	db "ECRUTEAK made some", $55
	db "medicine for me.", $57
; 0x9c5f0

UnknownText_0x9c5f0: ; 0x9c5f0
	db $0, "RHYDON: Gugooh!", $57
; 0x9c601

OlivineHouseBeta_MapEventHeader: ; 0x9c601
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $7, $3, 4, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapOlivineHouseBetaSignpost0Script
	signpost 1, 1, $0, MapOlivineHouseBetaSignpost1Script

	; people-events
	db 2
	person_event $29, 7, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x9c58f, $ffff
	person_event $9d, 8, 10, $4, $20, 255, 255, $0, 0, UnknownScript_0x9c592, $ffff
; 0x9c635

OlivinePunishmentSpeechHouse_MapScriptHeader: ; 0x9c635
	; trigger count
	db 0

	; callback count
	db 0
; 0x9c637

UnknownScript_0x9c637: ; 0x9c637
	jumptextfaceplayer UnknownText_0x9c643
; 0x9c63a

UnknownScript_0x9c63a: ; 0x9c63a
	jumptextfaceplayer UnknownText_0x9c6b1
; 0x9c63d

MapOlivinePunishmentSpeechHouseSignpost1Script: ; 0x9c63d
	jumpstd $0002
; 0x9c640

MapOlivinePunishmentSpeechHouseSignpost0Script: ; 0x9c640
	jumpstd $0003
; 0x9c643

UnknownText_0x9c643: ; 0x9c643
	db $0, "Along the way to", $4f
	db "CIANWOOD, there", $51
	db "are four deserted", $4f
	db "islands.", $51
	db "Bad kids are taken", $4f
	db "to the islands as", $55
	db "punishment!", $57
; 0x9c6b1

UnknownText_0x9c6b1: ; 0x9c6b1
	db $0, "Whenever I get in", $4f
	db "trouble, Daddy", $55
	db "always scares me.", $57
; 0x9c6e5

OlivinePunishmentSpeechHouse_MapEventHeader: ; 0x9c6e5
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 5, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $7, $3, 5, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapOlivinePunishmentSpeechHouseSignpost0Script
	signpost 1, 1, $0, MapOlivinePunishmentSpeechHouseSignpost1Script

	; people-events
	db 2
	person_event $2d, 6, 5, $3, $0, 255, 255, $0, 0, UnknownScript_0x9c637, $ffff
	person_event $28, 9, 9, $5, $2, 255, 255, $0, 0, UnknownScript_0x9c63a, $ffff
; 0x9c719

OlivineGoodRodHouse_MapScriptHeader: ; 0x9c719
	; trigger count
	db 0

	; callback count
	db 0
; 0x9c71b

UnknownScript_0x9c71b: ; 0x9c71b
	faceplayer
	loadfont
	checkbit1 $0018
	iftrue UnknownScript_0x9c740
	2writetext UnknownText_0x9c749
	yesorno
	iffalse UnknownScript_0x9c73a
	2writetext UnknownText_0x9c7db
	keeptextopen
	verbosegiveitem GOOD_ROD, 1
	2writetext UnknownText_0x9c807
	closetext
	loadmovesprites
	setbit1 $0018
	end
; 0x9c73a

UnknownScript_0x9c73a: ; 0x9c73a
	2writetext UnknownText_0x9c84c
	closetext
	loadmovesprites
	end
; 0x9c740

UnknownScript_0x9c740: ; 0x9c740
	2writetext UnknownText_0x9c87f
	closetext
	loadmovesprites
	end
; 0x9c746

UnknownScript_0x9c746: ; 0x9c746
	jumpstd $0002
; 0x9c749

UnknownText_0x9c749: ; 0x9c749
	db $0, "OLIVINE is on the", $4f
	db "sea!", $51
	db "And if it's on the", $4f
	db "sea, there are", $55
	db "bound to be fish!", $51
	db "I've fished here", $4f
	db "for 30 years.", $51
	db "Would you like to", $4f
	db "face the sea and", $55
	db "fish?", $57
; 0x9c7db

UnknownText_0x9c7db: ; 0x9c7db
	db $0, "Ah, hahah!", $4f
	db "We have ourselves", $55
	db "a new angler!", $57
; 0x9c807

UnknownText_0x9c807: ; 0x9c807
	db $0, "Fish aren't found", $4f
	db "in the sea alone.", $51
	db "They go wherever", $4f
	db "there is water.", $57
; 0x9c84c

UnknownText_0x9c84c: ; 0x9c84c
	db $0, "Whaaat? You don't", $4f
	db "like to fish!?", $55
	db "Incomprehensible!", $57
; 0x9c87f

UnknownText_0x9c87f: ; 0x9c87f
	db $0, "How are things?", $4f
	db "Land the big one?", $57
; 0x9c8a2

OlivineGoodRodHouse_MapEventHeader: ; 0x9c8a2
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 6, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $7, $3, 6, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $3b, 7, 6, $6, $0, 255, 255, $a0, 0, UnknownScript_0x9c71b, $ffff
; 0x9c8bf

OlivineCafe_MapScriptHeader: ; 0x9c8bf
	; trigger count
	db 0

	; callback count
	db 0
; 0x9c8c1

UnknownScript_0x9c8c1: ; 0x9c8c1
	faceplayer
	loadfont
	checkbit1 $0013
	iftrue UnknownScript_0x9c8d3
	2writetext UnknownText_0x9c8df
	keeptextopen
	verbosegiveitem HM_04, 1
	setbit1 $0013
UnknownScript_0x9c8d3: ; 0x9c8d3
	2writetext UnknownText_0x9c965
	closetext
	loadmovesprites
	end
; 0x9c8d9

UnknownScript_0x9c8d9: ; 0x9c8d9
	jumptextfaceplayer UnknownText_0x9c9c5
; 0x9c8dc

UnknownScript_0x9c8dc: ; 0x9c8dc
	jumptextfaceplayer UnknownText_0x9ca09
; 0x9c8df

UnknownText_0x9c8df: ; 0x9c8df
	db $0, "Hah! Your #MON", $4f
	db "sure look like", $55
	db "lightweights!", $51
	db "They don't have", $4f
	db "the power to move", $55
	db "boulders aside.", $51
	db "Here, use this", $4f
	db "and teach them", $55
	db "STRENGTH!", $57
; 0x9c965

UnknownText_0x9c965: ; 0x9c965
	db $0, "On the sea, the", $4f
	db "only thing you can", $51
	db "count on is your", $4f
	db "own good self!", $51
	db "I'm so proud of my", $4f
	db "buff bod!", $57
; 0x9c9c5

UnknownText_0x9c9c5: ; 0x9c9c5
	db $0, "OLIVINE CAFE's", $4f
	db "menu is chock full", $51
	db "of hearty fare for", $4f
	db "beefy SAILORS!", $57
; 0x9ca09

UnknownText_0x9ca09: ; 0x9ca09
	db $0, "Whenever I roll", $4f
	db "into this town, I", $51
	db "always visit the", $4f
	db "OLIVINE CAFE.", $51
	db "Everything on the", $4f
	db "menu makes me feel", $51
	db "stronger. I can't", $4f
	db "stop eating!", $57
; 0x9ca8e

OlivineCafe_MapEventHeader: ; 0x9ca8e
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 7, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $7, $3, 7, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $49, 7, 8, $8, $0, 255, 255, $0, 0, UnknownScript_0x9c8c1, $ffff
	person_event $3b, 7, 11, $4, $10, 255, 255, $0, 0, UnknownScript_0x9c8d9, $ffff
	person_event $49, 10, 10, $7, $0, 255, 255, $0, 0, UnknownScript_0x9c8dc, $ffff
; 0x9cac5

OlivineMart_MapScriptHeader: ; 0x9cac5
	; trigger count
	db 0

	; callback count
	db 0
; 0x9cac7

UnknownScript_0x9cac7: ; 0x9cac7
	loadfont
	pokemart $0, $000d
	loadmovesprites
	end
; 0x9cace

UnknownScript_0x9cace: ; 0x9cace
	jumptextfaceplayer UnknownText_0x9cad4
; 0x9cad1

UnknownScript_0x9cad1: ; 0x9cad1
	jumptextfaceplayer UnknownText_0x9cb16
; 0x9cad4

UnknownText_0x9cad4: ; 0x9cad4
	db $0, "Do your #MON", $4f
	db "already know the", $51
	db "move for carrying", $4f
	db "people on water?", $57
; 0x9cb16

UnknownText_0x9cb16: ; 0x9cb16
	db $0, "My BUTTERFREE came", $4f
	db "from my boyfriend", $55
	db "overseas.", $51
	db "It carried some", $4f
	db "MAIL from him.", $51
	db "Want to know what", $4f
	db "it says?", $51
	db "Let's see… Nope!", $4f
	db "It's a secret!", $57
; 0x9cb9e

OlivineMart_MapEventHeader: ; 0x9cb9e
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 8, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY
	warp_def $7, $3, 8, GROUP_OLIVINE_CITY, MAP_OLIVINE_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x9cac7, $ffff
	person_event $24, 6, 10, $5, $2, 255, 255, $a0, 0, UnknownScript_0x9cace, $ffff
	person_event $28, 10, 5, $8, $0, 255, 255, $0, 0, UnknownScript_0x9cad1, $ffff
; 0x9cbd5

Route38EcruteakGate_MapScriptHeader: ; 0x9cbd5
	; trigger count
	db 0

	; callback count
	db 0
; 0x9cbd7

UnknownScript_0x9cbd7: ; 0x9cbd7
	jumptextfaceplayer UnknownText_0x9cbda
; 0x9cbda

UnknownText_0x9cbda: ; 0x9cbda
	db $0, "Where did you say", $4f
	db "you're from?", $51
	db "NEW BARK TOWN?", $51
	db "PROF.ELM lives", $4f
	db "over there, right?", $51
	db "You've come a long", $4f
	db "way to get here.", $57
; 0x9cc4d

Route38EcruteakGate_MapEventHeader: ; 0x9cc4d
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 1, GROUP_ROUTE_38, MAP_ROUTE_38
	warp_def $5, $0, 2, GROUP_ROUTE_38, MAP_ROUTE_38
	warp_def $4, $9, 14, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $5, $9, 15, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 6, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x9cbd7, $ffff
; 0x9cc74

Route39Barn_MapScriptHeader: ; 0x9cc74
	; trigger count
	db 0

	; callback count
	db 0
; 0x9cc76

UnknownScript_0x9cc76: ; 0x9cc76
	faceplayer
	loadfont
	checkbit1 $003d
	iftrue UnknownScript_0x9cc87
	2writetext UnknownText_0x9cd2e
	closetext
	loadmovesprites
	spriteface $2, $3
	end
; 0x9cc87

UnknownScript_0x9cc87: ; 0x9cc87
	2writetext UnknownText_0x9cd5a
	closetext
	loadmovesprites
	spriteface $2, $3
	end
; 0x9cc90

UnknownScript_0x9cc90: ; 0x9cc90
	faceplayer
	loadfont
	checkbit1 $003d
	iftrue UnknownScript_0x9cca1
	2writetext UnknownText_0x9cd2e
	closetext
	loadmovesprites
	spriteface $3, $2
	end
; 0x9cca1

UnknownScript_0x9cca1: ; 0x9cca1
	2writetext UnknownText_0x9cd5a
	closetext
	loadmovesprites
	spriteface $3, $2
	end
; 0x9ccaa

UnknownScript_0x9ccaa: ; 0x9ccaa
	loadfont
	checkbit1 $003d
	iftrue UnknownScript_0x9cd25
	2writetext UnknownText_0x9cd70
	writebyte MILTANK
	special $005f
	keeptextopen
	2writetext UnknownText_0x9cd80
	checkbit1 $003f
	iftrue UnknownScript_0x9ccc6
	closetext
	loadmovesprites
	end
; 0x9ccc6

UnknownScript_0x9ccc6: ; 0x9ccc6
	keeptextopen
	2writetext UnknownText_0x9cda2
	yesorno
	iffalse UnknownScript_0x9cd1f
	checkitem BERRY
	iffalse UnknownScript_0x9cd19
	takeitem BERRY, 1
	copybytetovar MooMooBerries
	addvar $1
	copyvartobyte MooMooBerries
	if_equal $3, UnknownScript_0x9ccf0
	if_equal $5, UnknownScript_0x9ccfa
	if_equal $7, UnknownScript_0x9cd04
	2writetext UnknownText_0x9cdbc
	closetext
	loadmovesprites
	end
; 0x9ccf0

UnknownScript_0x9ccf0: ; 0x9ccf0
	2writetext UnknownText_0x9cdbc
	keeptextopen
	2writetext UnknownText_0x9cdd8
	closetext
	loadmovesprites
	end
; 0x9ccfa

UnknownScript_0x9ccfa: ; 0x9ccfa
	2writetext UnknownText_0x9cdbc
	keeptextopen
	2writetext UnknownText_0x9cdfc
	closetext
	loadmovesprites
	end
; 0x9cd04

UnknownScript_0x9cd04: ; 0x9cd04
	playmusic $000d
	2writetext UnknownText_0x9cdbc
	pause 60
	keeptextopen
	special $003d
	2writetext UnknownText_0x9ce1b
	closetext
	loadmovesprites
	setbit1 $003d
	end
; 0x9cd19

UnknownScript_0x9cd19: ; 0x9cd19
	2writetext UnknownText_0x9ce3c
	closetext
	loadmovesprites
	end
; 0x9cd1f

UnknownScript_0x9cd1f: ; 0x9cd1f
	2writetext UnknownText_0x9ce4f
	closetext
	loadmovesprites
	end
; 0x9cd25

UnknownScript_0x9cd25: ; 0x9cd25
	2writetext UnknownText_0x9cd92
	cry MILTANK
	closetext
	loadmovesprites
	end
; 0x9cd2e

UnknownText_0x9cd2e: ; 0x9cd2e
	db $0, "MOOMOO is sick…", $51
	db "She needs lots of", $4f
	db "BERRIES.", $57
; 0x9cd5a

UnknownText_0x9cd5a: ; 0x9cd5a
	db $0, "We're feeding", $4f
	db "MOOMOO!", $57
; 0x9cd70

UnknownText_0x9cd70: ; 0x9cd70
	db $0, "MILTANK: …Moo…", $57
; 0x9cd80

UnknownText_0x9cd80: ; 0x9cd80
	db $0, "Its cry is weak…", $57
; 0x9cd92

UnknownText_0x9cd92: ; 0x9cd92
	db $0, "MILTANK: Mooo!", $57
; 0x9cda2

UnknownText_0x9cda2: ; 0x9cda2
	db $0, "Give a BERRY to", $4f
	db "MILTANK?", $57
; 0x9cdbc

UnknownText_0x9cdbc: ; 0x9cdbc
	db $0, $52, " gave a", $4f
	db "BERRY to MILTANK.", $57
; 0x9cdd8

UnknownText_0x9cdd8: ; 0x9cdd8
	db $0, "MILTANK became a", $4f
	db "little healthier!", $57
; 0x9cdfc

UnknownText_0x9cdfc: ; 0x9cdfc
	db $0, "MILTANK became", $4f
	db "quite healthy!", $57
; 0x9ce1b

UnknownText_0x9ce1b: ; 0x9ce1b
	db $0, "MILTANK became", $4f
	db "totally healthy!", $57
; 0x9ce3c

UnknownText_0x9ce3c: ; 0x9ce3c
	db $0, $52, " has no", $4f
	db "BERRIES…", $57
; 0x9ce4f

UnknownText_0x9ce4f: ; 0x9ce4f
	db $0, $52, " wouldn't", $4f
	db "give a BERRY.", $51
	db "MILTANK looks sad.", $57
; 0x9ce7b

Route39Barn_MapEventHeader: ; 0x9ce7b
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $3, 1, GROUP_ROUTE_39, MAP_ROUTE_39
	warp_def $7, $4, 1, GROUP_ROUTE_39, MAP_ROUTE_39

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $26, 7, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x9cc76, $ffff
	person_event $26, 7, 8, $8, $0, 255, 255, $a0, 0, UnknownScript_0x9cc90, $ffff
	person_event $99, 7, 7, $16, $0, 255, 255, $0, 0, UnknownScript_0x9ccaa, $ffff
; 0x9ceb2

Route39Farmhouse_MapScriptHeader: ; 0x9ceb2
	; trigger count
	db 0

	; callback count
	db 0
; 0x9ceb4

UnknownScript_0x9ceb4: ; 0x9ceb4
	faceplayer
	loadfont
	checkbit1 $003d
	iftrue UnknownScript_0x9cec5
	2writetext UnknownText_0x9cf38
	closetext
	loadmovesprites
	setbit1 $003f
	end
; 0x9cec5

UnknownScript_0x9cec5: ; 0x9cec5
	checkitem MOOMOO_MILK
	iftrue UnknownScript_0x9cf08
	2writetext UnknownText_0x9cfe1
	special $0051
	yesorno
	iffalse UnknownScript_0x9cf02
	checkmoney $0, 500
	if_equal $2, UnknownScript_0x9cef6
	giveitem MOOMOO_MILK, $1
	iffalse UnknownScript_0x9cefc
	takemoney $0, 500
	special $0051
	waitbutton
	playsound $0022
	2writetext UnknownText_0x9d05d
	keeptextopen
	itemnotify
	loadmovesprites
	end
; 0x9cef6

UnknownScript_0x9cef6: ; 0x9cef6
	2writetext UnknownText_0x9d07c
	closetext
	loadmovesprites
	end
; 0x9cefc

UnknownScript_0x9cefc: ; 0x9cefc
	2writetext UnknownText_0x9d09d
	closetext
	loadmovesprites
	end
; 0x9cf02

UnknownScript_0x9cf02: ; 0x9cf02
	2writetext UnknownText_0x9d0b7
	closetext
	loadmovesprites
	end
; 0x9cf08

UnknownScript_0x9cf08: ; 0x9cf08
	2writetext UnknownText_0x9d0dc
	closetext
	loadmovesprites
	end
; 0x9cf0e

UnknownScript_0x9cf0e: ; 0x9cf0e
	faceplayer
	loadfont
	checkbit1 $003e
	iftrue UnknownScript_0x9cf2f
	checkbit1 $003d
	iftrue UnknownScript_0x9cf22
	2writetext UnknownText_0x9d0f6
	closetext
	loadmovesprites
	end
; 0x9cf22

UnknownScript_0x9cf22: ; 0x9cf22
	2writetext UnknownText_0x9d156
	keeptextopen
	verbosegiveitem TM_13, 1
	iffalse UnknownScript_0x9cf33
	setbit1 $003e
UnknownScript_0x9cf2f: ; 0x9cf2f
	2writetext UnknownText_0x9d1c7
	closetext
UnknownScript_0x9cf33: ; 0x9cf33
	loadmovesprites
	end
; 0x9cf35

MapRoute39FarmhouseSignpost1Script: ; 0x9cf35
	jumpstd $0002
; 0x9cf38

UnknownText_0x9cf38: ; 0x9cf38
	db $0, "My MILTANK ain't", $4f
	db "givin' me milk", $55
	db "n'more.", $51
	db "This here FARM's", $4f
	db "got famous milk.", $51
	db "Most everyone", $4f
	db "wants a drink.", $51
	db "It'll give me lots", $4f
	db "o' milk if'n I", $51
	db "feed it lots o'", $4f
	db "BERRIES, I reckon.", $57
; 0x9cfe1

UnknownText_0x9cfe1: ; 0x9cfe1
	db $0, "How'd you like my", $4f
	db "MOOMOO MILK?", $51
	db "It's my pride and", $4f
	db "joy, there.", $51
	db "Give it to #MON", $4f
	db "to restore HP!", $51
	db "I'll give it to ya", $4f
	db "fer just ¥500.", $57
; 0x9d05d

UnknownText_0x9d05d: ; 0x9d05d
	db $0, "Here ya go!", $4f
	db "Drink up'n enjoy!", $57
; 0x9d07c

UnknownText_0x9d07c: ; 0x9d07c
	db $0, "Sorry, there.", $4f
	db "No cash, no sale!", $57
; 0x9d09d

UnknownText_0x9d09d: ; 0x9d09d
	db $0, "I reckon yer", $4f
	db "PACK's full.", $57
; 0x9d0b7

UnknownText_0x9d0b7: ; 0x9d0b7
	db $0, "You don't want it?", $4f
	db "Come again, hear?", $57
; 0x9d0dc

UnknownText_0x9d0dc: ; 0x9d0dc
	db $0, "I best go do my", $4f
	db "milkin'.", $57
; 0x9d0f6

UnknownText_0x9d0f6: ; 0x9d0f6
	db $0, "Our milk even goes", $4f
	db "out to KANTO.", $51
	db "So if our own", $4f
	db "MILTANK won't give", $51
	db "us any milk, we're", $4f
	db "in trouble.", $57
; 0x9d156

UnknownText_0x9d156: ; 0x9d156
	db $0, "You fixed our", $4f
	db "MILTANK, hon. Now", $51
	db "it gives MOOMOO", $4f
	db "MILK again.", $51
	db "Here's somethin'", $4f
	db "fer your trouble.", $57
; 0x9d1b5

UnknownText_0x9d1b5: ; 0x9d1b5
	db $0, $52, " received", $4f
	db "TM13.", $57
; 0x9d1c7

UnknownText_0x9d1c7: ; 0x9d1c7
	db $0, "That there's", $4f
	db "SNORE.", $51
	db "It's a rare move", $4f
	db "that only works", $51
	db "while the #MON", $4f
	db "is asleep.", $51
	db "You best think how", $4f
	db "you ought to use", $55
	db "it, hon.", $57
; 0x9d242

Route39Farmhouse_MapEventHeader: ; 0x9d242
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_ROUTE_39, MAP_ROUTE_39
	warp_def $7, $3, 2, GROUP_ROUTE_39, MAP_ROUTE_39

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapRoute39FarmhouseSignpost1Script
	signpost 1, 1, $0, MapRoute39FarmhouseSignpost1Script

	; people-events
	db 2
	person_event $2d, 6, 7, $6, $0, 255, 255, $90, 0, UnknownScript_0x9ceb4, $ffff
	person_event $2e, 8, 9, $8, $0, 255, 255, $b0, 0, UnknownScript_0x9cf0e, $ffff
; 0x9d276

ManiasHouse_MapScriptHeader: ; 0x9d276
	; trigger count
	db 0

	; callback count
	db 0
; 0x9d278

UnknownScript_0x9d278: ; 0x9d278
	faceplayer
	loadfont
	checkbit1 $0046
	iftrue UnknownScript_0x9d2fa
	checkbit1 $0045
	iftrue UnknownScript_0x9d2a4
	2writetext UnknownText_0x9d303
	yesorno
	iffalse UnknownScript_0x9d2b6
	special $004b
	iffalse UnknownScript_0x9d2b0
	2writetext UnknownText_0x9d3ed
	keeptextopen
	waitbutton
	2writetext UnknownText_0x9d41b
	playsound $0091
	waitbutton
	loadmovesprites
	setbit1 $0045
	end
; 0x9d2a4

UnknownScript_0x9d2a4: ; 0x9d2a4
	checkbit2 $0055
	iffalse UnknownScript_0x9d2bc
	2writetext UnknownText_0x9d3ed
	closetext
	loadmovesprites
	end
; 0x9d2b0

UnknownScript_0x9d2b0: ; 0x9d2b0
	2writetext UnknownText_0x9d42f
	closetext
	loadmovesprites
	end
; 0x9d2b6

UnknownScript_0x9d2b6: ; 0x9d2b6
	2writetext UnknownText_0x9d449
	closetext
	loadmovesprites
	end
; 0x9d2bc

UnknownScript_0x9d2bc: ; 0x9d2bc
	2writetext UnknownText_0x9d470
	yesorno
	iffalse UnknownScript_0x9d2ee
	special $004c
	if_equal $0, UnknownScript_0x9d2df
	if_equal $1, UnknownScript_0x9d2ee
	if_equal $3, UnknownScript_0x9d2e5
	if_equal $4, UnknownScript_0x9d2fa
	2writetext UnknownText_0x9d4b1
	closetext
	loadmovesprites
	setbit1 $0046
	end
; 0x9d2df

UnknownScript_0x9d2df: ; 0x9d2df
	2writetext UnknownText_0x9d4bd
	closetext
	loadmovesprites
	end
; 0x9d2e5

UnknownScript_0x9d2e5: ; 0x9d2e5
	2writetext UnknownText_0x9d4e3
	closetext
	loadmovesprites
	setbit1 $0046
	end
; 0x9d2ee

UnknownScript_0x9d2ee: ; 0x9d2ee
	2writetext UnknownText_0x9d53f
	closetext
	loadmovesprites
	end
; 0x9d2f4

UnknownScript_0x9d2f4: ; 0x9d2f4
	2writetext UnknownText_0x9d5b0
	closetext
	loadmovesprites
	end
; 0x9d2fa

UnknownScript_0x9d2fa: ; 0x9d2fa
	2writetext UnknownText_0x9d56c
	closetext
	loadmovesprites
	end
; 0x9d300

UnknownScript_0x9d300: ; 0x9d300
	jumpstd $0002
; 0x9d303

UnknownText_0x9d303: ; 0x9d303
	db $0, "I, I'm in shock!", $51
	db "A guy about your", $4f
	db "age with piercing", $51
	db "eyes and long hair", $4f
	db "came in.", $51
	db "He scared me into", $4f
	db "giving him my", $55
	db "prized #MON!", $51
	db "I still have one", $4f
	db "left, but what if", $55
	db "he comes back?", $51
	db "You look strong.", $4f
	db "Could you look", $51
	db "after my #MON", $4f
	db "for a while?", $57
; 0x9d3ed

UnknownText_0x9d3ed: ; 0x9d3ed
	db $0, "Oh, thank you!", $51
	db "Take good care of", $4f
	db "it, please!", $57
; 0x9d41b

UnknownText_0x9d41b: ; 0x9d41b
	db $0, $52, " received a", $4f
	db "#MON.", $57
; 0x9d42f

UnknownText_0x9d42f: ; 0x9d42f
	db $0, "Your #MON party", $4f
	db "is full.", $57
; 0x9d449

UnknownText_0x9d449: ; 0x9d449
	db $0, "Oh, no… What'll", $4f
	db "I do if he comes", $55
	db "back?", $57
; 0x9d470

UnknownText_0x9d470: ; 0x9d470
	db $0, "Hi! How's my #-", $4f
	db "MON?", $51
	db "I think I'm safe", $4f
	db "now, so may I have", $55
	db "it back?", $57
; 0x9d4b1

UnknownText_0x9d4b1: ; 0x9d4b1
	db $0, "Thank you!", $57
; 0x9d4bd

UnknownText_0x9d4bd: ; 0x9d4bd
	db $0, "Hey, you don't", $4f
	db "have my #MON", $55
	db "with you.", $57
; 0x9d4e3

UnknownText_0x9d4e3: ; 0x9d4e3
	db $0, "My #MON has", $4f
	db "come to like you.", $51
	db "All right, you", $4f
	db "should keep it.", $51
	db "But promise to", $4f
	db "be good to it!", $57
; 0x9d53f

UnknownText_0x9d53f: ; 0x9d53f
	db $0, "Oh, no, no… That's", $4f
	db "the same as being", $55
	db "robbed.", $57
; 0x9d56c

UnknownText_0x9d56c: ; 0x9d56c
	db $0, "For #MON, hap-", $4f
	db "piness is being", $51
	db "with a person who", $4f
	db "treats them well.", $57
; 0x9d5b0

UnknownText_0x9d5b0: ; 0x9d5b0
	db $0, "If I take my #-", $4f
	db "MON back, what are", $51
	db "you going to use", $4f
	db "in battle?", $57
; 0x9d5f0

ManiasHouse_MapEventHeader: ; 0x9d5f0
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY
	warp_def $7, $3, 1, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $2c, 8, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x9d278, $ffff
; 0x9d60d

CianwoodGym_MapScriptHeader: ; 0x9d60d
	; trigger count
	db 0

	; callback count
	db 0
; 0x9d60f

UnknownScript_0x9d60f: ; 0x9d60f
	faceplayer
	loadfont
	checkbit1 $04c2
	iftrue UnknownScript_0x9d656
	2writetext UnknownText_0x9d6f9
	closetext
	loadmovesprites
	spriteface $2, $3
	loadfont
	2writetext UnknownText_0x9d76f
	closetext
	loadmovesprites
	applymovement $7, MovementData_0x9d6f3
	playsound $001b
	earthquake 80
	disappear $7
	pause 30
	faceplayer
	loadfont
	2writetext UnknownText_0x9d78a
	closetext
	loadmovesprites
	winlosstext UnknownText_0x9d7f6, $0000
	loadtrainer CHUCK, 1
	startbattle
	returnafterbattle
	setbit1 $04c2
	loadfont
	2writetext UnknownText_0x9d835
	playsound $009c
	waitbutton
	setbit2 $0020
	checkcode $7
	2call UnknownScript_0x9d681
UnknownScript_0x9d656: ; 0x9d656
	checkbit1 $000a
	iftrue UnknownScript_0x9d67b
	setbit1 $04a5
	setbit1 $04a7
	setbit1 $04a8
	setbit1 $04aa
	2writetext UnknownText_0x9d84d
	keeptextopen
	verbosegiveitem TM_01, 1
	iffalse UnknownScript_0x9d67f
	setbit1 $000a
	2writetext UnknownText_0x9d8da
	closetext
	loadmovesprites
	end
; 0x9d67b

UnknownScript_0x9d67b: ; 0x9d67b
	2writetext UnknownText_0x9d930
	closetext
UnknownScript_0x9d67f: ; 0x9d67f
	loadmovesprites
	end
; 0x9d681

UnknownScript_0x9d681: ; 0x9d681
	if_equal $7, UnknownScript_0x9d68d
	if_equal $6, UnknownScript_0x9d68a
	end
; 0x9d68a

UnknownScript_0x9d68a: ; 0x9d68a
	jumpstd $0012
; 0x9d68d

UnknownScript_0x9d68d: ; 0x9d68d
	jumpstd $0013
; 0x9d690

TrainerBlackbeltYoshi: ; 0x9d690
	; bit/flag number
	dw $4a5

	; trainer group && trainer id
	db BLACKBELT_T, YOSHI

	; text when seen
	dw BlackbeltYoshiSeenText

	; text when trainer beaten
	dw BlackbeltYoshiBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BlackbeltYoshiScript
; 0x9d69c

BlackbeltYoshiScript: ; 0x9d69c
	talkaftercancel
	loadfont
	2writetext UnknownText_0x9d9fa
	closetext
	loadmovesprites
	end
; 0x9d6a4

TrainerBlackbeltLao: ; 0x9d6a4
	; bit/flag number
	dw $4a7

	; trainer group && trainer id
	db BLACKBELT_T, LAO

	; text when seen
	dw BlackbeltLaoSeenText

	; text when trainer beaten
	dw BlackbeltLaoBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BlackbeltLaoScript
; 0x9d6b0

BlackbeltLaoScript: ; 0x9d6b0
	talkaftercancel
	loadfont
	2writetext UnknownText_0x9da61
	closetext
	loadmovesprites
	end
; 0x9d6b8

TrainerBlackbeltNob: ; 0x9d6b8
	; bit/flag number
	dw $4a8

	; trainer group && trainer id
	db BLACKBELT_T, NOB

	; text when seen
	dw BlackbeltNobSeenText

	; text when trainer beaten
	dw BlackbeltNobBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BlackbeltNobScript
; 0x9d6c4

BlackbeltNobScript: ; 0x9d6c4
	talkaftercancel
	loadfont
	2writetext UnknownText_0x9dac0
	closetext
	loadmovesprites
	end
; 0x9d6cc

TrainerBlackbeltLung: ; 0x9d6cc
	; bit/flag number
	dw $4aa

	; trainer group && trainer id
	db BLACKBELT_T, LUNG

	; text when seen
	dw BlackbeltLungSeenText

	; text when trainer beaten
	dw BlackbeltLungBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BlackbeltLungScript
; 0x9d6d8

BlackbeltLungScript: ; 0x9d6d8
	talkaftercancel
	loadfont
	2writetext UnknownText_0x9db14
	closetext
	loadmovesprites
	end
; 0x9d6e0

UnknownScript_0x9d6e0: ; 0x9d6e0
	jumpstd $000e
; 0x9d6e3

MapCianwoodGymSignpost1Script: ; 0x9d6e3
	checkbit2 $0020
	iftrue UnknownScript_0x9d6ec
	jumpstd $002d
; 0x9d6ec

UnknownScript_0x9d6ec: ; 0x9d6ec
	trainertotext CHUCK, 1, $1
	jumpstd $002e
; 0x9d6f3

MovementData_0x9d6f3: ; 0x9d6f3
	db $39 ; movement
	big_step_left
	big_step_up
	fast_jump_step_right
	db $38 ; movement
	step_end
; 0x9d6f9

UnknownText_0x9d6f9: ; 0x9d6f9
	db $0, "WAHAHAH!", $51
	db "So you've come", $4f
	db "this far!", $51
	db "Let me tell you,", $4f
	db "I'm tough!", $51
	db "My #MON will", $4f
	db "crush stones and", $55
	db "shatter bones!", $51
	db "Watch this!", $57
; 0x9d76f

UnknownText_0x9d76f: ; 0x9d76f
	db $0, "CHUCK: Urggh!", $4f
	db "…", $51
	db "Oooarrgh!", $57
; 0x9d78a

UnknownText_0x9d78a: ; 0x9d78a
	db $0, "There! Scared now,", $4f
	db "are you?", $51
	db "What?", $4f
	db "It has nothing to", $51
	db "do with #MON?", $4f
	db "That's true!", $51
	db "Come on. We shall", $4f
	db "do battle!", $57
; 0x9d7f6

UnknownText_0x9d7f6: ; 0x9d7f6
	db $0, "Wha? Huh?", $4f
	db "I lost?", $51
	db "How about that!", $4f
	db "You're worthy of", $55
	db "STORMBADGE!", $57
; 0x9d835

UnknownText_0x9d835: ; 0x9d835
	db $0, $52, " received", $4f
	db "STORMBADGE.", $57
; 0x9d84d

UnknownText_0x9d84d: ; 0x9d84d
	db $0, "STORMBADGE makes", $4f
	db "all #MON up to", $51
	db "L70 obey, even", $4f
	db "traded ones.", $51
	db "It also lets your", $4f
	db "#MON use FLY", $51
	db "when you're not in", $4f
	db "a battle.", $51
	db "Here, take this", $4f
	db "too!", $57
; 0x9d8da

UnknownText_0x9d8da: ; 0x9d8da
	db $0, "That is DYNAMIC-", $4f
	db "PUNCH.", $51
	db "It doesn't always", $4f
	db "hit, but when it", $51
	db "does, it causes", $4f
	db "confusion!", $57
; 0x9d930

UnknownText_0x9d930: ; 0x9d930
	db $0, "WAHAHAH! I enjoyed", $4f
	db "battling you!", $51
	db "But a loss is a", $4f
	db "loss!", $51
	db "From now on, I'm", $4f
	db "going to train 24", $55
	db "hours a day!", $57
; 0x9d997

BlackbeltYoshiSeenText: ; 0x9d997
	db $0, "My #MON and I", $4f
	db "are bound togeth-", $55
	db "er by friendship.", $51
	db "Our bond will", $4f
	db "never be broken!", $57
; 0x9d9e9

BlackbeltYoshiBeatenText: ; 0x9d9e9
	db $0, "This isn't real!", $57
; 0x9d9fa

UnknownText_0x9d9fa: ; 0x9d9fa
	db $0, "You seem to have a", $4f
	db "strong bond with", $55
	db "your #MON too!", $57
; 0x9da2e

BlackbeltLaoSeenText: ; 0x9da2e
	db $0, "We martial artists", $4f
	db "fear nothing!", $57
; 0x9da50

BlackbeltLaoBeatenText: ; 0x9da50
	db $0, "That's shocking!", $57
; 0x9da61

UnknownText_0x9da61: ; 0x9da61
	db $0, "Fighting #MON", $4f
	db "are afraid of psy-", $55
	db "chics…", $57
; 0x9da8a

BlackbeltNobSeenText: ; 0x9da8a
	db $0, "Words are useless.", $4f
	db "Let your fists do", $55
	db "the talking!", $57
; 0x9dabd

BlackbeltNobBeatenText: ; 0x9dabd
	db $0, "…", $57
; 0x9dac0

UnknownText_0x9dac0: ; 0x9dac0
	db $0, "I lost! ", $4f
	db "I'm speechless!", $57
; 0x9dad9

BlackbeltLungSeenText: ; 0x9dad9
	db $0, "My raging fists", $4f
	db "will shatter your", $55
	db "#MON!", $57
; 0x9db02

BlackbeltLungBeatenText: ; 0x9db02
	db $0, "I got shattered!", $57
; 0x9db14

UnknownText_0x9db14: ; 0x9db14
	db $0, "My #MON lost…", $4f
	db "My… my pride is", $55
	db "shattered…", $57
; 0x9db3e

CianwoodGym_MapEventHeader: ; 0x9db3e
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $11, $4, 2, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY
	warp_def $11, $5, 2, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 15, 3, $0, MapCianwoodGymSignpost1Script
	signpost 15, 6, $0, MapCianwoodGymSignpost1Script

	; people-events
	db 9
	person_event $16, 5, 8, $6, $0, 255, 255, $b0, 0, UnknownScript_0x9d60f, $ffff
	person_event $41, 16, 6, $9, $0, 255, 255, $b2, 3, TrainerBlackbeltYoshi, $ffff
	person_event $41, 16, 11, $8, $0, 255, 255, $b2, 3, TrainerBlackbeltLao, $ffff
	person_event $41, 13, 7, $9, $0, 255, 255, $b2, 2, TrainerBlackbeltNob, $ffff
	person_event $41, 9, 9, $8, $0, 255, 255, $b2, 1, TrainerBlackbeltLung, $ffff
	person_event $5a, 5, 9, $19, $0, 255, 255, $0, 0, UnknownScript_0x9d6e0, $ffff
	person_event $5a, 11, 7, $19, $0, 255, 255, $0, 0, UnknownScript_0x9d6e0, $ffff
	person_event $5a, 11, 8, $19, $0, 255, 255, $0, 0, UnknownScript_0x9d6e0, $ffff
	person_event $5a, 11, 9, $19, $0, 255, 255, $0, 0, UnknownScript_0x9d6e0, $ffff
; 0x9dbcd

CianwoodPokeCenter1F_MapScriptHeader: ; 0x9dbcd
	; trigger count
	db 0

	; callback count
	db 0
; 0x9dbcf

UnknownScript_0x9dbcf: ; 0x9dbcf
	jumpstd $0000
; 0x9dbd2

UnknownScript_0x9dbd2: ; 0x9dbd2
	jumptextfaceplayer UnknownText_0x9dbed
; 0x9dbd5

CianwoodGymGuyScript: ; 0x9dbd5
	faceplayer
	checkbit1 $04c2
	iftrue .CianwoodGymGuyWinScript
	loadfont
	2writetext CianwoodGymGuyText
	closetext
	loadmovesprites
	end

.CianwoodGymGuyWinScript
	loadfont
	2writetext CianwoodGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x9dbea

UnknownScript_0x9dbea: ; 0x9dbea
	jumptextfaceplayer UnknownText_0x9ded7
; 0x9dbed

UnknownText_0x9dbed: ; 0x9dbed
	db $0, "Did you meet the", $4f
	db "#MANIAC?", $51
	db "He's always brag-", $4f
	db "ging about his", $55
	db "rare #MON.", $57
; 0x9dc33

CianwoodGymGuyText: ; 0x9dc33
	db $0, "The #MON GYM", $4f
	db "trainers here are", $55
	db "macho bullies.", $51
	db "If I stick around,", $4f
	db "they might come", $55
	db "after me.", $51
	db "Here's some ad-", $4f
	db "vice: the GYM", $51
	db "LEADER uses the", $4f
	db "fighting-type.", $51
	db "So you should", $4f
	db "confound him with", $55
	db "psychic #MON.", $51
	db "Wipe out his #-", $4f
	db "MON before they", $51
	db "can use their", $4f
	db "physical strength.", $51
	db "And those boulders", $4f
	db "in the middle of", $55
	db "the GYM?", $51
	db "If you don't move", $4f
	db "them correctly,", $51
	db "you won't reach", $4f
	db "the GYM LEADER.", $51
	db "If you get stuck,", $4f
	db "go outside.", $57
; 0x9ddc5

CianwoodGymGuyWinText: ; 0x9ddc5
	db $0, $52, "! You won!", $4f
	db "I could tell by", $55
	db "looking at you!", $57
; 0x9ddf2

UnknownText_0x9ddf2: ; 0x9ddf2
	db $0, "Don't you get the", $4f
	db "urge to show off", $51
	db "your #MON to", $4f
	db "friends?", $51
	db "I wish I could", $4f
	db "show the #MON I", $51
	db "raised to my pal", $4f
	db "in VIOLET.", $57
; 0x9de66

UnknownText_0x9de66: ; 0x9de66
	db $0, "I've been battling", $4f
	db "my pal in VIOLET", $51
	db "using a MOBILE", $4f
	db "ADAPTER link.", $51
	db "I'm down 5-7", $4f
	db "against him. I've", $55
	db "gotta crank it up!", $57
; 0x9ded7

UnknownText_0x9ded7: ; 0x9ded7
	db $0, "I love showing off", $4f
	db "the #MON that", $51
	db "I've raised.", $4f
	db "Don't you?", $51
	db "I'm going to get", $4f
	db "into a bunch of", $51
	db "battles, and show", $4f
	db "off my #MON!", $57
; 0x9df4e

CianwoodPokeCenter1F_MapEventHeader: ; 0x9df4e
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 3, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY
	warp_def $7, $4, 3, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x9dbcf, $ffff
	person_event $28, 9, 5, $4, $10, 255, 255, $a0, 0, UnknownScript_0x9dbd2, $ffff
	person_event $48, 7, 9, $6, $0, 255, 255, $80, 0, CianwoodGymGuyScript, $ffff
	person_event $2b, 10, 12, $5, $1, 255, 255, $90, 0, UnknownScript_0x9dbea, $ffff
; 0x9df97

CianwoodPharmacy_MapScriptHeader: ; 0x9df97
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x9df9d, $0000

	; callback count
	db 0
; 0x9df9d

UnknownScript_0x9df9d: ; 0x9df9d
	end
; 0x9df9e

UnknownScript_0x9df9e: ; 0x9df9e
	faceplayer
	loadfont
	checkbit1 $0023
	iftrue UnknownScript_0x9dfc4
	checkbit1 $0037
	iffalse UnknownScript_0x9dfc4
	2writetext UnknownText_0x9dfcd
	keeptextopen
	giveitem SECRETPOTION, $1
	2writetext UnknownText_0x9e056
	playsound $0091
	waitbutton
	itemnotify
	setbit1 $0023
	2writetext UnknownText_0x9e070
	closetext
	loadmovesprites
	end
; 0x9dfc4

UnknownScript_0x9dfc4: ; 0x9dfc4
	pokemart $3, $0004
	loadmovesprites
	end
; 0x9dfca

MapCianwoodPharmacySignpost1Script: ; 0x9dfca
	jumpstd $0001
; 0x9dfcd

UnknownText_0x9dfcd: ; 0x9dfcd
	db $0, "Your #MON ap-", $4f
	db "pear to be fine.", $51
	db "Is something wor- ", $4f
	db "rying you?", $51
	db "…", $51
	db "The LIGHTHOUSE", $4f
	db "#MON is in", $55
	db "trouble?", $51
	db "I got it!", $51
	db "This ought to do", $4f
	db "the trick.", $57
; 0x9e056

UnknownText_0x9e056: ; 0x9e056
	db $0, $52, " received", $4f
	db "SECRETPOTION.", $57
; 0x9e070

UnknownText_0x9e070: ; 0x9e070
	db $0, "My SECRETPOTION is", $4f
	db "a tad too strong.", $51
	db "I only offer it in", $4f
	db "an emergency.", $57
; 0x9e0b7

CianwoodPharmacy_MapEventHeader: ; 0x9e0b7
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY
	warp_def $7, $3, 4, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapCianwoodPharmacySignpost1Script
	signpost 1, 1, $0, MapCianwoodPharmacySignpost1Script

	; people-events
	db 1
	person_event $4b, 7, 6, $6, $0, 255, 255, $80, 0, UnknownScript_0x9df9e, $ffff
; 0x9e0de

CianwoodCityPhotoStudio_MapScriptHeader: ; 0x9e0de
	; trigger count
	db 0

	; callback count
	db 0
; 0x9e0e0

UnknownScript_0x9e0e0: ; 0x9e0e0
	faceplayer
	loadfont
	2writetext UnknownText_0x9e0f9
	yesorno
	iffalse UnknownScript_0x9e0f3
	2writetext UnknownText_0x9e142
	closetext
	special $0068
	closetext
	loadmovesprites
	end
; 0x9e0f3

UnknownScript_0x9e0f3: ; 0x9e0f3
	2writetext UnknownText_0x9e156
	closetext
	loadmovesprites
	end
; 0x9e0f9

UnknownText_0x9e0f9: ; 0x9e0f9
	db $0, "You have magnifi-", $4f
	db "cent #MON with", $55
	db "you.", $51
	db "How about a photo", $4f
	db "for a souvenir?", $57
; 0x9e142

UnknownText_0x9e142: ; 0x9e142
	db $0, "OK! Big smile now!", $57
; 0x9e156

UnknownText_0x9e156: ; 0x9e156
	db $0, "Oh, that's too", $4f
	db "bad. I thought it", $51
	db "would be a great", $4f
	db "memento…", $57
; 0x9e191

CianwoodCityPhotoStudio_MapEventHeader: ; 0x9e191
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 5, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY
	warp_def $7, $3, 5, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $3b, 7, 6, $6, $0, 255, 255, $80, 0, UnknownScript_0x9e0e0, $ffff
; 0x9e1ae

CianwoodLugiaSpeechHouse_MapScriptHeader: ; 0x9e1ae
	; trigger count
	db 0

	; callback count
	db 0
; 0x9e1b0

UnknownScript_0x9e1b0: ; 0x9e1b0
	jumptextfaceplayer UnknownText_0x9e1bc
; 0x9e1b3

UnknownScript_0x9e1b3: ; 0x9e1b3
	jumptextfaceplayer UnknownText_0x9e23f
; 0x9e1b6

UnknownScript_0x9e1b6: ; 0x9e1b6
	jumptextfaceplayer UnknownText_0x9e2a9
; 0x9e1b9

MapCianwoodLugiaSpeechHouseSignpost1Script: ; 0x9e1b9
	jumpstd $0002
; 0x9e1bc

UnknownText_0x9e1bc: ; 0x9e1bc
	db $0, "You came from", $4f
	db "OLIVINE?", $51
	db "Do you remember", $4f
	db "the four islands", $55
	db "along the way?", $51
	db "I heard that a ", $4f
	db "mythical sea crea-", $55
	db "ture is hiding in", $55
	db "them.", $57
; 0x9e23f

UnknownText_0x9e23f: ; 0x9e23f
	db $0, "I heard that you", $4f
	db "can only see it if", $51
	db "you have a SILVER", $4f
	db "WING.", $51
	db "It must have the", $4f
	db "same scent as the", $55
	db "creature.", $57
; 0x9e2a9

UnknownText_0x9e2a9: ; 0x9e2a9
	db $0, "I've heard that", $4f
	db "the whirlpools", $51
	db "around the islands", $4f
	db "are caused by the", $55
	db "sea creature.", $51
	db "You might need a", $4f
	db "special move to", $55
	db "get past them.", $57
; 0x9e32b

CianwoodLugiaSpeechHouse_MapEventHeader: ; 0x9e32b
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 6, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY
	warp_def $7, $3, 6, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapCianwoodLugiaSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapCianwoodLugiaSpeechHouseSignpost1Script

	; people-events
	db 3
	person_event $29, 8, 6, $6, $0, 255, 255, $0, 0, UnknownScript_0x9e1b0, $ffff
	person_event $28, 9, 10, $5, $1, 255, 255, $a0, 0, UnknownScript_0x9e1b3, $ffff
	person_event $26, 6, 4, $7, $0, 255, 255, $90, 0, UnknownScript_0x9e1b6, $ffff
; 0x9e36c

PokeSeersHouse_MapScriptHeader: ; 0x9e36c
	; trigger count
	db 0

	; callback count
	db 0
; 0x9e36e

UnknownScript_0x9e36e: ; 0x9e36e
	faceplayer
	loadfont
	special $0091
	closetext
	loadmovesprites
	end
; 0x9e376

PokeSeersHouse_MapEventHeader: ; 0x9e376
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 7, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY
	warp_def $7, $3, 7, GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $30, 7, 6, $6, $0, 255, 255, $80, 0, UnknownScript_0x9e36e, $ffff
; 0x9e393

BattleTower1F_MapScriptHeader: ; 0x9e393
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x9e39d, $0000
	dw $63d3, $0000

	; callback count
	db 0
; 0x9e39d

UnknownScript_0x9e39d: ; 0x9e39d
	writebyte $9
	special $0086
	iffalse UnknownScript_0x9e3d1
	writebyte $2
	special $0086
	if_equal $0, UnknownScript_0x9e3d1
	if_equal $2, UnknownScript_0x9e3c4
	if_equal $3, UnknownScript_0x9e3d1
	if_equal $4, UnknownScript_0x9e3d1
	loadfont
	2writetext UnknownText_0x9f037
	closetext
	loadmovesprites
	priorityjump UnknownScript_0x9e44e
	end
; 0x9e3c4

UnknownScript_0x9e3c4: ; 0x9e3c4
	priorityjump UnknownScript_0x9e555
; 0x9e3c7

UnknownScript_0x9e3c7: ; 0x9e3c7
	writebyte $4
	special $0086
	writebyte $6
	special $0086
UnknownScript_0x9e3d1: ; 0x9e3d1
	dotrigger $1
	end
; 0x9e3d4

MapBattleTower1FSignpost0Script: ; 0x9e3d4
	loadfont
	2writetext UnknownText_0x9ed3c
	yesorno
	iffalse UnknownScript_0x9e3e0
	2writetext UnknownText_0x9ed72
	closetext
UnknownScript_0x9e3e0: ; 0x9e3e0
	loadmovesprites
	end
; 0x9e3e2

UnknownScript_0x9e3e2: ; 0x9e3e2
	writebyte $2
	special $0086
	if_equal $3, $74e4 ; wtf ?
	loadfont
	2writetext UnknownText_0x9e5ab
	keeptextopen
	writebyte $0
	special $0086
	if_not_equal $0, UnknownScript_0x9e3fc
	2jump UnknownScript_0x9e49e
; 0x9e3fc

UnknownScript_0x9e3fc: ; 0x9e3fc
	2writetext UnknownText_0x9e5ea
	writebyte $1
	special $0088
	if_equal $1, UnknownScript_0x9e40f
	if_equal $2, UnknownScript_0x9e4a5
	2jump UnknownScript_0x9e4b0
; 0x9e40f

UnknownScript_0x9e40f: ; 0x9e40f
	writebyte $1a
	special $0086
	special $007c
	if_not_equal $0, UnknownScript_0x9e4bb
	2writetext UnknownText_0x9ef1f
	yesorno
	iffalse UnknownScript_0x9e3fc
	dotrigger $0
	special $0004
	iffalse UnknownScript_0x9e3fc
	dotrigger $1
	writebyte $1
	special $0086
	special $0074
	if_equal $a, UnknownScript_0x9e3fc
	if_not_equal $0, UnknownScript_0x9e550
	writebyte $11
	special $0086
	2writetext UnknownText_0x9e60a
	closetext
	loadmovesprites
	writebyte $1e
	special $0086
	2jump UnknownScript_0x9e454
; 0x9e44e

UnknownScript_0x9e44e: ; 0x9e44e
	loadmovesprites
	writebyte $8
	special $0086
UnknownScript_0x9e454: ; 0x9e454
	musicfadeout $0000, $8
	domaptrigger GROUP_BATTLE_TOWER_BATTLE_ROOM, MAP_BATTLE_TOWER_BATTLE_ROOM, $0
	domaptrigger GROUP_BATTLE_TOWER_ELEVATOR, MAP_BATTLE_TOWER_ELEVATOR, $0
	domaptrigger GROUP_BATTLE_TOWER_HALLWAY, MAP_BATTLE_TOWER_HALLWAY, $0
	follow $2, $0
	applymovement $2, MovementData_0x9e571
	writebyte $a
	special $0086
	warpsound
	disappear $2
	stopfollow
	applymovement $0, $6576
	warpcheck
	end
; 0x9e47a

UnknownScript_0x9e47a: ; 0x9e47a
	writebyte $1c
	special $0086
	writebyte $1b
	special $0086
	if_equal $12, UnknownScript_0x9e498
	itemtotext $0, $1
	giveitem $ff, $5
	2writetext UnknownText_0x9eb7e
	writebyte $1d
	special $0086
	loadmovesprites
	end
; 0x9e498

UnknownScript_0x9e498: ; 0x9e498
	2writetext UnknownText_0x9eb94
	closetext
	loadmovesprites
	end
; 0x9e49e

UnknownScript_0x9e49e: ; 0x9e49e
	2writetext UnknownText_0x9ec3d
	yesorno
	iffalse UnknownScript_0x9e4a8
UnknownScript_0x9e4a5: ; 0x9e4a5
	2writetext UnknownText_0x9e886
UnknownScript_0x9e4a8: ; 0x9e4a8
	writebyte $1
	special $0086
	2jump UnknownScript_0x9e3fc
; 0x9e4b0

UnknownScript_0x9e4b0: ; 0x9e4b0
	2writetext UnknownText_0x9ec09
	closetext
	loadmovesprites
	end
; 0x9e4b6

UnknownScript_0x9e4b6: ; 0x9e4b6
	special $008b
	loadmovesprites
	end
; 0x9e4bb

UnknownScript_0x9e4bb: ; 0x9e4bb
	closetext
	loadmovesprites
	end
; 0x9e4be

INCBIN "baserom.gbc",$9e4be,$9e4e4 - $9e4be

UnknownScript_0x9e4e4: ; 0x9e4e4
	closetext
	spriteface $2, $0
	loadmovesprites
	end
; 0x9e4ea

UnknownScript_0x9e4ea: ; 0x9e4ea
	writebyte $18
	special $0086
	if_not_equal $0, UnknownScript_0x9e542
	writebyte $19
	special $0086
	if_not_equal $0, UnknownScript_0x9e549
	special $007c
	if_not_equal $0, UnknownScript_0x9e4bb
	writebyte $5
	special $0086
	if_equal $0, UnknownScript_0x9e512
	2writetext UnknownText_0x9ecb0
	2jump UnknownScript_0x9e515
; 0x9e512

UnknownScript_0x9e512: ; 0x9e512
	2writetext UnknownText_0x9ec6d
UnknownScript_0x9e515: ; 0x9e515
	yesorno
	iffalse UnknownScript_0x9e3fc
	2writetext UnknownText_0x9ef79
	yesorno
	iffalse UnknownScript_0x9e3fc
	dotrigger $0
	special $0004
	iffalse UnknownScript_0x9e3fc
	dotrigger $1
	writebyte $6
	special $0086
	writebyte $12
	special $0086
	2writetext UnknownText_0x9e60a
	closetext
	2jump UnknownScript_0x9e44e
; 0x9e53b

UnknownScript_0x9e53b: ; 0x9e53b
	2writetext UnknownText_0x9f076
	closetext
	2jump UnknownScript_0x9e4b0
; 0x9e542

UnknownScript_0x9e542: ; 0x9e542
	2writetext UnknownText_0x9f1e5
	closetext
	2jump UnknownScript_0x9e3fc
; 0x9e549

UnknownScript_0x9e549: ; 0x9e549
	2writetext UnknownText_0x9f217
	closetext
	2jump UnknownScript_0x9e3fc
; 0x9e550

UnknownScript_0x9e550: ; 0x9e550
	special $008b
	loadmovesprites
	end
; 0x9e555

UnknownScript_0x9e555: ; 0x9e555
	loadfont
	2writetext UnknownText_0x9ee18
	closetext
	2jump UnknownScript_0x9e4b0
; 0x9e55d

UnknownScript_0x9e55d: ; 0x9e55d
	faceplayer
	loadfont
	2writetext UnknownText_0x9f264
	closetext
	loadmovesprites
	spriteface $3, $3
	end
; 0x9e568

UnknownScript_0x9e568: ; 0x9e568
	jumptextfaceplayer UnknownText_0x9f2a4
; 0x9e56b

UnknownScript_0x9e56b: ; 0x9e56b
	jumptextfaceplayer UnknownText_0x9f35b
; 0x9e56e

UnknownScript_0x9e56e: ; 0x9e56e
	jumptextfaceplayer UnknownText_0x9f2e3
; 0x9e571

MovementData_0x9e571: ; 0x9e571
	step_up
	step_up
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x9e578

MovementData_0x9e578: ; 0x9e578
	step_down
	step_end
; 0x9e57a

MovementData_0x9e57a: ; 0x9e57a
	step_right
	step_right
	step_right
	step_right
	step_up
	step_right
	turn_head_left
	step_end
; 0x9e582

MovementData_0x9e582: ; 0x9e582
	step_left
	step_left
	step_left
	step_left
	step_left
	step_left
	step_up
	step_left
	turn_head_right
	step_end
; 0x9e58c

MovementData_0x9e58c: ; 0x9e58c
	step_up
	step_up
	step_up
	step_up
	turn_head_right
	step_end
; 0x9e592

MovementData_0x9e592: ; 0x9e592
	slow_step_down
	slow_step_down
	slow_step_down
	turn_head_left
	step_end
; 0x9e597

MovementData_0x9e597: ; 0x9e597
	turn_head_up
	slow_step_up
	slow_step_up
	slow_step_up
	step_end
; 0x9e59c

MovementData_0x9e59c: ; 0x9e59c
	slow_step_right
	slow_step_right
	slow_step_up
	slow_step_up
	step_end
; 0x9e5a1

MovementData_0x9e5a1: ; 0x9e5a1
	slow_step_down
	slow_step_down
	slow_step_left
	slow_step_left
	turn_head_right
	step_end
; 0x9e5a7

MovementData_0x9e5a7: ; 0x9e5a7
	turn_head_down
	step_end
; 0x9e5a9

MovementData_0x9e5a9: ; 0x9e5a9
	turn_head_right
	step_end
; 0x9e5ab

UnknownText_0x9e5ab: ; 0x9e5ab
	db $0, "BATTLE TOWER", $4f
	db "welcomes you!", $51
	db "I could show you", $4f
	db "to a BATTLE ROOM.", $57
; 0x9e5ea

UnknownText_0x9e5ea: ; 0x9e5ea
	db $0, "Want to go into a", $4f
	db "BATTLE ROOM?", $57
; 0x9e60a

UnknownText_0x9e60a: ; 0x9e60a
	db $0, "Right this way to", $4f
	db "your BATTLE ROOM.", $57
; 0x9e62f

UnknownText_0x9e62f: ; 0x9e62f
	db $0, "BATTLE TOWER is a", $4f
	db "facility made for", $55
	db "#MON battles.", $51
	db "Countless #MON", $4f
	db "trainers gather", $51
	db "from all over to", $4f
	db "hold battles in", $51
	db "specially designed", $4f
	db "BATTLE ROOMS.", $51
	db "There are many", $4f
	db "BATTLE ROOMS in", $55
	db "the BATTLE TOWER.", $51
	db "Each ROOM holds", $4f
	db "seven trainers.", $51
	db "If you defeat the", $4f
	db "seven in a ROOM,", $51
	db "and you have a", $4f
	db "good record, you", $51
	db "could become the", $4f
	db "ROOM's LEADER.", $51
	db "All LEADERS will", $4f
	db "be recorded in the", $51
	db "HONOR ROLL for", $4f
	db "posterity.", $51
	db "You may challenge", $4f
	db "in up to five", $51
	db "BATTLE ROOMS each", $4f
	db "day.", $51
	db "However, you may", $4f
	db "battle only once a", $51
	db "day in any given", $4f
	db "ROOM.", $51
	db "To interrupt a", $4f
	db "session, you must", $51
	db "SAVE. If not, you", $4f
	db "won't be able to", $51
	db "resume your ROOM", $4f
	db "challenge.", $51
	db $57
; 0x9e886

UnknownText_0x9e886: ; 0x9e886
	db $0, "BATTLE TOWER is a", $4f
	db "facility made for", $55
	db "#MON battles.", $51
	db "Countless #MON", $4f
	db "trainers gather", $51
	db "from all over to", $4f
	db "hold battles in", $51
	db "specially designed", $4f
	db "BATTLE ROOMS.", $51
	db "There are many", $4f
	db "BATTLE ROOMS in", $55
	db "the BATTLE TOWER.", $51
	db "Each ROOM holds", $4f
	db "seven trainers.", $51
	db "Beat them all, and", $4f
	db "win a prize.", $51
	db "To interrupt a", $4f
	db "session, you must", $51
	db "SAVE. If not, you", $4f
	db "won't be able to", $51
	db "resume your ROOM", $4f
	db "challenge.", $51
	db $57
; 0x9e9eb

UnknownText_0x9e9eb: ; 0x9e9eb
	db $0, "Received a list of", $4f
	db "LEADERS on the", $55
	db "HONOR ROLL.", $51
	db $57
; 0x9ea1b

UnknownText_0x9ea1b: ; 0x9ea1b
	db $0, "Please confirm on", $4f
	db "this monitor.", $57
; 0x9ea3c

UnknownText_0x9ea3c: ; 0x9ea3c
	db $0, "Thank you!", $51
	db $57
; 0x9ea49

UnknownText_0x9ea49: ; 0x9ea49
	db $0, "Thanks for", $4f
	db "visiting!", $57
; 0x9ea5f

UnknownText_0x9ea5f: ; 0x9ea5f
	db $0, "Congratulations!", $51
	db "You've beaten all", $4f
	db "the trainers!", $51
	db "Your feat may be", $4f
	db "worth registering,", $51
	db $52, ". With your", $4f
	db "results, you may", $51
	db "be chosen as a", $4f
	db "ROOM LEADER.", $51
	db $57
; 0x9eaef

UnknownText_0x9eaef: ; 0x9eaef
	db $0, "Congratulations!", $51
	db "You've beaten all", $4f
	db "the trainers!", $51
	db "For that, you get", $4f
	db "this great prize!", $51
	db $57
; 0x9eb45

UnknownText_0x9eb45: ; 0x9eb45
	db $0, "Would you like to", $4f
	db "register your", $51
	db "record with the", $4f
	db "CENTER?", $57
; 0x9eb7e

UnknownText_0x9eb7e: ; 0x9eb7e
	db $0, $52, " got five", $4f
	db "@"
	text_from_ram $d0ac
	db $0, "!@"
	sound0x0F
	text_waitbutton
	db $50
; 0x9eb94

UnknownText_0x9eb94: ; 0x9eb94
	db $0, "Oops, your PACK is", $4f
	db "stuffed full.", $51
	db "Please make room", $4f
	db "and come back.", $57
; 0x9ebd6

UnknownText_0x9ebd6: ; 0x9ebd6
	db $0, "Your registration", $4f
	db "is complete.", $51
	db "Please come again!", $57
; 0x9ec09

UnknownText_0x9ec09: ; 0x9ec09
	db $0, "We hope to serve", $4f
	db "you again.", $57
; 0x9ec26

UnknownText_0x9ec26: ; 0x9ec26
	db $0, "Please step this", $4f
	db "way.", $57
; 0x9ec3d

UnknownText_0x9ec3d: ; 0x9ec3d
	db $0, "Would you like to", $4f
	db "hear about the", $55
	db "BATTLE TOWER?", $57
; 0x9ec6d

UnknownText_0x9ec6d: ; 0x9ec6d
	db $0, "Your record from", $4f
	db "the previous", $51
	db "BATTLE ROOM can't", $4f
	db "be registered. OK?", $57
; 0x9ecb0

UnknownText_0x9ecb0: ; 0x9ecb0
	db $0, "Your record from", $4f
	db "the previous", $51
	db "BATTLE ROOM can't", $4f
	db "be registered.", $51
	db "Also, the existing", $4f
	db "record will be", $55
	db "deleted. OK?", $57
; 0x9ed1e

UnknownText_0x9ed1e: ; 0x9ed1e
	db $0, "Check the LEADER", $4f
	db "HONOR ROLL?", $57
; 0x9ed3c

UnknownText_0x9ed3c: ; 0x9ed3c
	db $0, "BATTLE TOWER rules", $4f
	db "are written here.", $51
	db "Read the rules?", $57
; 0x9ed72

UnknownText_0x9ed72: ; 0x9ed72
	db $0, "Three #MON may", $4f
	db "enter battles.", $51
	db "All three must be", $4f
	db "different.", $51
	db "The items they", $4f
	db "hold must also be", $55
	db "different.", $51
	db "Certain #MON", $4f
	db "may also have", $51
	db "level restrictions", $4f
	db "placed on them.", $57
; 0x9ee18

UnknownText_0x9ee18: ; 0x9ee18
	db $0, "Excuse me!", $4f
	db "You didn't SAVE", $51
	db "before exiting", $4f
	db "the BATTLE ROOM.", $51
	db "I'm awfully sorry,", $4f
	db "but your challenge", $51
	db "will be declared", $4f
	db "invalid.", $57
; 0x9ee92

UnknownText_0x9ee92: ; 0x9ee92
	db $0, "Your #MON will", $4f
	db "be healed to full", $55
	db "health.", $57
; 0x9eebc

UnknownText_0x9eebc: ; 0x9eebc
	db $0, "Next up, opponent", $4f
	db "no.@"
	text_from_ram $d099
	db $0, ". Ready?", $57
; 0x9eee0

UnknownText_0x9eee0: ; 0x9eee0
	db $0, "Your session will", $4f
	db "be SAVED before", $51
	db "connecting with", $4f
	db "the CENTER.", $57
; 0x9ef1f

UnknownText_0x9ef1f: ; 0x9ef1f
	db $0, "Before entering", $4f
	db "the BATTLE ROOM,", $51
	db "your progress will", $4f
	db "be saved.", $57
; 0x9ef5e

UnknownText_0x9ef5e: ; 0x9ef5e
	db $0, "SAVE and end the", $4f
	db "session?", $57
; 0x9ef79

UnknownText_0x9ef79: ; 0x9ef79
	db $0, "Your record will", $4f
	db "be SAVED before", $51
	db "you go back into", $4f
	db "the previous ROOM.", $57
; 0x9efbf

UnknownText_0x9efbf: ; 0x9efbf
	db $0, "Cancel your BATTLE", $4f
	db "ROOM challenge?", $57
; 0x9efe3

UnknownText_0x9efe3: ; 0x9efe3
	db $0, "We have your", $4f
	db "previous record on", $51
	db "file. Would you", $4f
	db "like to register", $55
	db "it at the CENTER?", $57
; 0x9f037

UnknownText_0x9f037: ; 0x9f037
	db $0, "We've been waiting", $4f
	db "for you. This way", $51
	db "to a BATTLE ROOM,", $4f
	db "please.", $57
; 0x9f076

UnknownText_0x9f076: ; 0x9f076
	db $0, "You may enter only", $4f
	db "five BATTLE ROOMS", $55
	db "each day.", $51
	db "Please come back", $4f
	db "tomorrow.", $57
; 0x9f0c1

UnknownText_0x9f0c1: ; 0x9f0c1
	db $0, "Sorry, but it's", $4f
	db "not possible to", $51
	db "register your", $4f
	db "current record at", $51
	db "the CENTER because", $4f
	db "too much time has", $51
	db "elapsed since the", $4f
	db "start of your", $55
	db "challenge.", $57
; 0x9f151

; a dupe?
UnknownText_0x9f151: ; 0x9f151
	db $0, "Sorry, but it's", $4f
	db "not possible to", $51
	db "register your most", $4f
	db "recent record at", $51
	db "the CENTER because", $4f
	db "too much time has", $51
	db "elapsed since the", $4f
	db "start of your", $55
	db "challenge.", $57
; 0x9f1e5

UnknownText_0x9f1e5: ; 0x9f1e5
	db $0, "One or more of", $4f
	db "your #MON's", $55
	db "levels exceeds @"
	deciram ScriptVar, $13
	db $0, ".", $57
; 0x9f217

UnknownText_0x9f217: ; 0x9f217
	text_from_ram $cd49
	db $0, " may not", $4f
	db "enter a BATTLE", $55
	db "ROOM under L70.", $51
	db "This BATTLE ROOM", $4f
	db "is for L@"
	deciram ScriptVar, $13
	db $0, ".", $57
; 0x9f264

UnknownText_0x9f264: ; 0x9f264
	db $0, "Destroyed by the", $4f
	db "first opponent in", $51
	db "no time at all…", $4f
	db "I'm no good…", $57
; 0x9f2a4

UnknownText_0x9f2a4: ; 0x9f2a4
	db $0, "There are lots of", $4f
	db "BATTLE ROOMS, but", $51
	db "I'm going to win", $4f
	db "them all!", $57
; 0x9f2e3

UnknownText_0x9f2e3: ; 0x9f2e3
	db $0, "It's a grueling", $4f
	db "task, not being", $51
	db "able to use items", $4f
	db "in battle.", $51
	db "Making your", $4f
	db "#MON hold items", $51
	db "is the key to", $4f
	db "winning battles.", $57
; 0x9f35b

UnknownText_0x9f35b: ; 0x9f35b
	db $0, "I'm trying to see", $4f
	db "how far I can go", $51
	db "using just bug", $4f
	db "#MON.", $51
	db "Don't let there be", $4f
	db "any fire #MON…", $57
; 0x9f3b4

BattleTower1F_MapEventHeader: ; 0x9f3b4
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $9, $7, 3, GROUP_BATTLE_TOWER_OUTSIDE, MAP_BATTLE_TOWER_OUTSIDE
	warp_def $9, $8, 4, GROUP_BATTLE_TOWER_OUTSIDE, MAP_BATTLE_TOWER_OUTSIDE
	warp_def $0, $7, 1, GROUP_BATTLE_TOWER_ELEVATOR, MAP_BATTLE_TOWER_ELEVATOR

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 6, 6, $0, MapBattleTower1FSignpost0Script

	; people-events
	db 5
	person_event $42, 10, 11, $6, $0, 255, 255, $0, 0, UnknownScript_0x9e3e2, $ffff
	person_event $27, 13, 18, $9, $0, 255, 255, $b0, 0, UnknownScript_0x9e55d, $ffff
	person_event $24, 13, 8, $5, $1, 255, 255, $80, 0, UnknownScript_0x9e568, $ffff
	person_event $25, 7, 5, $2, $11, 255, 255, $90, 0, UnknownScript_0x9e56b, $ffff
	person_event $30, 7, 18, $4, $10, 255, 255, $0, 0, UnknownScript_0x9e56e, $ffff
; 0x9f40f

BattleTowerBattleRoom_MapScriptHeader: ; 0x9f40f
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x9f419, $0000
	dw UnknownScript_0x9f420, $0000

	; callback count
	db 0
; 0x9f419

UnknownScript_0x9f419: ; 0x9f419
	disappear $2
	priorityjump UnknownScript_0x9f421
	dotrigger $1
; 0x9f420

UnknownScript_0x9f420: ; 0x9f420
	end
; 0x9f421

UnknownScript_0x9f421: ; 0x9f421
	applymovement $0, MovementData_0x9e58c
UnknownScript_0x9f425: ; 0x9f425
	writebyte $2
	special $007a
	appear $2
	warpsound
	waitbutton
	applymovement $2, MovementData_0x9e592
	loadfont
	storetext 1, UnknownText_0x9f930 + 37 - $3000, $f
	follownotexact $0, $f
	giveegg 0, 123
	if_not_equal $0, UnknownScript_0x9f4c2
	copybytetovar $cf64
	if_equal $7, UnknownScript_0x9f4d9
	applymovement $2, MovementData_0x9e597
	warpsound
	disappear $2
	applymovement $3, MovementData_0x9e59c
	applymovement $0, MovementData_0x9e5a7
	loadfont
	2writetext UnknownText_0x9ee92
	closetext
	loadmovesprites
	playmusic $000d
	special $002e
	special $00a4
	pause 60
	special $0031
	special $003d
	loadfont
	2writetext UnknownText_0x9eebc
	yesorno
	iffalse UnknownScript_0x9f483
UnknownScript_0x9f477: ; 0x9f477
	loadmovesprites
	applymovement $0, MovementData_0x9e5a9
	applymovement $3, MovementData_0x9e5a1
	2jump UnknownScript_0x9f425
; 0x9f483

UnknownScript_0x9f483: ; 0x9f483
	2writetext UnknownText_0x9ef5e
	yesorno
	iffalse UnknownScript_0x9f4a3
	writebyte $7
	special $0086
	writebyte $1f
	special $0086
	writebyte $3
	special $0086
	playsound $0025
	waitbutton
	special $002e
	special $007e
UnknownScript_0x9f4a3: ; 0x9f4a3
	2writetext UnknownText_0x9efbf
	yesorno
	iffalse UnknownScript_0x9f477
	writebyte $4
	special $0086
	writebyte $6
	special $0086
	loadmovesprites
	special $002e
	warpfacing $1, GROUP_BATTLE_TOWER_1F, MAP_BATTLE_TOWER_1F, $7, $7
	loadfont
	2jump UnknownScript_0x9e4b0
; 0x9f4c2

UnknownScript_0x9f4c2: ; 0x9f4c2
	pause 60
	special $002f
	warpfacing $1, GROUP_BATTLE_TOWER_1F, MAP_BATTLE_TOWER_1F, $7, $7
	writebyte $4
	special $0086
	loadfont
	2writetext UnknownText_0x9ea49
	closetext
	loadmovesprites
	end
; 0x9f4d9

UnknownScript_0x9f4d9: ; 0x9f4d9
	pause 60
	special $002f
	warpfacing $1, GROUP_BATTLE_TOWER_1F, MAP_BATTLE_TOWER_1F, $7, $7
	loadfont
	2writetext UnknownText_0x9eaef
	2jump UnknownScript_0x9e47a
; 0x9f4eb

UnknownScript_0x9f4eb: ; 0x9f4eb
	writebyte $4
	special $0086
	loadfont
	2writetext UnknownText_0x9f0c1
	closetext
	loadmovesprites
	end
; 0x9f4f7

UnknownScript_0x9f4f7: ; 0x9f4f7
	writebyte $4
	special $0086
	writebyte $6
	special $0086
	loadfont
	2writetext UnknownText_0x9ea49
	2writetext UnknownText_0x9ec09
	closetext
	loadmovesprites
	end
; 0x9f50b

INCBIN "baserom.gbc",$9f50b,$9f52e-$9f50b

BattleTowerBattleRoom_MapEventHeader: ; 0x9f52e
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $3, 4, GROUP_BATTLE_TOWER_HALLWAY, MAP_BATTLE_TOWER_HALLWAY
	warp_def $7, $4, 4, GROUP_BATTLE_TOWER_HALLWAY, MAP_BATTLE_TOWER_HALLWAY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $27, 4, 8, $6, $0, 255, 255, $0, 0, ObjectEvent, $0791
	person_event $42, 10, 5, $9, $0, 255, 255, $0, 0, ObjectEvent, $ffff
; 0x9f558

BattleTowerElevator_MapScriptHeader: ; 0x9f558
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x9f562, $0000
	dw UnknownScript_0x9f567, $0000

	; callback count
	db 0
; 0x9f562

UnknownScript_0x9f562: ; 0x9f562
	priorityjump UnknownScript_0x9f568
	dotrigger $1
; 0x9f567

UnknownScript_0x9f567: ; 0x9f567
	end
; 0x9f568

UnknownScript_0x9f568: ; 0x9f568
	follow $2, $0
	applymovement $2, MovementData_0x9f58f
	applymovement $0, MovementData_0x9f592
	writebyte $a
	special $0086
	playsound $006e
	earthquake 60
	waitbutton
	follow $2, $0
	applymovement $2, MovementData_0x9e578
	stopfollow
	warpsound
	disappear $2
	applymovement $0, MovementData_0x9e578
	warpcheck
	end
; 0x9f58f

MovementData_0x9f58f: ; 0x9f58f
	step_right
	turn_head_down
	step_end
; 0x9f592

MovementData_0x9f592: ; 0x9f592
	turn_head_down
	step_end
; 0x9f594

BattleTowerElevator_MapEventHeader: ; 0x9f594
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $1, 1, GROUP_BATTLE_TOWER_HALLWAY, MAP_BATTLE_TOWER_HALLWAY
	warp_def $3, $2, 1, GROUP_BATTLE_TOWER_HALLWAY, MAP_BATTLE_TOWER_HALLWAY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $42, 6, 5, $9, $0, 255, 255, $0, 0, MovementData_0x9f58f, $ffff
; 0x9f5b1

BattleTowerHallway_MapScriptHeader: ; 0x9f5b1
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x9f5bb, $0000
	dw UnknownScript_0x9f5c0, $0000

	; callback count
	db 0
; 0x9f5bb

UnknownScript_0x9f5bb: ; 0x9f5bb
	priorityjump UnknownScript_0x9f5c1
	dotrigger $1
; 0x9f5c0

UnknownScript_0x9f5c0: ; 0x9f5c0
	end
; 0x9f5c1

UnknownScript_0x9f5c1: ; 0x9f5c1
	follow $2, $0
	3callasm $27, $75cb
	2jump UnknownScript_0x9f5dc
; 0x9f5cb

INCBIN "baserom.gbc",$9f5cb,$9f5dc - $9f5cb

UnknownScript_0x9f5dc: ; 0x9f5dc
	if_equal $3, UnknownScript_0x9f603
	if_equal $4, UnknownScript_0x9f603
	if_equal $5, UnknownScript_0x9f60a
	if_equal $6, UnknownScript_0x9f60a
	if_equal $7, UnknownScript_0x9f611
	if_equal $8, UnknownScript_0x9f611
	if_equal $9, UnknownScript_0x9f618
	if_equal $a, UnknownScript_0x9f618
	applymovement $2, MovementData_0x9e57a
	2jump UnknownScript_0x9f61f
; 0x9f603

UnknownScript_0x9f603: ; 0x9f603
	applymovement $2, $657c
	2jump UnknownScript_0x9f61f
; 0x9f60a

UnknownScript_0x9f60a: ; 0x9f60a
	applymovement $2, $6586
	2jump UnknownScript_0x9f61f
; 0x9f611

UnknownScript_0x9f611: ; 0x9f611
	applymovement $2, $6584
	2jump UnknownScript_0x9f61f
; 0x9f618

UnknownScript_0x9f618: ; 0x9f618
	applymovement $2, MovementData_0x9e582
	2jump UnknownScript_0x9f61f
; 0x9f61f

UnknownScript_0x9f61f: ; 0x9f61f
	faceperson $0, $2
	loadfont
	2writetext UnknownText_0x9ec26
	closetext
	loadmovesprites
	stopfollow
	applymovement $0, $6576
	warpcheck
	end
; 0x9f62f

BattleTowerHallway_MapEventHeader: ; 0x9f62f
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $1, $b, 1, GROUP_BATTLE_TOWER_ELEVATOR, MAP_BATTLE_TOWER_ELEVATOR
	warp_def $0, $5, 1, GROUP_BATTLE_TOWER_BATTLE_ROOM, MAP_BATTLE_TOWER_BATTLE_ROOM
	warp_def $0, $7, 1, GROUP_BATTLE_TOWER_BATTLE_ROOM, MAP_BATTLE_TOWER_BATTLE_ROOM
	warp_def $0, $9, 1, GROUP_BATTLE_TOWER_BATTLE_ROOM, MAP_BATTLE_TOWER_BATTLE_ROOM
	warp_def $0, $d, 1, GROUP_BATTLE_TOWER_BATTLE_ROOM, MAP_BATTLE_TOWER_BATTLE_ROOM
	warp_def $0, $f, 1, GROUP_BATTLE_TOWER_BATTLE_ROOM, MAP_BATTLE_TOWER_BATTLE_ROOM

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $42, 6, 15, $6, $0, 255, 255, $0, 0, BattleTowerHallway_MapEventHeader, $ffff
; 0x9f660

Route40BattleTowerGate_MapScriptHeader: ; 0x9f660
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x9f665
; 0x9f665

UnknownScript_0x9f665: ; 0x9f665
	clearbit1 $07cf
	return
; 0x9f669

UnknownScript_0x9f669: ; 0x9f669
	jumptextfaceplayer UnknownText_0x9f716
; 0x9f66c

UnknownScript_0x9f66c: ; 0x9f66c
	jumptextfaceplayer UnknownText_0x9f7c8
; 0x9f66f

UnknownText_0x9f66f: ; 0x9f66f
	db $0, "Did you come to", $4f
	db "see the BATTLE", $55
	db "TOWER too?", $51
	db "But I guess you", $4f
	db "can't go in yet.", $57
; 0x9f6ba

UnknownText_0x9f6ba: ; 0x9f6ba
	db $0, "BATTLE TOWER has", $4f
	db "opened.", $51
	db "I want to go, but", $4f
	db "I haven't thought", $51
	db "up a cool line for", $4f
	db "when I win.", $57
; 0x9f716

UnknownText_0x9f716: ; 0x9f716
	db $0, "Are you going to", $4f
	db "the BATTLE TOWER?", $51
	db "This is a secret,", $4f
	db "but if you win a", $51
	db "whole lot, you can", $4f
	db "win special gifts.", $57
; 0x9f783

UnknownText_0x9f783: ; 0x9f783
	db $0, "I'm going to train", $4f
	db "my #MON so I'll", $51
	db "be all ready for", $4f
	db "the BATTLE TOWER.", $57
; 0x9f7c8

UnknownText_0x9f7c8: ; 0x9f7c8
	db $0, "The levels of the", $4f
	db "#MON I want to", $51
	db "use are all", $4f
	db "different.", $51
	db "I have to go train", $4f
	db "them now!", $57
; 0x9f81e

Route40BattleTowerGate_MapEventHeader: ; 0x9f81e
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $7, $4, 1, GROUP_ROUTE_40, MAP_ROUTE_40
	warp_def $7, $5, 1, GROUP_ROUTE_40, MAP_ROUTE_40
	warp_def $0, $4, 1, GROUP_BATTLE_TOWER_OUTSIDE, MAP_BATTLE_TOWER_OUTSIDE
	warp_def $0, $5, 2, GROUP_BATTLE_TOWER_OUTSIDE, MAP_BATTLE_TOWER_OUTSIDE

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $2c, 7, 7, $3, $0, 255, 255, $a0, 0, UnknownScript_0x9f669, $07cf
	person_event $26, 9, 11, $4, $10, 255, 255, $80, 0, UnknownScript_0x9f66c, $ffff
; 0x9f852

BattleTowerOutside_MapScriptHeader: ; 0x9f852
	; trigger count
	db 0

	; callback count
	db 2

	; callbacks

	dbw 1, UnknownScript_0x9f85a

	dbw 2, UnknownScript_0x9f85b
; 0x9f85a

UnknownScript_0x9f85a: ; 0x9f85a
	return
; 0x9f85b

UnknownScript_0x9f85b: ; 0x9f85b
	clearbit1 $07cf
	return
; 0x9f85f

UnknownScript_0x9f85f: ; 0x9f85f
	jumptextfaceplayer UnknownText_0x9f930
; 0x9f862

UnknownScript_0x9f862: ; 0x9f862
	jumptextfaceplayer UnknownText_0x9f9db
; 0x9f865

UnknownScript_0x9f865: ; 0x9f865
	jumptextfaceplayer UnknownText_0x9fa8c
; 0x9f868

MapBattleTowerOutsideSignpost0Script: ; 0x9f868
	jumptext UnknownText_0x9fafc
; 0x9f86b

UnknownText_0x9f86b: ; 0x9f86b
	db $0, "Wow, the BATTLE", $4f
	db "TOWER is huge! My", $51
	db "neck is tired from", $4f
	db "looking up at it.", $57
; 0x9f8b3

UnknownText_0x9f8b3: ; 0x9f8b3
	db $0, "Wow, the BATTLE", $4f
	db "TOWER is huge!", $51
	db "Since there are a", $4f
	db "whole bunch of", $51
	db "trainers inside,", $4f
	db "there must also be", $51
	db "a wide variety of", $4f
	db "#MON.", $57
; 0x9f930

UnknownText_0x9f930: ; 0x9f930
	db $0, "Wow, the BATTLE", $4f
	db "TOWER is huge!", $51
	db "There must be many", $4f
	db "kinds of #MON", $55
	db "in there!", $57
; 0x9f97b

UnknownText_0x9f97b: ; 0x9f97b
	db $0, "What on earth do", $4f
	db "they do here?", $51
	db "If the name says", $4f
	db "anything, I guess", $51
	db "it must be for", $4f
	db "#MON battles.", $57
; 0x9f9db

UnknownText_0x9f9db: ; 0x9f9db
	db $0, "You can use only", $4f
	db "three #MON.", $51
	db "It's so hard to", $4f
	db "decide which three", $51
	db "should go into", $4f
	db "battle…", $57
; 0x9fa32

UnknownText_0x9fa32: ; 0x9fa32
	db $0, "Ehehehe…", $4f
	db "I sneaked out of", $55
	db "work to come here.", $51
	db "I'm never giving", $4f
	db "up until I become", $55
	db "a LEADER!", $57
; 0x9fa8c

UnknownText_0x9fa8c: ; 0x9fa8c
	db $0, "Hehehe, I snuck", $4f
	db "out from work.", $51
	db "I can't bail out", $4f
	db "until I've won!", $51
	db "I have to win it", $4f
	db "all. That I must!", $57
; 0x9faee

UnknownText_0x9faee: ; 0x9faee
	db $0, "BATTLE TOWER", $57
; 0x9fafc

UnknownText_0x9fafc: ; 0x9fafc
	db $0, "BATTLE TOWER", $51
	db "Take the Ultimate", $4f
	db "Trainer Challenge!", $57
; 0x9fb2f

UnknownText_0x9fb2f: ; 0x9fb2f
	db $0, "The BATTLE TOWER's", $4f
	db "doors are closed…", $57
; 0x9fb54

UnknownText_0x9fb54: ; 0x9fb54
	db $0, "It's open!", $57
; 0x9fb5f

BattleTowerOutside_MapEventHeader: ; 0x9fb5f
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $15, $8, 3, GROUP_ROUTE_40_BATTLE_TOWER_GATE, MAP_ROUTE_40_BATTLE_TOWER_GATE
	warp_def $15, $9, 4, GROUP_ROUTE_40_BATTLE_TOWER_GATE, MAP_ROUTE_40_BATTLE_TOWER_GATE
	warp_def $9, $8, 1, GROUP_BATTLE_TOWER_1F, MAP_BATTLE_TOWER_1F
	warp_def $9, $9, 2, GROUP_BATTLE_TOWER_1F, MAP_BATTLE_TOWER_1F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 10, 10, $0, MapBattleTowerOutsideSignpost0Script

	; people-events
	db 4
	person_event $66, 16, 10, $7, $0, 255, 255, $80, 0, UnknownScript_0x9f85f, $ffff
	person_event $2a, 15, 17, $2, $11, 255, 255, $a0, 0, UnknownScript_0x9f862, $ffff
	person_event $49, 22, 16, $5, $1, 255, 255, $0, 0, UnknownScript_0x9f865, $07cf
	person_event $28, 28, 16, $3, $0, 255, 255, $a0, 0, ObjectEvent, $ffff
; 0x9fbb2

SECTION "bank28",DATA,BANK[$28]

INCBIN "baserom.gbc",$A0000,$4000

SECTION "bank29",DATA,BANK[$29]

INCBIN "baserom.gbc",$A4000,$4000

SECTION "bank2A",DATA,BANK[$2A]

Route32_BlockData: ; 0xa8000
	INCBIN "maps/Route32.blk"
; 0xa81c2

Route40_BlockData: ; 0xa81c2
	INCBIN "maps/Route40.blk"
; 0xa8276

Route36_BlockData: ; 0xa8276
	INCBIN "maps/Route36.blk"
; 0xa8384

Route44_BlockData: ; 0xa8384
	INCBIN "maps/Route44.blk"
; 0xa8492

Route28_BlockData: ; 0xa8492
	INCBIN "maps/Route28.blk"
; 0xa8546

INCBIN "baserom.gbc",$a8546,$a8552 - $a8546

CeladonCity_BlockData: ; 0xa8552
	INCBIN "maps/CeladonCity.blk"
; 0xa86ba

SaffronCity_BlockData: ; 0xa86ba
	INCBIN "maps/SaffronCity.blk"
; 0xa8822

Route2_BlockData: ; 0xa8822
	INCBIN "maps/Route2.blk"
; 0xa8930

ElmsHouse_BlockData: ; 0xa8930
	INCBIN "maps/ElmsHouse.blk"
; 0xa8940

INCBIN "baserom.gbc",$a8940,$5a

Route11_BlockData: ; 0xa899a
	INCBIN "maps/Route11.blk"
; 0xa8a4e

INCBIN "baserom.gbc",$a8a4e,$a8aa8 - $a8a4e

Route15_BlockData: ; 0xa8aa8
	INCBIN "maps/Route15.blk"
; 0xa8b5c

INCBIN "baserom.gbc",$a8b5c,$24

Route19_BlockData: ; 0xa8b80
	INCBIN "maps/Route19.blk"
; 0xa8c34

INCBIN "baserom.gbc",$a8c34,$a8d9c - $a8c34

Route10South_BlockData: ; 0xa8d9c
	INCBIN "maps/Route10South.blk"
; 0xa8df6

CinnabarPokeCenter2FBeta_BlockData: ; 0xa8df6
	INCBIN "maps/CinnabarPokeCenter2FBeta.blk"
; 0xa8e16

Route41_BlockData: ; 0xa8e16
	INCBIN "maps/Route41.blk"
; 0xa90b9

Route33_BlockData: ; 0xa90b9
	INCBIN "maps/Route33.blk"
; 0xa9113

Route45_BlockData: ; 0xa9113
	INCBIN "maps/Route45.blk"
; 0xa92d5

Route29_BlockData: ; 0xa92d5
	INCBIN "maps/Route29.blk"
; 0xa93e3

Route37_BlockData: ; 0xa93e3
	INCBIN "maps/Route37.blk"
; 0xa943d

LavenderTown_BlockData: ; 0xa943d
	INCBIN "maps/LavenderTown.blk"
; 0xa9497

PalletTown_BlockData: ; 0xa9497
	INCBIN "maps/PalletTown.blk"
; 0xa94f1

Route25_BlockData: ; 0xa94f1
	INCBIN "maps/Route25.blk"
; 0xa95ff

Route24_BlockData: ; 0xa95ff
	INCBIN "maps/Route24.blk"
; 0xa9659

INCBIN "baserom.gbc",$a9659,$a97c1 - $a9659

Route3_BlockData: ; 0xa97c1
	INCBIN "maps/Route3.blk"
; 0xa98cf

PewterCity_BlockData: ; 0xa98cf
	INCBIN "maps/PewterCity.blk"
; 0xa9a37

INCBIN "baserom.gbc",$a9a37,$a9bf9 - $a9a37

Route12_BlockData: ; 0xa9bf9
	INCBIN "maps/Route12.blk"
; 0xa9d07

INCBIN "baserom.gbc",$a9d07,$168

Route20_BlockData: ; 0xa9e6f
	INCBIN "maps/Route20.blk"
; 0xa9f7d

INCBIN "baserom.gbc",$a9f7d,$a9ff7 - $a9f7d

Route30_BlockData: ; 0xa9ff7
	INCBIN "maps/Route30.blk"
; 0xaa105

Route26_BlockData: ; 0xaa105
	INCBIN "maps/Route26.blk"
; 0xaa321

Route42_BlockData: ; 0xaa321
	INCBIN "maps/Route42.blk"
; 0xaa42f

Route34_BlockData: ; 0xaa42f
	INCBIN "maps/Route34.blk"
; 0xaa53d

Route46_BlockData: ; 0xaa53d
	INCBIN "maps/Route46.blk"
; 0xaa5f1

FuchsiaCity_BlockData: ; 0xaa5f1
	INCBIN "maps/FuchsiaCity.blk"
; 0xaa759

Route38_BlockData: ; 0xaa759
	INCBIN "maps/Route38.blk"
; 0xaa80d

INCBIN "baserom.gbc",$aa80d,$5a

OlivineVoltorbHouse_BlockData: ; 0xaa867
	INCBIN "maps/OlivineVoltorbHouse.blk"
; 0xaa877

SafariZoneFuchsiaGateBeta_BlockData: ; 0xaa877
	INCBIN "maps/SafariZoneFuchsiaGateBeta.blk"
; 0xaa88b

INCBIN "baserom.gbc",$aa88b,$aaa4d - $aa88b

CinnabarIsland_BlockData: ; 0xaaa4d
	INCBIN "maps/CinnabarIsland.blk"
; 0xaaaa7

Route4_BlockData: ; 0xaaaa7
	INCBIN "maps/Route4.blk"
; 0xaab5b

Route8_BlockData: ; 0xaab5b
	INCBIN "maps/Route8.blk"
; 0xaac0f

INCBIN "baserom.gbc",$aac0f,$aac69 - $aac0f

ViridianCity_BlockData: ; 0xaac69
	INCBIN "maps/ViridianCity.blk"
; 0xaadd1

Route13_BlockData: ; 0xaadd1
	INCBIN "maps/Route13.blk"
; 0xaaedf

Route21_BlockData: ; 0xaaedf
	INCBIN "maps/Route21.blk"
; 0xaaf93

INCBIN "baserom.gbc",$aaf93,$aafed - $aaf93

Route17_BlockData: ; 0xaafed
	INCBIN "maps/Route17.blk"
; 0xab1af

INCBIN "baserom.gbc",$ab1af,$ab209 - $ab1af

Route31_BlockData: ; 0xab209
	INCBIN "maps/Route31.blk"
; 0xab2bd

Route27_BlockData: ; 0xab2bd
	INCBIN "maps/Route27.blk"
; 0xab425

Route35_BlockData: ; 0xab425
	INCBIN "maps/Route35.blk"
; 0xab4d9

Route43_BlockData: ; 0xab4d9
	INCBIN "maps/Route43.blk"
; 0xab5e7

Route39_BlockData: ; 0xab5e7
	INCBIN "maps/Route39.blk"
; 0xab69b

KrissHouse1F_BlockData: ; 0xab69b
	INCBIN "maps/KrissHouse1F.blk"
; 0xab6af

Route38EcruteakGate_BlockData: ; 0xab6af
	INCBIN "maps/Route38EcruteakGate.blk"
; 0xab6c3

INCBIN "baserom.gbc",$ab6c3,$ab82b - $ab6c3

VermilionCity_BlockData: ; 0xab82b
	INCBIN "maps/VermilionCity.blk"
; 0xab993

INCBIN "baserom.gbc",$ab993,$abb55 - $ab993

ElmsLab_BlockData: ; 0xabb55
	INCBIN "maps/ElmsLab.blk"
; 0xabb73

CeruleanCity_BlockData: ; 0xabb73
	INCBIN "maps/CeruleanCity.blk"
; 0xabcdb

Route1_BlockData: ; 0xabcdb
	INCBIN "maps/Route1.blk"
; 0xabd8f

Route5_BlockData: ; 0xabd8f
	INCBIN "maps/Route5.blk"
; 0xabde9

Route9_BlockData: ; 0xabde9
	INCBIN "maps/Route9.blk"
; 0xabef7

Route22_BlockData: ; 0xabef7
	INCBIN "maps/Route22.blk"
; 0xabfab

INCBIN "baserom.gbc",$abfab,$55

SECTION "bank2B",DATA,BANK[$2B]

Route14_BlockData: ; 0xac000
	INCBIN "maps/Route14.blk"
; 0xac0b4

INCBIN "baserom.gbc",$ac0b4,$5a

OlivineMart_BlockData: ; 0xac10e
	INCBIN "maps/OlivineMart.blk"
; 0xac126

Route10North_BlockData: ; 0xac126
	INCBIN "maps/Route10North.blk"
; 0xac180

INCBIN "baserom.gbc",$ac180,$168

OlivinePokeCenter1F_BlockData: ; 0xac2e8
	INCBIN "maps/OlivinePokeCenter1F.blk"
; 0xac2fc

INCBIN "baserom.gbc",$ac2fc,$ac340 - $ac2fc

EarlsPokemonAcademy_BlockData: ; 0xac340
	INCBIN "maps/EarlsPokemonAcademy.blk"
; 0xac360

INCBIN "baserom.gbc",$ac360,$ac3b4 - $ac360

GoldenrodDeptStore1F_BlockData: ; 0xac3b4
	INCBIN "maps/GoldenrodDeptStore1F.blk"
; 0xac3d4

GoldenrodDeptStore2F_BlockData: ; 0xac3d4
	INCBIN "maps/GoldenrodDeptStore2F.blk"
; 0xac3f4

GoldenrodDeptStore3F_BlockData: ; 0xac3f4
	INCBIN "maps/GoldenrodDeptStore3F.blk"
; 0xac414

GoldenrodDeptStore4F_BlockData: ; 0xac414
	INCBIN "maps/GoldenrodDeptStore4F.blk"
; 0xac434

GoldenrodDeptStore5F_BlockData: ; 0xac434
	INCBIN "maps/GoldenrodDeptStore5F.blk"
; 0xac454

GoldenrodDeptStore6F_BlockData: ; 0xac454
	INCBIN "maps/GoldenrodDeptStore6F.blk"
; 0xac474

GoldenrodDeptStoreElevator_BlockData: ; 0xac474
	INCBIN "maps/GoldenrodDeptStoreElevator.blk"
; 0xac478

CeladonMansion1F_BlockData: ; 0xac478
	INCBIN "maps/CeladonMansion1F.blk"
; 0xac48c

CeladonMansion2F_BlockData: ; 0xac48c
	INCBIN "maps/CeladonMansion2F.blk"
; 0xac4a0

CeladonMansion3F_BlockData: ; 0xac4a0
	INCBIN "maps/CeladonMansion3F.blk"
; 0xac4b4

CeladonMansionRoof_BlockData: ; 0xac4b4
	INCBIN "maps/CeladonMansionRoof.blk"
; 0xac4c8

INCBIN "baserom.gbc",$ac4c8,$ac4d8 - $ac4c8

CeladonGameCorner_BlockData: ; 0xac4d8
	INCBIN "maps/CeladonGameCorner.blk"
; 0xac51e

CeladonGameCornerPrizeRoom_BlockData: ; 0xac51e
	INCBIN "maps/CeladonGameCornerPrizeRoom.blk"
; 0xac527

Colosseum_BlockData: ; 0xac527
	INCBIN "maps/Colosseum.blk"
; 0xac53b

TradeCenter_BlockData: ; 0xac53b
	INCBIN "maps/TradeCenter.blk"
; 0xac54f

EcruteakLugiaSpeechHouse_BlockData: ; 0xac54f
	INCBIN "maps/EcruteakLugiaSpeechHouse.blk"
; 0xac55f

INCBIN "baserom.gbc",$ac55f,$5a

UnionCaveB1F_BlockData: ; 0xac5b9
	INCBIN "maps/UnionCaveB1F.blk"
; 0xac66d

UnionCaveB2F_BlockData: ; 0xac66d
	INCBIN "maps/UnionCaveB2F.blk"
; 0xac721

UnionCave1F_BlockData: ; 0xac721
	INCBIN "maps/UnionCave1F.blk"
; 0xac7d5

NationalPark_BlockData: ; 0xac7d5
	INCBIN "maps/NationalPark.blk"
; 0xac9f1

Route6UndergroundEntrance_BlockData: ; 0xac9f1
	INCBIN "maps/Route6UndergroundEntrance.blk"
; 0xaca01

INCBIN "baserom.gbc",$aca01,$10

KurtsHouse_BlockData: ; 0xaca11
	INCBIN "maps/KurtsHouse.blk"
; 0xaca31

GoldenrodMagnetTrainStation_BlockData: ; 0xaca31
	INCBIN "maps/GoldenrodMagnetTrainStation.blk"
; 0xaca8b

RuinsofAlphOutside_BlockData: ; 0xaca8b
	INCBIN "maps/RuinsofAlphOutside.blk"
; 0xacb3f

INCBIN "baserom.gbc",$acb3f,$acb53 - $acb3f

RuinsofAlphInnerChamber_BlockData: ; 0xacb53
	INCBIN "maps/RuinsofAlphInnerChamber.blk"
; 0xacbdf

RuinsofAlphHoOhChamber_BlockData: ; 0xacbdf
	INCBIN "maps/RuinsofAlphHoOhChamber.blk"
; 0xacbf3

SproutTower1F_BlockData: ; 0xacbf3
	INCBIN "maps/SproutTower1F.blk"
; 0xacc43

INCBIN "baserom.gbc",$acc43,$acc4d - $acc43

SproutTower2F_BlockData: ; 0xacc4d
	INCBIN "maps/SproutTower2F.blk"
; 0xacc9d

INCBIN "baserom.gbc",$acc9d,$acca7 - $acc9d

SproutTower3F_BlockData: ; 0xacca7
	INCBIN "maps/SproutTower3F.blk"
; 0xaccf7

INCBIN "baserom.gbc",$accf7,$acd01 - $accf7

RadioTower1F_BlockData: ; 0xacd01
	INCBIN "maps/RadioTower1F.blk"
; 0xacd25

RadioTower2F_BlockData: ; 0xacd25
	INCBIN "maps/RadioTower2F.blk"
; 0xacd49

RadioTower3F_BlockData: ; 0xacd49
	INCBIN "maps/RadioTower3F.blk"
; 0xacd6d

RadioTower4F_BlockData: ; 0xacd6d
	INCBIN "maps/RadioTower4F.blk"
; 0xacd91

RadioTower5F_BlockData: ; 0xacd91
	INCBIN "maps/RadioTower5F.blk"
; 0xacdb5

NewBarkTown_BlockData: ; 0xacdb5
	INCBIN "maps/NewBarkTown.blk"
; 0xace0f

CherrygroveCity_BlockData: ; 0xace0f
	INCBIN "maps/CherrygroveCity.blk"
; 0xacec3

VioletCity_BlockData: ; 0xacec3
	INCBIN "maps/VioletCity.blk"
; 0xad02b

AzaleaTown_BlockData: ; 0xad02b
	INCBIN "maps/AzaleaTown.blk"
; 0xad0df

CianwoodCity_BlockData: ; 0xad0df
	INCBIN "maps/CianwoodCity.blk"
; 0xad274

GoldenrodCity_BlockData: ; 0xad274
	INCBIN "maps/GoldenrodCity.blk"
; 0xad3dc

OlivineCity_BlockData: ; 0xad3dc
	INCBIN "maps/OlivineCity.blk"
; 0xad544

EcruteakCity_BlockData: ; 0xad544
	INCBIN "maps/EcruteakCity.blk"
; 0xad6ac

MahoganyTown_BlockData: ; 0xad6ac
	INCBIN "maps/MahoganyTown.blk"
; 0xad706

LakeofRage_BlockData: ; 0xad706
	INCBIN "maps/LakeofRage.blk"
; 0xad86e

BlackthornCity_BlockData: ; 0xad86e
	INCBIN "maps/BlackthornCity.blk"
; 0xad9d6

SilverCaveOutside_BlockData: ; 0xad9d6
	INCBIN "maps/SilverCaveOutside.blk"
; 0xadb3e

Route6_BlockData: ; 0xadb3e
	INCBIN "maps/Route6.blk"
; 0xadb98

Route7_BlockData: ; 0xadb98
	INCBIN "maps/Route7.blk"
; 0xadbf2

Route16_BlockData: ; 0xadbf2
	INCBIN "maps/Route16.blk"
; 0xadc4c

Route18_BlockData: ; 0xadc4c
	INCBIN "maps/Route18.blk"
; 0xadca6

WarehouseEntrance_BlockData: ; 0xadca6
	INCBIN "maps/WarehouseEntrance.blk"
; 0xaddb4

UndergroundPathSwitchRoomEntrances_BlockData: ; 0xaddb4
	INCBIN "maps/UndergroundPathSwitchRoomEntrances.blk"
; 0xadec2

GoldenrodDeptStoreB1F_BlockData: ; 0xadec2
	INCBIN "maps/GoldenrodDeptStoreB1F.blk"
; 0xadf1c

UndergroundWarehouse_BlockData: ; 0xadf1c
	INCBIN "maps/UndergroundWarehouse.blk"
; 0xadf76

INCBIN "baserom.gbc",$adf76,$19

TinTower1F_BlockData: ; 0xadf8f
	INCBIN "maps/TinTower1F.blk"
; 0xadfe9

TinTower2F_BlockData: ; 0xadfe9
	INCBIN "maps/TinTower2F.blk"
; 0xae043

TinTower3F_BlockData: ; 0xae043
	INCBIN "maps/TinTower3F.blk"
; 0xae09d

TinTower4F_BlockData: ; 0xae09d
	INCBIN "maps/TinTower4F.blk"
; 0xae0f7

TinTower5F_BlockData: ; 0xae0f7
	INCBIN "maps/TinTower5F.blk"
; 0xae151

TinTower6F_BlockData: ; 0xae151
	INCBIN "maps/TinTower6F.blk"
; 0xae1ab

TinTower7F_BlockData: ; 0xae1ab
	INCBIN "maps/TinTower7F.blk"
; 0xae205

TinTower8F_BlockData: ; 0xae205
	INCBIN "maps/TinTower8F.blk"
; 0xae25f

TinTower9F_BlockData: ; 0xae25f
	INCBIN "maps/TinTower9F.blk"
; 0xae2b9

TinTowerRoof_BlockData: ; 0xae2b9
	INCBIN "maps/TinTowerRoof.blk"
; 0xae313

BurnedTower1F_BlockData: ; 0xae313
	INCBIN "maps/BurnedTower1F.blk"
; 0xae36d

BurnedTowerB1F_BlockData: ; 0xae36d
	INCBIN "maps/BurnedTowerB1F.blk"
; 0xae3c7

INCBIN "baserom.gbc",$ae3c7,$ae4d5 - $ae3c7

MountMortar1FOutside_BlockData: ; 0xae4d5
	INCBIN "maps/MountMortar1FOutside.blk"
; 0xae63d

MountMortar1FInside_BlockData: ; 0xae63d
	INCBIN "maps/MountMortar1FInside.blk"
; 0xae859

MountMortar2FInside_BlockData: ; 0xae859
	INCBIN "maps/MountMortar2FInside.blk"
; 0xae9c1

MountMortarB1F_BlockData: ; 0xae9c1
	INCBIN "maps/MountMortarB1F.blk"
; 0xaeb29

IcePath1F_BlockData: ; 0xaeb29
	INCBIN "maps/IcePath1F.blk"
; 0xaec91

IcePathB1F_BlockData: ; 0xaec91
	INCBIN "maps/IcePathB1F.blk"
; 0xaed45

IcePathB2FMahoganySide_BlockData: ; 0xaed45
	INCBIN "maps/IcePathB2FMahoganySide.blk"
; 0xaed9f

IcePathB2FBlackthornSide_BlockData: ; 0xaed9f
	INCBIN "maps/IcePathB2FBlackthornSide.blk"
; 0xaedcc

IcePathB3F_BlockData: ; 0xaedcc
	INCBIN "maps/IcePathB3F.blk"
; 0xaee26

WhirlIslandNW_BlockData: ; 0xaee26
	INCBIN "maps/WhirlIslandNW.blk"
; 0xaee53

WhirlIslandNE_BlockData: ; 0xaee53
	INCBIN "maps/WhirlIslandNE.blk"
; 0xaeead

WhirlIslandSW_BlockData: ; 0xaeead
	INCBIN "maps/WhirlIslandSW.blk"
; 0xaef07

WhirlIslandCave_BlockData: ; 0xaef07
	INCBIN "maps/WhirlIslandCave.blk"
; 0xaef34

WhirlIslandSE_BlockData: ; 0xaef34
	INCBIN "maps/WhirlIslandSE.blk"
; 0xaef61

WhirlIslandB1F_BlockData: ; 0xaef61
	INCBIN "maps/WhirlIslandB1F.blk"
; 0xaf0c9

WhirlIslandB2F_BlockData: ; 0xaf0c9
	INCBIN "maps/WhirlIslandB2F.blk"
; 0xaf17d

WhirlIslandLugiaChamber_BlockData: ; 0xaf17d
	INCBIN "maps/WhirlIslandLugiaChamber.blk"
; 0xaf1d7

SilverCaveRoom1_BlockData: ; 0xaf1d7
	INCBIN "maps/SilverCaveRoom1.blk"
; 0xaf28b

SilverCaveRoom2_BlockData: ; 0xaf28b
	INCBIN "maps/SilverCaveRoom2.blk"
; 0xaf399

SilverCaveRoom3_BlockData: ; 0xaf399
	INCBIN "maps/SilverCaveRoom3.blk"
; 0xaf44d

INCBIN "baserom.gbc",$af44d,$438

MahoganyMart1F_BlockData: ; 0xaf885
	INCBIN "maps/MahoganyMart1F.blk"
; 0xaf895

TeamRocketBaseB1F_BlockData: ; 0xaf895
	INCBIN "maps/TeamRocketBaseB1F.blk"
; 0xaf91c

TeamRocketBaseB2F_BlockData: ; 0xaf91c
	INCBIN "maps/TeamRocketBaseB2F.blk"
; 0xaf9a3

TeamRocketBaseB3F_BlockData: ; 0xaf9a3
	INCBIN "maps/TeamRocketBaseB3F.blk"
; 0xafa2a

INCBIN "baserom.gbc",$afa2a,$afa84 - $afa2a

IndigoPlateauPokeCenter1F_BlockData: ; 0xafa84
	INCBIN "maps/IndigoPlateauPokeCenter1F.blk"
; 0xafac3

WillsRoom_BlockData: ; 0xafac3
	INCBIN "maps/WillsRoom.blk"
; 0xafaf0

KogasRoom_BlockData: ; 0xafaf0
	INCBIN "maps/KogasRoom.blk"
; 0xafb1d

BrunosRoom_BlockData: ; 0xafb1d
	INCBIN "maps/BrunosRoom.blk"
; 0xafb4a

KarensRoom_BlockData: ; 0xafb4a
	INCBIN "maps/KarensRoom.blk"
; 0xafb77

AzaleaGym_BlockData: ; 0xafb77
	INCBIN "maps/AzaleaGym.blk"
; 0xafb9f

VioletGym_BlockData: ; 0xafb9f
	INCBIN "maps/VioletGym.blk"
; 0xafbc7

GoldenrodGym_BlockData: ; 0xafbc7
	INCBIN "maps/GoldenrodGym.blk"
; 0xafc21

EcruteakGym_BlockData: ; 0xafc21
	INCBIN "maps/EcruteakGym.blk"
; 0xafc4e

MahoganyGym_BlockData: ; 0xafc4e
	INCBIN "maps/MahoganyGym.blk"
; 0xafc7b

OlivineGym_BlockData: ; 0xafc7b
	INCBIN "maps/OlivineGym.blk"
; 0xafca3

INCBIN "baserom.gbc",$afca3,$afcb7 - $afca3

CianwoodGym_BlockData: ; 0xafcb7
	INCBIN "maps/CianwoodGym.blk"
; 0xafce4

BlackthornGym1F_BlockData: ; 0xafce4
	INCBIN "maps/BlackthornGym1F.blk"
; 0xafd11

BlackthornGym2F_BlockData: ; 0xafd11
	INCBIN "maps/BlackthornGym2F.blk"
; 0xafd3e

OlivineLighthouse1F_BlockData: ; 0xafd3e
	INCBIN "maps/OlivineLighthouse1F.blk"
; 0xafd98

OlivineLighthouse2F_BlockData: ; 0xafd98
	INCBIN "maps/OlivineLighthouse2F.blk"
; 0xafdf2

OlivineLighthouse3F_BlockData: ; 0xafdf2
	INCBIN "maps/OlivineLighthouse3F.blk"
; 0xafe4c

OlivineLighthouse4F_BlockData: ; 0xafe4c
	INCBIN "maps/OlivineLighthouse4F.blk"
; 0xafea6

OlivineLighthouse5F_BlockData: ; 0xafea6
	INCBIN "maps/OlivineLighthouse5F.blk"
; 0xaff00

OlivineLighthouse6F_BlockData: ; 0xaff00
	INCBIN "maps/OlivineLighthouse6F.blk"
; 0xaff5a

SECTION "bank2C",DATA,BANK[$2C]

INCBIN "baserom.gbc",$b0000,$b0023 - $b0000

SlowpokeWellB1F_BlockData: ; 0xb0023
	INCBIN "maps/SlowpokeWellB1F.blk"
; 0xb007d

SlowpokeWellB2F_BlockData: ; 0xb007d
	INCBIN "maps/SlowpokeWellB2F.blk"
; 0xb00d7

IlexForest_BlockData: ; 0xb00d7
	INCBIN "maps/IlexForest.blk"
; 0xb026c

DarkCaveVioletEntrance_BlockData: ; 0xb026c
	INCBIN "maps/DarkCaveVioletEntrance.blk"
; 0xb03d4

DarkCaveBlackthornEntrance_BlockData: ; 0xb03d4
	INCBIN "maps/DarkCaveBlackthornEntrance.blk"
; 0xb04e2

RuinsofAlphResearchCenter_BlockData: ; 0xb04e2
	INCBIN "maps/RuinsofAlphResearchCenter.blk"
; 0xb04f2

GoldenrodBikeShop_BlockData: ; 0xb04f2
	INCBIN "maps/GoldenrodBikeShop.blk"
; 0xb0502

DanceTheatre_BlockData: ; 0xb0502
	INCBIN "maps/DanceTheatre.blk"
; 0xb052c

EcruteakHouse_BlockData: ; 0xb052c
	INCBIN "maps/EcruteakHouse.blk"
; 0xb0586

GoldenrodGameCorner_BlockData: ; 0xb0586
	INCBIN "maps/GoldenrodGameCorner.blk"
; 0xb05cc

Route35NationalParkgate_BlockData: ; 0xb05cc
	INCBIN "maps/Route35NationalParkgate.blk"
; 0xb05dc

Route36NationalParkgate_BlockData: ; 0xb05dc
	INCBIN "maps/Route36NationalParkgate.blk"
; 0xb05f0

FastShip1F_BlockData: ; 0xb05f0
	INCBIN "maps/FastShip1F.blk"
; 0xb0680

FastShipB1F_BlockData: ; 0xb0680
	INCBIN "maps/FastShipB1F.blk"
; 0xb0700

INCBIN "baserom.gbc",$b0700,$10

FastShipCabins_NNW_NNE_NE_BlockData: ; 0xb0710
	INCBIN "maps/FastShipCabins_NNW_NNE_NE.blk"
; 0xb0750

FastShipCabins_SW_SSW_NW_BlockData: ; 0xb0750
	INCBIN "maps/FastShipCabins_SW_SSW_NW.blk"
; 0xb0790

FastShipCabins_SE_SSE_CaptainsCabin_BlockData: ; 0xb0790
	INCBIN "maps/FastShipCabins_SE_SSE_CaptainsCabin.blk"
; 0xb07e5

OlivinePort_BlockData: ; 0xb07e5
	INCBIN "maps/OlivinePort.blk"
; 0xb0899

VermilionPort_BlockData: ; 0xb0899
	INCBIN "maps/VermilionPort.blk"
; 0xb094d

OlivineCafe_BlockData: ; 0xb094d
	INCBIN "maps/OlivineCafe.blk"
; 0xb095d

KrissHouse2F_BlockData: ; 0xb095d
	INCBIN "maps/KrissHouse2F.blk"
; 0xb0969

SaffronTrainStation_BlockData: ; 0xb0969
	INCBIN "maps/SaffronTrainStation.blk"
; 0xb09c3

CeruleanGym_BlockData: ; 0xb09c3
	INCBIN "maps/CeruleanGym.blk"
; 0xb09eb

VermilionGym_BlockData: ; 0xb09eb
	INCBIN "maps/VermilionGym.blk"
; 0xb0a18

SaffronGym_BlockData: ; 0xb0a18
	INCBIN "maps/SaffronGym.blk"
; 0xb0a72

PowerPlant_BlockData: ; 0xb0a72
	INCBIN "maps/PowerPlant.blk"
; 0xb0acc

PokemonFanClub_BlockData: ; 0xb0acc
	INCBIN "maps/PokemonFanClub.blk"
; 0xb0ae0

FightingDojo_BlockData: ; 0xb0ae0
	INCBIN "maps/FightingDojo.blk"
; 0xb0afe

SilphCo1F_BlockData: ; 0xb0afe
	INCBIN "maps/SilphCo1F.blk"
; 0xb0b1e

ViridianGym_BlockData: ; 0xb0b1e
	INCBIN "maps/ViridianGym.blk"
; 0xb0b4b

TrainerHouse1F_BlockData: ; 0xb0b4b
	INCBIN "maps/TrainerHouse1F.blk"
; 0xb0b6e

TrainerHouseB1F_BlockData: ; 0xb0b6e
	INCBIN "maps/TrainerHouseB1F.blk"
; 0xb0b96

RedsHouse1F_BlockData: ; 0xb0b96
	INCBIN "maps/RedsHouse1F.blk"
; 0xb0ba6

RedsHouse2F_BlockData: ; 0xb0ba6
	INCBIN "maps/RedsHouse2F.blk"
; 0xb0bb6

OaksLab_BlockData: ; 0xb0bb6
	INCBIN "maps/OaksLab.blk"
; 0xb0bd4

MrFujisHouse_BlockData: ; 0xb0bd4
	INCBIN "maps/MrFujisHouse.blk"
; 0xb0be8

LavRadioTower1F_BlockData: ; 0xb0be8
	INCBIN "maps/LavRadioTower1F.blk"
; 0xb0c10

SilverCaveItemRooms_BlockData: ; 0xb0c10
	INCBIN "maps/SilverCaveItemRooms.blk"
; 0xb0c6a

DayCare_BlockData: ; 0xb0c6a
	INCBIN "maps/DayCare.blk"
; 0xb0c7e

SoulHouse_BlockData: ; 0xb0c7e
	INCBIN "maps/SoulHouse.blk"
; 0xb0c92

PewterGym_BlockData: ; 0xb0c92
	INCBIN "maps/PewterGym.blk"
; 0xb0cb5

CeladonGym_BlockData: ; 0xb0cb5
	INCBIN "maps/CeladonGym.blk"
; 0xb0ce2

INCBIN "baserom.gbc",$b0ce2,$b0cf6 - $b0ce2

CeladonCafe_BlockData: ; 0xb0cf6
	INCBIN "maps/CeladonCafe.blk"
; 0xb0d0e

INCBIN "baserom.gbc",$b0d0e,$18

RockTunnel1F_BlockData: ; 0xb0d26
	INCBIN "maps/RockTunnel1F.blk"
; 0xb0e34

RockTunnelB1F_BlockData: ; 0xb0e34
	INCBIN "maps/RockTunnelB1F.blk"
; 0xb0f42

DiglettsCave_BlockData: ; 0xb0f42
	INCBIN "maps/DiglettsCave.blk"
; 0xb0ff6

MountMoon_BlockData: ; 0xb0ff6
	INCBIN "maps/MountMoon.blk"
; 0xb107d

SeafoamGym_BlockData: ; 0xb107d
	INCBIN "maps/SeafoamGym.blk"
; 0xb1091

MrPokemonsHouse_BlockData: ; 0xb1091
	INCBIN "maps/MrPokemonsHouse.blk"
; 0xb10a1

VictoryRoadGate_BlockData: ; 0xb10a1
	INCBIN "maps/VictoryRoadGate.blk"
; 0xb10fb

OlivinePortPassage_BlockData: ; 0xb10fb
	INCBIN "maps/OlivinePortPassage.blk"
; 0xb1155

FuchsiaGym_BlockData: ; 0xb1155
	INCBIN "maps/FuchsiaGym.blk"
; 0xb1182

SafariZoneBeta_BlockData: ; 0xb1182
	INCBIN "maps/SafariZoneBeta.blk"
; 0xb1236

Underground_BlockData: ; 0xb1236
	INCBIN "maps/Underground.blk"
; 0xb1260

Route39Barn_BlockData: ; 0xb1260
	INCBIN "maps/Route39Barn.blk"
; 0xb1270

VictoryRoad_BlockData: ; 0xb1270
	INCBIN "maps/VictoryRoad.blk"
; 0xb13d8

Route23_BlockData: ; 0xb13d8
	INCBIN "maps/Route23.blk"
; 0xb1432

LancesRoom_BlockData: ; 0xb1432
	INCBIN "maps/LancesRoom.blk"
; 0xb146e

HallOfFame_BlockData: ; 0xb146e
	INCBIN "maps/HallOfFame.blk"
; 0xb1491

CopycatsHouse1F_BlockData: ; 0xb1491
	INCBIN "maps/CopycatsHouse1F.blk"
; 0xb14a1

CopycatsHouse2F_BlockData: ; 0xb14a1
	INCBIN "maps/CopycatsHouse2F.blk"
; 0xb14b0

GoldenrodFlowerShop_BlockData: ; 0xb14b0
	INCBIN "maps/GoldenrodFlowerShop.blk"
; 0xb14c0

MountMoonSquare_BlockData: ; 0xb14c0
	INCBIN "maps/MountMoonSquare.blk"
; 0xb1547

WiseTriosRoom_BlockData: ; 0xb1547
	INCBIN "maps/WiseTriosRoom.blk"
; 0xb1557

DragonsDen1F_BlockData: ; 0xb1557
	INCBIN "maps/DragonsDen1F.blk"
; 0xb1584

DragonsDenB1F_BlockData: ; 0xb1584
	INCBIN "maps/DragonsDenB1F.blk"
; 0xb16ec

TohjoFalls_BlockData: ; 0xb16ec
	INCBIN "maps/TohjoFalls.blk"
; 0xb1773

RuinsofAlphHoOhItemRoom_BlockData: ; 0xb1773
	INCBIN "maps/RuinsofAlphHoOhItemRoom.blk"
; 0xb1787

RuinsofAlphHoOhWordRoom_BlockData: ; 0xb1787
	INCBIN "maps/RuinsofAlphHoOhWordRoom.blk"
; 0xb17ff

RuinsofAlphKabutoWordRoom_BlockData: ; 0xb17ff
	INCBIN "maps/RuinsofAlphKabutoWordRoom.blk"
; 0xb1845

RuinsofAlphOmanyteWordRoom_BlockData: ; 0xb1845
	INCBIN "maps/RuinsofAlphOmanyteWordRoom.blk"
; 0xb1895

RuinsofAlphAerodactylWordRoom_BlockData: ; 0xb1895
	INCBIN "maps/RuinsofAlphAerodactylWordRoom.blk"
; 0xb18db

DragonShrine_BlockData: ; 0xb18db
	INCBIN "maps/DragonShrine.blk"
; 0xb18f4

BattleTower1F_BlockData: ; 0xb18f4
	INCBIN "maps/BattleTower1F.blk"
; 0xb191c

BattleTowerBattleRoom_BlockData: ; 0xb191c
	INCBIN "maps/BattleTowerBattleRoom.blk"
; 0xb192c

GoldenrodPokeComCenter2FMobile_BlockData: ; 0xb192c
	INCBIN "maps/GoldenrodPokeComCenter2FMobile.blk"
; 0xb1a2c

MobileTradeRoomMobile_BlockData: ; 0xb1a2c
	INCBIN "maps/MobileTradeRoomMobile.blk"
; 0xb1a40

MobileBattleRoom_BlockData: ; 0xb1a40
	INCBIN "maps/MobileBattleRoom.blk"
; 0xb1a54

BattleTowerHallway_BlockData: ; 0xb1a54
	INCBIN "maps/BattleTowerHallway.blk"
; 0xb1a6a

BattleTowerElevator_BlockData: ; 0xb1a6a
	INCBIN "maps/BattleTowerElevator.blk"
; 0xb1a6e

BattleTowerOutside_BlockData: ; 0xb1a6e
	INCBIN "maps/BattleTowerOutside.blk"
; 0xb1afa

INCBIN "baserom.gbc",$b1afa,$28

GoldenrodDeptStoreRoof_BlockData: ; 0xb1b22
	INCBIN "maps/GoldenrodDeptStoreRoof.blk"
; 0xb1b42

SECTION "bank2D",DATA,BANK[$2D]

Tileset21GFX: ; b4000
INCBIN "gfx/tilesets/lz/21.lz"
; b4893

INCBIN "baserom.gbc", $b4893, $b4da0 - $b4893

Tileset22GFX: ; b4da0
INCBIN "gfx/tilesets/lz/22.lz"
; b50d1

INCBIN "baserom.gbc", $b50d1, $b55e0 - $b50d1

Tileset08GFX: ; b55e0
INCBIN "gfx/tilesets/lz/08.lz"
; b59db

INCBIN "baserom.gbc", $b59db, $b5ee0 - $b59db

Tileset02GFX:
Tileset04GFX: ; b5ee0
INCBIN "gfx/tilesets/lz/04.lz"
; b6ae7

INCBIN "baserom.gbc", $b6ae7, $b74e8 - $b6ae7

Tileset16GFX: ; b74e8
INCBIN "gfx/tilesets/lz/16.lz"
; b799a

INCBIN "baserom.gbc", $b799a, $b8000 - $b799a


SECTION "bank2E",DATA,BANK[$2E]

INCBIN "baserom.gbc",$B8000,$b8219 - $b8000

Functionb8219: ; b8219
; deals strictly with rockmon encounter
	xor a
	ld [$d22e], a
	ld [$d143], a
	ld hl, WildRockMonMapTable
	call GetTreeMonEncounterTable
	jr nc, .quit
	call LoadWildTreeMonData
	jr nc, .quit
	ld a, $0a
	call $2fb1
	cp a, $04
	jr nc, .quit
	call $441f
	jr nc, .quit
	ret
.quit
	xor a
	ret
; b823e

db $05 ; ????

GetTreeMonEncounterTable: ; b823f
; reads a map-sensitive encounter table
; compares current map with maps in the table
; if there is a match, encounter table # is loaded into a
	ld a, [MapNumber]
	ld e, a
	ld a, [MapGroup]
	ld d, a
.loop
	ld a, [hli]
	cp a, $ff
	jr z, .quit
	cp d
	jr nz, .skip2
	ld a, [hli]
	cp e
	jr nz, .skip1
	jr .end
.skip2
	inc hl
.skip1
	inc hl
	jr .loop
.quit
	xor a
	ret
.end
	ld a, [hl]
	scf
	ret
; b825e

INCBIN "baserom.gbc",$B825E,$b82c5 - $b825e

WildRockMonMapTable: ; b82c5
	db GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY, $07
	db GROUP_ROUTE_40, MAP_ROUTE_40, $07
	db GROUP_DARK_CAVE_VIOLET_ENTRANCE, MAP_DARK_CAVE_VIOLET_ENTRANCE, $07
	db GROUP_SLOWPOKE_WELL_B1F, MAP_SLOWPOKE_WELL_B1F, $07
	db $ff ; end
; b82d2

LoadWildTreeMonData: ; b82d2
; input: a = table number
; returns wildtreemontable pointer in hl
; sets carry if successful
	cp a, $08 ; which table?
	jr nc, .quit ; only 8 tables
	and a
	jr z, .quit ; 0 is invalid
	ld e, a
	ld d, $00
	ld hl, WildTreeMonPointerTable
	add hl, de
	add hl, de
	ld a, [hli] ; store pointer in hl
	ld h, [hl]
	ld l, a
	scf
	ret
.quit
	xor a
	ret
; b82e8

WildTreeMonPointerTable: ; b82e8
; seems to point to "normal" tree encounter data
; as such only odd-numbered tables are used
; rockmon is 13th
	dw WildTreeMonTable1  ; filler
	dw WildTreeMonTable1  ; 1
	dw WildTreeMonTable3  ; 2
	dw WildTreeMonTable5  ; 3
	dw WildTreeMonTable7  ; 4
	dw WildTreeMonTable9  ; 5
	dw WildTreeMonTable11 ; 6
	dw WildRockMonTable   ; 7
	dw WildTreeMonTable1  ; 8
; b82fa

; structure: % species level

WildTreeMonTable1: ; b82fa
	db 50, SPEAROW, 10
	db 15, SPEAROW, 10
	db 15, SPEAROW, 10
	db 10, AIPOM, 10
	db 5, AIPOM, 10
	db 5, AIPOM, 10
	db $ff ; end
; b830d

WildTreeMonTable2 ; b830d
; unused
	db 50, SPEAROW, 10
	db 15, HERACROSS, 10
	db 15, HERACROSS, 10
	db 10, AIPOM, 10
	db 5, AIPOM, 10
	db 5, AIPOM, 10
	db $ff ; end
; b8320

WildTreeMonTable3: ; b8320
	db 50, SPEAROW, 10
	db 15, EKANS, 10
	db 15, SPEAROW, 10
	db 10, AIPOM, 10
	db 5, AIPOM, 10
	db 5, AIPOM, 10
	db $ff ; end
; b8333

WildTreeMonTable4: ; b8333
; unused
	db 50, SPEAROW, 10
	db 15, HERACROSS, 10
	db 15, HERACROSS, 10
	db 10, AIPOM, 10
	db 5, AIPOM, 10
	db 5, AIPOM, 10
	db $ff ; end
; b8346

WildTreeMonTable5: ; b8346
	db 50, HOOTHOOT, 10
	db 15, SPINARAK, 10
	db 15, LEDYBA, 10
	db 10, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db $ff ; end
; b8359

WildTreeMonTable6: ; b8359
; unused
	db 50, HOOTHOOT, 10
	db 15, PINECO, 10
	db 15, PINECO, 10
	db 10, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db $ff ; end
; b836c

WildTreeMonTable7: ; b836c
	db 50, HOOTHOOT, 10
	db 15, EKANS, 10
	db 15, HOOTHOOT, 10
	db 10, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db $ff ; end
; b837f

WildTreeMonTable8: ; b837f
; unused
	db 50, HOOTHOOT, 10
	db 15, PINECO, 10
	db 15, PINECO, 10
	db 10, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db $ff ; end
; b8392

WildTreeMonTable9: ; b8392
	db 50, HOOTHOOT, 10
	db 15, VENONAT, 10
	db 15, HOOTHOOT, 10
	db 10, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db $ff ; end
; b83a5

WildTreeMonTable10: ; b83a5
; unused
	db 50, HOOTHOOT, 10
	db 15, PINECO, 10
	db 15, PINECO, 10
	db 10, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db 5, EXEGGCUTE, 10
	db $ff ; end
; b83b8

WildTreeMonTable11: ; b83b8
	db 50, HOOTHOOT, 10
	db 15, PINECO, 10
	db 15, PINECO, 10
	db 10, NOCTOWL, 10
	db 5, BUTTERFREE, 10
	db 5, BEEDRILL, 10
	db $ff ; end
; b83cb

WildTreeMonTable12; b83cb
; unused
	db 50, HOOTHOOT, 10
	db 15, CATERPIE, 10
	db 15, WEEDLE, 10
	db 10, HOOTHOOT, 10
	db 5, METAPOD, 10
	db 5, KAKUNA, 10
	db $ff ; end
; b83de

WildRockMonTable: ; b83de
	db 90, KRABBY, 15
	db 10, SHUCKLE, 15
	db $ff ; end
; b83e5

INCBIN "baserom.gbc",$B83E5,$bc000 - $b83e5

SECTION "bank2F",DATA,BANK[$2F]

INCBIN "baserom.gbc",$BC000,$4000

SECTION "bank30",DATA,BANK[$30]

INCBIN "baserom.gbc",$C0000,$4000

SECTION "bank31",DATA,BANK[$31]

INCBIN "baserom.gbc",$C4000,$4000

SECTION "bank32",DATA,BANK[$32]

INCBIN "baserom.gbc",$C8000,$4000

SECTION "bank33",DATA,BANK[$33]

INCBIN "baserom.gbc",$cc000, $cfd9e - $cc000

Music_PostCredits: ; 0xcfd9e
INCLUDE "music/postcredits.asm"
; 0xcff04

INCBIN "baserom.gbc",$cff04, $d0000 - $cff04

SECTION "bank34",DATA,BANK[$34]

INCBIN "baserom.gbc",$D0000,$4000

SECTION "bank35",DATA,BANK[$35]

INCBIN "baserom.gbc",$D4000,$4000

SECTION "bank36",DATA,BANK[$36]

FontInversed:
INCBIN "gfx/font_inversed.1bpp",$0,$400

INCBIN "baserom.gbc",$D8400,$4000-$400

SECTION "bank37",DATA,BANK[$37]

Tileset31GFX: ; dc000
INCBIN "gfx/tilesets/lz/31.lz"
; dc3ce

INCBIN "baserom.gbc", $dc3ce, $dc3d0 - $dc3ce

Tileset18GFX: ; dc3d0
INCBIN "gfx/tilesets/lz/18.lz"
; dcc4e

INCBIN "baserom.gbc", $dcc4e, $dd150 - $dcc4e

Tileset05GFX: ; dd150
INCBIN "gfx/tilesets/lz/05.lz"
; dd5f8

INCBIN "baserom.gbc", $dd5f8, $ddb00 - $dd5f8

Tileset19GFX: ; ddb00
INCBIN "gfx/tilesets/lz/19.lz"
; ddf64

INCBIN "baserom.gbc", $ddf64, $de570 - $ddf64

Tileset11GFX: ; de570
INCBIN "gfx/tilesets/lz/11.lz"
; de98a

INCBIN "baserom.gbc", $de98a, $e0000 - $de98a


SECTION "bank38",DATA,BANK[$38]

INCBIN "baserom.gbc",$E0000,$4000


SECTION "bank39",DATA,BANK[$39]

INCBIN "baserom.gbc", $e4000, $e555d - $e4000

IntroSuicuneRunGFX: ; e555d
INCBIN "gfx/intro/lz/suicune_run.lz"
; e592b

INCBIN "baserom.gbc", $e592b, $e592d - $e592b

IntroPichuWooperGFX: ; e592d
INCBIN "gfx/intro/lz/pichu_wooper.lz"
; e5c70

INCBIN "baserom.gbc", $e5c70, $e5c7d - $e5c70

IntroBackgroundGFX: ; e5c7d
INCBIN "gfx/intro/lz/background.lz"
; e5e69

INCBIN "baserom.gbc", $e5e69, $e5e6d - $e5e69

IntroTilemap004: ; e5e6d
INCBIN "gfx/intro/lz/004.lz"
; e5ec5

INCBIN "baserom.gbc", $e5ec5, $e5ecd - $e5ec5

IntroTilemap003: ; e5ecd
INCBIN "gfx/intro/lz/003.lz"
; e5ed9

INCBIN "baserom.gbc", $e5ed9, $e5f5d - $e5ed9

IntroUnownsGFX: ; e5f5d
INCBIN "gfx/intro/lz/unowns.lz"
; e6348

INCBIN "baserom.gbc", $e6348, $e634d - $e6348

IntroPulseGFX: ; e634d
INCBIN "gfx/intro/lz/pulse.lz"
; e63d4

INCBIN "baserom.gbc", $e63d4, $e63dd - $e63d4

IntroTilemap002: ; e63dd
INCBIN "gfx/intro/lz/002.lz"
; e6418

INCBIN "baserom.gbc", $e6418, $e641d - $e6418

IntroTilemap001: ; e641d
INCBIN "gfx/intro/lz/001.lz"
; e6429

INCBIN "baserom.gbc", $e6429, $e642d - $e6429

IntroTilemap006: ; e642d
INCBIN "gfx/intro/lz/006.lz"
; e6472

INCBIN "baserom.gbc", $e6472, $e647d - $e6472

IntroTilemap005: ; e647d
INCBIN "gfx/intro/lz/005.lz"
; e6498

INCBIN "baserom.gbc", $e6498, $e649d - $e6498

IntroTilemap008: ; e649d
INCBIN "gfx/intro/lz/008.lz"
; e6550

INCBIN "baserom.gbc", $e6550, $e655d - $e6550

IntroTilemap007: ; e655d
INCBIN "gfx/intro/lz/007.lz"
; e65a4

INCBIN "baserom.gbc", $e65a4, $e662d - $e65a4

IntroCrystalUnownsGFX: ; e662d
INCBIN "gfx/intro/lz/crystal_unowns.lz"
; e6720

INCBIN "baserom.gbc", $e6720, $e672d - $e6720

IntroTilemap017: ; e672d
INCBIN "gfx/intro/lz/017.lz"
; e6761

INCBIN "baserom.gbc", $e6761, $e676d - $e6761

IntroTilemap015: ; e676d
INCBIN "gfx/intro/lz/015.lz"
; e6794

INCBIN "baserom.gbc", $e6794, $e681d - $e6794

IntroSuicuneCloseGFX: ; e681d
INCBIN "gfx/intro/lz/suicune_close.lz"
; e6c37

INCBIN "baserom.gbc", $e6c37, $e6c3d - $e6c37

IntroTilemap012: ; e6c3d
INCBIN "gfx/intro/lz/012.lz"
; e6d0a

INCBIN "baserom.gbc", $e6d0a, $e6d0d - $e6d0a

IntroTilemap011: ; e6d0d
INCBIN "gfx/intro/lz/011.lz"
; e6d65

INCBIN "baserom.gbc", $e6d65, $e6ded - $e6d65

IntroSuicuneJumpGFX: ; e6ded
INCBIN "gfx/intro/lz/suicune_jump.lz"
; e72a7

INCBIN "baserom.gbc", $e72a7, $e72ad - $e72a7

IntroSuicuneBackGFX: ; e72ad
INCBIN "gfx/intro/lz/suicune_back.lz"
; e7648

INCBIN "baserom.gbc", $e7648, $e764d - $e7648

IntroTilemap010: ; e764d
INCBIN "gfx/intro/lz/010.lz"
; e76a0

INCBIN "baserom.gbc", $e76a0, $e76ad - $e76a0

IntroTilemap009: ; e76ad
INCBIN "gfx/intro/lz/009.lz"
; e76bb

INCBIN "baserom.gbc", $e76bb, $e76bd - $e76bb

IntroTilemap014: ; e76bd
INCBIN "gfx/intro/lz/014.lz"
; e778b

INCBIN "baserom.gbc", $e778b, $e778d - $e778b

IntroTilemap013: ; e778d
INCBIN "gfx/intro/lz/013.lz"
; e77d9

INCBIN "baserom.gbc", $e77d9, $e785d - $e77d9

IntroUnownBackGFX: ; e785d
INCBIN "gfx/intro/lz/unown_back.lz"
; e799a

INCBIN "baserom.gbc", $e799a, $e7a70 - $e799a


SECTION "bank3A",DATA,BANK[$3A]

SoundRestart: ; e8000
; restart sound operation
; clear all relevant hardware registers & wram
	push hl
	push de
	push bc
	push af
	call MusicOff
	ld hl, $ff24 ; channel control registers
	xor a
	ld [hli], a ; ff24 ; volume/vin
	ld [hli], a ; ff25 ; sfx channels
	ld a, $80 ; all channels on
	ld [hli], a ; ff26 ; music channels

	ld hl, $ff10 ; sound channel registers
	ld e, $04 ; number of channels
.clearsound
;   sound channel   1      2      3      4
	xor a
	ld [hli], a ; $ff10, $ff15, $ff1a, $ff1f ; sweep = 0

	ld [hli], a ; $ff11, $ff16, $ff1b, $ff20 ; length/wavepattern = 0
	ld a, $08
	ld [hli], a ; $ff12, $ff17, $ff1c, $ff21 ; envelope = 0
	xor a
	ld [hli], a ; $ff13, $ff18, $ff1d, $ff22 ; frequency lo = 0
	ld a, $80
	ld [hli], a ; $ff14, $ff19, $ff1e, $ff23 ; restart sound (freq hi = 0)
	dec e
	jr nz, .clearsound

	ld hl, Channel1 ; start of channel data
	ld de, $01bf ; length of area to clear (entire sound wram area)
.clearchannels ; clear $c101-$c2bf
	xor a
	ld [hli], a
	dec de
	ld a, e
	or d
	jr nz, .clearchannels
	ld a, $77 ; max
	ld [Volume], a
	call MusicOn
	pop af
	pop bc
	pop de
	pop hl
	ret
; e803d

MusicFadeRestart: ; e803d
; restart but keep the music id to fade in to
	ld a, [MusicFadeIDHi]
	push af
	ld a, [MusicFadeIDLo]
	push af
	call SoundRestart
	pop af
	ld [MusicFadeIDLo], a
	pop af
	ld [MusicFadeIDHi], a
	ret
; e8051

MusicOn: ; e8051
	ld a, $01
	ld [MusicPlaying], a
	ret
; e8057

MusicOff: ; e8057
	xor a
	ld [MusicPlaying], a
	ret
; e805c

UpdateSound: ; e805c
; called once per frame
	; no use updating audio if it's not playing
	ld a, [MusicPlaying]
	and a
	ret z
	; start at ch1
	xor a
	ld [CurChannel], a ; just
	ld [SoundOutput], a ; off
	ld bc, Channel1
.loop
	; is the channel active?
	ld hl, Channel1Flags - Channel1
	add hl, bc
	bit 0, [hl]
	jp z, .nextchannel
	; check time left in the current note
	ld hl, Channel1NoteDuration - Channel1
	add hl, bc
	ld a, [hl]
	cp a, $02 ; 1 or 0?
	jr c, .noteover
	dec [hl]
	jr .asm_e8093
.noteover
	; reset vibrato delay
	ld hl, Channel1VibratoDelay - Channel1
	add hl, bc
	ld a, [hl]
	ld hl, Channel1VibratoDelayCount - Channel1
	add hl, bc
	ld [hl], a
	; turn vibrato off for now
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	res 1, [hl]
	; get next note
	call ParseMusic
.asm_e8093
	;
	call Functione84f9
	; duty cycle
	ld hl, Channel1DutyCycle - Channel1
	add hl, bc
	ld a, [hli]
	ld [$c292], a
	; intensity
	ld a, [hli]
	ld [$c293], a
	; frequency
	ld a, [hli]
	ld [$c294], a
	ld a, [hl]
	ld [$c295], a
	;
	call Functione8466 ; handle vibrato and other things
	call HandleNoise
	; turn off music when playing sfx?
	ld a, [SFXPriority]
	and a
	jr z, .next
	; are we in a sfx channel right now?
	ld a, [CurChannel]
	cp a, $04
	jr nc, .next
	; are any sfx channels active?
	; if so, mute
	ld hl, $c1cc ; Channel5Flags
	bit 0, [hl]
	jr nz, .restnote
	ld hl, $c1fe ; Channel6Flags
	bit 0, [hl]
	jr nz, .restnote
	ld hl, $c230 ; Channel7Flags
	bit 0, [hl]
	jr nz, .restnote
	ld hl, $c262 ; Channel8Flags
	bit 0, [hl]
	jr z, .next
.restnote
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 5, [hl] ; Rest
.next
	; are we in a sfx channel right now?
	ld a, [CurChannel]
	cp a, $04 ; sfx
	jr nc, .asm_e80ee
	ld hl, $00cb
	add hl, bc
	bit 0, [hl]
	jr nz, .asm_e80fc
.asm_e80ee
	call UpdateChannels
	ld hl, Channel1Tracks - Channel1
	add hl, bc
	ld a, [SoundOutput]
	or [hl]
	ld [SoundOutput], a
.asm_e80fc
	; clear note flags
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	xor a
	ld [hl], a
.nextchannel
	; next channel
	ld hl, Channel2 - Channel1
	add hl, bc
	ld c, l
	ld b, h
	ld a, [CurChannel]
	inc a
	ld [CurChannel], a
	cp a, $08 ; are we done?
	jp nz, .loop ; do it all again
	; writing to hardware registers?
	call Functione8307
	; fade music in/out
	call FadeMusic
	; write volume to hardware register
	ld a, [Volume]
	ld [$ff24], a
	; write SO on/off to hardware register
	ld a, [SoundOutput]
	ld [$ff25], a
	ret
; e8125

UpdateChannels: ; e8125
	ld hl, .ChannelFnPtrs
	ld a, [CurChannel]
	and a, $07
	add a
	ld e, a
	ld d, $00
	add hl, de
	ld a, [hli]
	ld h, [hl]
	ld l, a
	jp [hl]

.ChannelFnPtrs
	dw .Channel1
	dw .Channel2
	dw .Channel3
	dw .Channel4
; sfx ch ptrs are identical to music chs
; ..except 5
	dw .Channel5
	dw .Channel6
	dw .Channel7
	dw .Channel8

.Channel1
	ld a, [$c2a6]
	bit 7, a
	ret nz
.Channel5
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	bit 3, [hl]
	jr z, .asm_e8159
	;
	ld a, [SoundInput]
	ld [$ff10], a
.asm_e8159
	bit 5, [hl] ; rest
	jr nz, .ch1rest
	bit 4, [hl]
	jr nz, .asm_e81a2
	bit 1, [hl]
	jr nz, .asm_e816b
	bit 6, [hl]
	jr nz, .asm_e8184
	jr .asm_e8175
.asm_e816b
	ld a, [$c294]
	ld [$ff13], a
	ld a, [$c295]
	ld [$ff14], a
.asm_e8175
	bit 0, [hl]
	ret z
	ld a, [$c292]
	ld d, a
	ld a, [$ff11]
	and a, $3f ; sound length
	or d
	ld [$ff11], a
	ret
.asm_e8184
	ld a, [$c292]
	ld d, a
	ld a, [$ff11]
	and a, $3f ; sound length
	or d
	ld [$ff11], a
	ld a, [$c294]
	ld [$ff13], a
	ret
.ch1rest
	ld a, [$ff26]
	and a, %10001110 ; ch1 off
	ld [$ff26], a
	ld hl, $ff10
	call ClearChannel
	ret
.asm_e81a2
	ld hl, $c292
	ld a, $3f ; sound length
	or [hl]
	ld [$ff11], a
	ld a, [$c293]
	ld [$ff12], a
	ld a, [$c294]
	ld [$ff13], a
	ld a, [$c295]
	or a, $80
	ld [$ff14], a
	ret

.Channel2
.Channel6
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	bit 5, [hl] ; rest
	jr nz, .ch2rest
	bit 4, [hl]
	jr nz, .asm_e8204
	bit 6, [hl]
	jr nz, .asm_e81e6
	bit 0, [hl]
	ret z
	ld a, [$c292]
	ld d, a
	ld a, [$ff16]
	and a, $3f ; sound length
	or d
	ld [$ff16], a
	ret
.asm_e81db ; unused
	ld a, [$c294]
	ld [$ff18], a
	ld a, [$c295]
	ld [$ff19], a
	ret
.asm_e81e6
	ld a, [$c292]
	ld d, a
	ld a, [$ff16]
	and a, $3f ; sound length
	or d
	ld [$ff16], a
	ld a, [$c294]
	ld [$ff18], a
	ret
.ch2rest
	ld a, [$ff26]
	and a, %10001101 ; ch2 off
	ld [$ff26], a
	ld hl, $ff15
	call ClearChannel
	ret
.asm_e8204
	ld hl, $c292
	ld a, $3f ; sound length
	or [hl]
	ld [$ff16], a
	ld a, [$c293]
	ld [$ff17], a
	ld a, [$c294]
	ld [$ff18], a
	ld a, [$c295]
	or a, $80 ; initial (restart)
	ld [$ff19], a
	ret

.Channel3
.Channel7
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	bit 5, [hl] ; rest
	jr nz, .ch3rest
	bit 4, [hl]
	jr nz, .asm_e824d
	bit 6, [hl]
	jr nz, .asm_e823a
	ret
.asm_e822f ; unused
	ld a, [$c294]
	ld [$ff1d], a
	ld a, [$c295]
	ld [$ff1e], a
	ret
.asm_e823a
	ld a, [$c294]
	ld [$ff1d], a
	ret
.ch3rest
	ld a, [$ff26]
	and a, %10001011 ; ch3 off
	ld [$ff26], a
	ld hl, $ff1a
	call ClearChannel
	ret
.asm_e824d
	ld a, $3f
	ld [$ff1b], a
	xor a
	ld [$ff1a], a
	call .asm_e8268
	ld a, $80
	ld [$ff1a], a
	ld a, [$c294]
	ld [$ff1d], a
	ld a, [$c295]
	or a, $80
	ld [$ff1e], a
	ret
.asm_e8268
	push hl
	ld a, [$c293]
	and a, $0f ; only 0-9 are valid
	ld l, a
	ld h, $00
	; hl << 4
	; each wavepattern is $0f bytes long
	; so seeking is done in $10s
	add hl, hl
	add hl, hl
	add hl, hl
	add hl, hl
	ld de, WaveSamples
	add hl, de
	; load wavepattern into $ff30-$ff3f
	ld a, [hli]
	ld [$ff30], a
	ld a, [hli]
	ld [$ff31], a
	ld a, [hli]
	ld [$ff32], a
	ld a, [hli]
	ld [$ff33], a
	ld a, [hli]
	ld [$ff34], a
	ld a, [hli]
	ld [$ff35], a
	ld a, [hli]
	ld [$ff36], a
	ld a, [hli]
	ld [$ff37], a
	ld a, [hli]
	ld [$ff38], a
	ld a, [hli]
	ld [$ff39], a
	ld a, [hli]
	ld [$ff3a], a
	ld a, [hli]
	ld [$ff3b], a
	ld a, [hli]
	ld [$ff3c], a
	ld a, [hli]
	ld [$ff3d], a
	ld a, [hli]
	ld [$ff3e], a
	ld a, [hli]
	ld [$ff3f], a
	pop hl
	ld a, [$c293]
	and a, $f0
	sla a
	ld [$ff1c], a
	ret

.Channel4
.Channel8
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	bit 5, [hl] ; rest
	jr nz, .ch4rest
	bit 4, [hl]
	jr nz, .asm_e82d4
	ret
.asm_e82c1 ; unused
	ld a, [$c294]
	ld [$ff22], a
	ret
.ch4rest
	ld a, [$ff26]
	and a, %10000111 ; ch4 off
	ld [$ff26], a
	ld hl, $ff1f
	call ClearChannel
	ret
.asm_e82d4
	ld a, $3f ; sound length
	ld [$ff20], a
	ld a, [$c293]
	ld [$ff21], a
	ld a, [$c294]
	ld [$ff22], a
	ld a, $80
	ld [$ff23], a
	ret
; e82e7

_CheckSFX: ; e82e7
; return carry if any sfx channels are active
	ld hl, $c1cc ; Channel5Flags
	bit 0, [hl]
	jr nz, .sfxon
	ld hl, $c1fe ; Channel6Flags
	bit 0, [hl]
	jr nz, .sfxon
	ld hl, $c230 ; Channel7Flags
	bit 0, [hl]
	jr nz, .sfxon
	ld hl, $c262 ; Channel8Flags
	bit 0, [hl]
	jr nz, .sfxon
	and a
	ret
.sfxon
	scf
	ret
; e8307

Functione8307: ; e8307
; what is $c2a6?
	ld a, [$c2a6]
	bit 7, a
	ret z
	and a, $7f
	ld d, a
	call _CheckSFX
	jr c, .asm_e8335
	and a
	jr z, .asm_e8323
	cp a, $10
	jr z, .asm_e831e
	jr .asm_e8335
.asm_e831e
	ld hl, Tablee8354
	jr .updatehw
.asm_e8323
	ld hl, Tablee8350
.updatehw
	xor a
	ld [$ff10], a ; sweep off
	ld a, [hli]
	ld [$ff11], a ; sound length / duty cycle
	ld a, [hli]
	ld [$ff12], a ; ch1 volume envelope
	ld a, [hli]
	ld [$ff13], a ; ch1 frequency lo
	ld a, [hli]
	ld [$ff14], a ; ch1 frequency hi
.asm_e8335
	ld a, d
	inc a
	cp a, $1e
	jr c, .asm_e833c
	xor a
.asm_e833c
	or a, $80
	ld [$c2a6], a
	; is hw ch1 on?
	ld a, [SoundOutput]
	and a, $11
	ret nz
	; if not, turn it on
	ld a, [SoundOutput]
	or a, $11
	ld [SoundOutput], a
	ret
; e8350

Tablee8350: ; e8350
	db $80 ; duty 50%
	db $e2 ; volume $e, envelope decrease sweep 2
	db $50 ; frequency: $750
	db $87 ; restart sound
; e8354

Tablee8354: ; e8354
	db $80 ; duty 50%
	db $e2 ; volume $e, envelope decrease sweep 2
	db $ee ; frequency: $6ee
	db $86 ; restart sound
; e8358

FadeMusic: ; e8358
; fade music if applicable
; usage:
;	write to MusicFade
;	song fades out at the given rate
;	load song id in MusicFadeID
;	fade new song in
; notes:
;	max # frames per volume level is $3f

	; fading?
	ld a, [MusicFade]
	and a
	ret z
	; has the count ended?
	ld a, [MusicFadeCount]
	and a
	jr z, .update
	; count down
	dec a
	ld [MusicFadeCount], a
	ret
.update
	ld a, [MusicFade]
	ld d, a
	; get new count
	and a, $3f
	ld [MusicFadeCount], a
	; get SO1 volume
	ld a, [Volume]
	and a, $07
	; which way are we fading?
	bit 7, d
	jr nz, .fadein
	; fading out
	and a
	jr z, .novolume
	dec a
	jr .updatevolume
.novolume
	; make sure volume is off
	xor a
	ld [Volume], a
	; did we just get on a bike?
	ld a, [PlayerState]
	cp a, $01 ; bicycle
	jr z, .bicycle
	push bc
	; restart sound
	call MusicFadeRestart
	; get new song id
	ld a, [MusicFadeIDLo]
	and a
	jr z, .quit ; this assumes there are fewer than 256 songs!
	ld e, a
	ld a, [MusicFadeIDHi]
	ld d, a
	; load new song
	call LoadMusic
.quit
	; cleanup
	pop bc
	; stop fading
	xor a
	ld [MusicFade], a
	ret
.bicycle
	push bc
	; restart sound
	call MusicFadeRestart
	; this turns the volume up
	; turn it back down
	xor a
	ld [Volume], a
	; get new song id
	ld a, [MusicFadeIDLo]
	ld e, a
	ld a, [MusicFadeIDHi]
	ld d, a
	; load new song
	call LoadMusic
	pop bc
	; fade in
	ld hl, MusicFade
	set 7, [hl]
	ret
.fadein
	; are we done?
	cp a, $07
	jr nc, .maxvolume
	; inc volume
	inc a
	jr .updatevolume
.maxvolume
	; we're done
	xor a
	ld [MusicFade], a
	ret
.updatevolume
	; hi = lo
	ld d, a
	swap a
	or d
	ld [Volume], a
	ret
; e83d1

LoadNote: ; e83d1
	; check mute??
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	bit 1, [hl]
	ret z
	; get note duration
	ld hl, Channel1NoteDuration - Channel1
	add hl, bc
	ld a, [hl]
	ld hl, $c297 ; ????
	sub [hl]
	jr nc, .ok
	ld a, $01
.ok
	ld [hl], a
	; get frequency
	ld hl, Channel1Frequency - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	; ????
	ld hl, $0021
	add hl, bc
	ld a, e
	sub [hl]
	ld e, a
	ld a, d
	sbc a, $00
	ld d, a
	; ????
	ld hl, $0022
	add hl, bc
	sub [hl]
	jr nc, .asm_e8420
	; ????
	ld hl, Channel1Flags3 - Channel1
	add hl, bc
	set 1, [hl]
	; get frequency
	ld hl, Channel1Frequency - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	; ????
	ld hl, $0021
	add hl, bc
	ld a, [hl]
	sub e
	ld e, a
	ld a, d
	sbc a, $00
	ld d, a
	; ????
	ld hl, $0022
	add hl, bc
	ld a, [hl]
	sub d
	ld d, a
	jr .asm_e843e
.asm_e8420
	; ????
	ld hl, Channel1Flags3 - Channel1
	add hl, bc
	res 1, [hl]
	; get frequency
	ld hl, Channel1Frequency - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	; ????
	ld hl, $0021
	add hl, bc
	ld a, e
	sub [hl]
	ld e, a
	ld a, d
	sbc a, $00
	ld d, a
	; ????
	ld hl, $0022
	add hl, bc
	sub [hl]
	ld d, a
.asm_e843e
	push bc
	ld hl, $c297
	ld b, $00 ; loop count
.loop
	inc b
	ld a, e
	sub [hl]
	ld e, a
	jr nc, .loop
	ld a, d
	and a
	jr z, .quit
	dec d
	jr .loop
.quit
	ld a, e ; result
	add [hl]
	ld d, b ; loop count
	; ????
	pop bc
	ld hl, $0023
	add hl, bc
	ld [hl], d
	ld hl, $0024
	add hl, bc
	ld [hl], a
	; clear ????
	ld hl, $0025
	add hl, bc
	xor a
	ld [hl], a
	ret
; e8466

Functione8466: ; e8466
; handle vibrato and other things
; unknowns: $c292, $c294
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	bit 2, [hl]
	jr z, .next
	ld hl, $001c
	add hl, bc
	ld a, [hl]
	rlca
	rlca
	ld [hl], a
	and a, $c0
	ld [$c292], a
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 0, [hl]
.next
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	bit 4, [hl]
	jr z, .vibrato
	ld hl, $0027
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	ld hl, $c294
	ld a, [hli]
	ld h, [hl]
	ld l, a
	add hl, de
	ld e, l
	ld d, h
	ld hl, $c294
	ld [hl], e
	inc hl
	ld [hl], d
.vibrato
	; is vibrato on?
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	bit 0, [hl] ; vibrato
	jr z, .quit
	; is vibrato active for this note yet?
	; is the delay over?
	ld hl, Channel1VibratoDelayCount - Channel1
	add hl, bc
	ld a, [hl]
	and a
	jr nz, .subexit
	; is the extent nonzero?
	ld hl, Channel1VibratoExtent - Channel1
	add hl, bc
	ld a, [hl]
	and a
	jr z, .quit
	; save it for later
	ld d, a
	; is it time to toggle vibrato up/down?
	ld hl, Channel1VibratoRate - Channel1
	add hl, bc
	ld a, [hl]
	and a, $0f ; count
	jr z, .toggle
.subexit
	dec [hl]
	jr .quit
.toggle
	; refresh count
	ld a, [hl]
	swap [hl]
	or [hl]
	ld [hl], a
	; ????
	ld a, [$c294]
	ld e, a
	; toggle vibrato up/down
	ld hl, Channel1Flags3 - Channel1
	add hl, bc
	bit 0, [hl] ; vibrato up/down
	jr z, .down
; up
	; vibrato down
	res 0, [hl]
	; get the delay
	ld a, d
	and a, $0f ; lo
	;
	ld d, a
	ld a, e
	sub d
	jr nc, .asm_e84ef
	ld a, $00
	jr .asm_e84ef
.down
	; vibrato up
	set 0, [hl]
	; get the delay
	ld a, d
	and a, $f0 ; hi
	swap a ; move it to lo
	;
	add e
	jr nc, .asm_e84ef
	ld a, $ff
.asm_e84ef
	ld [$c294], a
	;
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 6, [hl]
.quit
	ret
; e84f9

Functione84f9: ; e84f9
	; quit if ????
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	bit 1, [hl]
	ret z
	; de = Frequency
	ld hl, Channel1Frequency - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	;
	ld hl, Channel1Flags3 - Channel1
	add hl, bc
	bit 1, [hl]
	jr z, .next
	;
	ld hl, $0023
	add hl, bc
	ld l, [hl]
	ld h, $00
	add hl, de
	ld d, h
	ld e, l
	; get ????
	ld hl, $0024
	add hl, bc
	ld a, [hl]
	; add it to ????
	ld hl, $0025
	add hl, bc
	add [hl]
	ld [hl], a
	ld a, $00
	adc e
	ld e, a
	ld a, $00
	adc d
	ld d, a
	;
	ld hl, $0022
	add hl, bc
	ld a, [hl]
	cp d
	jp c, .quit1
	jr nz, .quit2
	ld hl, $0021
	add hl, bc
	ld a, [hl]
	cp e
	jp c, .quit1
	jr .quit2
.next
	ld a, e
	ld hl, $0023
	add hl, bc
	ld e, [hl]
	sub e
	ld e, a
	ld a, d
	sbc a, $00
	ld d, a
	ld hl, $0024
	add hl, bc
	ld a, [hl]
	add a
	ld [hl], a
	ld a, e
	sbc a, $00
	ld e, a
	ld a, d
	sbc a, $00
	ld d,a
	ld hl, $0022
	add hl, bc
	ld a, d
	cp [hl]
	jr c, .quit1
	jr nz, .quit2
	ld hl, $0021
	add hl, bc
	ld a, e
	cp [hl]
	jr nc, .quit2
.quit1
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	res 1, [hl]
	ld hl, Channel1Flags3 - Channel1
	add hl, bc
	res 1, [hl]
	ret
.quit2
	ld hl, Channel1Frequency - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 1, [hl]
	set 0, [hl]
	ret
; e858c

HandleNoise: ; e858c
	; is noise sampling on?
	ld hl, Channel1Flags - Channel1
	add hl, bc
	bit 4, [hl] ; noise sampling
	ret z
	; are we in a sfx channel?
	ld a, [CurChannel]
	bit 2, a ; sfx
	jr nz, .next
	; is ch8 on? (noise)
	ld hl, $c262 ; Channel8Flags
	bit 0, [hl] ; on?
	jr z, .next
	; is ch8 playing noise?
	bit 4, [hl]
	ret nz ; quit if so
	;
.next
	ld a, [$c2a2]
	and a
	jr z, ReadNoiseSample
	dec a
	ld [$c2a2], a
	ret
; e85af

ReadNoiseSample: ; e85af
; sample struct:
;	[wx] [yy] [zz]
;	w: ? either 2 or 3
;	x: ? 0-7
;	zzyy: pointer to sample data
;		NOTE: these seem to have $4000 added to them later

	; de = NoiseSampleAddress
	ld hl, NoiseSampleAddress
	ld e, [hl]
	inc hl
	ld d, [hl]
	; is it empty?
	ld a, e
	or d
	jr z, .quit
	; get the noise sample
	ld a, [de]
	inc de
	; are we done?
	cp a, $ff
	jr z, .quit
	;
	and a, $0f ; bottom nybble
	inc a
	ld [$c2a2], a
	ld a, [de]
	inc de
	ld [$c293], a
	ld a, [de]
	inc de
	ld [$c294], a
	xor a
	ld [$c295], a
	;
	ld hl, NoiseSampleAddress
	ld [hl], e
	inc hl
	ld [hl], d
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 4, [hl]
	ret
.quit
	ret
; e85e1

ParseMusic: ; e85e1
; parses until a note is read or the song is ended
	call GetMusicByte ; store next byte in a
	cp a, $ff ; is the song over?
	jr z, .readff
	cp a, $d0 ; is it a note?
	jr c, .readnote
	; then it's a command
.readcommand
	call ParseCommand
	jr ParseMusic ; start over

.readnote
; CurMusicByte contains current note
; special notes
	ld hl, Channel1Flags - Channel1
	add hl, bc
	bit 3, [hl]
	jp nz, Functione8698
	bit 5, [hl]
	jp nz, Functione8698
	bit 4, [hl] ; noise sample
	jp nz, GetNoiseSample
; normal note
	; set note duration (bottom nybble)
	ld a, [CurMusicByte]
	and a, $0f
	call SetNoteDuration
	; get note pitch (top nybble)
	ld a, [CurMusicByte]
	swap a
	and a, $0f
	jr z, .rest ; pitch $0 -> rest
	; update pitch
	ld hl, Channel1Pitch - Channel1
	add hl, bc
	ld [hl], a
	; store pitch in e
	ld e, a
	; store octave in d
	ld hl, Channel1Octave - Channel1
	add hl, bc
	ld d, [hl]
	; update frequency
	call GetFrequency
	ld hl, Channel1Frequency - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	; ????
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 4, [hl]
	jp LoadNote
.rest
; note = rest
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 5, [hl] ; Rest
	ret
;
.readff
; $ff is reached in music data
	ld hl, Channel1Flags - Channel1
	add hl, bc
	bit 1, [hl] ; in a subroutine?
	jr nz, .readcommand ; execute
	ld a, [CurChannel]
	cp a, $04 ; channels 0-3?
	jr nc, .asm_e8651
	; ????
	ld hl, $00cb
	add hl, bc
	bit 0, [hl]
	jr nz, .ok
.asm_e8651
	ld hl, Channel1Flags - Channel1
	add hl, bc
	bit 5, [hl]
	call nz, RestoreVolume
	; end music
	ld a, [CurChannel]
	cp a, $04 ; channel 5?
	jr nz, .ok
	; ????
	xor a
	ld [$ff10], a ; sweep = 0
.ok
; stop playing
	; turn channel off
	ld hl, Channel1Flags - Channel1
	add hl, bc
	res 0, [hl]
	; note = rest
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 5, [hl]
	; clear music id & bank
	ld hl, Channel1MusicID - Channel1
	add hl, bc
	xor a
	ld [hli], a ; id hi
	ld [hli], a ; id lo
	ld [hli], a ; bank
	ret
; e8679

RestoreVolume: ; e8679
	; ch5 only
	ld a, [CurChannel]
	cp a, $04
	ret nz
	xor a
	ld hl, $c222
	ld [hli], a
	ld [hl], a
	ld hl, $c286
	ld [hli], a
	ld [hl], a
	ld a, [LastVolume]
	ld [Volume], a
	xor a
	ld [LastVolume], a
	ld [SFXPriority], a
	ret
; e8698

Functione8698: ; e8698
	; turn noise sampling on
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 4, [hl] ; noise sample
	; update note duration
	ld a, [CurMusicByte]
	call SetNoteDuration ; top nybble doesnt matter?
	; update intensity from next param
	call GetMusicByte
	ld hl, Channel1Intensity - Channel1
	add hl, bc
	ld [hl], a
	; update lo frequency from next param
	call GetMusicByte
	ld hl, Channel1FrequencyLo - Channel1
	add hl, bc
	ld [hl], a
	; are we on the last channel? (noise sampling)
	ld a, [CurChannel]
	and a, $03
	cp a, $03
	ret z
	; update hi frequency from next param
	call GetMusicByte
	ld hl, Channel1FrequencyHi - Channel1
	add hl, bc
	ld [hl], a
	ret
; e86c5

GetNoiseSample: ; e86c5
; load ptr to sample header in NoiseSampleAddress
	; are we on the last channel?
	ld a, [CurChannel]
	and a, $03
	cp a, $03
	; ret if not
	ret nz
	; update note duration
	ld a, [CurMusicByte]
	and a, $0f
	call SetNoteDuration
	; check current channel
	ld a, [CurChannel]
	bit 2, a ; are we in a sfx channel?
	jr nz, .sfx
	ld hl, $c262 ; Channel8Flags
	bit 0, [hl] ; is ch8 on? (noise)
	ret nz
	ld a, [MusicNoiseSampleSet]
	jr .next
.sfx
	ld a, [SFXNoiseSampleSet]
.next
	; load noise sample set id into de
	ld e, a
	ld d, $00
	; load ptr to noise sample set in hl
	ld hl, NoiseSampleSetsPointers
	add hl, de
	add hl, de
	ld a, [hli]
	ld h, [hl]
	ld l, a
	; get pitch
	ld a, [CurMusicByte]
	swap a
	; non-rest note?
	and a, $0f
	ret z
	; use 'pitch' to seek noise sample set
	ld e, a
	ld d, $00
	add hl, de
	add hl, de
	; load sample pointer into NoiseSampleAddress
	ld a, [hli]
	ld [NoiseSampleAddressLo], a
	ld a, [hl]
	ld [NoiseSampleAddressHi], a
	; clear ????
	xor a
	ld [$c2a2], a
	ret
; e870f

ParseCommand ; e870f
	; reload command
	ld a, [CurMusicByte]
	; get command #
	sub a, $d0 ; first command
	ld e, a
	ld d, $00
	; seek command pointer
	ld hl, MusicCommands
	add hl, de
	add hl, de
	; jump to the new pointer
	ld a, [hli]
	ld h, [hl]
	ld l, a
	jp [hl]
; e8720

MusicCommands: ; e8720
; pointer to each command in order
	; octaves
	dw MusicD0 ; octave 8
	dw MusicD0 ; octave 7
	dw MusicD0 ; octave 6
	dw MusicD0 ; octave 5
	dw MusicD0 ; octave 4
	dw MusicD0 ; octave 3
	dw MusicD0 ; octave 2
	dw MusicD0 ; octave 1
	dw MusicD8 ; note length + intensity
	dw MusicD9 ; set starting octave
	dw MusicDA ; tempo
	dw MusicDB ; duty cycle
	dw MusicDC ; intensity
	dw MusicDD ; update sound status
	dw MusicDE ; ???? + duty cycle
	dw MusicDF ;
	dw MusicE0 ;
	dw MusicE1 ; vibrato
	dw MusicE2 ;
	dw MusicE3 ; music noise sampling
	dw MusicE4 ; force panning
	dw MusicE5 ; volume
	dw MusicE6 ; tune
	dw MusicE7 ;
	dw MusicE8 ;
	dw MusicE9 ; global tempo
	dw MusicEA ; restart current channel from header
	dw MusicEB ; new song
	dw MusicEC ; sfx priority on
	dw MusicED ; sfx priority off
	dw MusicEE ;
	dw MusicEF ; stereo panning
	dw MusicF0 ; sfx noise sampling
	dw MusicF1 ; nothing
	dw MusicF1 ; nothing
	dw MusicF1 ; nothing
	dw MusicF1 ; nothing
	dw MusicF1 ; nothing
	dw MusicF1 ; nothing
	dw MusicF1 ; nothing
	dw MusicF1 ; nothing
	dw MusicF9 ;
	dw MusicFA ;
	dw MusicFB ;
	dw MusicFC ; jump
	dw MusicFD ; loop
	dw MusicFE ; call
	dw MusicFF ; return
; e8780

MusicF1: ; e8780
	ret
; e8781

MusicFF: ; e8781
; called when $ff is encountered w/ subroutine flag set
; end music stream
; return to caller of the subroutine
	; reset subroutine flag
	ld hl, Channel1Flags - Channel1
	add hl, bc
	res 1, [hl]
	; copy LastMusicAddress to MusicAddress
	ld hl, Channel1LastMusicAddress - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	ret
; e8796

MusicFE: ; e8796
; call music stream (subroutine)
; parameters: ll hh ; pointer to subroutine
	; get pointer from next 2 bytes
	call GetMusicByte
	ld e, a
	call GetMusicByte
	ld d, a
	push de
	; copy MusicAddress to LastMusicAddress
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	ld hl, Channel1LastMusicAddress - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	; load pointer into MusicAddress
	pop de
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	; set subroutine flag
	ld hl, Channel1Flags - Channel1
	add hl, bc
	set 1, [hl]
	ret
; e87bc

MusicFC: ; e87bc
; jump
; parameters: ll hh ; pointer
	; get pointer from next 2 bytes
	call GetMusicByte
	ld e, a
	call GetMusicByte
	ld d, a
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	ret
; e87cc

MusicFD: ; e87cc
; loops xx - 1 times
; 	00: infinite
; params: 3
;	xx ll hh
;		xx : loop count
;   	ll hh : pointer

	; get loop count
	call GetMusicByte
	ld hl, Channel1Flags - Channel1
	add hl, bc
	bit 2, [hl] ; has the loop been initiated?
	jr nz, .checkloop
	and a ; loop counter 0 = infinite
	jr z, .loop
	; initiate loop
	dec a
	set 2, [hl] ; set loop flag
	ld hl, Channel1LoopCount - Channel1
	add hl, bc
	ld [hl], a ; store loop counter
.checkloop
	ld hl, Channel1LoopCount - Channel1
	add hl, bc
	ld a, [hl]
	and a ; are we done?
	jr z, .endloop
	dec [hl]
.loop
	; get pointer
	call GetMusicByte
	ld e, a
	call GetMusicByte
	ld d, a
	; load new pointer into MusicAddress
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	ret

.endloop
	; reset loop flag
	ld hl, Channel1Flags - Channel1
	add hl, bc
	res 2, [hl]
	; skip to next command
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	inc de ; skip
	inc de ; pointer
	ld [hl], d
	dec hl
	ld [hl], e
	ret
; e880e

MusicFA: ; e880e
; set condition for a jump
; used with FB
; params: 1
;	xx ; condition

	; set condition
	call GetMusicByte
	ld hl, Channel1Condition - Channel1
	add hl, bc
	ld [hl], a
	ret
; e8817

MusicFB: ; e8817
; conditional jump
; used with FA
; params: 3
; 	xx: condition
;	ll hh: pointer

; check condition
	; a = condition
	call GetMusicByte
	; if existing condition matches, jump to new address
	ld hl, Channel1Condition - Channel1
	add hl, bc
	cp [hl]
	jr z, .jump
; skip to next command
	; get address
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	; skip pointer
	inc de
	inc de
	; update address
	ld [hl], d
	dec hl
	ld [hl], e
	ret
.jump
; jump to the new address
	; get pointer
	call GetMusicByte
	ld e, a
	call GetMusicByte
	ld d, a
	; update pointer in MusicAddress
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	ret
; e883e

MusicEE; e883e
; conditional jump
; checks a byte in ram corresponding to the current channel
; doesn't seem to be set by any commands
; params: 2
;		ll hh ; pointer

; if ????, jump
	; get channel
	ld a, [CurChannel]
	and a, $03 ; ch0-3
	ld e, a
	ld d, $00
	; hl = $c2b8 + channel id
	ld hl, $c2b8
	add hl, de
	; if set, jump
	ld a, [hl]
	and a
	jr nz, .jump
; skip to next command
	; get address
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	; skip pointer
	inc de
	inc de
	; update address
	ld [hl], d
	dec hl
	ld [hl], e
	ret
.jump
	; reset jump flag
	ld [hl], $00
	; de = pointer
	call GetMusicByte
	ld e, a
	call GetMusicByte
	ld d, a
	; update address
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	ret
; e886d

MusicF9: ; e886d
; sets some flag
; seems to be unused
; params: 0
	ld a, $01
	ld [$c2b5], a
	ret
; e8873

MusicE2: ; e8873
; seems to have been dummied out
; params: 1
	call GetMusicByte
	ld hl, $002c
	add hl, bc
	ld [hl], a
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	set 3, [hl]
	ret
; e8882

MusicE1: ; e8882
; vibrato
; params: 2
;	1: [xx]
	; delay in frames
;	2: [yz]
	; y: extent
	; z: rate (# frames per cycle)

	; set vibrato flag?
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	set 0, [hl]
	; start at lower frequency (extent is positive)
	ld hl, Channel1Flags3 - Channel1
	add hl, bc
	res 0, [hl]
	; get delay
	call GetMusicByte
; update delay
	ld hl, Channel1VibratoDelay - Channel1
	add hl, bc
	ld [hl], a
; update delay count
	ld hl, Channel1VibratoDelayCount - Channel1
	add hl, bc
	ld [hl], a
; update extent
; this is split into halves only to get added back together at the last second
	; get extent/rate
	call GetMusicByte
	ld hl, Channel1VibratoExtent - Channel1
	add hl, bc
	ld d, a
	; get top nybble
	and a, $f0
	swap a
	srl a ; halve
	ld e, a
	adc a, $00 ; round up
	swap a
	or e
	ld [hl], a
; update rate
	ld hl, Channel1VibratoRate - Channel1
	add hl, bc
	; get bottom nybble
	ld a, d
	and a, $0f
	ld d, a
	swap a
	or d
	ld [hl], a
	ret
; e88bd

MusicE0: ; e88bd
; ????
; params: 2
	call GetMusicByte
	ld [$c297], a
	call GetMusicByte
	ld d, a
	and a, $0f
	ld e, a
	ld a, d
	swap a
	and a, $0f
	ld d, a
	call GetFrequency
	ld hl, $0021
	add hl, bc
	ld [hl], e
	ld hl, $0022
	add hl, bc
	ld [hl], d
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	set 1, [hl]
	ret
; e88e4

MusicE6: ; e88e4
; tone
; params: 2
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	set 4, [hl]
	ld hl, $0028
	add hl, bc
	call GetMusicByte
	ld [hld], a
	call GetMusicByte
	ld [hl], a
	ret
; e88f7

MusicE7: ; e88f7
; shrug
; params: 1
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	set 6, [hl]
	call GetMusicByte
	ld hl, $0029
	add hl, bc
	ld [hl], a
	ret
; e8906

MusicDE: ; e8906
; ???? + duty cycle
; params: 1
	;
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	set 2, [hl] ; duty cycle
	;
	call GetMusicByte
	rrca
	rrca
	ld hl, $001c
	add hl, bc
	ld [hl], a
	; update duty cycle
	and a, $c0 ; only uses top 2 bits
	ld hl, Channel1DutyCycle - Channel1
	add hl, bc
	ld [hl], a
	ret
; e891e

MusicE8: ; e891e
; shrug
; params: 1
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	set 5, [hl]
	call GetMusicByte
	ld hl, $002a
	add hl, bc
	ld [hl], a
	ret
; e892d

MusicDF: ; e892d
; toggle something
; params: none
	ld hl, Channel1Flags - Channel1
	add hl, bc
	bit 3, [hl]
	jr z, .on
	res 3, [hl]
	ret
.on
	set 3, [hl]
	ret
; e893b

MusicE3: ; e893b
; toggle music noise sampling
; can't be used as a straight toggle since the param is not read from on->off
; params:
; 	noise on: 1
; 	noise off: 0
	; check if noise sampling is on
	ld hl, Channel1Flags - Channel1
	add hl, bc
	bit 4, [hl]
	jr z, .on
	; turn noise sampling off
	res 4, [hl]
	ret
.on
	; turn noise sampling on
	set 4, [hl]
	call GetMusicByte
	ld [MusicNoiseSampleSet], a
	ret
; e894f

MusicF0: ; e894f
; toggle sfx noise sampling
; params:
;	on: 1
; 	off: 0
	; check if noise sampling is on
	ld hl, Channel1Flags - Channel1
	add hl, bc
	bit 4, [hl]
	jr z, .on
	; turn noise sampling off
	res 4, [hl]
	ret
.on
	; turn noise sampling on
	set 4, [hl]
	call GetMusicByte
	ld [SFXNoiseSampleSet], a
	ret
; e8963

MusicD8: ; e8963
; note length
;	# frames per 16th note
; intensity: see MusicDC
; params: 2
	; note length
	call GetMusicByte
	ld hl, $002d
	add hl, bc
	ld [hl], a
	ld a, [CurChannel]
	and a, $03
	cp a, $03
	ret z
	; intensity
	call MusicDC
	ret
; e8977

MusicDD: ; e8977
; update sound status
; params: 1
	call GetMusicByte
	ld [SoundInput], a
	ld hl, Channel1NoteFlags - Channel1
	add hl, bc
	set 3, [hl]
	ret
; e8984

MusicDB: ; e8984
; duty cycle
; params: 1
	call GetMusicByte
	rrca
	rrca
	and a, $c0
	ld hl, Channel1DutyCycle - Channel1
	add hl, bc
	ld [hl], a
	ret
; e8991

MusicDC: ; e8991
; intensity
; params: 1
;	hi: pressure
;   lo: velocity
	call GetMusicByte
	ld hl, Channel1Intensity - Channel1
	add hl, bc
	ld [hl], a
	ret
; e899a

MusicDA: ; e899a
; global tempo
; params: 2
;	de: tempo
	call GetMusicByte
	ld d, a
	call GetMusicByte
	ld e, a
	call SetGlobalTempo
	ret
; e89a6

MusicD0: ; e89a6
; used by d0-d7
; set octave based on lo nybble of the command
	ld hl, Channel1Octave - Channel1
	add hl, bc
	ld a, [CurMusicByte] ; get current command
	and a, $07
	ld [hl], a
	ret
; e89b1

MusicD9: ; e89b1
; set starting octave
; this forces all notes up by the starting octave
; params: 1
	call GetMusicByte
	ld hl, Channel1StartingOctave - Channel1
	add hl, bc
	ld [hl], a
	ret
; e89ba

MusicEF: ; e89ba
; stereo panning
; params: 1
	; stereo on?
	ld a, [Options]
	bit 5, a ; stereo
	jr nz, MusicE4
	; skip param
	call GetMusicByte
	ret
; e89c5

MusicE4: ; e89c5
; force panning
; params: 1
	call SetLRTracks
	call GetMusicByte
	ld hl, Channel1Tracks - Channel1
	add hl, bc
	and [hl]
	ld [hl], a
	ret
; e89d2

MusicE5: ; e89d2
; set volume
; params: 1
;	see Volume
	; read param even if it's not used
	call GetMusicByte
	; is the song fading?
	ld a, [MusicFade]
	and a
	ret nz
	; reload param
	ld a, [CurMusicByte]
	; set volume
	ld [Volume], a
	ret
; e89e1

MusicE9: ; e89e1
; set global tempo to current channel tempo +- param
; params: 1 signed
	call GetMusicByte
	ld e, a
	; check sign
	cp a, $80
	jr nc, .negative
;positive
	ld d, $00
	jr .ok
.negative
	ld d, $ff
.ok
	ld hl, Channel1Tempo - Channel1
	add hl, bc
	ld a, [hli]
	ld h, [hl]
	ld l, a
	add hl, de
	ld e, l
	ld d, h
	call SetGlobalTempo
	ret
; e89fd

MusicEC: ; e89fd
; turn sfx priority on
; params: none
	ld a, $01
	ld [SFXPriority], a
	ret
; e8a03

MusicED: ; e8a03
; turn sfx priority off
; params: none
	xor a
	ld [SFXPriority], a
	ret
; e8a08

MusicEA: ; e8a08
; restart current channel from channel header (same bank)
; params: 2 (5)
; ll hh: pointer to new channel header
;	header format: 0x yy zz
;		x: channel # (0-3)
;		zzyy: pointer to new music data

	; update music id
	ld hl, Channel1MusicID - Channel1
	add hl, bc
	ld a, [hli]
	ld [MusicIDLo], a
	ld a, [hl]
	ld [MusicIDHi], a
	; update music bank
	ld hl, Channel1MusicBank - Channel1
	add hl, bc
	ld a, [hl]
	ld [MusicBank], a
	; get pointer to new channel header
	call GetMusicByte
	ld l, a
	call GetMusicByte
	ld h, a
	ld e, [hl]
	inc hl
	ld d, [hl]
	push bc ; save current channel
	call LoadChannel
	call StartChannel
	pop bc ; restore current channel
	ret
; e8a30

MusicEB: ; e8a30
; new song
; params: 2
;	de: song id
	call GetMusicByte
	ld e, a
	call GetMusicByte
	ld d, a
	push bc
	call LoadMusic
	pop bc
	ret
; e8a3e

GetMusicByte: ; e8a3e
; returns byte from current address in a
; advances to next byte in music data
; input: bc = start of current channel
	push hl
	push de
	; load address into de
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld a, [hli]
	ld e, a
	ld d, [hl]
	; load bank into a
	ld hl, Channel1MusicBank - Channel1
	add hl, bc
	ld a, [hl]
	; get byte
	call LoadMusicByte ; load data into CurMusicByte
	inc de ; advance to next byte for next time this is called
	; update channeldata address
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	ld a, e
	ld [hli], a
	ld [hl], d
	; cleanup
	pop de
	pop hl
	; store channeldata in a
	ld a, [CurMusicByte]
	ret
; e8a5d

GetFrequency: ; e8a5d
; generate frequency
; input:
; 	d: octave
;	e: pitch
; output:
; 	de: frequency

; get octave
	; get starting octave
	ld hl, Channel1StartingOctave - Channel1
	add hl, bc
	ld a, [hl]
	swap a ; hi nybble
	and a, $0f
	; add current octave
	add d
	push af ; we'll use this later
	; get starting octave
	ld hl, Channel1StartingOctave - Channel1
	add hl, bc
	ld a, [hl]
	and a, $0f ; lo nybble
	;
	ld l, a ; ok
	ld d, $00
	ld h, d
	add hl, de ; add current pitch
	add hl, hl ; skip 2 bytes for each
	ld de, FrequencyTable
	add hl, de
	ld e, [hl]
	inc hl
	ld d, [hl]
	; get our octave
	pop af
.loop
	; [7 - octave] loops
	cp a, $07
	jr nc, .ok
	; sra de
	sra d
	rr e
	inc a
	jr .loop
.ok
	ld a, d
	and a, $07 ; top 3 bits for frequency (11 total)
	ld d, a
	ret
; e8a8d

SetNoteDuration: ; e8a8d
; input: a = note duration in 16ths
	; store delay units in de
	inc a
	ld e, a
	ld d, $00
	; store NoteLength in a
	ld hl, Channel1NoteLength - Channel1
	add hl, bc
	ld a, [hl]
	; multiply NoteLength by delay units
	ld l, $00 ; just multiply
	call MultiplySimple
	ld a, l ; % $100
	; store Tempo in de
	ld hl, Channel1Tempo - Channel1
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	; add ???? to the next result
	ld hl, $0016
	add hl, bc
	ld l, [hl]
	; multiply Tempo by last result (NoteLength * delay % $100)
	call MultiplySimple
	; copy result to de
	ld e, l
	ld d, h
	; store result in ????
	ld hl, $0016
	add hl, bc
	ld [hl], e
	; store result in NoteDuration
	ld hl, Channel1NoteDuration - Channel1
	add hl, bc
	ld [hl], d
	ret
; e8ab8

MultiplySimple: ; e8ab8
; multiplies a and de
; adds the result to l
; stores the result in hl
	ld h, $00
.loop
	; halve a
	srl a
	; is there a remainder?
	jr nc, .skip
	; add it to the result
	add hl, de
.skip
	; add de, de
	sla e
	rl d
	; are we done?
	and a
	jr nz, .loop
	ret
; e8ac7

SetGlobalTempo: ; e8ac7
	push bc ; save current channel
	; are we dealing with music or sfx?
	ld a, [CurChannel]
	cp a, $04
	jr nc, .sfxchannels
	ld bc, Channel1
	call SetTempo
	ld bc, Channel2
	call SetTempo
	ld bc, Channel3
	call SetTempo
	ld bc, Channel4
	call SetTempo
	jr .end
.sfxchannels
	ld bc, Channel5
	call SetTempo
	ld bc, Channel6
	call SetTempo
	ld bc, Channel7
	call SetTempo
	ld bc, Channel8
	call SetTempo
.end
	pop bc ; restore current channel
	ret
; e8b03

SetTempo: ; e8b03
; input:
; 	de: note length
	; update Tempo
	ld hl, Channel1Tempo - Channel1
	add hl, bc
	ld [hl], e
	inc hl
	ld [hl], d
	; clear ????
	xor a
	ld hl, $0016
	add hl, bc
	ld [hl], a
	ret
; e8b11

StartChannel: ; e8b11
	call SetLRTracks
	ld hl, Channel1Flags - Channel1
	add hl, bc
	set 0, [hl] ; turn channel on
	ret
; e8b1b

SetLRTracks: ; e8b1b
; set tracks for a the current channel to default
; seems to be redundant since this is overwritten by stereo data later
	push de
	; store current channel in de
	ld a, [CurChannel]
	and a, $03
	ld e, a
	ld d, $00
	; get this channel's lr tracks
	call GetLRTracks
	add hl, de ; de = channel 0-3
	ld a, [hl]
	; load lr tracks into Tracks
	ld hl, Channel1Tracks - Channel1
	add hl, bc
	ld [hl], a
	pop de
	ret
; e8b30

LoadMusic: ; e8b30
; load music
	call MusicOff
	ld hl, MusicID
	ld [hl], e ; song number
	inc hl
	ld [hl], d ; MusicIDHi (always $00)
	ld hl, Music
	add hl, de ; three
	add hl, de ; byte
	add hl, de ; pointer
	ld a, [hli]
	ld [MusicBank], a
	ld e, [hl]
	inc hl
	ld d, [hl] ; music header address
	call FarLoadMusicByte ; store first byte of music header in a
	rlca
	rlca
	and a, $03 ; get number of channels
	inc a
.loop
; start playing channels
	push af
	call LoadChannel
	call StartChannel
	pop af
	dec a
	jr nz, .loop
	xor a
	ld [$c2b5], a
	ld [$c2b8], a
	ld [$c2b9], a
	ld [$c2ba], a
	ld [$c2bb], a
	ld [NoiseSampleAddressLo], a
	ld [NoiseSampleAddressHi], a
	ld [$c2a2], a
	ld [MusicNoiseSampleSet], a
	call MusicOn
	ret
; e8b79

PlayCry: ; e8b79
; input: de = cry id
	call MusicOff
	; load cry id
	ld hl, MusicID
	ld [hl], e
	inc hl
	ld [hl], d
	; seek pointer table
	ld hl, Cries
	add hl, de
	add hl, de
	add hl, de
	; get bank
	ld a, [hli]
	ld [MusicBank], a
	; get address
	ld e, [hl]
	inc hl
	ld d, [hl]
; read cry header
	; get byte at bank:address
	call FarLoadMusicByte
	; get top 2 bits (# chs)
	rlca
	rlca
	and a, $03
	inc a ; ch count -> loop count
.loop
	push af
	call LoadChannel
	ld hl, Channel1Flags - Channel1
	add hl, bc
	set 5, [hl]
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	set 4, [hl]
	ld hl, $0027
	add hl, bc
	ld a, [$c2b0]
	ld [hli], a
	ld a, [$c2b1]
	ld [hl], a
	; are we on the last channel? (music & sfx)
	ld a, [CurChannel]
	and a, $03
	cp a, $03
	jr nc, .start
	; update tempo
	ld hl, Channel1Tempo - Channel1
	add hl, bc
	ld a, [$c2b2]
	ld [hli], a
	ld a, [$c2b3]
	ld [hl], a
.start
	call StartChannel
	ld a, [$c2bc]
	and a
	jr z, .next
; play cry from the side of the monster it's coming from (stereo only)
; outside of battles cries play on both tracks
	; is stereo on?
	ld a, [Options]
	bit 5, a ; stereo
	jr z, .next
	; and [Tracks], [CryTracks]
	ld hl, Channel1Tracks - Channel1
	add hl, bc
	ld a, [hl]
	ld hl, CryTracks
	and a, [hl]
	ld hl, Channel1Tracks - Channel1
	add hl, bc
	ld [hl], a
.next
	pop af
	dec a
	jr nz, .loop
	; save current volume
	ld a, [LastVolume]
	and a
	jr nz, .end
	ld a, [Volume]
	ld [LastVolume], a
	; cries have max volume
	ld a, $77
	ld [Volume], a
.end
	ld a, $01 ; stop playing music
	ld [SFXPriority], a
	call MusicOn
	ret
; e8c04

LoadSFX: ; e8c04
; clear channels if they aren't already
	call MusicOff
	ld hl, $c1cc ; Channel5Flags
	bit 0, [hl] ; ch5 on?
	jr z, .ch6
	res 0, [hl] ; turn it off
	xor a
	ld [$ff11], a ; length/wavepattern = 0
	ld a, $08
	ld [$ff12], a ; envelope = 0
	xor a
	ld [$ff13], a ; frequency lo = 0
	ld a, $80
	ld [$ff14], a ; restart sound (freq hi = 0)
	xor a
	ld [SoundInput], a ; global sound off
	ld [$ff10], a ; sweep = 0
.ch6
	ld hl, $c1fe ; ch6 on?
	bit 0, [hl]
	jr z, .ch7
	res 0, [hl] ; turn it off
	xor a
	ld [$ff16], a ; length/wavepattern = 0
	ld a, $08
	ld [$ff17], a ; envelope = 0
	xor a
	ld [$ff18], a ; frequency lo = 0
	ld a, $80
	ld [$ff19], a ; restart sound (freq hi = 0)
.ch7
	ld hl, $c230 ; ch7 on?
	bit 0, [hl]
	jr z, .ch8
	res 0, [hl] ; turn it off
	xor a
	ld [$ff1a], a ; sound mode #3 off
	ld [$ff1b], a ; length/wavepattern = 0
	ld a, $08
	ld [$ff1c], a ; envelope = 0
	xor a
	ld [$ff1d], a ; frequency lo = 0
	ld a, $80
	ld [$ff1e], a ; restart sound (freq hi = 0)
.ch8
	ld hl, $c262 ; ch8 on?
	bit 0, [hl]
	jr z, .chscleared
	res 0, [hl] ; turn it off
	xor a
	ld [$ff20], a ; length/wavepattern = 0
	ld a, $08
	ld [$ff21], a ; envelope = 0
	xor a
	ld [$ff22], a ; frequency lo = 0
	ld a, $80
	ld [$ff23], a ; restart sound (freq hi = 0)
	xor a
	ld [NoiseSampleAddressLo], a
	ld [NoiseSampleAddressHi], a
.chscleared
; start reading sfx header for # chs
	ld hl, MusicID
	ld [hl], e
	inc hl
	ld [hl], d
	ld hl, SFX
	add hl, de ; three
	add hl, de ; byte
	add hl, de ; pointers
	; get bank
	ld a, [hli]
	ld [MusicBank], a
	; get address
	ld e, [hl]
	inc hl
	ld d, [hl]
	; get # channels
	call FarLoadMusicByte
	rlca ; top 2
	rlca ; bits
	and a, $03
	inc a ; # channels -> # loops
.startchannels
	push af
	call LoadChannel ; bc = current channel
	ld hl, Channel1Flags - Channel1
	add hl, bc
	set 3, [hl]
	call StartChannel
	pop af
	dec a
	jr nz, .startchannels
	call MusicOn
	xor a
	ld [SFXPriority], a
	ret
; e8ca6


PlaySFX: ; e8ca6
; play sfx de

	call MusicOff
	
; standard procedure if stereo's off
	ld a, [Options]
	bit 5, a
	jp z, LoadSFX
	
; else, let's go ahead with this
	ld hl, MusicID
	ld [hl], e
	inc hl
	ld [hl], d
	
; get sfx ptr
	ld hl, SFX
	add hl, de
	add hl, de
	add hl, de
	
; bank
	ld a, [hli]
	ld [MusicBank], a
; address
	ld e, [hl]
	inc hl
	ld d, [hl]
	
; bit 2-3
	call FarLoadMusicByte
	rlca
	rlca
	and 3 ; ch1-4
	inc a
	
.loop
	push af
	call LoadChannel
	
	ld hl, Channel1Flags - Channel1
	add hl, bc
	set 3, [hl]
	
	push de
	; get tracks for this channel
	ld a, [CurChannel]
	and 3 ; ch1-4
	ld e, a
	ld d, $0
	call GetLRTracks
	add hl, de
	ld a, [hl]
	ld hl, $c2bc
	and [hl]
	
	ld hl, Channel1Tracks - Channel1
	add hl, bc
	ld [hl], a
	
	ld hl, $0030 ; $c131 - Channel1
	add hl, bc
	ld [hl], a
	
	ld a, [CryTracks]
	cp 2 ; ch 1-2
	jr c, .asm_e8d0c
	
; ch3-4
	ld a, [$c2be]
	
	ld hl, $002e ; $c12f - Channel1
	add hl, bc
	ld [hl], a
	
	ld hl, $002f ; $c130 - Channel1
	add hl, bc
	ld [hl], a
	
	ld hl, Channel1Flags2 - Channel1
	add hl, bc
	set 7, [hl]
	
.asm_e8d0c
	pop de
	
; turn channel on
	ld hl, Channel1Flags - Channel1
	add hl, bc
	set 0, [hl] ; on
	
; done?
	pop af
	dec a
	jr nz, .loop
	
; we're done
	call MusicOn
	ret
; e8d1b


LoadChannel: ; e8d1b
; prep channel for use
; input:
; 	de:
	; get pointer to current channel
	call FarLoadMusicByte
	inc de
	and a, $07 ; bit 0-2 (current channel)
	ld [CurChannel], a
	ld c, a
	ld b, $00
	ld hl, ChannelPointers
	add hl, bc
	add hl, bc
	ld c, [hl]
	inc hl
	ld b, [hl] ; bc = channel pointer
	ld hl, Channel1Flags - Channel1
	add hl, bc
	res 0, [hl] ; channel off
	call ChannelInit
	; load music pointer
	ld hl, Channel1MusicAddress - Channel1
	add hl, bc
	call FarLoadMusicByte
	ld [hli], a
	inc de
	call FarLoadMusicByte
	ld [hl], a
	inc de
	; load music id
	ld hl, Channel1MusicID - Channel1
	add hl, bc
	ld a, [MusicIDLo]
	ld [hli], a
	ld a, [MusicIDHi]
	ld [hl], a
	; load music bank
	ld hl, Channel1MusicBank - Channel1
	add hl, bc
	ld a, [MusicBank]
	ld [hl], a
	ret
; e8d5b

ChannelInit: ; e8d5b
; make sure channel is cleared
; set default tempo and note length in case nothing is loaded
; input:
;   bc = channel struct pointer
	push de
	xor a
	; get channel struct location and length
	ld hl, Channel1MusicID - Channel1 ; start
	add hl, bc
	ld e, Channel2 - Channel1 ; channel struct length
	; clear channel
.loop
	ld [hli], a
	dec e
	jr nz, .loop
	; set tempo to default ($100)
	ld hl, Channel1Tempo - Channel1
	add hl, bc
	xor a
	ld [hli], a
	inc a
	ld [hl], a
	; set note length to default ($01) (fast)
	ld hl, Channel1NoteLength - Channel1
	add hl, bc
	ld [hl], a
	pop de
	ret
; e8d76

FarLoadMusicByte: ; e8d76
; input:
;   de = current music address
; output:
;   a = CurMusicByte
	ld a, [MusicBank]
	call LoadMusicByte
	ld a, [CurMusicByte]
	ret
; e8d80

FrequencyTable: ; e8d80
	dw $0000 ; filler
	dw $f82c
	dw $f89d
	dw $f907
	dw $f96b
	dw $f9ca
	dw $fa23
	dw $fa77
	dw $fac7
	dw $fb12
	dw $fb58
	dw $fb9b
	dw $fbda
	dw $fc16
	dw $fc4e
	dw $fc83
	dw $fcb5
	dw $fce5
	dw $fd11
	dw $fd3b
	dw $fd63
	dw $fd89
	dw $fdac
	dw $fdcd
	dw $fded
; e8db2

WaveSamples: ; e8db2
	; these are streams of 32 4-bit values used as wavepatterns
	; nothing interesting here!
	db $02, $46, $8a, $ce, $ff, $fe, $ed, $dc, $cb, $a9, $87, $65, $44, $33, $22, $11
	db $02, $46, $8a, $ce, $ef, $ff, $fe, $ee, $dd, $cb, $a9, $87, $65, $43, $22, $11
	db $13, $69, $bd, $ee, $ee, $ff, $ff, $ed, $de, $ff, $ff, $ee, $ee, $db, $96, $31
	db $02, $46, $8a, $cd, $ef, $fe, $de, $ff, $ee, $dc, $ba, $98, $76, $54, $32, $10
	db $01, $23, $45, $67, $8a, $cd, $ee, $f7, $7f, $ee, $dc, $a8, $76, $54, $32, $10
	db $00, $11, $22, $33, $44, $33, $22, $11, $ff, $ee, $cc, $aa, $88, $aa, $cc, $ee
	db $02, $46, $8a, $ce, $cb, $a9, $87, $65, $ff, $fe, $ed, $dc, $44, $33, $22, $11
	db $c0, $a9, $87, $f5, $ff, $fe, $ed, $dc, $44, $33, $22, $f1, $02, $46, $8a, $ce
	db $44, $33, $22, $1f, $00, $46, $8a, $ce, $f8, $fe, $ed, $dc, $cb, $a9, $87, $65
	db $11, $00, $00, $08, $00, $13, $57, $9a, $b4, $ba, $a9, $98, $87, $65, $43, $21
; e8e52

NoiseSampleSetsPointers: ; e8e52
	dw NoiseSampleSets0
	dw NoiseSampleSets1
	dw NoiseSampleSets2
	dw NoiseSampleSets3
	dw NoiseSampleSets4
	dw NoiseSampleSets5
; e8e5e

NoiseSampleSets:
NoiseSampleSets0: ; e8e5e
	dw NoiseSampleSet00 ; rest
	dw NoiseSampleSet01 ; c
	dw NoiseSampleSet02 ; c#
	dw NoiseSampleSet03 ; d
	dw NoiseSampleSet04 ; d#
	dw NoiseSampleSet05 ; e
	dw NoiseSampleSet06 ; f
	dw NoiseSampleSet07 ; f#
	dw NoiseSampleSet08 ; g
	dw NoiseSampleSet09 ; g#
	dw NoiseSampleSet10 ; a
	dw NoiseSampleSet11 ; a#
	dw NoiseSampleSet12 ; b
NoiseSampleSets1: ; e8e78
	dw NoiseSampleSet00
	dw NoiseSampleSet08
	dw NoiseSampleSet09
	dw NoiseSampleSet10
	dw NoiseSampleSet11
	dw NoiseSampleSet12
	dw NoiseSampleSet13
	dw NoiseSampleSet14
	dw NoiseSampleSet15
	dw NoiseSampleSet16
	dw NoiseSampleSet17
	dw NoiseSampleSet18
	dw NoiseSampleSet19
NoiseSampleSets2: ; e8e92
	dw NoiseSampleSet00
	dw NoiseSampleSet01
	dw NoiseSampleSet17
	dw NoiseSampleSet18
	dw NoiseSampleSet19
	dw NoiseSampleSet05
	dw NoiseSampleSet06
	dw NoiseSampleSet07
	dw NoiseSampleSet08
	dw NoiseSampleSet09
	dw NoiseSampleSet10
	dw NoiseSampleSet11
	dw NoiseSampleSet12
NoiseSampleSets3: ; e8eac
	dw NoiseSampleSet21
	dw NoiseSampleSet22
	dw NoiseSampleSet23
	dw NoiseSampleSet24
	dw NoiseSampleSet25
	dw NoiseSampleSet26
	dw NoiseSampleSet20
	dw NoiseSampleSet27
	dw NoiseSampleSet28
	dw NoiseSampleSet29
	dw NoiseSampleSet21
	dw NoiseSampleSet37
	dw NoiseSampleSet34
NoiseSampleSets4: ; e8ec6
	dw NoiseSampleSet21
	dw NoiseSampleSet20
	dw NoiseSampleSet23
	dw NoiseSampleSet24
	dw NoiseSampleSet25
	dw NoiseSampleSet33
	dw NoiseSampleSet26
	dw NoiseSampleSet35
	dw NoiseSampleSet31
	dw NoiseSampleSet32
	dw NoiseSampleSet36
	dw NoiseSampleSet37
	dw NoiseSampleSet30
NoiseSampleSets5: ; e8ee0
	dw NoiseSampleSet00
	dw NoiseSampleSet17
	dw NoiseSampleSet18
	dw NoiseSampleSet19
	dw NoiseSampleSet27
	dw NoiseSampleSet28
	dw NoiseSampleSet29
	dw NoiseSampleSet05
	dw NoiseSampleSet06
	dw NoiseSampleSet30
	dw NoiseSampleSet24
	dw NoiseSampleSet23
	dw NoiseSampleSet37
; e8efa

NoiseSampleSet00: ; e8efa
; unused
	db $20, $11, $00
	db $ff ; end
; e8efe

NoiseSampleSet01: ; e8efe
	db $20, $c1, $33
	db $ff ; end
; e8f02

NoiseSampleSet02: ; e8f02
	db $20, $b1, $33
	db $ff ; end
; e8f06

NoiseSampleSet03: ; e8f06
	db $20, $a1, $33
	db $ff ; end
; e8f0a

NoiseSampleSet04: ; e8f0a
	db $20, $81, $33
	db $ff ; end
; e8f0e

NoiseSampleSet05: ; e8f0e
	db $27, $84, $37
	db $26, $84, $36
	db $25, $83, $35
	db $24, $83, $34
	db $23, $82, $33
	db $22, $81, $32
	db $ff ; end
; e8f21

NoiseSampleSet06: ; e8f21
	db $20, $51, $2a
	db $ff ; end
; e8f25

NoiseSampleSet07: ; e8f25
	db $21, $41, $2b
	db $20, $61, $2a
	db $ff ; end
; e8f2c

NoiseSampleSet08: ; e8f2c
	db $20, $81, $10
	db $ff ; end
; e8f30

NoiseSampleSet09: ; e8f30
	db $20, $82, $23
	db $ff ; end
; e8f34

NoiseSampleSet10: ; e8f34
	db $20, $82, $25
	db $ff ; end
; e8f38

NoiseSampleSet11: ; e8f38
	db $20, $82, $26
	db $ff ; end
; e8f3c

NoiseSampleSet12: ; e8f3c
	db $20, $a1, $10
	db $ff ; end
; e8f40

NoiseSampleSet13: ; e8f40
	db $20, $a2, $11
	db $ff ; end
; e8f44

NoiseSampleSet14: ; e8f44
	db $20, $a2, $50
	db $ff ; end
; e8f48

NoiseSampleSet15: ; e8f48
	db $20, $a1, $18
	db $20, $31, $33
	db $ff ; end
; e8f4f

NoiseSampleSet16: ; e8f4f
	db $22, $91, $28
	db $20, $71, $18
	db $ff ; end
; e8f56

NoiseSampleSet17: ; e8f56
	db $20, $91, $22
	db $ff ; end
; e8f5a

NoiseSampleSet18: ; e8f5a
	db $20, $71, $22
	db $ff ; end
; e8f5e

NoiseSampleSet19: ; e8f5e
	db $20, $61, $22
	db $ff ; end
; e8f62

NoiseSampleSet20: ; e8f62
	db $20, $11, $11
	db $ff ; end
; e8f66

NoiseSampleSet21: ; e8f66
	db $ff
; e8f67

NoiseSampleSet22: ; e8f67
	db $20, $91, $33
	db $ff ; end
; e8f6b

NoiseSampleSet23: ; e8f6b
	db $20, $51, $32
	db $ff ; end
; e8f6f

NoiseSampleSet24: ; e8f6f
	db $20, $81, $31
	db $ff ; end
; e8f73

NoiseSampleSet25: ; e8f73
	db $20, $88, $6b
	db $20, $71, $00
	db $ff ; end
; e8f7a

NoiseSampleSet26: ; e8f7a
	db $30, $91, $18
	db $ff ; end
; e8f7e

NoiseSampleSet27: ; e8f7e
	db $27, $92, $10
	db $ff ; end
; e8f82

NoiseSampleSet28: ; e8f82
	db $33, $91, $00
	db $33, $11, $00
	db $ff ; end
; e8f89

NoiseSampleSet29: ; e8f89
	db $33, $91, $11
	db $33, $11, $00
	db $ff ; end
; e8f90

NoiseSampleSet30: ; e8f90
	db $33, $88, $15
	db $20, $65, $12
	db $ff ; end
; e8f97

NoiseSampleSet31: ; e8f97
	db $33, $51, $21
	db $33, $11, $11
	db $ff ; end
; e8f9e

NoiseSampleSet32: ; e8f9e
	db $33, $51, $50
	db $33, $11, $11
	db $ff ; end
; e8fa5

NoiseSampleSet33: ; e8fa5
	db $20, $a1, $31
	db $ff ; end
; e8fa9

NoiseSampleSet34: ; e8fa9
	db $20, $84, $12
	db $ff ; end
; e8fad

NoiseSampleSet35: ; e8fad
	db $33, $81, $00
	db $33, $11, $00
	db $ff ; end
; e8fb4

NoiseSampleSet36: ; e8fb4
	db $33, $81, $21
	db $33, $11, $11
	db $ff ; end
; e8fbb

NoiseSampleSet37: ; e8fbb
	db $20, $a8, $6b
	db $20, $71, $00
	db $ff ; end
; e8fc2

GetLRTracks: ; e8fc2
; gets the default sound l/r channels
; stores mono/stereo table in hl
	ld a, [Options]
	bit 5, a ; stereo
	; made redundant, could have had a purpose in gold
	jr nz, .stereo
	ld hl, MonoTracks
	ret
.stereo
	ld hl, StereoTracks
	ret
; e8fd1

MonoTracks: ; e8fd1
; bit corresponds to track #
; hi: left channel
; lo: right channel
	db $11, $22, $44, $88
; e8fd5

StereoTracks: ; e8fd5
; made redundant
; seems to be modified on a per-song basis
	db $11, $22, $44, $88
; e8fd9

ChannelPointers: ; e8fd9
; music channels
	dw Channel1
	dw Channel2
	dw Channel3
	dw Channel4
; sfx channels
	dw Channel5
	dw Channel6
	dw Channel7
	dw Channel8
; e8fe9

ClearChannels: ; e8fe9
; runs ClearChannel for all 4 channels
; doesn't seem to be used, but functionally identical to SoundRestart
	ld hl, $ff24
	xor a
	ld [hli], a
	ld [hli], a
	ld a, $80
	ld [hli], a
	ld hl, $ff10
	ld e, $04
.loop
	call ClearChannel
	dec e
	jr nz, .loop
	ret
; e8ffe

ClearChannel: ; e8ffe
; input: hl = beginning hw sound register ($ff10, $ff15, $ff1a, $ff1f)
; output: 00 00 80 00 80

;   sound channel   1      2      3      4
	xor a
	ld [hli], a ; $ff10, $ff15, $ff1a, $ff1f ; sweep = 0

	ld [hli], a ; $ff11, $ff16, $ff1b, $ff20 ; length/wavepattern = 0
	ld a, $08
	ld [hli], a ; $ff12, $ff17, $ff1c, $ff21 ; envelope = 0
	xor a
	ld [hli], a ; $ff13, $ff18, $ff1d, $ff22 ; frequency lo = 0
	ld a, $80
	ld [hli], a ; $ff14, $ff19, $ff1e, $ff23 ; restart sound (freq hi = 0)
	ret
; e900a

PlayTrainerEncounterMusic: ; e900a
; input: e = trainer type
	; turn fade off
	xor a
	ld [MusicFade], a
	; play nothing for one frame
	push de
	ld de, $0000 ; id: Music_Nothing
	call StartMusic
	call DelayFrame
	; play new song
	call MaxVolume
	pop de
	ld d, $00
	ld hl, TrainerEncounterMusic
	add hl, de
	ld e, [hl]
	call StartMusic
	ret
; e9027

TrainerEncounterMusic: ; e9027
	db MUSIC_HIKER_ENCOUNTER
	db MUSIC_YOUNGSTER_ENCOUNTER	; falkner
	db MUSIC_LASS_ENCOUNTER			; whitney
	db MUSIC_YOUNGSTER_ENCOUNTER	; bugsy
	db MUSIC_OFFICER_ENCOUNTER		; morty
	db MUSIC_OFFICER_ENCOUNTER		; pryce
	db MUSIC_LASS_ENCOUNTER			; jasmine
	db MUSIC_OFFICER_ENCOUNTER		; chuck
	db MUSIC_BEAUTY_ENCOUNTER		; clair
	db MUSIC_RIVAL_ENCOUNTER		; rival1
	db MUSIC_HIKER_ENCOUNTER		; pokemon_prof
	db MUSIC_HIKER_ENCOUNTER		; will
	db MUSIC_HIKER_ENCOUNTER		; cal
	db MUSIC_OFFICER_ENCOUNTER		; bruno
	db MUSIC_HIKER_ENCOUNTER		; karen
	db MUSIC_HIKER_ENCOUNTER		; koga
	db MUSIC_OFFICER_ENCOUNTER		; champion
	db MUSIC_YOUNGSTER_ENCOUNTER	; brock
	db MUSIC_LASS_ENCOUNTER			; misty
	db MUSIC_OFFICER_ENCOUNTER		; lt_surge
	db MUSIC_ROCKET_ENCOUNTER		; scientist
	db MUSIC_OFFICER_ENCOUNTER		; erika
	db MUSIC_YOUNGSTER_ENCOUNTER	; youngster
	db MUSIC_YOUNGSTER_ENCOUNTER	; schoolboy
	db MUSIC_YOUNGSTER_ENCOUNTER	; bird_keeper
	db MUSIC_LASS_ENCOUNTER			; lass
	db MUSIC_LASS_ENCOUNTER			; janine
	db MUSIC_HIKER_ENCOUNTER		; cooltrainerm
	db MUSIC_BEAUTY_ENCOUNTER		; cooltrainerf
	db MUSIC_BEAUTY_ENCOUNTER		; beauty
	db MUSIC_POKEMANIAC_ENCOUNTER	; pokemaniac
	db MUSIC_ROCKET_ENCOUNTER		; gruntm
	db MUSIC_HIKER_ENCOUNTER		; gentleman
	db MUSIC_BEAUTY_ENCOUNTER		; skier
	db MUSIC_BEAUTY_ENCOUNTER		; teacher
	db MUSIC_BEAUTY_ENCOUNTER		; sabrina
	db MUSIC_YOUNGSTER_ENCOUNTER	; bug_catcher
	db MUSIC_HIKER_ENCOUNTER		; fisher
	db MUSIC_HIKER_ENCOUNTER		; swimmerm
	db MUSIC_BEAUTY_ENCOUNTER		; swimmerf
	db MUSIC_HIKER_ENCOUNTER		; sailor
	db MUSIC_POKEMANIAC_ENCOUNTER	; super_nerd
	db MUSIC_RIVAL_ENCOUNTER		; rival2
	db MUSIC_HIKER_ENCOUNTER		; guitarist
	db MUSIC_HIKER_ENCOUNTER		; hiker
	db MUSIC_HIKER_ENCOUNTER		; biker
	db MUSIC_OFFICER_ENCOUNTER		; blaine
	db MUSIC_POKEMANIAC_ENCOUNTER	; burglar
	db MUSIC_HIKER_ENCOUNTER		; firebreather
	db MUSIC_POKEMANIAC_ENCOUNTER	; juggler
	db MUSIC_HIKER_ENCOUNTER		; blackbelt_t
	db MUSIC_ROCKET_ENCOUNTER		; executivem
	db MUSIC_YOUNGSTER_ENCOUNTER	; psychic_t
	db MUSIC_LASS_ENCOUNTER			; picnicker
	db MUSIC_YOUNGSTER_ENCOUNTER	; camper
	db MUSIC_ROCKET_ENCOUNTER		; executivef
	db MUSIC_SAGE_ENCOUNTER			; sage
	db MUSIC_SAGE_ENCOUNTER			; medium
	db MUSIC_HIKER_ENCOUNTER		; boarder
	db MUSIC_HIKER_ENCOUNTER		; pokefanm
	db MUSIC_KIMONO_ENCOUNTER		; kimono_girl
	db MUSIC_LASS_ENCOUNTER			; twins
	db MUSIC_BEAUTY_ENCOUNTER		; pokefanf
	db MUSIC_HIKER_ENCOUNTER		; red
	db MUSIC_RIVAL_ENCOUNTER		; blue
	db MUSIC_HIKER_ENCOUNTER		; officer
	db MUSIC_ROCKET_ENCOUNTER		; gruntf
	db MUSIC_HIKER_ENCOUNTER		; mysticalman
	db MUSIC_HIKER_ENCOUNTER
	db MUSIC_HIKER_ENCOUNTER
	db MUSIC_HIKER_ENCOUNTER
; e906e

Music: ; e906e
	dbw BANK(Music_Nothing), Music_Nothing ; 0xe91a3
	dbw BANK(Music_TitleScreen), Music_TitleScreen ; 0xeb808
	dbw BANK(Music_Route1), Music_Route1 ; 0xec000
	dbw BANK(Music_Route3), Music_Route3 ; 0xec2ca
	dbw BANK(Music_Route12), Music_Route12 ; 0xec506
	dbw BANK(Music_MagnetTrain), Music_MagnetTrain ; 0xef5f0
	dbw BANK(Music_KantoGymLeaderBattle), Music_KantoGymLeaderBattle ; 0xec720
	dbw BANK(Music_KantoTrainerBattle), Music_KantoTrainerBattle ; 0xec9fa
	dbw BANK(Music_KantoWildPokemonBattle), Music_KantoWildPokemonBattle ; 0xed06d
	dbw BANK(Music_PokemonCenter), Music_PokemonCenter ; 0xed5c6
	dbw BANK(Music_LookHiker), Music_LookHiker ; 0xf7411
	dbw BANK(Music_LookLass), Music_LookLass ; 0xed79b
	dbw BANK(Music_LookOfficer), Music_LookOfficer ; 0xed82d
	dbw BANK(Music_HealPokemon), Music_HealPokemon ; 0xf0697
	dbw BANK(Music_LavenderTown), Music_LavenderTown ; 0xef72f
	dbw BANK(Music_Route2), Music_Route2 ; 0xed8dd
	dbw BANK(Music_MtMoon), Music_MtMoon ; 0xedb29
	dbw BANK(Music_ShowMeAround), Music_ShowMeAround ; 0xedbd8
	dbw BANK(Music_GameCorner), Music_GameCorner ; 0xedd6d
	dbw BANK(Music_Bicycle), Music_Bicycle ; 0xee119
	dbw BANK(Music_HallOfFame), Music_HallOfFame ; 0xf05bf
	dbw BANK(Music_ViridianCity), Music_ViridianCity ; 0xf4000
	dbw BANK(Music_CeladonCity), Music_CeladonCity ; 0xf435b
	dbw BANK(Music_TrainerVictory), Music_TrainerVictory ; 0xebeab
	dbw BANK(Music_WildPokemonVictory), Music_WildPokemonVictory ; 0xf4518
	dbw BANK(Music_GymLeaderVictory), Music_GymLeaderVictory ; 0xf462c
	dbw BANK(Music_MtMoonSquare), Music_MtMoonSquare ; 0xf4815
	dbw BANK(Music_Gym), Music_Gym ; 0xf48ae
	dbw BANK(Music_PalletTown), Music_PalletTown ; 0xf4b0c
	dbw BANK(Music_ProfOaksPokemonTalk), Music_ProfOaksPokemonTalk ; 0xf4c9f
	dbw BANK(Music_ProfOak), Music_ProfOak ; 0xf4dea
	dbw BANK(Music_LookRival), Music_LookRival ; 0xf4f79
	dbw BANK(Music_AfterTheRivalFight), Music_AfterTheRivalFight ; 0xf5127
	dbw BANK(Music_Surf), Music_Surf ; 0xf518a
	dbw BANK(Music_Evolution), Music_Evolution ; 0xf06e1
	dbw BANK(Music_NationalPark), Music_NationalPark ; 0xf54e8
	dbw BANK(Music_Credits), Music_Credits ; 0x1f31c
	dbw BANK(Music_AzaleaTown), Music_AzaleaTown ; 0xf57e8
	dbw BANK(Music_CherrygroveCity), Music_CherrygroveCity ; 0xf5b03
	dbw BANK(Music_LookKimonoGirl), Music_LookKimonoGirl ; 0xf79b8
	dbw BANK(Music_UnionCave), Music_UnionCave ; 0xf5c60
	dbw BANK(Music_JohtoWildPokemonBattle), Music_JohtoWildPokemonBattle ; 0xf5dc5
	dbw BANK(Music_JohtoTrainerBattle), Music_JohtoTrainerBattle ; 0xf6096
	dbw BANK(Music_Route30), Music_Route30 ; 0xefc01
	dbw BANK(Music_EcruteakCity), Music_EcruteakCity ; 0xef2d0
	dbw BANK(Music_VioletCity), Music_VioletCity ; 0xf0000
	dbw BANK(Music_JohtoGymLeaderBattle), Music_JohtoGymLeaderBattle ; 0xea50d
	dbw BANK(Music_ChampionBattle), Music_ChampionBattle ; 0xea9c1
	dbw BANK(Music_RivalBattle), Music_RivalBattle ; 0xe974f
	dbw BANK(Music_RocketBattle), Music_RocketBattle ; 0xe9b6f
	dbw BANK(Music_ElmsLab), Music_ElmsLab ; 0xea040
	dbw BANK(Music_DarkCave), Music_DarkCave ; 0xea2be
	dbw BANK(Music_Route29), Music_Route29 ; 0xf0386
	dbw BANK(Music_Route36), Music_Route36 ; 0xe94e9
	dbw BANK(Music_SSAqua), Music_SSAqua ; 0xead99
	dbw BANK(Music_LookYoungster), Music_LookYoungster ; 0xf66c3
	dbw BANK(Music_LookBeauty), Music_LookBeauty ; 0xeee3e
	dbw BANK(Music_LookRocket), Music_LookRocket ; 0xf74a2
	dbw BANK(Music_LookPokemaniac), Music_LookPokemaniac ; 0xebde1
	dbw BANK(Music_LookSage), Music_LookSage ; 0xee35e
	dbw BANK(Music_NewBarkTown), Music_NewBarkTown ; 0xeb2d3
	dbw BANK(Music_GoldenrodCity), Music_GoldenrodCity ; 0xeb453
	dbw BANK(Music_VermilionCity), Music_VermilionCity ; 0xeb676
	dbw BANK(Music_PokemonChannel), Music_PokemonChannel ; 0xee45f
	dbw BANK(Music_PokeFluteChannel), Music_PokeFluteChannel ; 0xf7b13
	dbw BANK(Music_TinTower), Music_TinTower ; 0xf6811
	dbw BANK(Music_SproutTower), Music_SproutTower ; 0xf6974
	dbw BANK(Music_BurnedTower), Music_BurnedTower ; 0xf6a99
	dbw BANK(Music_Lighthouse), Music_Lighthouse ; 0xee569
	dbw BANK(Music_LakeOfRage), Music_LakeOfRage ; 0xee6c5
	dbw BANK(Music_IndigoPlateau), Music_IndigoPlateau ; 0xee852
	dbw BANK(Music_Route37), Music_Route37 ; 0xee94b
	dbw BANK(Music_RocketHideout), Music_RocketHideout ; 0xeeb75
	dbw BANK(Music_DragonsDen), Music_DragonsDen ; 0xeece8
	dbw BANK(Music_JohtoWildPokemonBattleNight), Music_JohtoWildPokemonBattleNight ; 0xf605c
	dbw BANK(Music_RuinsOfAlphRadioSignal), Music_RuinsOfAlphRadioSignal ; 0xeedcb
	dbw BANK(Music_SuccessfulCapture), Music_SuccessfulCapture ; 0xf4602
	dbw BANK(Music_Route26), Music_Route26 ; 0xeefb2
	dbw BANK(Music_Mom), Music_Mom ; 0xf6bf2
	dbw BANK(Music_VictoryRoad), Music_VictoryRoad ; 0xf6c72
	dbw BANK(Music_PokemonLullaby), Music_PokemonLullaby ; 0xf6d79
	dbw BANK(Music_PokemonMarch), Music_PokemonMarch ; 0xf6e23
	dbw BANK(Music_GoldSilverOpening), Music_GoldSilverOpening ; 0xf7055
	dbw BANK(Music_GoldSilverOpening2), Music_GoldSilverOpening2 ; 0xf7308
	dbw BANK(Music_MainMenu), Music_MainMenu ; 0xf78fd
	dbw BANK(Music_RuinsOfAlphInterior), Music_RuinsOfAlphInterior ; 0xebd9e
	dbw BANK(Music_RocketTheme), Music_RocketTheme ; 0xf766d
	dbw BANK(Music_DancingHall), Music_DancingHall ; 0xef9bc
	dbw BANK(Music_BugCatchingContestResults), Music_BugCatchingContestResults ; 0xefb3e
	dbw BANK(Music_BugCatchingContest), Music_BugCatchingContest ; 0xf7c16
	dbw BANK(Music_LakeOfRageRocketsRadioSignal), Music_LakeOfRageRocketsRadioSignal ; 0xef5b1
	dbw BANK(Music_Printer), Music_Printer ; 0xf07fd
	dbw BANK(Music_PostCredits), Music_PostCredits ; 0xcfd9e
	dbw BANK(Music_Clair), Music_Clair ; 0x1fa8d
	dbw BANK(Music_MobileAdapterMenu), Music_MobileAdapterMenu ; 0x17801f
	dbw BANK(Music_MobileAdapter), Music_MobileAdapter ; 0x1fc87
	dbw BANK(Music_BuenasPassword), Music_BuenasPassword ; 0x178153
	dbw BANK(Music_LookMysticalMan), Music_LookMysticalMan ; 0x17843b
	dbw BANK(Music_CrystalOpening), Music_CrystalOpening ; 0x1786e8
	dbw BANK(Music_BattleTowerTheme), Music_BattleTowerTheme ; 0x178889
	dbw BANK(Music_SuicuneBattle), Music_SuicuneBattle ; 0x178b81
	dbw BANK(Music_BattleTowerLobby), Music_BattleTowerLobby ; 0x17948b
	dbw BANK(Music_MobileCenter), Music_MobileCenter ; 0x17961d
; e91a3

Music_Nothing: ; 0xe91a3
INCLUDE "music/nothing.asm"
; 0xe91b0

Cries: ; e91b0
; 3-byte pointers
	dbw $3c, $747d
	dbw $3c, $7486
	dbw $3c, $748f
	dbw $3c, $7498
	dbw $3c, $74a1
	dbw $3c, $74aa
	dbw $3c, $74b3
	dbw $3c, $74bc
	dbw $3c, $74c5
	dbw $3c, $74ce
	dbw $3c, $74d7
	dbw $3c, $74e0
	dbw $3c, $74e9
	dbw $3c, $74f2
	dbw $3c, $74fb
	dbw $3c, $7504
	dbw $3c, $750d
	dbw $3c, $7516
	dbw $3c, $751f
	dbw $3c, $7528
	dbw $3c, $7531
	dbw $3c, $753a
	dbw $3c, $7543
	dbw $3c, $754c
	dbw $3c, $7555
	dbw $3c, $755e
	dbw $3c, $7567
	dbw $3c, $7570
	dbw $3c, $7579
	dbw $3c, $7582
	dbw $3c, $758b
	dbw $3c, $7594
	dbw $3c, $759d
	dbw $3c, $75a6
	dbw $3c, $75af
	dbw $3c, $75b8
	dbw $3c, $75c1
	dbw $3c, $75ca
	dbw $3c, $6d81
	dbw $3c, $6d96
	dbw $3c, $6d8a
	dbw $3c, $6dde
	dbw $3c, $6d9f
	dbw $3c, $6dc0
	dbw $3c, $6d90
	dbw $3c, $6da8
	dbw $3c, $6db1
	dbw $3c, $6db7
	dbw $3c, $6dc6
	dbw $3c, $6dcf
	dbw $3c, $6e35
	dbw $3c, $6dd8
	dbw $3c, $6e3e
	dbw $3c, $6de7
	dbw $3c, $6ded
	dbw $3c, $6e6b
	dbw $3c, $6df6
	dbw $3c, $6e74
	dbw $3c, $6e08
	dbw $3c, $6e11
	dbw $3c, $6e1a
	dbw $3c, $6e23
	dbw $3c, $6e2c
	dbw $3c, $6e62
	dbw $3c, $6e47
	dbw $3c, $6e50
	dbw $3c, $6e59
	dbw $3c, $6dff
; e927c

SFX: ; e927c
	dbw $3c, $4b3f ; dex fanfare 50-79
	dbw $3c, $4c2f ; item
	dbw $3c, $4c89 ; caught mon
	dbw $3c, $4941 ; pokeballs placed on table
	dbw $3c, $4947 ; potion
	dbw $3c, $494a ; full heal
	dbw $3c, $494d ; menu
	dbw $3c, $4950 ; read text
	dbw $3c, $4950 ; read text
	dbw $3c, $4bd5 ; dex fanfare 20-49
	dbw $3c, $4cea ; dex fanfare 80-109
	dbw $3c, $4953 ; poison
	dbw $3c, $4956 ; got safari balls
	dbw $3c, $4959 ; boot pc
	dbw $3c, $495c ; shut down pc
	dbw $3c, $495f ; choose pc option
	dbw $3c, $4962 ; bide / escape rope
	dbw $3c, $4965 ; push button
	dbw $3c, $4968 ; second part of itemfinder
	dbw $3c, $496b ; warp to
	dbw $3c, $496e ; warp from
	dbw $3c, $4971 ; change dex mode
	dbw $3c, $4974 ; jump over ledge
	dbw $3c, $4977 ; grass rustle
	dbw $3c, $497a ; fly
	dbw $3c, $497d ; wrong
	dbw $3c, $4983 ; squeak
	dbw $3c, $4986 ; strength
	dbw $3c, $4989 ; boat
	dbw $3c, $498f ; wall open
	dbw $3c, $4992 ; place puzzle piece down
	dbw $3c, $4995 ; enter door
	dbw $3c, $4998 ; switch pokemon
	dbw $3c, $499e ; score tally? ; sounds like something out of game corner
	dbw $3c, $49a4 ; buy/sell
	dbw $3c, $49ad ; exit building
	dbw $3c, $49aa ; bump
	dbw $3c, $49b0 ; save
	dbw $3c, $49f8 ; pokeflute
	dbw $3c, $49fb ; elevator end
	dbw $3c, $49fe ; throw ball
	dbw $3c, $4a04 ; smokescreen
	dbw $3c, $4a0a ;	; something skidding on water?
	dbw $3c, $4a10 ; run
	dbw $3c, $4a13 ; slot machine start
	dbw $3c, $4dbe ; fanfare
	dbw $3c, $4a3d ; peck
	dbw $3c, $4a40 ; kinesis
	dbw $3c, $4a43 ; lick
	dbw $3c, $4a46 ; pound
	dbw $3c, $4a49 ; move puzzle piece
	dbw $3c, $4a4c ; comet punch
	dbw $3c, $4a4f ; mega punch
	dbw $3c, $4a52 ; scratch
	dbw $3c, $4a55 ; vicegrip
	dbw $3c, $4a58 ; razor wind
	dbw $3c, $4a5b ; cut
	dbw $3c, $4a5e ; wing attack
	dbw $3c, $4a61 ; whirlwind
	dbw $3c, $4a64 ; bind
	dbw $3c, $4a67 ; vine whip
	dbw $3c, $4a6a ; double kick
	dbw $3c, $4a6d ; mega kick
	dbw $3c, $4a70 ; headbutt
	dbw $3c, $4a73 ; horn attack
	dbw $3c, $4a76 ; tackle
	dbw $3c, $4a79 ; poison sting
	dbw $3c, $4a7c ; poisonpowder
	dbw $3c, $4a7f ; doubleslap
	dbw $3c, $4a82 ; bite
	dbw $3c, $4a88 ; jump kick
	dbw $3c, $4a8b ; stomp
	dbw $3c, $4a8e ; tail whip
	dbw $3c, $4a91 ; karate chop
	dbw $3c, $4a94 ; submission
	dbw $3c, $4a97 ; water gun
	dbw $3c, $4a9d ; swords dance
	dbw $3c, $4aa0 ; thunder
	dbw $3c, $4aa3 ; supersonic
	dbw $3c, $4aac ; leer
	dbw $3c, $4ab5 ; ember
	dbw $3c, $4abb ; bubblebeam
	dbw $3c, $4ac4 ; hydro pump
	dbw $3c, $4aca ; surf
	dbw $3c, $4ad3 ; psybeam
	dbw $3c, $4adc ; leech seed
	dbw $3c, $4ae5 ; thundershock
	dbw $3c, $4aee ; psychic
	dbw $3c, $4af7 ; screech
	dbw $3c, $4afd ; bone club
	dbw $3c, $4b03 ; sharpen
	dbw $3c, $4b09 ; egg bomb
	dbw $3c, $4b12 ; sing
	dbw $3c, $4b18 ; sky attack
	dbw $3c, $4b21 ; hyper beam
	dbw $3c, $4b24 ; shine
	dbw $3c, $4a1c ;
	dbw $3c, $4a1f ; $60
	dbw $3c, $4a22 ; tap
	dbw $3c, $4a25 ; tap
	dbw $3c, $4a28 ; burn ; that is not a burn
	dbw $3c, $4a2b ;
	dbw $3c, $4a2e ; similar to $60
	dbw $3c, $4a31 ; get coin from slots
	dbw $3c, $4a34 ; pay day
	dbw $3c, $4a3a ; metronome
	dbw $3c, $4a19 ; call
	dbw $3c, $4b2d ; hang up
	dbw $3c, $4b30 ; no signal
	dbw $3c, $4b2a ; sandstorm
	dbw $3c, $4b33 ; elevator
	dbw $3c, $52b4 ; protect
	dbw $3c, $52f6 ; sketch
	dbw $3c, $5314 ; rain dance
	dbw $3c, $5334 ; aeroblast
	dbw $3c, $5352 ; spark
	dbw $3c, $5360 ; curse
	dbw $3c, $537d ; rage
	dbw $3c, $539c ; thief
	dbw $3c, $53b0 ; thief
	dbw $3c, $53ca ; spider web
	dbw $3c, $53f7 ; mind reader
	dbw $3c, $541d ; nighmare
	dbw $3c, $5453 ; snore
	dbw $3c, $5469 ; sweet kiss
	dbw $3c, $547f ; sweet kiss
	dbw $3c, $54a5 ; belly drum
	dbw $3c, $54ba ;
	dbw $3c, $54d0 ; sludge bomb
	dbw $3c, $54f5 ; foresight
	dbw $3c, $5515 ; spite
	dbw $3c, $553a ; outrage
	dbw $3c, $554d ; perish song
	dbw $3c, $5570 ; giga drain
	dbw $3c, $55b4 ; attract
	dbw $3c, $55cc ; kinesis
	dbw $3c, $55de ; zap cannon
	dbw $3c, $55ef ; mean look
	dbw $3c, $5621 ; heal bell
	dbw $3c, $5637 ; return
	dbw $3c, $5653 ; exp bar
	dbw $3c, $567f ; milk drink
	dbw $3c, $569f ; present
	dbw $3c, $56b9 ; morning sun
	dbw $3c, $4b3f ; level up
	dbw $3c, $4b86 ; key item
	dbw $3c, $4d56 ; fanfare
	dbw $3c, $4dc7 ; register phone #
	dbw $3c, $4e26 ; 3rd place
	dbw $3c, $4e66 ; get egg from daycare man
	dbw $3c, $4e66 ; get egg from daycare lady
	dbw $3c, $4edc ; move deleted
	dbw $3c, $4f5e ; 2nd place
	dbw $3c, $4fe2 ; 1st place
	dbw $3c, $5069 ; choose a card
	dbw $3c, $5104 ; get tm
	dbw $3c, $517d ; get badge
	dbw $3c, $5236 ; quit slots
	dbw $3c, $5775 ; nothing
	dbw $3c, $5878 ; dex fanfare <20
	dbw $3c, $58d2 ; dex fanfare 140-169
	dbw $3c, $5951 ; dex fanfare 170-199
	dbw $3c, $59d6 ; dex fanfare 200-229
	dbw $3c, $5a66 ; dex fanfare >=230
	dbw $3c, $5784 ; evolved
	dbw $3c, $579b ; master ball
	dbw $3c, $57c0 ; egg crack
	dbw $3c, $57d9 ; charizard fireball (gs intro)
	dbw $3c, $57ff ; pokemon appears (gs intro)
	dbw $3c, $5818 ; flash
	dbw $3c, $5846 ; game freak logo
	dbw $3c, $5b33 ; not very effective
	dbw $3c, $5b40 ; damage
	dbw $3c, $5b50 ; super effective
	dbw $3c, $5b63 ; ball bounce
	dbw $3c, $56df ; moonlight
	dbw $3c, $56fd ; encore
	dbw $3c, $5721 ; beat up
	dbw $3c, $574c ; batom pass
	dbw $3c, $4944 ; ball wiggle
	dbw $3c, $5734 ; sweet scent
	dbw $3c, $5bb3 ; sweet scent
	dbw $3c, $5bec ; hit end of exp bar
	dbw $3c, $5c10 ; give trademon
	dbw $3c, $5c3e ; get trademon
	dbw $3c, $5c6c ; train arrived
	dbw $3c, $675b ; stop slot
	dbw $3c, $5cb4 ; 2 boops
	dbw $3c, $6769 ; glass ting
	dbw $3c, $6773 ; 2 glass ting
	dbw $5e, $582d ; intro unown 1
	dbw $5e, $583e ; intro unown 2
	dbw $5e, $584f ; intro unown 3
	dbw $5e, $586e ; boop
	dbw $5e, $5888 ; game freak ditto transform
	dbw $5e, $58a0 ; intro suicune 1
	dbw $5e, $58aa ; intro pichu
	dbw $5e, $58c0 ; intro suicune 2
	dbw $5e, $58f4 ; intro suicune 3
	dbw $5e, $5907 ; game freak ditto bounce
	dbw $5e, $591d ; intro suicune 4
	dbw $5e, $5942 ; game freak presents
	dbw $5e, $5961 ; tingle
	dbw $3c, $5cd0 ; sand?
	dbw $5e, $597c ; two pc beeps
	dbw $5e, $5992 ; 4 note ditty
	dbw $5e, $59cb ; twinkle
; e94e9

Music_Route36: ; 0xe94e9
INCLUDE "music/route36.asm"
; 0xe974f

Music_RivalBattle: ; 0xe974f
INCLUDE "music/rivalbattle.asm"
; 0xe9b6f

Music_RocketBattle: ; 0xe9b6f
INCLUDE "music/rocketbattle.asm"
; 0xea040

Music_ElmsLab: ; 0xea040
INCLUDE "music/elmslab.asm"
; 0xea2be

Music_DarkCave: ; 0xea2be
INCLUDE "music/darkcave.asm"
; 0xea50d

Music_JohtoGymLeaderBattle: ; 0xea50d
INCLUDE "music/johtogymleaderbattle.asm"
; 0xea9c1

Music_ChampionBattle: ; 0xea9c1
INCLUDE "music/championbattle.asm"
; 0xead99

Music_SSAqua: ; 0xead99
INCLUDE "music/ssaqua.asm"
; 0xeb2d3

Music_NewBarkTown: ; 0xeb2d3
INCLUDE "music/newbarktown.asm"
; 0xeb453

Music_GoldenrodCity: ; 0xeb453
INCLUDE "music/goldenrodcity.asm"
; 0xeb676

Music_VermilionCity: ; 0xeb676
INCLUDE "music/vermilioncity.asm"
; 0xeb808

Music_TitleScreen: ; 0xeb808
INCLUDE "music/titlescreen.asm"
; 0xebd9e

Music_RuinsOfAlphInterior: ; 0xebd9e
INCLUDE "music/ruinsofalphinterior.asm"
; 0xebde1

Music_LookPokemaniac: ; 0xebde1
INCLUDE "music/lookpokemaniac.asm"

Music_TrainerVictory: ; 0xebeab
INCLUDE "music/trainervictory.asm"
; 0xebfc3

SECTION "bank3B",DATA,BANK[$3B]

Music_Route1: ; 0xec000
INCLUDE "music/route1.asm"
; 0xec2ca

Music_Route3: ; 0xec2ca
INCLUDE "music/route3.asm"
; 0xec506

Music_Route12: ; 0xec506
INCLUDE "music/route12.asm"
; 0xec720

Music_KantoGymLeaderBattle: ; 0xec720
INCLUDE "music/kantogymleaderbattle.asm"
; 0xec9fa

Music_KantoTrainerBattle: ; 0xec9fa
INCLUDE "music/kantotrainerbattle.asm"
; 0xed06d

Music_KantoWildPokemonBattle: ; 0xed06d
INCLUDE "music/kantowildpokemonbattle.asm"
; 0xed5c6

Music_PokemonCenter: ; 0xed5c6
INCLUDE "music/pokemoncenter.asm"
; 0xed79b

Music_LookLass: ; 0xed79b
INCLUDE "music/looklass.asm"
; 0xed82d

Music_LookOfficer: ; 0xed82d
INCLUDE "music/lookofficer.asm"
; 0xed8dd

Music_Route2: ; 0xed8dd
INCLUDE "music/route2.asm"
; 0xedb29

Music_MtMoon: ; 0xedb29
INCLUDE "music/mtmoon.asm"
; 0xedbd8

Music_ShowMeAround: ; 0xedbd8
INCLUDE "music/showmearound.asm"
; 0xedd6d

Music_GameCorner: ; 0xedd6d
INCLUDE "music/gamecorner.asm"
; 0xee119

Music_Bicycle: ; 0xee119
INCLUDE "music/bicycle.asm"
; 0xee35e

Music_LookSage: ; 0xee35e
INCLUDE "music/looksage.asm"
; 0xee45f

Music_PokemonChannel: ; 0xee45f
INCLUDE "music/pokemonchannel.asm"
; 0xee569

Music_Lighthouse: ; 0xee569
INCLUDE "music/lighthouse.asm"
; 0xee6c5

Music_LakeOfRage: ; 0xee6c5
INCLUDE "music/lakeofrage.asm"
; 0xee852

Music_IndigoPlateau: ; 0xee852
INCLUDE "music/indigoplateau.asm"
; 0xee94b

Music_Route37: ; 0xee94b
INCLUDE "music/route37.asm"
; 0xeeb75

Music_RocketHideout: ; 0xeeb75
INCLUDE "music/rockethideout.asm"
; 0xeece8

Music_DragonsDen: ; 0xeece8
INCLUDE "music/dragonsden.asm"
; 0xeedcb

Music_RuinsOfAlphRadioSignal: ; 0xeedcb
INCLUDE "music/ruinsofalphradiosignal.asm"
; 0xeee3e

Music_LookBeauty: ; 0xeee3e
INCLUDE "music/lookbeauty.asm"
; 0xeefb2

Music_Route26: ; 0xeefb2
INCLUDE "music/route26.asm"
; 0xef2d0

Music_EcruteakCity: ; 0xef2d0
INCLUDE "music/ecruteakcity.asm"
; 0xef5b1

Music_LakeOfRageRocketsRadioSignal: ; 0xef5b1
INCLUDE "music/lakeofragerocketsradiosignal.asm"
; 0xef5f0

Music_MagnetTrain: ; 0xef5f0
INCLUDE "music/magnettrain.asm"
; 0xef72f

Music_LavenderTown: ; 0xef72f
INCLUDE "music/lavendertown.asm"
; 0xef9bc

Music_DancingHall: ; 0xef9bc
INCLUDE "music/dancinghall.asm"
; 0xefb3e

Music_BugCatchingContestResults: ; 0xefb3e
INCLUDE "music/bugcatchingcontestresults.asm"
; 0xefc01

Music_Route30: ; 0xefc01
INCLUDE "music/route30.asm"
; 0xefef5

SECTION "bank3C",DATA,BANK[$3C]

Music_VioletCity: ; 0xf0000
INCLUDE "music/violetcity.asm"
; 0xf0386

Music_Route29: ; 0xf0386
INCLUDE "music/route29.asm"
; 0xf05bf

Music_HallOfFame: ; 0xf05bf
INCLUDE "music/halloffame.asm"
; 0xf0697

Music_HealPokemon: ; 0xf0697
INCLUDE "music/healpokemon.asm"
; 0xf06e1

Music_Evolution: ; 0xf06e1
INCLUDE "music/evolution.asm"
; 0xf07fd

Music_Printer: ; 0xf07fd
INCLUDE "music/printer.asm"
; 0xf0941

INCBIN "baserom.gbc", $f0941, $f3fb6 - $f0941

SECTION "bank3D",DATA,BANK[$3D]

Music_ViridianCity: ; 0xf4000
INCLUDE "music/viridiancity.asm"
; 0xf435b

Music_CeladonCity: ; 0xf435b
INCLUDE "music/celadoncity.asm"
; 0xf4518

Music_WildPokemonVictory: ; 0xf4518
INCLUDE "music/wildpokemonvictory.asm"
; 0xf4602

Music_SuccessfulCapture: ; 0xf4602
INCLUDE "music/successfulcapture.asm"
; 0xf462c

Music_GymLeaderVictory: ; 0xf462c
INCLUDE "music/gymleadervictory.asm"
; 0xf4815

Music_MtMoonSquare: ; 0xf4815
INCLUDE "music/mtmoonsquare.asm"
; 0xf48ae

Music_Gym: ; 0xf48ae
INCLUDE "music/gym.asm"
; 0xf4b0c

Music_PalletTown: ; 0xf4b0c
INCLUDE "music/pallettown.asm"
; 0xf4c9f

Music_ProfOaksPokemonTalk: ; 0xf4c9f
INCLUDE "music/profoakspokemontalk.asm"
; 0xf4dea

Music_ProfOak: ; 0xf4dea
INCLUDE "music/profoak.asm"
; 0xf4f79

Music_LookRival: ; 0xf4f79
INCLUDE "music/lookrival.asm"
; 0xf5127

Music_AfterTheRivalFight: ; 0xf5127
INCLUDE "music/aftertherivalfight.asm"
; 0xf518a

Music_Surf: ; 0xf518a
INCLUDE "music/surf.asm"
; 0xf54e8

Music_NationalPark: ; 0xf54e8
INCLUDE "music/nationalpark.asm"
; 0xf57e8

Music_AzaleaTown: ; 0xf57e8
INCLUDE "music/azaleatown.asm"
; 0xf5b03

Music_CherrygroveCity: ; 0xf5b03
INCLUDE "music/cherrygrovecity.asm"
; 0xf5c60

Music_UnionCave: ; 0xf5c60
INCLUDE "music/unioncave.asm"
; 0xf5dc5

Music_JohtoWildPokemonBattle: ; 0xf5dc5
INCLUDE "music/johtowildpokemonbattle.asm"
; 0xf605c

Music_JohtoWildPokemonBattleNight: ; 0xf605c
INCLUDE "music/johtowildpokemonbattlenight.asm"
; 0xf6096

Music_JohtoTrainerBattle: ; 0xf6096
INCLUDE "music/johtotrainerbattle.asm"
; 0xf66c3

Music_LookYoungster: ; 0xf66c3
INCLUDE "music/lookyoungster.asm"
; 0xf6811

Music_TinTower: ; 0xf6811
INCLUDE "music/tintower.asm"
; 0xf6974

Music_SproutTower: ; 0xf6974
INCLUDE "music/sprouttower.asm"
; 0xf6a99

Music_BurnedTower: ; 0xf6a99
INCLUDE "music/burnedtower.asm"
; 0xf6bf2

Music_Mom: ; 0xf6bf2
INCLUDE "music/mom.asm"
; 0xf6c72

Music_VictoryRoad: ; 0xf6c72
INCLUDE "music/victoryroad.asm"
; 0xf6d79

Music_PokemonLullaby: ; 0xf6d79
INCLUDE "music/pokemonlullaby.asm"
; 0xf6e23

Music_PokemonMarch: ; 0xf6e23
INCLUDE "music/pokemonmarch.asm"
; 0xf7055

Music_GoldSilverOpening: ; 0xf7055
INCLUDE "music/goldsilveropening.asm"
; 0xf7308

Music_GoldSilverOpening2: ; 0xf7308
INCLUDE "music/goldsilveropening2.asm"
; 0xf7411

Music_LookHiker: ; 0xf7411
INCLUDE "music/lookhiker.asm"
; 0xf74a2

Music_LookRocket: ; 0xf74a2
; RocketTheme borrows heavily from this song
INCLUDE "music/lookrocket.asm"
; 0xf766d

Music_RocketTheme: ; 0xf766d
; borrows heavily from LookRocket
INCLUDE "music/rockettheme.asm"
; 0xf78fd

Music_MainMenu: ; 0xf78fd
INCLUDE "music/mainmenu.asm"
; 0xf79b8

Music_LookKimonoGirl: ; 0xf79b8
INCLUDE "music/lookkimonogirl.asm"
; 0xf7b13

Music_PokeFluteChannel: ; 0xf7b13
INCLUDE "music/pokeflutechannel.asm"
; 0xf7c16

Music_BugCatchingContest: ; 0xf7c16
INCLUDE "music/bugcatchingcontest.asm"
; 0xf7ef3


SECTION "bank3E",DATA,BANK[$3E]

FontExtra:
INCBIN "gfx/font_extra.2bpp",$0,$200

Font:
INCBIN "gfx/font.1bpp",$0,$400

FontBattleExtra:
INCBIN "gfx/font_battle_extra.2bpp",$0,$200

INCBIN "baserom.gbc", $f8800, $f8ba0 - $f8800

TownMapGFX: ; f8ba0
INCBIN "gfx/misc/lz/town_map.lz"
; f8ea2

INCBIN "baserom.gbc", $f8ea2, $fbbfc - $f8ea2

CalcMagikarpLength: ; fbbfc
; Stores Magikarp's length at $d1ea-$d1eb in big endian
;
; input:
;   de: EnemyMonDVs
;   bc: PlayerID
; output:
;   $d1ea-$d1eb: length
;
; does a whole bunch of arbitrary nonsense
; cycles through a table of arbitrary values
; http://web.archive.org/web/20110628181718/http://upokecenter.com/games/gs/guides/magikarp.php

; b = rrcrrc(atkdefdv) xor rrc(pidhi)
	ld h, b
	ld l, c
	ld a, [hli]
	ld b, a
	ld c, [hl] ; ld bc, [PlayerID]
	rrc b
	rrc c
	ld a, [de]
	inc de
	rrca
	rrca
	xor b
	ld b, a
	
; c = rrcrrc(spdspcdv) xor rrc(pidlo)
	ld a, [de]
	rrca
	rrca
	xor c
	ld c, a
	
; if bc < $000a:
	ld a, b
	and a
	jr nz, .loadtable
	ld a, c
	cp a, $0a
	jr nc, .loadtable
	
; de = hl = bc + $be
	ld hl, $00be
	add hl, bc
	ld d, h
	ld e, l
	jr .endtable
	
.loadtable
	ld hl, .MagikarpLengthTable
	ld a, $02
	ld [$d265], a
	
.readtable
	ld a, [hli]
	ld e, a
	ld a, [hli]
	ld d, a
	call .BLessThanD
	jr nc, .advancetable
	
; c = bc / [hl]
	call .BCMinusDE
	ld a, b
	ld [$ffb3], a
	ld a, c
	ld [$ffb4], a
	ld a, [hl]
	ld [$ffb7], a
	ld b, $02
	call Divide
	ld a, [$ffb6]
	ld c, a
	
; de = c + $64 * (2 + number of rows down the table)
	xor a
	ld [$ffb4], a
	ld [$ffb5], a
	ld a, $64
	ld [$ffb6], a
	ld a, [$d265]
	ld [$ffb7], a
	call Multiply
	ld b, $00
	ld a, [$ffb6]
	add c
	ld e, a
	ld a, [$ffb5]
	adc b
	ld d, a
	jr .endtable
	
.advancetable
	inc hl ; align to next triplet
	ld a, [$d265]
	inc a
	ld [$d265], a
	cp a, $10
	jr c, .readtable
	
	call .BCMinusDE
	ld hl, $0640
	add hl, bc
	ld d, h
	ld e, l
	
.endtable
	ld h, d
	ld l, e
	add hl, hl
	add hl, hl
	add hl, de
	add hl, hl ; hl = de * 10
	
	ld de, $ff02
	ld a, $ff
.loop
	inc a
	add hl, de ; - 254
	jr c, .loop
	
	ld d, $00
	
; mod $0c
.modloop
	cp a, $0c
	jr c, .done
	sub a, $0c
	inc d
	jr .modloop
	
.done
	ld e, a
	ld hl, $d1ea
	ld [hl], d
	inc hl
	ld [hl], e
	ret
; fbc9a

.BLessThanD ; fbc9a
; return carry if b < d
	ld a, b
	cp d
	ret c
	ret nc
; fbc9e

.CLessThanE ; fbc9e
; unused
	ld a, c
	cp e
	ret
; fbca1

.BCMinusDE ; fbca1
; bc -= de
	ld a, c
	sub e
	ld c, a
	ld a, b
	sbc d
	ld b, a
	ret
; fbca8

.MagikarpLengthTable ; fbca8
;		????, divisor
	dwb $006e, $01
	dwb $0136, $02
	dwb $02c6, $04
	dwb $0a96, $14
	dwb $1e1e, $32
	dwb $452e, $64
	dwb $7fc6, $96
	dwb $ba5e, $96
	dwb $e16e, $64
	dwb $f4f6, $32
	dwb $fcc6, $14
	dwb $feba, $05
	dwb $ff82, $02
; fbccf

INCBIN "baserom.gbc",$FBCCF,$fc000-$fbccf

SECTION "bank3F",DATA,BANK[$3F]

INCBIN "baserom.gbc",$FC000,$fcdc2-$fc000

LoadTradesPointer: ; 0xfcdc2
	ld d, 0
	push de
	ld a, [$cf63]
	and $f
	swap a
	ld e, a
	ld d, $0
	ld hl, Trades
	add hl, de
	add hl, de
	pop de
	add hl, de
	ret
; 0xfcdd7

INCBIN "baserom.gbc",$fcdd7,$fce58-$fcdd7

Trades: ; 0xfce58
; byte 1: dialog
; byte 2: givemon
; byte 3: getmon
; bytes 4-14 nickname
; bytes 15-16 DVs
; byte 17 held item
; bytes 18-19 ID
; bytes 20-30 OT name
; byte 31 gender
; byte 32 XXX always zero?

	db 0,ABRA,MACHOP,"MUSCLE@@@@@",$37,$66,GOLD_BERRY,$54,$92,"MIKE@@@@@@@",0,0
	db 0,BELLSPROUT,ONIX,"ROCKY@@@@@@",$96,$66,BITTER_BERRY,$1e,$bf,"KYLE@@@@@@@",0,0
	db 1,KRABBY,VOLTORB,"VOLTY@@@@@@",$98,$88,PRZCUREBERRY,$05,$72,"TIM@@@@@@@@",0,0
	db 3,DRAGONAIR,DODRIO,"DORIS@@@@@@",$77,$66,SMOKE_BALL,$1b,$01,"EMY@@@@@@@@",2,0
	db 2,HAUNTER,XATU,"PAUL@@@@@@@",$96,$86,MYSTERYBERRY,$00,$3d,"CHRIS@@@@@@",0,0
	db 3,CHANSEY,AERODACTYL,"AEROY@@@@@@",$96,$66,GOLD_BERRY,$7b,$67,"KIM@@@@@@@@",0,0
	db 0,DUGTRIO,MAGNETON,"MAGGIE@@@@@",$96,$66,METAL_COAT,$a2,$c3,"FOREST@@@@@",0,0

INCBIN "baserom.gbc",$fcf38,$fd1d2-$fcf38

SECTION "bank40",DATA,BANK[$40]

INCBIN "baserom.gbc",$100000,$4000

SECTION "bank41",DATA,BANK[$41]

INCBIN "baserom.gbc",$104000,$1060bb - $104000

Function1060bb: ; 1060bb
; commented out
	ret
; 1060bc

INCBIN "baserom.gbc",$1060bc,$108000 - $1060bc

SECTION "bank42",DATA,BANK[$42]

INCBIN "baserom.gbc", $108000, $109407 - $108000

IntroLogoGFX: ; 109407
INCBIN "gfx/intro/lz/logo.lz"
; 10983f

INCBIN "baserom.gbc", $10983f, $10c000 - $10983f


SECTION "bank43",DATA,BANK[$43]

INCBIN "baserom.gbc", $10c000, $10ef46 - $10c000

TitleSuicuneGFX: ; 10ef46
INCBIN "gfx/title/lz/suicune.lz"
; 10f31b

INCBIN "baserom.gbc", $10f31b, $10f326 - $10f31b

TitleLogoGFX: ; 10f326
INCBIN "gfx/title/lz/logo.lz"
; 10fced

INCBIN "baserom.gbc", $10fced, $10fcee - $10fced

TitleCrystalGFX: ; 10fcee
INCBIN "gfx/title/lz/crystal.lz"
; 10fed7

INCBIN "baserom.gbc", $10fed7, $110000 - $10fed7


SECTION "bank44",DATA,BANK[$44]

INCBIN "baserom.gbc",$110000,$4000


SECTION "bank45",DATA,BANK[$45]

INCBIN "baserom.gbc",$114000,$117a7f - $114000

; everything from here to the end of the bank is related to the
; Mobile Stadium option from the continue/newgame menu.
; XXX better function names
Function117a7f: ; 0x117a7f
	ld a, [$ffaa]
	push af
	ld a, $1
	ld [$ffaa], a
	call Function117a8d
	pop af
	ld [$ffaa], a
	ret
; 0x117a8d

Function117a8d: ; 0x117a8d
	call Function117a94
	call Function117acd
	ret
; 0x117a94

Function117a94: ; 0x117a94
	xor a
	ld [$cf63], a
	ld [$cf64], a
	ld [$cf65], a
	ld [$cf66], a
	call $31f3
	call $300b
	ld a, $5c
	ld hl, $6e78
	rst $8
	ld a, $41
	ld hl, $4000
	rst $8
	ret
; 0x117ab4

Function117ab4: ; 0x117ab4
	call $31f3
	call $300b
	ld a, $5c
	ld hl, $6e78
	rst $8
	ld a, $5c
	ld hl, $6eb9
	rst $8
	ld a, $41
	ld hl, $4061
	rst $8
	ret
; 0x117acd

Function117acd: ; 0x117acd
	call $0a57
	ld a, [$cf63]
	bit 7, a
	jr nz, .asm_117ae2 ; 0x117ad5 $b
	call Function117ae9
	ld a, $41
	ld hl, $4000
	rst $8
	jr Function117acd
.asm_117ae2
	call $31f3
	call $300b
	ret

Function117ae9: ; 0x117ae9
	ld a, [$cf63]
	ld e, a
	ld d, $0
	ld hl, Pointers117af8
	add hl, de
	add hl, de
	ld a, [hli]
	ld h, [hl]
	ld l, a
	jp [hl]

Pointers117af8: ; 0x117af8
	dw Function117b06
	dw Function117b14
	dw Function117b28
	dw Function117b31
	dw Function117b4f
	dw Function117bb6
	dw Function117c4a

Function117b06:
	ld a, $5c
	ld hl, $6eb9
	rst $8
	ld a, $10
	ld [$cf64], a
	jp Function117cdd

Function117b14:
	ld hl, $cf64
	dec [hl]
	ret nz
	ld hl, Data117cbc
	call $1d35
	call $1cbb
	call $1cfd
	jp Function117cdd

Function117b28:
	ld hl, MobileStadiumEntryText
	call $1057
	jp Function117cdd

Function117b31:
	ld hl, Data117cc4
	call $1d35
	call $1cbb
	call $1cfd
	ld hl, $c550
	ld de, YesNo117ccc
	call $1078
	ld hl, $c54f
	ld a, "▶"
	ld [hl], a
	jp Function117cdd

Function117b4f:
	ld a, [$ffa7]
	cp $2
	jr z, .asm_117ba4 ; 0x117b53 $4f
	cp $1
	jr z, .asm_117b8c ; 0x117b57 $33
	cp $80
	jr z, .asm_117b76 ; 0x117b5b $19
	cp $40
	ret nz
	ld a, [$cf64]
	and a
	ret z
	dec a
	ld [$cf64], a
	ld hl, $c54f
	ld a, "▶"
	ld [hl], a
	ld hl, $c577
	ld a, " "
	ld [hl], a
	ret
.asm_117b76
	ld a, [$cf64]
	and a
	ret nz
	inc a
	ld [$cf64], a
	ld hl, $c54f
	ld a, " "
	ld [hl], a
	ld hl, $c577
	ld a, "▶"
	ld [hl], a
	ret
.asm_117b8c
	call $2009
	ld a, [$cf64]
	and a
	jr nz, .asm_117ba4 ; 0x117b93 $f
	call $1c07
	call $1c07
	ld a, $41
	ld hl, $4061
	rst $8
	jp Function117cdd
.asm_117ba4
	call $1c07
	call $1c07
	ld a, $41
	ld hl, $4061
	rst $8
	ld a, $80
	ld [$cf63], a
	ret

Function117bb6:
	call Function117c89
	ld a, $1
	ld [$ffd4], a
	ld a, $46
	ld hl, $4284
	rst $8
	call $300b
	ld a, [$c300]
	and a
	jr z, .asm_117be7 ; 0x117bca $1b
	cp $a
	jr z, .asm_117be1 ; 0x117bce $11
.asm_117bd0
	ld a, $2
	ld [$c303], a
	ld a, $5f
	ld hl, $7555
	rst $8
	ld a, $80
	ld [$cf63], a
	ret
.asm_117be1
	ld a, $80
	ld [$cf63], a
	ret
.asm_117be7
	ld a, [$ff70]
	push af
	ld a, $3
	ld [$ff70], a
	ld a, [$cd89]
	and $1
	jr nz, .asm_117c16 ; 0x117bf3 $21
	ld a, [$d000]
	cp $fe
	jr nz, .asm_117c16 ; 0x117bfa $1a
	ld a, [$d001]
	cp $f
	jr nz, .asm_117c16 ; 0x117c01 $13
	ld hl, $dfec
	ld de, $cd69
	ld c, $10
.asm_117c0b
	ld a, [de]
	inc de
	cp [hl]
	jr nz, .asm_117c16 ; 0x117c0e $6
	inc hl
	dec c
	jr nz, .asm_117c0b ; 0x117c12 $f7
	jr .asm_117c20 ; 0x117c14 $a
.asm_117c16
	pop af
	ld [$ff70], a
	ld a, $d3
	ld [$c300], a
	jr .asm_117bd0 ; 0x117c1e $b0
.asm_117c20
	pop af
	ld [$ff70], a
	ld a, $5c
	ld hl, $6eb9
	rst $8
	ld a, [$ff70]
	push af
	ld a, $3
	ld [$ff70], a
	ld a, $7
	call GetSRAMBank
	ld hl, $d002
	ld de, $b000
	ld bc, $1000
	call $3026
	call CloseSRAM
	pop af
	ld [$ff70], a
	jp Function117cdd

Function117c4a:
	ld hl, Data117cbc
	call $1d35
	call $1cbb
	call $1cfd
	ld a, $41
	ld hl, $4061
	rst $8
	ld hl, MobileStadiumSuccessText
	call $1057
	ld a, [$ff70]
	push af
	ld a, $5
	ld [$ff70], a
	ld hl, $d000
	ld de, $0008
	ld c, $8
.asm_117c71
	push hl
	ld a, $ff
	ld [hli], a
	ld a, " "
	ld [hl], a
	pop hl
	add hl, de
	dec c
	jr nz, .asm_117c71 ; 0x117c7b $f4
	call $04b6
	pop af
	ld [$ff70], a
	ld a, $80
	ld [$cf63], a
	ret

Function117c89:
	ld a, $7
	call GetSRAMBank
	ld l, $0
	ld h, l
	ld de, $b000
	ld bc, $0ffc
.asm_117c97
	push bc
	ld a, [de]
	inc de
	ld c, a
	ld b, $0
	add hl, bc
	pop bc
	dec bc
	ld a, b
	or c
	jr nz, .asm_117c97 ; 0x117ca2 $f3
	ld a, l
	ld [$cd83], a
	ld a, h
	ld [$cd84], a
	ld hl, $bfea
	ld de, $cd69
	ld bc, $0010
	call CopyBytes
	call CloseSRAM
	ret

Data117cbc: ; 0x117cbc
	db $40,$0c,$00,$11,$13,$00,$00,$00

Data117cc4: ; 0x117cc4
	db $40,$07,$0e,$0b,$13,$00,$00,$00 ; XXX what is this

YesNo117ccc: ; 0x117ccc
	db "はい", $4e ; Yes
	db "いいえ@"   ; No

MobileStadiumEntryText: ; 0x117cd3
	TX_FAR _MobileStadiumEntryText
	db "@"

MobileStadiumSuccessText: ; 0x117cd8
	TX_FAR _MobileStadiumSuccessText
	db "@"

Function117cdd: ; 0x117cdd
	ld hl,$cf63
	inc [hl]
	ret

SECTION "bank46",DATA,BANK[$46]

INCBIN "baserom.gbc",$118000,$4000

SECTION "bank47",DATA,BANK[$47]

INCBIN "baserom.gbc",$11C000,$4000


SECTION "bank48",DATA,BANK[$48]

PicPointers: ; 120000
	dbw BANK(BulbasaurFrontpic) - $36, BulbasaurFrontpic ; 14fd6d
	dbw BANK(BulbasaurBackpic) - $36, BulbasaurBackpic ; 16049b
	dbw BANK(IvysaurFrontpic) - $36, IvysaurFrontpic ; 13f4a2
	dbw BANK(IvysaurBackpic) - $36, IvysaurBackpic ; 1592f7
	dbw BANK(VenusaurFrontpic) - $36, VenusaurFrontpic ; 122f81
	dbw BANK(VenusaurBackpic) - $36, VenusaurBackpic ; 14c000
	dbw BANK(CharmanderFrontpic) - $36, CharmanderFrontpic ; 142065
	dbw BANK(CharmanderBackpic) - $36, CharmanderBackpic ; 15f4cb
	dbw BANK(CharmeleonFrontpic) - $36, CharmeleonFrontpic ; 132881
	dbw BANK(CharmeleonBackpic) - $36, CharmeleonBackpic ; 150925
	dbw BANK(CharizardFrontpic) - $36, CharizardFrontpic ; 127937
	dbw BANK(CharizardBackpic) - $36, CharizardBackpic ; 155c7a
	dbw BANK(SquirtleFrontpic) - $36, SquirtleFrontpic ; 145ae2
	dbw BANK(SquirtleBackpic) - $36, SquirtleBackpic ; 1644b7
	dbw BANK(WartortleFrontpic) - $36, WartortleFrontpic ; 1345d2
	dbw BANK(WartortleBackpic) - $36, WartortleBackpic ; 156216
	dbw BANK(BlastoiseFrontpic) - $36, BlastoiseFrontpic ; 12409c
	dbw BANK(BlastoiseBackpic) - $36, BlastoiseBackpic ; 155132
	dbw BANK(CaterpieFrontpic) - $36, CaterpieFrontpic ; 15dcc6
	dbw BANK(CaterpieBackpic) - $36, CaterpieBackpic ; 160fd2
	dbw BANK(MetapodFrontpic) - $36, MetapodFrontpic ; 15d699
	dbw BANK(MetapodBackpic) - $36, MetapodBackpic ; 163c88
	dbw BANK(ButterfreeFrontpic) - $36, ButterfreeFrontpic ; 12a24a
	dbw BANK(ButterfreeBackpic) - $36, ButterfreeBackpic ; 146f39
	dbw BANK(WeedleFrontpic) - $36, WeedleFrontpic ; 15afeb
	dbw BANK(WeedleBackpic) - $36, WeedleBackpic ; 1632c3
	dbw BANK(KakunaFrontpic) - $36, KakunaFrontpic ; 15a6cc
	dbw BANK(KakunaBackpic) - $36, KakunaBackpic ; 162141
	dbw BANK(BeedrillFrontpic) - $36, BeedrillFrontpic ; 125976
	dbw BANK(BeedrillBackpic) - $36, BeedrillBackpic ; 14f748
	dbw BANK(PidgeyFrontpic) - $36, PidgeyFrontpic ; 143ccc
	dbw BANK(PidgeyBackpic) - $36, PidgeyBackpic ; 150188
	dbw BANK(PidgeottoFrontpic) - $36, PidgeottoFrontpic ; 13a4cf
	dbw BANK(PidgeottoBackpic) - $36, PidgeottoBackpic ; 160c7b
	dbw BANK(PidgeotFrontpic) - $36, PidgeotFrontpic ; 129b1d
	dbw BANK(PidgeotBackpic) - $36, PidgeotBackpic ; 159d9d
	dbw BANK(RattataFrontpic) - $36, RattataFrontpic ; 141819
	dbw BANK(RattataBackpic) - $36, RattataBackpic ; 15b664
	dbw BANK(RaticateFrontpic) - $36, RaticateFrontpic ; 1312dd
	dbw BANK(RaticateBackpic) - $36, RaticateBackpic ; 156647
	dbw BANK(SpearowFrontpic) - $36, SpearowFrontpic ; 141c43
	dbw BANK(SpearowBackpic) - $36, SpearowBackpic ; 15e413
	dbw BANK(FearowFrontpic) - $36, FearowFrontpic ; 127551
	dbw BANK(FearowBackpic) - $36, FearowBackpic ; 1637b1
	dbw BANK(EkansFrontpic) - $36, EkansFrontpic ; 140000
	dbw BANK(EkansBackpic) - $36, EkansBackpic ; 156911
	dbw BANK(ArbokFrontpic) - $36, ArbokFrontpic ; 126d70
	dbw BANK(ArbokBackpic) - $36, ArbokBackpic ; 16166e
	dbw BANK(PikachuFrontpic) - $36, PikachuFrontpic ; 14047d
	dbw BANK(PikachuBackpic) - $36, PikachuBackpic ; 156ea1
	dbw BANK(RaichuFrontpic) - $36, RaichuFrontpic ; 12b765
	dbw BANK(RaichuBackpic) - $36, RaichuBackpic ; 153446
	dbw BANK(SandshrewFrontpic) - $36, SandshrewFrontpic ; 1438d2
	dbw BANK(SandshrewBackpic) - $36, SandshrewBackpic ; 14e650
	dbw BANK(SandslashFrontpic) - $36, SandslashFrontpic ; 12f23c
	dbw BANK(SandslashBackpic) - $36, SandslashBackpic ; 14cb56
	dbw BANK(NidoranFFrontpic) - $36, NidoranFFrontpic ; 143ad2
	dbw BANK(NidoranFBackpic) - $36, NidoranFBackpic ; 15aab6
	dbw BANK(NidorinaFrontpic) - $36, NidorinaFrontpic ; 135ca2
	dbw BANK(NidorinaBackpic) - $36, NidorinaBackpic ; 152cf3
	dbw BANK(NidoqueenFrontpic) - $36, NidoqueenFrontpic ; 124d24
	dbw BANK(NidoqueenBackpic) - $36, NidoqueenBackpic ; 150aa9
	dbw BANK(NidoranMFrontpic) - $36, NidoranMFrontpic ; 14289f
	dbw BANK(NidoranMBackpic) - $36, NidoranMBackpic ; 14d1c5
	dbw BANK(NidorinoFrontpic) - $36, NidorinoFrontpic ; 12eefb
	dbw BANK(NidorinoBackpic) - $36, NidorinoBackpic ; 153a1b
	dbw BANK(NidokingFrontpic) - $36, NidokingFrontpic ; 121976
	dbw BANK(NidokingBackpic) - $36, NidokingBackpic ; 145350
	dbw BANK(ClefairyFrontpic) - $36, ClefairyFrontpic ; 1481c7
	dbw BANK(ClefairyBackpic) - $36, ClefairyBackpic ; 1579a6
	dbw BANK(ClefableFrontpic) - $36, ClefableFrontpic ; 1397d4
	dbw BANK(ClefableBackpic) - $36, ClefableBackpic ; 14ab7a
	dbw BANK(VulpixFrontpic) - $36, VulpixFrontpic ; 137836
	dbw BANK(VulpixBackpic) - $36, VulpixBackpic ; 1567ac
	dbw BANK(NinetalesFrontpic) - $36, NinetalesFrontpic ; 121012
	dbw BANK(NinetalesBackpic) - $36, NinetalesBackpic ; 14a4bf
	dbw BANK(JigglypuffFrontpic) - $36, JigglypuffFrontpic ; 144f83
	dbw BANK(JigglypuffBackpic) - $36, JigglypuffBackpic ; 163d7d
	dbw BANK(WigglytuffFrontpic) - $36, WigglytuffFrontpic ; 138fff
	dbw BANK(WigglytuffBackpic) - $36, WigglytuffBackpic ; 162fc1
	dbw BANK(ZubatFrontpic) - $36, ZubatFrontpic ; 147108
	dbw BANK(ZubatBackpic) - $36, ZubatBackpic ; 14ec80
	dbw BANK(GolbatFrontpic) - $36, GolbatFrontpic ; 130000
	dbw BANK(GolbatBackpic) - $36, GolbatBackpic ; 165c46
	dbw BANK(OddishFrontpic) - $36, OddishFrontpic ; 14d82c
	dbw BANK(OddishBackpic) - $36, OddishBackpic ; 163e72
	dbw BANK(GloomFrontpic) - $36, GloomFrontpic ; 13f00b
	dbw BANK(GloomBackpic) - $36, GloomBackpic ; 14f2aa
	dbw BANK(VileplumeFrontpic) - $36, VileplumeFrontpic ; 1364ff
	dbw BANK(VileplumeBackpic) - $36, VileplumeBackpic ; 154b80
	dbw BANK(ParasFrontpic) - $36, ParasFrontpic ; 14516a
	dbw BANK(ParasBackpic) - $36, ParasBackpic ; 160000
	dbw BANK(ParasectFrontpic) - $36, ParasectFrontpic ; 13378f
	dbw BANK(ParasectBackpic) - $36, ParasectBackpic ; 143ec6
	dbw BANK(VenonatFrontpic) - $36, VenonatFrontpic ; 146089
	dbw BANK(VenonatBackpic) - $36, VenonatBackpic ; 157b05
	dbw BANK(VenomothFrontpic) - $36, VenomothFrontpic ; 1315fa
	dbw BANK(VenomothBackpic) - $36, VenomothBackpic ; 1491ae
	dbw BANK(DiglettFrontpic) - $36, DiglettFrontpic ; 158576
	dbw BANK(DiglettBackpic) - $36, DiglettBackpic ; 1658aa
	dbw BANK(DugtrioFrontpic) - $36, DugtrioFrontpic ; 13b1a2
	dbw BANK(DugtrioBackpic) - $36, DugtrioBackpic ; 15a81a
	dbw BANK(MeowthFrontpic) - $36, MeowthFrontpic ; 1434cd
	dbw BANK(MeowthBackpic) - $36, MeowthBackpic ; 15c792
	dbw BANK(PersianFrontpic) - $36, PersianFrontpic ; 130ca1
	dbw BANK(PersianBackpic) - $36, PersianBackpic ; 151834
	dbw BANK(PsyduckFrontpic) - $36, PsyduckFrontpic ; 1458fe
	dbw BANK(PsyduckBackpic) - $36, PsyduckBackpic ; 156d3d
	dbw BANK(GolduckFrontpic) - $36, GolduckFrontpic ; 1293d7
	dbw BANK(GolduckBackpic) - $36, GolduckBackpic ; 1596fa
	dbw BANK(MankeyFrontpic) - $36, MankeyFrontpic ; 1443ee
	dbw BANK(MankeyBackpic) - $36, MankeyBackpic ; 14de7b
	dbw BANK(PrimeapeFrontpic) - $36, PrimeapeFrontpic ; 12bae0
	dbw BANK(PrimeapeBackpic) - $36, PrimeapeBackpic ; 155f49
	dbw BANK(GrowlitheFrontpic) - $36, GrowlitheFrontpic ; 148553
	dbw BANK(GrowlitheBackpic) - $36, GrowlitheBackpic ; 152fe1
	dbw BANK(ArcanineFrontpic) - $36, ArcanineFrontpic ; 125d84
	dbw BANK(ArcanineBackpic) - $36, ArcanineBackpic ; 14f8d2
	dbw BANK(PoliwagFrontpic) - $36, PoliwagFrontpic ; 15241a
	dbw BANK(PoliwagBackpic) - $36, PoliwagBackpic ; 1643c7
	dbw BANK(PoliwhirlFrontpic) - $36, PoliwhirlFrontpic ; 134e76
	dbw BANK(PoliwhirlBackpic) - $36, PoliwhirlBackpic ; 15a041
	dbw BANK(PoliwrathFrontpic) - $36, PoliwrathFrontpic ; 12d7ca
	dbw BANK(PoliwrathBackpic) - $36, PoliwrathBackpic ; 1535bd
	dbw BANK(AbraFrontpic) - $36, AbraFrontpic ; 14783f
	dbw BANK(AbraBackpic) - $36, AbraBackpic ; 15a42f
	dbw BANK(KadabraFrontpic) - $36, KadabraFrontpic ; 132b8b
	dbw BANK(KadabraBackpic) - $36, KadabraBackpic ; 155de2
	dbw BANK(AlakazamFrontpic) - $36, AlakazamFrontpic ; 1284ad
	dbw BANK(AlakazamBackpic) - $36, AlakazamBackpic ; 1474a5
	dbw BANK(MachopFrontpic) - $36, MachopFrontpic ; 1413e9
	dbw BANK(MachopBackpic) - $36, MachopBackpic ; 15a2e0
	dbw BANK(MachokeFrontpic) - $36, MachokeFrontpic ; 12d10f
	dbw BANK(MachokeBackpic) - $36, MachokeBackpic ; 1532cf
	dbw BANK(MachampFrontpic) - $36, MachampFrontpic ; 120b05
	dbw BANK(MachampBackpic) - $36, MachampBackpic ; 145cc5
	dbw BANK(BellsproutFrontpic) - $36, BellsproutFrontpic ; 149c2b
	dbw BANK(BellsproutBackpic) - $36, BellsproutBackpic ; 160920
	dbw BANK(WeepinbellFrontpic) - $36, WeepinbellFrontpic ; 140b2a
	dbw BANK(WeepinbellBackpic) - $36, WeepinbellBackpic ; 15a968
	dbw BANK(VictreebelFrontpic) - $36, VictreebelFrontpic ; 12b3e9
	dbw BANK(VictreebelBackpic) - $36, VictreebelBackpic ; 15c650
	dbw BANK(TentacoolFrontpic) - $36, TentacoolFrontpic ; 149fa0
	dbw BANK(TentacoolBackpic) - $36, TentacoolBackpic ; 160250
	dbw BANK(TentacruelFrontpic) - $36, TentacruelFrontpic ; 136d41
	dbw BANK(TentacruelBackpic) - $36, TentacruelBackpic ; 152e6a
	dbw BANK(GeodudeFrontpic) - $36, GeodudeFrontpic ; 155570
	dbw BANK(GeodudeBackpic) - $36, GeodudeBackpic ; 1548a3
	dbw BANK(GravelerFrontpic) - $36, GravelerFrontpic ; 139fa0
	dbw BANK(GravelerBackpic) - $36, GravelerBackpic ; 15ac04
	dbw BANK(GolemFrontpic) - $36, GolemFrontpic ; 134b97
	dbw BANK(GolemBackpic) - $36, GolemBackpic ; 165724
	dbw BANK(PonytaFrontpic) - $36, PonytaFrontpic ; 139a6e
	dbw BANK(PonytaBackpic) - $36, PonytaBackpic ; 152124
	dbw BANK(RapidashFrontpic) - $36, RapidashFrontpic ; 1244d8
	dbw BANK(RapidashBackpic) - $36, RapidashBackpic ; 14d9c0
	dbw BANK(SlowpokeFrontpic) - $36, SlowpokeFrontpic ; 148718
	dbw BANK(SlowpokeBackpic) - $36, SlowpokeBackpic ; 164869
	dbw BANK(SlowbroFrontpic) - $36, SlowbroFrontpic ; 129eb5
	dbw BANK(SlowbroBackpic) - $36, SlowbroBackpic ; 15944e
	dbw BANK(MagnemiteFrontpic) - $36, MagnemiteFrontpic ; 15bb84
	dbw BANK(MagnemiteBackpic) - $36, MagnemiteBackpic ; 15bf54
	dbw BANK(MagnetonFrontpic) - $36, MagnetonFrontpic ; 13b42d
	dbw BANK(MagnetonBackpic) - $36, MagnetonBackpic ; 14b228
	dbw BANK(FarfetchDFrontpic) - $36, FarfetchDFrontpic ; 136237
	dbw BANK(FarfetchDBackpic) - $36, FarfetchDBackpic ; 14d02a
	dbw BANK(DoduoFrontpic) - $36, DoduoFrontpic ; 14ad26
	dbw BANK(DoduoBackpic) - $36, DoduoBackpic ; 14db54
	dbw BANK(DodrioFrontpic) - $36, DodrioFrontpic ; 12c000
	dbw BANK(DodrioBackpic) - $36, DodrioBackpic ; 148000
	dbw BANK(SeelFrontpic) - $36, SeelFrontpic ; 13c000
	dbw BANK(SeelBackpic) - $36, SeelBackpic ; 15d7d6
	dbw BANK(DewgongFrontpic) - $36, DewgongFrontpic ; 12b06d
	dbw BANK(DewgongBackpic) - $36, DewgongBackpic ; 164692
	dbw BANK(GrimerFrontpic) - $36, GrimerFrontpic ; 142ebe
	dbw BANK(GrimerBackpic) - $36, GrimerBackpic ; 160a3f
	dbw BANK(MukFrontpic) - $36, MukFrontpic ; 12e51c
	dbw BANK(MukBackpic) - $36, MukBackpic ; 15882f
	dbw BANK(ShellderFrontpic) - $36, ShellderFrontpic ; 149de6
	dbw BANK(ShellderBackpic) - $36, ShellderBackpic ; 14eaf5
	dbw BANK(CloysterFrontpic) - $36, CloysterFrontpic ; 12a964
	dbw BANK(CloysterBackpic) - $36, CloysterBackpic ; 147bd4
	dbw BANK(GastlyFrontpic) - $36, GastlyFrontpic ; 133194
	dbw BANK(GastlyBackpic) - $36, GastlyBackpic ; 1636b7
	dbw BANK(HaunterFrontpic) - $36, HaunterFrontpic ; 13d153
	dbw BANK(HaunterBackpic) - $36, HaunterBackpic ; 15cf1b
	dbw BANK(GengarFrontpic) - $36, GengarFrontpic ; 13a9f4
	dbw BANK(GengarBackpic) - $36, GengarBackpic ; 15b51a
	dbw BANK(OnixFrontpic) - $36, OnixFrontpic ; 12ca47
	dbw BANK(OnixBackpic) - $36, OnixBackpic ; 152595
	dbw BANK(DrowzeeFrontpic) - $36, DrowzeeFrontpic ; 138562
	dbw BANK(DrowzeeBackpic) - $36, DrowzeeBackpic ; 1635bc
	dbw BANK(HypnoFrontpic) - $36, HypnoFrontpic ; 12ebb6
	dbw BANK(HypnoBackpic) - $36, HypnoBackpic ; 14e1a0
	dbw BANK(KrabbyFrontpic) - $36, KrabbyFrontpic ; 144bae
	dbw BANK(KrabbyBackpic) - $36, KrabbyBackpic ; 14bc0f
	dbw BANK(KinglerFrontpic) - $36, KinglerFrontpic ; 13032e
	dbw BANK(KinglerBackpic) - $36, KinglerBackpic ; 15b3cf
	dbw BANK(VoltorbFrontpic) - $36, VoltorbFrontpic ; 1610ee
	dbw BANK(VoltorbBackpic) - $36, VoltorbBackpic ; 164fa8
	dbw BANK(ElectrodeFrontpic) - $36, ElectrodeFrontpic ; 153e72
	dbw BANK(ElectrodeBackpic) - $36, ElectrodeBackpic ; 163a9c
	dbw BANK(ExeggcuteFrontpic) - $36, ExeggcuteFrontpic ; 13065a
	dbw BANK(ExeggcuteBackpic) - $36, ExeggcuteBackpic ; 15637c
	dbw BANK(ExeggutorFrontpic) - $36, ExeggutorFrontpic ; 132e90
	dbw BANK(ExeggutorBackpic) - $36, ExeggutorBackpic ; 14626a
	dbw BANK(CuboneFrontpic) - $36, CuboneFrontpic ; 142275
	dbw BANK(CuboneBackpic) - $36, CuboneBackpic ; 14ef96
	dbw BANK(MarowakFrontpic) - $36, MarowakFrontpic ; 13757a
	dbw BANK(MarowakBackpic) - $36, MarowakBackpic ; 154733
	dbw BANK(HitmonleeFrontpic) - $36, HitmonleeFrontpic ; 125142
	dbw BANK(HitmonleeBackpic) - $36, HitmonleeBackpic ; 1619b3
	dbw BANK(HitmonchanFrontpic) - $36, HitmonchanFrontpic ; 13fb74
	dbw BANK(HitmonchanBackpic) - $36, HitmonchanBackpic ; 154cee
	dbw BANK(LickitungFrontpic) - $36, LickitungFrontpic ; 132260
	dbw BANK(LickitungBackpic) - $36, LickitungBackpic ; 15cb58
	dbw BANK(KoffingFrontpic) - $36, KoffingFrontpic ; 145ea7
	dbw BANK(KoffingBackpic) - $36, KoffingBackpic ; 15270f
	dbw BANK(WeezingFrontpic) - $36, WeezingFrontpic ; 12a5d7
	dbw BANK(WeezingBackpic) - $36, WeezingBackpic ; 15984f
	dbw BANK(RhyhornFrontpic) - $36, RhyhornFrontpic ; 12977f
	dbw BANK(RhyhornBackpic) - $36, RhyhornBackpic ; 15f5f8
	dbw BANK(RhydonFrontpic) - $36, RhydonFrontpic ; 12901e
	dbw BANK(RhydonBackpic) - $36, RhydonBackpic ; 14c67f
	dbw BANK(ChanseyFrontpic) - $36, ChanseyFrontpic ; 13c502
	dbw BANK(ChanseyBackpic) - $36, ChanseyBackpic ; 15eee4
	dbw BANK(TangelaFrontpic) - $36, TangelaFrontpic ; 13c77c
	dbw BANK(TangelaBackpic) - $36, TangelaBackpic ; 164ec3
	dbw BANK(KangaskhanFrontpic) - $36, KangaskhanFrontpic ; 128c54
	dbw BANK(KangaskhanBackpic) - $36, KangaskhanBackpic ; 13be45
	dbw BANK(HorseaFrontpic) - $36, HorseaFrontpic ; 159c4a
	dbw BANK(HorseaBackpic) - $36, HorseaBackpic ; 162bb0
	dbw BANK(SeadraFrontpic) - $36, SeadraFrontpic ; 1406b7
	dbw BANK(SeadraBackpic) - $36, SeadraBackpic ; 14ccf2
	dbw BANK(GoldeenFrontpic) - $36, GoldeenFrontpic ; 13dafc
	dbw BANK(GoldeenBackpic) - $36, GoldeenBackpic ; 14fbe4
	dbw BANK(SeakingFrontpic) - $36, SeakingFrontpic ; 12e1cc
	dbw BANK(SeakingBackpic) - $36, SeakingBackpic ; 156a75
	dbw BANK(StaryuFrontpic) - $36, StaryuFrontpic ; 1430c4
	dbw BANK(StaryuBackpic) - $36, StaryuBackpic ; 160d98
	dbw BANK(StarmieFrontpic) - $36, StarmieFrontpic ; 13a238
	dbw BANK(StarmieBackpic) - $36, StarmieBackpic ; 14fef5
	dbw BANK(MrMimeFrontpic) - $36, MrMimeFrontpic ; 133a8a
	dbw BANK(MrMimeBackpic) - $36, MrMimeBackpic ; 160eb5
	dbw BANK(ScytherFrontpic) - $36, ScytherFrontpic ; 12db25
	dbw BANK(ScytherBackpic) - $36, ScytherBackpic ; 154a12
	dbw BANK(JynxFrontpic) - $36, JynxFrontpic ; 13e6c0
	dbw BANK(JynxBackpic) - $36, JynxBackpic ; 165b93
	dbw BANK(ElectabuzzFrontpic) - $36, ElectabuzzFrontpic ; 131c32
	dbw BANK(ElectabuzzBackpic) - $36, ElectabuzzBackpic ; 150dae
	dbw BANK(MagmarFrontpic) - $36, MagmarFrontpic ; 136a82
	dbw BANK(MagmarBackpic) - $36, MagmarBackpic ; 14e00e
	dbw BANK(PinsirFrontpic) - $36, PinsirFrontpic ; 12fbdf
	dbw BANK(PinsirBackpic) - $36, PinsirBackpic ; 14a821
	dbw BANK(TaurosFrontpic) - $36, TaurosFrontpic ; 122b2d
	dbw BANK(TaurosBackpic) - $36, TaurosBackpic ; 164c10
	dbw BANK(MagikarpFrontpic) - $36, MagikarpFrontpic ; 141e54
	dbw BANK(MagikarpBackpic) - $36, MagikarpBackpic ; 158c3f
	dbw BANK(GyaradosFrontpic) - $36, GyaradosFrontpic ; 128886
	dbw BANK(GyaradosBackpic) - $36, GyaradosBackpic ; 14a30c
	dbw BANK(LaprasFrontpic) - $36, LaprasFrontpic ; 1348b7
	dbw BANK(LaprasBackpic) - $36, LaprasBackpic ; 15e67e
	dbw BANK(DittoFrontpic) - $36, DittoFrontpic ; 157426
	dbw BANK(DittoBackpic) - $36, DittoBackpic ; 1631c3
	dbw BANK(EeveeFrontpic) - $36, EeveeFrontpic ; 146d68
	dbw BANK(EeveeBackpic) - $36, EeveeBackpic ; 151e2d
	dbw BANK(VaporeonFrontpic) - $36, VaporeonFrontpic ; 138000
	dbw BANK(VaporeonBackpic) - $36, VaporeonBackpic ; 160128
	dbw BANK(JolteonFrontpic) - $36, JolteonFrontpic ; 12f575
	dbw BANK(JolteonBackpic) - $36, JolteonBackpic ; 15db8b
	dbw BANK(FlareonFrontpic) - $36, FlareonFrontpic ; 135f6d
	dbw BANK(FlareonBackpic) - $36, FlareonBackpic ; 14fa5b
	dbw BANK(PorygonFrontpic) - $36, PorygonFrontpic ; 142aab
	dbw BANK(PorygonBackpic) - $36, PorygonBackpic ; 15fe26
	dbw BANK(OmanyteFrontpic) - $36, OmanyteFrontpic ; 1496f1
	dbw BANK(OmanyteBackpic) - $36, OmanyteBackpic ; 150000
	dbw BANK(OmastarFrontpic) - $36, OmastarFrontpic ; 13ac85
	dbw BANK(OmastarBackpic) - $36, OmastarBackpic ; 12be51
	dbw BANK(KabutoFrontpic) - $36, KabutoFrontpic ; 157003
	dbw BANK(KabutoBackpic) - $36, KabutoBackpic ; 15c50d
	dbw BANK(KabutopsFrontpic) - $36, KabutopsFrontpic ; 1356fc
	dbw BANK(KabutopsBackpic) - $36, KabutopsBackpic ; 14f5be
	dbw BANK(AerodactylFrontpic) - $36, AerodactylFrontpic ; 12de7b
	dbw BANK(AerodactylBackpic) - $36, AerodactylBackpic ; 15a57e
	dbw BANK(SnorlaxFrontpic) - $36, SnorlaxFrontpic ; 138d5a
	dbw BANK(SnorlaxBackpic) - $36, SnorlaxBackpic ; 14bf55
	dbw BANK(ArticunoFrontpic) - $36, ArticunoFrontpic ; 1226d6
	dbw BANK(ArticunoBackpic) - $36, ArticunoBackpic ; 1630c3
	dbw BANK(ZapdosFrontpic) - $36, ZapdosFrontpic ; 12697c
	dbw BANK(ZapdosBackpic) - $36, ZapdosBackpic ; 15ea19
	dbw BANK(MoltresFrontpic) - $36, MoltresFrontpic ; 126580
	dbw BANK(MoltresBackpic) - $36, MoltresBackpic ; 14c1a2
	dbw BANK(DratiniFrontpic) - $36, DratiniFrontpic ; 14b07d
	dbw BANK(DratiniBackpic) - $36, DratiniBackpic ; 1639a3
	dbw BANK(DragonairFrontpic) - $36, DragonairFrontpic ; 13b6b5
	dbw BANK(DragonairBackpic) - $36, DragonairBackpic ; 15e8e6
	dbw BANK(DragoniteFrontpic) - $36, DragoniteFrontpic ; 12d46e
	dbw BANK(DragoniteBackpic) - $36, DragoniteBackpic ; 16189c
	dbw BANK(MewtwoFrontpic) - $36, MewtwoFrontpic ; 127161
	dbw BANK(MewtwoBackpic) - $36, MewtwoBackpic ; 158000
	dbw BANK(MewFrontpic) - $36, MewFrontpic ; 13e213
	dbw BANK(MewBackpic) - $36, MewBackpic ; 15a191
	dbw BANK(ChikoritaFrontpic) - $36, ChikoritaFrontpic ; 13d898
	dbw BANK(ChikoritaBackpic) - $36, ChikoritaBackpic ; 15eb4c
	dbw BANK(BayleefFrontpic) - $36, BayleefFrontpic ; 1367c3
	dbw BANK(BayleefBackpic) - $36, BayleefBackpic ; 14d695
	dbw BANK(MeganiumFrontpic) - $36, MeganiumFrontpic ; 124904
	dbw BANK(MeganiumBackpic) - $36, MeganiumBackpic ; 15c8d4
	dbw BANK(CyndaquilFrontpic) - $36, CyndaquilFrontpic ; 13f931
	dbw BANK(CyndaquilBackpic) - $36, CyndaquilBackpic ; 14d4fb
	dbw BANK(QuilavaFrontpic) - $36, QuilavaFrontpic ; 127d1c
	dbw BANK(QuilavaBackpic) - $36, QuilavaBackpic ; 14e331
	dbw BANK(TyphlosionFrontpic) - $36, TyphlosionFrontpic ; 123c4d
	dbw BANK(TyphlosionBackpic) - $36, TyphlosionBackpic ; 1507a1
	dbw BANK(TotodileFrontpic) - $36, TotodileFrontpic ; 140d61
	dbw BANK(TotodileBackpic) - $36, TotodileBackpic ; 15b138
	dbw BANK(CroconawFrontpic) - $36, CroconawFrontpic ; 12e86a
	dbw BANK(CroconawBackpic) - $36, CroconawBackpic ; 14e4c1
	dbw BANK(FeraligatrFrontpic) - $36, FeraligatrFrontpic ; 1214dd
	dbw BANK(FeraligatrBackpic) - $36, FeraligatrBackpic ; 14aed2
	dbw BANK(SentretFrontpic) - $36, SentretFrontpic ; 1542e2
	dbw BANK(SentretBackpic) - $36, SentretBackpic ; 162cb5
	dbw BANK(FurretFrontpic) - $36, FurretFrontpic ; 13f6ec
	dbw BANK(FurretBackpic) - $36, FurretBackpic ; 1560b0
	dbw BANK(HoothootFrontpic) - $36, HoothootFrontpic ; 147d9e
	dbw BANK(HoothootBackpic) - $36, HoothootBackpic ; 15c000
	dbw BANK(NoctowlFrontpic) - $36, NoctowlFrontpic ; 1342eb
	dbw BANK(NoctowlBackpic) - $36, NoctowlBackpic ; 15c144
	dbw BANK(LedybaFrontpic) - $36, LedybaFrontpic ; 13a762
	dbw BANK(LedybaBackpic) - $36, LedybaBackpic ; 14d360
	dbw BANK(LedianFrontpic) - $36, LedianFrontpic ; 13edba
	dbw BANK(LedianBackpic) - $36, LedianBackpic ; 150f30
	dbw BANK(SpinarakFrontpic) - $36, SpinarakFrontpic ; 15f142
	dbw BANK(SpinarakBackpic) - $36, SpinarakBackpic ; 164000
	dbw BANK(AriadosFrontpic) - $36, AriadosFrontpic ; 134000
	dbw BANK(AriadosBackpic) - $36, AriadosBackpic ; 158d98
	dbw BANK(CrobatFrontpic) - $36, CrobatFrontpic ; 13c284
	dbw BANK(CrobatBackpic) - $36, CrobatBackpic ; 162470
	dbw BANK(ChinchouFrontpic) - $36, ChinchouFrontpic ; 141602
	dbw BANK(ChinchouBackpic) - $36, ChinchouBackpic ; 15edb2
	dbw BANK(LanturnFrontpic) - $36, LanturnFrontpic ; 146442
	dbw BANK(LanturnBackpic) - $36, LanturnBackpic ; 160b5d
	dbw BANK(PichuFrontpic) - $36, PichuFrontpic ; 150c2c
	dbw BANK(PichuBackpic) - $36, PichuBackpic ; 1606de
	dbw BANK(CleffaFrontpic) - $36, CleffaFrontpic ; 14a159
	dbw BANK(CleffaBackpic) - $36, CleffaBackpic ; 1634c0
	dbw BANK(IgglybuffFrontpic) - $36, IgglybuffFrontpic ; 1564e2
	dbw BANK(IgglybuffBackpic) - $36, IgglybuffBackpic ; 162793
	dbw BANK(TogepiFrontpic) - $36, TogepiFrontpic ; 15cc99
	dbw BANK(TogepiBackpic) - $36, TogepiBackpic ; 162362
	dbw BANK(TogeticFrontpic) - $36, TogeticFrontpic ; 13bbc1
	dbw BANK(TogeticBackpic) - $36, TogeticBackpic ; 154453
	dbw BANK(NatuFrontpic) - $36, NatuFrontpic ; 161ac9
	dbw BANK(NatuBackpic) - $36, NatuBackpic ; 16558e
	dbw BANK(XatuFrontpic) - $36, XatuFrontpic ; 13dfbc
	dbw BANK(XatuBackpic) - $36, XatuBackpic ; 15d05b
	dbw BANK(MareepFrontpic) - $36, MareepFrontpic ; 1469c4
	dbw BANK(MareepBackpic) - $36, MareepBackpic ; 157164
	dbw BANK(FlaaffyFrontpic) - $36, FlaaffyFrontpic ; 13f257
	dbw BANK(FlaaffyBackpic) - $36, FlaaffyBackpic ; 154171
	dbw BANK(AmpharosFrontpic) - $36, AmpharosFrontpic ; 1359d1
	dbw BANK(AmpharosBackpic) - $36, AmpharosBackpic ; 162689
	dbw BANK(BellossomFrontpic) - $36, BellossomFrontpic ; 138ab4
	dbw BANK(BellossomBackpic) - $36, BellossomBackpic ; 157c64
	dbw BANK(MarillFrontpic) - $36, MarillFrontpic ; 148c66
	dbw BANK(MarillBackpic) - $36, MarillBackpic ; 1638aa
	dbw BANK(AzumarillFrontpic) - $36, AzumarillFrontpic ; 133492
	dbw BANK(AzumarillBackpic) - $36, AzumarillBackpic ; 16289c
	dbw BANK(SudowoodoFrontpic) - $36, SudowoodoFrontpic ; 14023f
	dbw BANK(SudowoodoBackpic) - $36, SudowoodoBackpic ; 154000
	dbw BANK(PolitoedFrontpic) - $36, PolitoedFrontpic ; 131916
	dbw BANK(PolitoedBackpic) - $36, PolitoedBackpic ; 161785
	dbw BANK(HoppipFrontpic) - $36, HoppipFrontpic ; 14dce8
	dbw BANK(HoppipBackpic) - $36, HoppipBackpic ; 15ddff
	dbw BANK(SkiploomFrontpic) - $36, SkiploomFrontpic ; 1467f0
	dbw BANK(SkiploomBackpic) - $36, SkiploomBackpic ; 15f014
	dbw BANK(JumpluffFrontpic) - $36, JumpluffFrontpic ; 1372bd
	dbw BANK(JumpluffBackpic) - $36, JumpluffBackpic ; 154e5b
	dbw BANK(AipomFrontpic) - $36, AipomFrontpic ; 147672
	dbw BANK(AipomBackpic) - $36, AipomBackpic ; 15ad51
	dbw BANK(SunkernFrontpic) - $36, SunkernFrontpic ; 1538a8
	dbw BANK(SunkernBackpic) - $36, SunkernBackpic ; 15e549
	dbw BANK(SunfloraFrontpic) - $36, SunfloraFrontpic ; 13d3c3
	dbw BANK(SunfloraBackpic) - $36, SunfloraBackpic ; 14c342
	dbw BANK(YanmaFrontpic) - $36, YanmaFrontpic ; 13929d
	dbw BANK(YanmaBackpic) - $36, YanmaBackpic ; 14a670
	dbw BANK(WooperFrontpic) - $36, WooperFrontpic ; 157846
	dbw BANK(WooperBackpic) - $36, WooperBackpic ; 164b27
	dbw BANK(QuagsireFrontpic) - $36, QuagsireFrontpic ; 13fdb7
	dbw BANK(QuagsireBackpic) - $36, QuagsireBackpic ; 15d913
	dbw BANK(EspeonFrontpic) - $36, EspeonFrontpic ; 13dd5e
	dbw BANK(EspeonBackpic) - $36, EspeonBackpic ; 15ae9e
	dbw BANK(UmbreonFrontpic) - $36, UmbreonFrontpic ; 13d62e
	dbw BANK(UmbreonBackpic) - $36, UmbreonBackpic ; 159049
	dbw BANK(MurkrowFrontpic) - $36, MurkrowFrontpic ; 139d07
	dbw BANK(MurkrowBackpic) - $36, MurkrowBackpic ; 1591a0
	dbw BANK(SlowkingFrontpic) - $36, SlowkingFrontpic ; 12c371
	dbw BANK(SlowkingBackpic) - $36, SlowkingBackpic ; 14b720
	dbw BANK(MisdreavusFrontpic) - $36, MisdreavusFrontpic ; 144000
	dbw BANK(MisdreavusBackpic) - $36, MisdreavusBackpic ; 15529d
	dbw $ff, $ffff ; unowns use their own table
	dbw $ff, $ffff ; see UnownPicPointers
	dbw BANK(WobbuffetFrontpic) - $36, WobbuffetFrontpic ; 13e915
	dbw BANK(WobbuffetBackpic) - $36, WobbuffetBackpic ; 162254
	dbw BANK(GirafarigFrontpic) - $36, GirafarigFrontpic ; 1382b3
	dbw BANK(GirafarigBackpic) - $36, GirafarigBackpic ; 155842
	dbw BANK(PinecoFrontpic) - $36, PinecoFrontpic ; 1449c0
	dbw BANK(PinecoBackpic) - $36, PinecoBackpic ; 15d55a
	dbw BANK(ForretressFrontpic) - $36, ForretressFrontpic ; 13b93b
	dbw BANK(ForretressBackpic) - $36, ForretressBackpic ; 165f86
	dbw BANK(DunsparceFrontpic) - $36, DunsparceFrontpic ; 137da1
	dbw BANK(DunsparceBackpic) - $36, DunsparceBackpic ; 164954
	dbw BANK(GligarFrontpic) - $36, GligarFrontpic ; 137aed
	dbw BANK(GligarBackpic) - $36, GligarBackpic ; 15061c
	dbw BANK(SteelixFrontpic) - $36, SteelixFrontpic ; 1280c9
	dbw BANK(SteelixBackpic) - $36, SteelixBackpic ; 1516b4
	dbw BANK(SnubbullFrontpic) - $36, SnubbullFrontpic ; 13c9f5
	dbw BANK(SnubbullBackpic) - $36, SnubbullBackpic ; 15b284
	dbw BANK(GranbullFrontpic) - $36, GranbullFrontpic ; 13cc6e
	dbw BANK(GranbullBackpic) - $36, GranbullBackpic ; 15e06f
	dbw BANK(QwilfishFrontpic) - $36, QwilfishFrontpic ; 14b3d1
	dbw BANK(QwilfishBackpic) - $36, QwilfishBackpic ; 150496
	dbw BANK(ScizorFrontpic) - $36, ScizorFrontpic ; 12555c
	dbw BANK(ScizorBackpic) - $36, ScizorBackpic ; 1556d9
	dbw BANK(ShuckleFrontpic) - $36, ShuckleFrontpic ; 151fa9
	dbw BANK(ShuckleBackpic) - $36, ShuckleBackpic ; 1645a6
	dbw BANK(HeracrossFrontpic) - $36, HeracrossFrontpic ; 133d7b
	dbw BANK(HeracrossBackpic) - $36, HeracrossBackpic ; 151232
	dbw BANK(SneaselFrontpic) - $36, SneaselFrontpic ; 13880e
	dbw BANK(SneaselBackpic) - $36, SneaselBackpic ; 158ef1
	dbw BANK(TeddiursaFrontpic) - $36, TeddiursaFrontpic ; 14ee0b
	dbw BANK(TeddiursaBackpic) - $36, TeddiursaBackpic ; 161e07
	dbw BANK(UrsaringFrontpic) - $36, UrsaringFrontpic ; 13514e
	dbw BANK(UrsaringBackpic) - $36, UrsaringBackpic ; 161bde
	dbw BANK(SlugmaFrontpic) - $36, SlugmaFrontpic ; 14838d
	dbw BANK(SlugmaBackpic) - $36, SlugmaBackpic ; 15c3ca
	dbw BANK(MagcargoFrontpic) - $36, MagcargoFrontpic ; 130982
	dbw BANK(MagcargoBackpic) - $36, MagcargoBackpic ; 14f434
	dbw BANK(SwinubFrontpic) - $36, SwinubFrontpic ; 15fbd2
	dbw BANK(SwinubBackpic) - $36, SwinubBackpic ; 157f20
	dbw BANK(PiloswineFrontpic) - $36, PiloswineFrontpic ; 13af15
	dbw BANK(PiloswineBackpic) - $36, PiloswineBackpic ; 16531d
	dbw BANK(CorsolaFrontpic) - $36, CorsolaFrontpic ; 140f92
	dbw BANK(CorsolaBackpic) - $36, CorsolaBackpic ; 15ec7f
	dbw BANK(RemoraidFrontpic) - $36, RemoraidFrontpic ; 15229f
	dbw BANK(RemoraidBackpic) - $36, RemoraidBackpic ; 1572c5
	dbw BANK(OctilleryFrontpic) - $36, OctilleryFrontpic ; 13e46a
	dbw BANK(OctilleryBackpic) - $36, OctilleryBackpic ; 1629a4
	dbw BANK(DelibirdFrontpic) - $36, DelibirdFrontpic ; 13eb68
	dbw BANK(DelibirdBackpic) - $36, DelibirdBackpic ; 15898a
	dbw BANK(MantineFrontpic) - $36, MantineFrontpic ; 131f4b
	dbw BANK(MantineBackpic) - $36, MantineBackpic ; 165172
	dbw BANK(SkarmoryFrontpic) - $36, SkarmoryFrontpic ; 12acf0
	dbw BANK(SkarmoryBackpic) - $36, SkarmoryBackpic ; 163b92
	dbw BANK(HoundourFrontpic) - $36, HoundourFrontpic ; 1441f7
	dbw BANK(HoundourBackpic) - $36, HoundourBackpic ; 1642d7
	dbw BANK(HoundoomFrontpic) - $36, HoundoomFrontpic ; 135425
	dbw BANK(HoundoomBackpic) - $36, HoundoomBackpic ; 1607ff
	dbw BANK(KingdraFrontpic) - $36, KingdraFrontpic ; 132573
	dbw BANK(KingdraBackpic) - $36, KingdraBackpic ; 157586
	dbw BANK(PhanpyFrontpic) - $36, PhanpyFrontpic ; 14c4e1
	dbw BANK(PhanpyBackpic) - $36, PhanpyBackpic ; 161f1b
	dbw BANK(DonphanFrontpic) - $36, DonphanFrontpic ; 12f8ac
	dbw BANK(DonphanBackpic) - $36, DonphanBackpic ; 164a3e
	dbw BANK(Porygon2Frontpic) - $36, Porygon2Frontpic ; 1436d1
	dbw BANK(Porygon2Backpic) - $36, Porygon2Backpic ; 15d2db
	dbw BANK(StantlerFrontpic) - $36, StantlerFrontpic ; 130fbf
	dbw BANK(StantlerBackpic) - $36, StantlerBackpic ; 1559aa
	dbw BANK(SmeargleFrontpic) - $36, SmeargleFrontpic ; 139539
	dbw BANK(SmeargleBackpic) - $36, SmeargleBackpic ; 155b12
	dbw BANK(TyrogueFrontpic) - $36, TyrogueFrontpic ; 14661a
	dbw BANK(TyrogueBackpic) - $36, TyrogueBackpic ; 155407
	dbw BANK(HitmontopFrontpic) - $36, HitmontopFrontpic ; 12c6df
	dbw BANK(HitmontopBackpic) - $36, HitmontopBackpic ; 147a0a
	dbw BANK(SmoochumFrontpic) - $36, SmoochumFrontpic ; 1488dd
	dbw BANK(SmoochumBackpic) - $36, SmoochumBackpic ; 1605bd
	dbw BANK(ElekidFrontpic) - $36, ElekidFrontpic ; 136fff
	dbw BANK(ElekidBackpic) - $36, ElekidBackpic ; 14b8c6
	dbw BANK(MagbyFrontpic) - $36, MagbyFrontpic ; 1408f1
	dbw BANK(MagbyBackpic) - $36, MagbyBackpic ; 15e7b2
	dbw BANK(MiltankFrontpic) - $36, MiltankFrontpic ; 13cee2
	dbw BANK(MiltankBackpic) - $36, MiltankBackpic ; 151534
	dbw BANK(BlisseyFrontpic) - $36, BlisseyFrontpic ; 12cdac
	dbw BANK(BlisseyBackpic) - $36, BlisseyBackpic ; 16257d
	dbw BANK(RaikouFrontpic) - $36, RaikouFrontpic ; 121e00
	dbw BANK(RaikouBackpic) - $36, RaikouBackpic ; 1640f3
	dbw BANK(EnteiFrontpic) - $36, EnteiFrontpic ; 1233cb
	dbw BANK(EnteiBackpic) - $36, EnteiBackpic ; 1599a3
	dbw BANK(SuicuneFrontpic) - $36, SuicuneFrontpic ; 123810
	dbw BANK(SuicuneBackpic) - $36, SuicuneBackpic ; 14b579
	dbw BANK(LarvitarFrontpic) - $36, LarvitarFrontpic ; 14c81c
	dbw BANK(LarvitarBackpic) - $36, LarvitarBackpic ; 15fcfc
	dbw BANK(PupitarFrontpic) - $36, PupitarFrontpic ; 149a6d
	dbw BANK(PupitarBackpic) - $36, PupitarBackpic ; 1510b1
	dbw BANK(TyranitarFrontpic) - $36, TyranitarFrontpic ; 126183
	dbw BANK(TyranitarBackpic) - $36, TyranitarBackpic ; 14c9b9
	dbw BANK(LugiaFrontpic) - $36, LugiaFrontpic ; 12226e
	dbw BANK(LugiaBackpic) - $36, LugiaBackpic ; 161208
	dbw BANK(HoOhFrontpic) - $36, HoOhFrontpic ; 1205ee
	dbw BANK(HoOhBackpic) - $36, HoOhBackpic ; 159ef0
	dbw BANK(CelebiFrontpic) - $36, CelebiFrontpic ; 1445e1
	dbw BANK(CelebiBackpic) - $36, CelebiBackpic ; 14ba6b
	dbw $ff, $ffff ; unused
	dbw $ff, $ffff ; unused
	dbw BANK(EggPic) - $36, 	EggPic ; 151caf
	dbw $ff, $ffff ; unused
; 1205ee

HoOhFrontpic: ; 1205ee
INCBIN "gfx/frontpics/lz/250.lz"
MachampFrontpic: ; 120b05
INCBIN "gfx/frontpics/lz/068.lz"
NinetalesFrontpic: ; 121012
INCBIN "gfx/frontpics/lz/038.lz"
FeraligatrFrontpic: ; 1214dd
INCBIN "gfx/frontpics/lz/160.lz"
NidokingFrontpic: ; 121976
INCBIN "gfx/frontpics/lz/034.lz"
RaikouFrontpic: ; 121e00
INCBIN "gfx/frontpics/lz/243.lz"
LugiaFrontpic: ; 12226e
INCBIN "gfx/frontpics/lz/249.lz"
ArticunoFrontpic: ; 1226d6
INCBIN "gfx/frontpics/lz/144.lz"
TaurosFrontpic: ; 122b2d
INCBIN "gfx/frontpics/lz/128.lz"
VenusaurFrontpic: ; 122f81
INCBIN "gfx/frontpics/lz/003.lz"
EnteiFrontpic: ; 1233cb
INCBIN "gfx/frontpics/lz/244.lz"
SuicuneFrontpic: ; 123810
INCBIN "gfx/frontpics/lz/245.lz"
TyphlosionFrontpic: ; 123c4d
INCBIN "gfx/frontpics/lz/157.lz"
; 123ffa


SECTION "bank49",DATA,BANK[$49]

UnownPicPointers: ; 124000
	dbw BANK(UnownAFrontpic) - $36, UnownAFrontpic ; 165659
	dbw BANK(UnownABackpic) - $36, UnownABackpic ; 165659
	dbw BANK(UnownBFrontpic) - $36, UnownBFrontpic ; 16477e
	dbw BANK(UnownBBackpic) - $36, UnownBBackpic ; 16477e
	dbw BANK(UnownCFrontpic) - $36, UnownCFrontpic ; 15f724
	dbw BANK(UnownCBackpic) - $36, UnownCBackpic ; 15f724
	dbw BANK(UnownDFrontpic) - $36, UnownDFrontpic ; 1513b3
	dbw BANK(UnownDBackpic) - $36, UnownDBackpic ; 1513b3
	dbw BANK(UnownEFrontpic) - $36, UnownEFrontpic ; 12ff0e
	dbw BANK(UnownEBackpic) - $36, UnownEBackpic ; 12ff0e
	dbw BANK(UnownFFrontpic) - $36, UnownFFrontpic ; 1654bf
	dbw BANK(UnownFBackpic) - $36, UnownFBackpic ; 1654bf
	dbw BANK(UnownGFrontpic) - $36, UnownGFrontpic ; 161555
	dbw BANK(UnownGBackpic) - $36, UnownGBackpic ; 161555
	dbw BANK(UnownHFrontpic) - $36, UnownHFrontpic ; 1633c3
	dbw BANK(UnownHBackpic) - $36, UnownHBackpic ; 1633c3
	dbw BANK(UnownIFrontpic) - $36, UnownIFrontpic ; 165e47
	dbw BANK(UnownIBackpic) - $36, UnownIBackpic ; 165e47
	dbw BANK(UnownJFrontpic) - $36, UnownJFrontpic ; 16508d
	dbw BANK(UnownJBackpic) - $36, UnownJBackpic ; 16508d
	dbw BANK(UnownKFrontpic) - $36, UnownKFrontpic ; 1641e6
	dbw BANK(UnownKBackpic) - $36, UnownKBackpic ; 1641e6
	dbw BANK(UnownLFrontpic) - $36, UnownLFrontpic ; 16524a
	dbw BANK(UnownLBackpic) - $36, UnownLBackpic ; 16524a
	dbw BANK(UnownMFrontpic) - $36, UnownMFrontpic ; 1653ef
	dbw BANK(UnownMBackpic) - $36, UnownMBackpic ; 1653ef
	dbw BANK(UnownNFrontpic) - $36, UnownNFrontpic ; 164ddd
	dbw BANK(UnownNBackpic) - $36, UnownNBackpic ; 164ddd
	dbw BANK(UnownOFrontpic) - $36, UnownOFrontpic ; 162dba
	dbw BANK(UnownOBackpic) - $36, UnownOBackpic ; 162dba
	dbw BANK(UnownPFrontpic) - $36, UnownPFrontpic ; 165a26
	dbw BANK(UnownPBackpic) - $36, UnownPBackpic ; 165a26
	dbw BANK(UnownQFrontpic) - $36, UnownQFrontpic ; 165969
	dbw BANK(UnownQBackpic) - $36, UnownQBackpic ; 165969
	dbw BANK(UnownRFrontpic) - $36, UnownRFrontpic ; 1660ab
	dbw BANK(UnownRBackpic) - $36, UnownRBackpic ; 1660ab
	dbw BANK(UnownSFrontpic) - $36, UnownSFrontpic ; 162aab
	dbw BANK(UnownSBackpic) - $36, UnownSBackpic ; 162aab
	dbw BANK(UnownTFrontpic) - $36, UnownTFrontpic ; 162ebe
	dbw BANK(UnownTBackpic) - $36, UnownTBackpic ; 162ebe
	dbw BANK(UnownUFrontpic) - $36, UnownUFrontpic ; 1657ea
	dbw BANK(UnownUBackpic) - $36, UnownUBackpic ; 1657ea
	dbw BANK(UnownVFrontpic) - $36, UnownVFrontpic ; 16202e
	dbw BANK(UnownVBackpic) - $36, UnownVBackpic ; 16202e
	dbw BANK(UnownWFrontpic) - $36, UnownWFrontpic ; 15f39e
	dbw BANK(UnownWBackpic) - $36, UnownWBackpic ; 15f39e
	dbw BANK(UnownXFrontpic) - $36, UnownXFrontpic ; 164cf7
	dbw BANK(UnownXBackpic) - $36, UnownXBackpic ; 164cf7
	dbw BANK(UnownYFrontpic) - $36, UnownYFrontpic ; 165cf6
	dbw BANK(UnownYBackpic) - $36, UnownYBackpic ; 165cf6
	dbw BANK(UnownZFrontpic) - $36, UnownZFrontpic ; 15faa7
	dbw BANK(UnownZBackpic) - $36, UnownZBackpic ; 15faa7
; 12409c

BlastoiseFrontpic: ; 12409c
INCBIN "gfx/frontpics/lz/009.lz"
RapidashFrontpic: ; 1244d8
INCBIN "gfx/frontpics/lz/078.lz"
MeganiumFrontpic: ; 124904
INCBIN "gfx/frontpics/lz/154.lz"
NidoqueenFrontpic: ; 124d24
INCBIN "gfx/frontpics/lz/031.lz"
HitmonleeFrontpic: ; 125142
INCBIN "gfx/frontpics/lz/106.lz"
ScizorFrontpic: ; 12555c
INCBIN "gfx/frontpics/lz/212.lz"
BeedrillFrontpic: ; 125976
INCBIN "gfx/frontpics/lz/015.lz"
ArcanineFrontpic: ; 125d84
INCBIN "gfx/frontpics/lz/059.lz"
TyranitarFrontpic: ; 126183
INCBIN "gfx/frontpics/lz/248.lz"
MoltresFrontpic: ; 126580
INCBIN "gfx/frontpics/lz/146.lz"
ZapdosFrontpic: ; 12697c
INCBIN "gfx/frontpics/lz/145.lz"
ArbokFrontpic: ; 126d70
INCBIN "gfx/frontpics/lz/024.lz"
MewtwoFrontpic: ; 127161
INCBIN "gfx/frontpics/lz/150.lz"
FearowFrontpic: ; 127551
INCBIN "gfx/frontpics/lz/022.lz"
CharizardFrontpic: ; 127937
INCBIN "gfx/frontpics/lz/006.lz"
QuilavaFrontpic: ; 127d1c
INCBIN "gfx/frontpics/lz/156.lz"
; 127ffe


SECTION "bank4a",DATA,BANK[$4a]

TrainerPicPointers: ; 128000
	dbw BANK(FalknerPic) - $36, FalknerPic ; 152a03
	dbw BANK(WhitneyPic) - $36, WhitneyPic ; 15da4f
	dbw BANK(BugsyPic) - $36, BugsyPic ; 1545c3
	dbw BANK(MortyPic) - $36, MortyPic ; 15c287
	dbw BANK(PrycePic) - $36, PrycePic ; 161322
	dbw BANK(JasminePic) - $36, JasminePic ; 15d41b
	dbw BANK(ChuckPic) - $36, ChuckPic ; 146b97
	dbw BANK(ClairPic) - $36, ClairPic ; 149370
	dbw BANK(Rival1Pic) - $36, Rival1Pic ; 157dc2
	dbw BANK(PokemonProfPic) - $36, PokemonProfPic ; 15815e
	dbw BANK(WillPic) - $36, WillPic ; 15b8f5
	dbw BANK(CalPic) - $36, CalPic ; 1582bc
	dbw BANK(BrunoPic) - $36, BrunoPic ; 142cb5
	dbw BANK(KarenPic) - $36, KarenPic ; 152b7b
	dbw BANK(KogaPic) - $36, KogaPic ; 153158
	dbw BANK(ChampionPic) - $36, ChampionPic ; 141a2f
	dbw BANK(BrockPic) - $36, BrockPic ; 16143c
	dbw BANK(MistyPic) - $36, MistyPic ; 15f850
	dbw BANK(LtSurgePic) - $36, LtSurgePic ; 1519b3
	dbw BANK(ScientistPic) - $36, ScientistPic ; 15030f
	dbw BANK(ErikaPic) - $36, ErikaPic ; 15bccb
	dbw BANK(YoungsterPic) - $36, YoungsterPic ; 15b7ad
	dbw BANK(SchoolboyPic) - $36, SchoolboyPic ; 15ba3d
	dbw BANK(BirdKeeperPic) - $36, BirdKeeperPic ; 152889
	dbw BANK(LassPic) - $36, LassPic ; 14a9ce
	dbw BANK(JaninePic) - $36, JaninePic ; 15be10
	dbw BANK(CooltrainermPic) - $36, CooltrainermPic ; 154fc7
	dbw BANK(CooltrainerfPic) - $36, CooltrainerfPic ; 153d00
	dbw BANK(BeautyPic) - $36, BeautyPic ; 14e969
	dbw BANK(PokemaniacPic) - $36, PokemaniacPic ; 149531
	dbw BANK(GruntmPic) - $36, GruntmPic ; 14f120
	dbw BANK(GentlemanPic) - $36, GentlemanPic ; 15e1a7
	dbw BANK(SkierPic) - $36, SkierPic ; 1498af
	dbw BANK(TeacherPic) - $36, TeacherPic ; 151b31
	dbw BANK(SabrinaPic) - $36, SabrinaPic ; 158ae5
	dbw BANK(BugCatcherPic) - $36, BugCatcherPic ; 14bdb2
	dbw BANK(FisherPic) - $36, FisherPic ; 144d9a
	dbw BANK(SwimmermPic) - $36, SwimmermPic ; 153733
	dbw BANK(SwimmerfPic) - $36, SwimmerfPic ; 158419
	dbw BANK(SailorPic) - $36, SailorPic ; 14e7dd
	dbw BANK(SuperNerdPic) - $36, SuperNerdPic ; 15cdda
	dbw BANK(Rival2Pic) - $36, Rival2Pic ; 15f270
	dbw BANK(GuitaristPic) - $36, GuitaristPic ; 148e29
	dbw BANK(HikerPic) - $36, HikerPic ; 1432c9
	dbw BANK(BikerPic) - $36, BikerPic ; 142692
	dbw BANK(BlainePic) - $36, BlainePic ; 15f97c
	dbw BANK(BurglarPic) - $36, BurglarPic ; 156bd9
	dbw BANK(FirebreatherPic) - $36, FirebreatherPic ; 1411c1
	dbw BANK(JugglerPic) - $36, JugglerPic ; 148aa2
	dbw BANK(BlackbeltTPic) - $36, BlackbeltTPic ; 142484
	dbw BANK(ExecutivemPic) - $36, ExecutivemPic ; 15e2dd
	dbw BANK(PsychicTPic) - $36, PsychicTPic ; 1595a4
	dbw BANK(PicnickerPic) - $36, PicnickerPic ; 15ca16
	dbw BANK(CamperPic) - $36, CamperPic ; 1576e6
	dbw BANK(ExecutivefPic) - $36, ExecutivefPic ; 160377
	dbw BANK(SagePic) - $36, SagePic ; 161cf3
	dbw BANK(MediumPic) - $36, MediumPic ; 1447d1
	dbw BANK(BoarderPic) - $36, BoarderPic ; 14571a
	dbw BANK(PokefanmPic) - $36, PokefanmPic ; 145535
	dbw BANK(KimonoGirlPic) - $36, KimonoGirlPic ; 1472d7
	dbw BANK(TwinsPic) - $36, TwinsPic ; 14ce8e
	dbw BANK(PokefanfPic) - $36, PokefanfPic ; 148fec
	dbw BANK(RedPic) - $36, RedPic ; 15d19b
	dbw BANK(BluePic) - $36, BluePic ; 15df37
	dbw BANK(OfficerPic) - $36, OfficerPic ; 1586d3
	dbw BANK(GruntfPic) - $36, GruntfPic ; 159af7
	dbw BANK(MysticalmanPic) - $36, MysticalmanPic ; 153b8e
; 1280c9

SteelixFrontpic: ; 1280c9
INCBIN "gfx/frontpics/lz/208.lz"
AlakazamFrontpic: ; 1284ad
INCBIN "gfx/frontpics/lz/065.lz"
GyaradosFrontpic: ; 128886
INCBIN "gfx/frontpics/lz/130.lz"
KangaskhanFrontpic: ; 128c54
INCBIN "gfx/frontpics/lz/115.lz"
RhydonFrontpic: ; 12901e
INCBIN "gfx/frontpics/lz/112.lz"
GolduckFrontpic: ; 1293d7
INCBIN "gfx/frontpics/lz/055.lz"
RhyhornFrontpic: ; 12977f
INCBIN "gfx/frontpics/lz/111.lz"
PidgeotFrontpic: ; 129b1d
INCBIN "gfx/frontpics/lz/018.lz"
SlowbroFrontpic: ; 129eb5
INCBIN "gfx/frontpics/lz/080.lz"
ButterfreeFrontpic: ; 12a24a
INCBIN "gfx/frontpics/lz/012.lz"
WeezingFrontpic: ; 12a5d7
INCBIN "gfx/frontpics/lz/110.lz"
CloysterFrontpic: ; 12a964
INCBIN "gfx/frontpics/lz/091.lz"
SkarmoryFrontpic: ; 12acf0
INCBIN "gfx/frontpics/lz/227.lz"
DewgongFrontpic: ; 12b06d
INCBIN "gfx/frontpics/lz/087.lz"
VictreebelFrontpic: ; 12b3e9
INCBIN "gfx/frontpics/lz/071.lz"
RaichuFrontpic: ; 12b765
INCBIN "gfx/frontpics/lz/026.lz"
PrimeapeFrontpic: ; 12bae0
INCBIN "gfx/frontpics/lz/057.lz"
OmastarBackpic: ; 12be51
INCBIN "gfx/backpics/lz/139.lz"
; 12bffe


SECTION "bank4b",DATA,BANK[$4b]

DodrioFrontpic: ; 12c000
INCBIN "gfx/frontpics/lz/085.lz"
SlowkingFrontpic: ; 12c371
INCBIN "gfx/frontpics/lz/199.lz"
HitmontopFrontpic: ; 12c6df
INCBIN "gfx/frontpics/lz/237.lz"
OnixFrontpic: ; 12ca47
INCBIN "gfx/frontpics/lz/095.lz"
BlisseyFrontpic: ; 12cdac
INCBIN "gfx/frontpics/lz/242.lz"
MachokeFrontpic: ; 12d10f
INCBIN "gfx/frontpics/lz/067.lz"
DragoniteFrontpic: ; 12d46e
INCBIN "gfx/frontpics/lz/149.lz"
PoliwrathFrontpic: ; 12d7ca
INCBIN "gfx/frontpics/lz/062.lz"
ScytherFrontpic: ; 12db25
INCBIN "gfx/frontpics/lz/123.lz"
AerodactylFrontpic: ; 12de7b
INCBIN "gfx/frontpics/lz/142.lz"
SeakingFrontpic: ; 12e1cc
INCBIN "gfx/frontpics/lz/119.lz"
MukFrontpic: ; 12e51c
INCBIN "gfx/frontpics/lz/089.lz"
CroconawFrontpic: ; 12e86a
INCBIN "gfx/frontpics/lz/159.lz"
HypnoFrontpic: ; 12ebb6
INCBIN "gfx/frontpics/lz/097.lz"
NidorinoFrontpic: ; 12eefb
INCBIN "gfx/frontpics/lz/033.lz"
SandslashFrontpic: ; 12f23c
INCBIN "gfx/frontpics/lz/028.lz"
JolteonFrontpic: ; 12f575
INCBIN "gfx/frontpics/lz/135.lz"
DonphanFrontpic: ; 12f8ac
INCBIN "gfx/frontpics/lz/232.lz"
PinsirFrontpic: ; 12fbdf
INCBIN "gfx/frontpics/lz/127.lz"
UnownEFrontpic: ; 12ff0e
INCBIN "gfx/frontpics/lz/201e.lz"
; 130000



SECTION "bank4C",DATA,BANK[$4C]

GolbatFrontpic: ; 130000
INCBIN "gfx/frontpics/lz/042.lz"
KinglerFrontpic: ; 13032e
INCBIN "gfx/frontpics/lz/099.lz"
ExeggcuteFrontpic: ; 13065a
INCBIN "gfx/frontpics/lz/102.lz"
MagcargoFrontpic: ; 130982
INCBIN "gfx/frontpics/lz/219.lz"
PersianFrontpic: ; 130ca1
INCBIN "gfx/frontpics/lz/053.lz"
StantlerFrontpic: ; 130fbf
INCBIN "gfx/frontpics/lz/234.lz"
RaticateFrontpic: ; 1312dd
INCBIN "gfx/frontpics/lz/020.lz"
VenomothFrontpic: ; 1315fa
INCBIN "gfx/frontpics/lz/049.lz"
PolitoedFrontpic: ; 131916
INCBIN "gfx/frontpics/lz/186.lz"
ElectabuzzFrontpic: ; 131c32
INCBIN "gfx/frontpics/lz/125.lz"
MantineFrontpic: ; 131f4b
INCBIN "gfx/frontpics/lz/226.lz"
LickitungFrontpic: ; 132260
INCBIN "gfx/frontpics/lz/108.lz"
KingdraFrontpic: ; 132573
INCBIN "gfx/frontpics/lz/230.lz"
CharmeleonFrontpic: ; 132881
INCBIN "gfx/frontpics/lz/005.lz"
KadabraFrontpic: ; 132b8b
INCBIN "gfx/frontpics/lz/064.lz"
ExeggutorFrontpic: ; 132e90
INCBIN "gfx/frontpics/lz/103.lz"
GastlyFrontpic: ; 133194
INCBIN "gfx/frontpics/lz/092.lz"
AzumarillFrontpic: ; 133492
INCBIN "gfx/frontpics/lz/184.lz"
ParasectFrontpic: ; 13378f
INCBIN "gfx/frontpics/lz/047.lz"
MrMimeFrontpic: ; 133a8a
INCBIN "gfx/frontpics/lz/122.lz"
HeracrossFrontpic: ; 133d7b
INCBIN "gfx/frontpics/lz/214.lz"
; 133fff


SECTION "bank4d",DATA,BANK[$4d]

AriadosFrontpic: ; 134000
INCBIN "gfx/frontpics/lz/168.lz"
NoctowlFrontpic: ; 1342eb
INCBIN "gfx/frontpics/lz/164.lz"
WartortleFrontpic: ; 1345d2
INCBIN "gfx/frontpics/lz/008.lz"
LaprasFrontpic: ; 1348b7
INCBIN "gfx/frontpics/lz/131.lz"
GolemFrontpic: ; 134b97
INCBIN "gfx/frontpics/lz/076.lz"
PoliwhirlFrontpic: ; 134e76
INCBIN "gfx/frontpics/lz/061.lz"
UrsaringFrontpic: ; 13514e
INCBIN "gfx/frontpics/lz/217.lz"
HoundoomFrontpic: ; 135425
INCBIN "gfx/frontpics/lz/229.lz"
KabutopsFrontpic: ; 1356fc
INCBIN "gfx/frontpics/lz/141.lz"
AmpharosFrontpic: ; 1359d1
INCBIN "gfx/frontpics/lz/181.lz"
NidorinaFrontpic: ; 135ca2
INCBIN "gfx/frontpics/lz/030.lz"
FlareonFrontpic: ; 135f6d
INCBIN "gfx/frontpics/lz/136.lz"
FarfetchDFrontpic: ; 136237
INCBIN "gfx/frontpics/lz/083.lz"
VileplumeFrontpic: ; 1364ff
INCBIN "gfx/frontpics/lz/045.lz"
BayleefFrontpic: ; 1367c3
INCBIN "gfx/frontpics/lz/153.lz"
MagmarFrontpic: ; 136a82
INCBIN "gfx/frontpics/lz/126.lz"
TentacruelFrontpic: ; 136d41
INCBIN "gfx/frontpics/lz/073.lz"
ElekidFrontpic: ; 136fff
INCBIN "gfx/frontpics/lz/239.lz"
JumpluffFrontpic: ; 1372bd
INCBIN "gfx/frontpics/lz/189.lz"
MarowakFrontpic: ; 13757a
INCBIN "gfx/frontpics/lz/105.lz"
VulpixFrontpic: ; 137836
INCBIN "gfx/frontpics/lz/037.lz"
GligarFrontpic: ; 137aed
INCBIN "gfx/frontpics/lz/207.lz"
DunsparceFrontpic: ; 137da1
INCBIN "gfx/frontpics/lz/206.lz"
; 137fff


SECTION "bank4E",DATA,BANK[$4E]

VaporeonFrontpic: ; 138000
INCBIN "gfx/frontpics/lz/134.lz"
GirafarigFrontpic: ; 1382b3
INCBIN "gfx/frontpics/lz/203.lz"
DrowzeeFrontpic: ; 138562
INCBIN "gfx/frontpics/lz/096.lz"
SneaselFrontpic: ; 13880e
INCBIN "gfx/frontpics/lz/215.lz"
BellossomFrontpic: ; 138ab4
INCBIN "gfx/frontpics/lz/182.lz"
SnorlaxFrontpic: ; 138d5a
INCBIN "gfx/frontpics/lz/143.lz"
WigglytuffFrontpic: ; 138fff
INCBIN "gfx/frontpics/lz/040.lz"
YanmaFrontpic: ; 13929d
INCBIN "gfx/frontpics/lz/193.lz"
SmeargleFrontpic: ; 139539
INCBIN "gfx/frontpics/lz/235.lz"
ClefableFrontpic: ; 1397d4
INCBIN "gfx/frontpics/lz/036.lz"
PonytaFrontpic: ; 139a6e
INCBIN "gfx/frontpics/lz/077.lz"
MurkrowFrontpic: ; 139d07
INCBIN "gfx/frontpics/lz/198.lz"
GravelerFrontpic: ; 139fa0
INCBIN "gfx/frontpics/lz/075.lz"
StarmieFrontpic: ; 13a238
INCBIN "gfx/frontpics/lz/121.lz"
PidgeottoFrontpic: ; 13a4cf
INCBIN "gfx/frontpics/lz/017.lz"
LedybaFrontpic: ; 13a762
INCBIN "gfx/frontpics/lz/165.lz"
GengarFrontpic: ; 13a9f4
INCBIN "gfx/frontpics/lz/094.lz"
OmastarFrontpic: ; 13ac85
INCBIN "gfx/frontpics/lz/139.lz"
PiloswineFrontpic: ; 13af15
INCBIN "gfx/frontpics/lz/221.lz"
DugtrioFrontpic: ; 13b1a2
INCBIN "gfx/frontpics/lz/051.lz"
MagnetonFrontpic: ; 13b42d
INCBIN "gfx/frontpics/lz/082.lz"
DragonairFrontpic: ; 13b6b5
INCBIN "gfx/frontpics/lz/148.lz"
ForretressFrontpic: ; 13b93b
INCBIN "gfx/frontpics/lz/205.lz"
TogeticFrontpic: ; 13bbc1
INCBIN "gfx/frontpics/lz/176.lz"
KangaskhanBackpic: ; 13be45
INCBIN "gfx/backpics/lz/115.lz"
; 13c000


SECTION "bank4f",DATA,BANK[$4f]

SeelFrontpic: ; 13c000
INCBIN "gfx/frontpics/lz/086.lz"
CrobatFrontpic: ; 13c284
INCBIN "gfx/frontpics/lz/169.lz"
ChanseyFrontpic: ; 13c502
INCBIN "gfx/frontpics/lz/113.lz"
TangelaFrontpic: ; 13c77c
INCBIN "gfx/frontpics/lz/114.lz"
SnubbullFrontpic: ; 13c9f5
INCBIN "gfx/frontpics/lz/209.lz"
GranbullFrontpic: ; 13cc6e
INCBIN "gfx/frontpics/lz/210.lz"
MiltankFrontpic: ; 13cee2
INCBIN "gfx/frontpics/lz/241.lz"
HaunterFrontpic: ; 13d153
INCBIN "gfx/frontpics/lz/093.lz"
SunfloraFrontpic: ; 13d3c3
INCBIN "gfx/frontpics/lz/192.lz"
UmbreonFrontpic: ; 13d62e
INCBIN "gfx/frontpics/lz/197.lz"
ChikoritaFrontpic: ; 13d898
INCBIN "gfx/frontpics/lz/152.lz"
GoldeenFrontpic: ; 13dafc
INCBIN "gfx/frontpics/lz/118.lz"
EspeonFrontpic: ; 13dd5e
INCBIN "gfx/frontpics/lz/196.lz"
XatuFrontpic: ; 13dfbc
INCBIN "gfx/frontpics/lz/178.lz"
MewFrontpic: ; 13e213
INCBIN "gfx/frontpics/lz/151.lz"
OctilleryFrontpic: ; 13e46a
INCBIN "gfx/frontpics/lz/224.lz"
JynxFrontpic: ; 13e6c0
INCBIN "gfx/frontpics/lz/124.lz"
WobbuffetFrontpic: ; 13e915
INCBIN "gfx/frontpics/lz/202.lz"
DelibirdFrontpic: ; 13eb68
INCBIN "gfx/frontpics/lz/225.lz"
LedianFrontpic: ; 13edba
INCBIN "gfx/frontpics/lz/166.lz"
GloomFrontpic: ; 13f00b
INCBIN "gfx/frontpics/lz/044.lz"
FlaaffyFrontpic: ; 13f257
INCBIN "gfx/frontpics/lz/180.lz"
IvysaurFrontpic: ; 13f4a2
INCBIN "gfx/frontpics/lz/002.lz"
FurretFrontpic: ; 13f6ec
INCBIN "gfx/frontpics/lz/162.lz"
CyndaquilFrontpic: ; 13f931
INCBIN "gfx/frontpics/lz/155.lz"
HitmonchanFrontpic: ; 13fb74
INCBIN "gfx/frontpics/lz/107.lz"
QuagsireFrontpic: ; 13fdb7
INCBIN "gfx/frontpics/lz/195.lz"
; 13fff7


SECTION "bank50",DATA,BANK[$50]

EkansFrontpic: ; 140000
INCBIN "gfx/frontpics/lz/023.lz"
SudowoodoFrontpic: ; 14023f
INCBIN "gfx/frontpics/lz/185.lz"
PikachuFrontpic: ; 14047d
INCBIN "gfx/frontpics/lz/025.lz"
SeadraFrontpic: ; 1406b7
INCBIN "gfx/frontpics/lz/117.lz"
MagbyFrontpic: ; 1408f1
INCBIN "gfx/frontpics/lz/240.lz"
WeepinbellFrontpic: ; 140b2a
INCBIN "gfx/frontpics/lz/070.lz"
TotodileFrontpic: ; 140d61
INCBIN "gfx/frontpics/lz/158.lz"
CorsolaFrontpic: ; 140f92
INCBIN "gfx/frontpics/lz/222.lz"
FirebreatherPic: ; 1411c1
INCBIN "gfx/trainers/lz/047.lz"
MachopFrontpic: ; 1413e9
INCBIN "gfx/frontpics/lz/066.lz"
ChinchouFrontpic: ; 141602
INCBIN "gfx/frontpics/lz/170.lz"
RattataFrontpic: ; 141819
INCBIN "gfx/frontpics/lz/019.lz"
ChampionPic: ; 141a2f
INCBIN "gfx/trainers/lz/015.lz"
SpearowFrontpic: ; 141c43
INCBIN "gfx/frontpics/lz/021.lz"
MagikarpFrontpic: ; 141e54
INCBIN "gfx/frontpics/lz/129.lz"
CharmanderFrontpic: ; 142065
INCBIN "gfx/frontpics/lz/004.lz"
CuboneFrontpic: ; 142275
INCBIN "gfx/frontpics/lz/104.lz"
BlackbeltTPic: ; 142484
INCBIN "gfx/trainers/lz/049.lz"
BikerPic: ; 142692
INCBIN "gfx/trainers/lz/044.lz"
NidoranMFrontpic: ; 14289f
INCBIN "gfx/frontpics/lz/032.lz"
PorygonFrontpic: ; 142aab
INCBIN "gfx/frontpics/lz/137.lz"
BrunoPic: ; 142cb5
INCBIN "gfx/trainers/lz/012.lz"
GrimerFrontpic: ; 142ebe
INCBIN "gfx/frontpics/lz/088.lz"
StaryuFrontpic: ; 1430c4
INCBIN "gfx/frontpics/lz/120.lz"
HikerPic: ; 1432c9
INCBIN "gfx/trainers/lz/043.lz"
MeowthFrontpic: ; 1434cd
INCBIN "gfx/frontpics/lz/052.lz"
Porygon2Frontpic: ; 1436d1
INCBIN "gfx/frontpics/lz/233.lz"
SandshrewFrontpic: ; 1438d2
INCBIN "gfx/frontpics/lz/027.lz"
NidoranFFrontpic: ; 143ad2
INCBIN "gfx/frontpics/lz/029.lz"
PidgeyFrontpic: ; 143ccc
INCBIN "gfx/frontpics/lz/016.lz"
ParasectBackpic: ; 143ec6
INCBIN "gfx/backpics/lz/047.lz"
; 144000

SECTION "bank51",DATA,BANK[$51]

MisdreavusFrontpic: ; 144000
INCBIN "gfx/frontpics/lz/200.lz"
HoundourFrontpic: ; 1441f7
INCBIN "gfx/frontpics/lz/228.lz"
MankeyFrontpic: ; 1443ee
INCBIN "gfx/frontpics/lz/056.lz"
CelebiFrontpic: ; 1445e1
INCBIN "gfx/frontpics/lz/251.lz"
MediumPic: ; 1447d1
INCBIN "gfx/trainers/lz/056.lz"
PinecoFrontpic: ; 1449c0
INCBIN "gfx/frontpics/lz/204.lz"
KrabbyFrontpic: ; 144bae
INCBIN "gfx/frontpics/lz/098.lz"
FisherPic: ; 144d9a
INCBIN "gfx/trainers/lz/036.lz"
JigglypuffFrontpic: ; 144f83
INCBIN "gfx/frontpics/lz/039.lz"
ParasFrontpic: ; 14516a
INCBIN "gfx/frontpics/lz/046.lz"
NidokingBackpic: ; 145350
INCBIN "gfx/backpics/lz/034.lz"
PokefanmPic: ; 145535
INCBIN "gfx/trainers/lz/058.lz"
BoarderPic: ; 14571a
INCBIN "gfx/trainers/lz/057.lz"
PsyduckFrontpic: ; 1458fe
INCBIN "gfx/frontpics/lz/054.lz"
SquirtleFrontpic: ; 145ae2
INCBIN "gfx/frontpics/lz/007.lz"
MachampBackpic: ; 145cc5
INCBIN "gfx/backpics/lz/068.lz"
KoffingFrontpic: ; 145ea7
INCBIN "gfx/frontpics/lz/109.lz"
VenonatFrontpic: ; 146089
INCBIN "gfx/frontpics/lz/048.lz"
ExeggutorBackpic: ; 14626a
INCBIN "gfx/backpics/lz/103.lz"
LanturnFrontpic: ; 146442
INCBIN "gfx/frontpics/lz/171.lz"
TyrogueFrontpic: ; 14661a
INCBIN "gfx/frontpics/lz/236.lz"
SkiploomFrontpic: ; 1467f0
INCBIN "gfx/frontpics/lz/188.lz"
MareepFrontpic: ; 1469c4
INCBIN "gfx/frontpics/lz/179.lz"
ChuckPic: ; 146b97
INCBIN "gfx/trainers/lz/006.lz"
EeveeFrontpic: ; 146d68
INCBIN "gfx/frontpics/lz/133.lz"
ButterfreeBackpic: ; 146f39
INCBIN "gfx/backpics/lz/012.lz"
ZubatFrontpic: ; 147108
INCBIN "gfx/frontpics/lz/041.lz"
KimonoGirlPic: ; 1472d7
INCBIN "gfx/trainers/lz/059.lz"
AlakazamBackpic: ; 1474a5
INCBIN "gfx/backpics/lz/065.lz"
AipomFrontpic: ; 147672
INCBIN "gfx/frontpics/lz/190.lz"
AbraFrontpic: ; 14783f
INCBIN "gfx/frontpics/lz/063.lz"
HitmontopBackpic: ; 147a0a
INCBIN "gfx/backpics/lz/237.lz"
CloysterBackpic: ; 147bd4
INCBIN "gfx/backpics/lz/091.lz"
HoothootFrontpic: ; 147d9e
INCBIN "gfx/frontpics/lz/163.lz"
UnownFBackpic: ; 147f67
INCBIN "gfx/backpics/lz/201f.lz"
; 148000


SECTION "bank52",DATA,BANK[$52]

DodrioBackpic: ; 148000
INCBIN "gfx/backpics/lz/085.lz"
ClefairyFrontpic: ; 1481c7
INCBIN "gfx/frontpics/lz/035.lz"
SlugmaFrontpic: ; 14838d
INCBIN "gfx/frontpics/lz/218.lz"
GrowlitheFrontpic: ; 148553
INCBIN "gfx/frontpics/lz/058.lz"
SlowpokeFrontpic: ; 148718
INCBIN "gfx/frontpics/lz/079.lz"
SmoochumFrontpic: ; 1488dd
INCBIN "gfx/frontpics/lz/238.lz"
JugglerPic: ; 148aa2
INCBIN "gfx/trainers/lz/048.lz"
MarillFrontpic: ; 148c66
INCBIN "gfx/frontpics/lz/183.lz"
GuitaristPic: ; 148e29
INCBIN "gfx/trainers/lz/042.lz"
PokefanfPic: ; 148fec
INCBIN "gfx/trainers/lz/061.lz"
VenomothBackpic: ; 1491ae
INCBIN "gfx/backpics/lz/049.lz"
ClairPic: ; 149370
INCBIN "gfx/trainers/lz/007.lz"
PokemaniacPic: ; 149531
INCBIN "gfx/trainers/lz/029.lz"
OmanyteFrontpic: ; 1496f1
INCBIN "gfx/frontpics/lz/138.lz"
SkierPic: ; 1498af
INCBIN "gfx/trainers/lz/032.lz"
PupitarFrontpic: ; 149a6d
INCBIN "gfx/frontpics/lz/247.lz"
BellsproutFrontpic: ; 149c2b
INCBIN "gfx/frontpics/lz/069.lz"
ShellderFrontpic: ; 149de6
INCBIN "gfx/frontpics/lz/090.lz"
TentacoolFrontpic: ; 149fa0
INCBIN "gfx/frontpics/lz/072.lz"
CleffaFrontpic: ; 14a159
INCBIN "gfx/frontpics/lz/173.lz"
GyaradosBackpic: ; 14a30c
INCBIN "gfx/backpics/lz/130.lz"
NinetalesBackpic: ; 14a4bf
INCBIN "gfx/backpics/lz/038.lz"
YanmaBackpic: ; 14a670
INCBIN "gfx/backpics/lz/193.lz"
PinsirBackpic: ; 14a821
INCBIN "gfx/backpics/lz/127.lz"
LassPic: ; 14a9ce
INCBIN "gfx/trainers/lz/024.lz"
ClefableBackpic: ; 14ab7a
INCBIN "gfx/backpics/lz/036.lz"
DoduoFrontpic: ; 14ad26
INCBIN "gfx/frontpics/lz/084.lz"
FeraligatrBackpic: ; 14aed2
INCBIN "gfx/backpics/lz/160.lz"
DratiniFrontpic: ; 14b07d
INCBIN "gfx/frontpics/lz/147.lz"
MagnetonBackpic: ; 14b228
INCBIN "gfx/backpics/lz/082.lz"
QwilfishFrontpic: ; 14b3d1
INCBIN "gfx/frontpics/lz/211.lz"
SuicuneBackpic: ; 14b579
INCBIN "gfx/backpics/lz/245.lz"
SlowkingBackpic: ; 14b720
INCBIN "gfx/backpics/lz/199.lz"
ElekidBackpic: ; 14b8c6
INCBIN "gfx/backpics/lz/239.lz"
CelebiBackpic: ; 14ba6b
INCBIN "gfx/backpics/lz/251.lz"
KrabbyBackpic: ; 14bc0f
INCBIN "gfx/backpics/lz/098.lz"
BugCatcherPic: ; 14bdb2
INCBIN "gfx/trainers/lz/035.lz"
SnorlaxBackpic: ; 14bf55
INCBIN "gfx/backpics/lz/143.lz"
; 14bffb


SECTION "bank53",DATA,BANK[$53]

VenusaurBackpic: ; 14c000
INCBIN "gfx/backpics/lz/003.lz"
MoltresBackpic: ; 14c1a2
INCBIN "gfx/backpics/lz/146.lz"
SunfloraBackpic: ; 14c342
INCBIN "gfx/backpics/lz/192.lz"
PhanpyFrontpic: ; 14c4e1
INCBIN "gfx/frontpics/lz/231.lz"
RhydonBackpic: ; 14c67f
INCBIN "gfx/backpics/lz/112.lz"
LarvitarFrontpic: ; 14c81c
INCBIN "gfx/frontpics/lz/246.lz"
TyranitarBackpic: ; 14c9b9
INCBIN "gfx/backpics/lz/248.lz"
SandslashBackpic: ; 14cb56
INCBIN "gfx/backpics/lz/028.lz"
SeadraBackpic: ; 14ccf2
INCBIN "gfx/backpics/lz/117.lz"
TwinsPic: ; 14ce8e
INCBIN "gfx/trainers/lz/060.lz"
FarfetchDBackpic: ; 14d02a
INCBIN "gfx/backpics/lz/083.lz"
NidoranMBackpic: ; 14d1c5
INCBIN "gfx/backpics/lz/032.lz"
LedybaBackpic: ; 14d360
INCBIN "gfx/backpics/lz/165.lz"
CyndaquilBackpic: ; 14d4fb
INCBIN "gfx/backpics/lz/155.lz"
BayleefBackpic: ; 14d695
INCBIN "gfx/backpics/lz/153.lz"
OddishFrontpic: ; 14d82c
INCBIN "gfx/frontpics/lz/043.lz"
RapidashBackpic: ; 14d9c0
INCBIN "gfx/backpics/lz/078.lz"
DoduoBackpic: ; 14db54
INCBIN "gfx/backpics/lz/084.lz"
HoppipFrontpic: ; 14dce8
INCBIN "gfx/frontpics/lz/187.lz"
MankeyBackpic: ; 14de7b
INCBIN "gfx/backpics/lz/056.lz"
MagmarBackpic: ; 14e00e
INCBIN "gfx/backpics/lz/126.lz"
HypnoBackpic: ; 14e1a0
INCBIN "gfx/backpics/lz/097.lz"
QuilavaBackpic: ; 14e331
INCBIN "gfx/backpics/lz/156.lz"
CroconawBackpic: ; 14e4c1
INCBIN "gfx/backpics/lz/159.lz"
SandshrewBackpic: ; 14e650
INCBIN "gfx/backpics/lz/027.lz"
SailorPic: ; 14e7dd
INCBIN "gfx/trainers/lz/039.lz"
BeautyPic: ; 14e969
INCBIN "gfx/trainers/lz/028.lz"
ShellderBackpic: ; 14eaf5
INCBIN "gfx/backpics/lz/090.lz"
ZubatBackpic: ; 14ec80
INCBIN "gfx/backpics/lz/041.lz"
TeddiursaFrontpic: ; 14ee0b
INCBIN "gfx/frontpics/lz/216.lz"
CuboneBackpic: ; 14ef96
INCBIN "gfx/backpics/lz/104.lz"
GruntmPic: ; 14f120
INCBIN "gfx/trainers/lz/030.lz"
GloomBackpic: ; 14f2aa
INCBIN "gfx/backpics/lz/044.lz"
MagcargoBackpic: ; 14f434
INCBIN "gfx/backpics/lz/219.lz"
KabutopsBackpic: ; 14f5be
INCBIN "gfx/backpics/lz/141.lz"
BeedrillBackpic: ; 14f748
INCBIN "gfx/backpics/lz/015.lz"
ArcanineBackpic: ; 14f8d2
INCBIN "gfx/backpics/lz/059.lz"
FlareonBackpic: ; 14fa5b
INCBIN "gfx/backpics/lz/136.lz"
GoldeenBackpic: ; 14fbe4
INCBIN "gfx/backpics/lz/118.lz"
BulbasaurFrontpic: ; 14fd6d
INCBIN "gfx/frontpics/lz/001.lz"
StarmieBackpic: ; 14fef5
INCBIN "gfx/backpics/lz/121.lz"
; 150000


SECTION "bank54",DATA,BANK[$54]

OmanyteBackpic: ; 150000
INCBIN "gfx/backpics/lz/138.lz"
PidgeyBackpic: ; 150188
INCBIN "gfx/backpics/lz/016.lz"
ScientistPic: ; 15030f
INCBIN "gfx/trainers/lz/019.lz"
QwilfishBackpic: ; 150496
INCBIN "gfx/backpics/lz/211.lz"
GligarBackpic: ; 15061c
INCBIN "gfx/backpics/lz/207.lz"
TyphlosionBackpic: ; 1507a1
INCBIN "gfx/backpics/lz/157.lz"
CharmeleonBackpic: ; 150925
INCBIN "gfx/backpics/lz/005.lz"
NidoqueenBackpic: ; 150aa9
INCBIN "gfx/backpics/lz/031.lz"
PichuFrontpic: ; 150c2c
INCBIN "gfx/frontpics/lz/172.lz"
ElectabuzzBackpic: ; 150dae
INCBIN "gfx/backpics/lz/125.lz"
LedianBackpic: ; 150f30
INCBIN "gfx/backpics/lz/166.lz"
PupitarBackpic: ; 1510b1
INCBIN "gfx/backpics/lz/247.lz"
HeracrossBackpic: ; 151232
INCBIN "gfx/backpics/lz/214.lz"
UnownDFrontpic: ; 1513b3
INCBIN "gfx/frontpics/lz/201d.lz"
MiltankBackpic: ; 151534
INCBIN "gfx/backpics/lz/241.lz"
SteelixBackpic: ; 1516b4
INCBIN "gfx/backpics/lz/208.lz"
PersianBackpic: ; 151834
INCBIN "gfx/backpics/lz/053.lz"
LtSurgePic: ; 1519b3
INCBIN "gfx/trainers/lz/018.lz"
TeacherPic: ; 151b31
INCBIN "gfx/trainers/lz/033.lz"
EggPic: ; 151caf
INCBIN "gfx/frontpics/lz/egg.lz"
EeveeBackpic: ; 151e2d
INCBIN "gfx/backpics/lz/133.lz"
ShuckleFrontpic: ; 151fa9
INCBIN "gfx/frontpics/lz/213.lz"
PonytaBackpic: ; 152124
INCBIN "gfx/backpics/lz/077.lz"
RemoraidFrontpic: ; 15229f
INCBIN "gfx/frontpics/lz/223.lz"
PoliwagFrontpic: ; 15241a
INCBIN "gfx/frontpics/lz/060.lz"
OnixBackpic: ; 152595
INCBIN "gfx/backpics/lz/095.lz"
KoffingBackpic: ; 15270f
INCBIN "gfx/backpics/lz/109.lz"
BirdKeeperPic: ; 152889
INCBIN "gfx/trainers/lz/023.lz"
FalknerPic: ; 152a03
INCBIN "gfx/trainers/lz/000.lz"
KarenPic: ; 152b7b
INCBIN "gfx/trainers/lz/013.lz"
NidorinaBackpic: ; 152cf3
INCBIN "gfx/backpics/lz/030.lz"
TentacruelBackpic: ; 152e6a
INCBIN "gfx/backpics/lz/073.lz"
GrowlitheBackpic: ; 152fe1
INCBIN "gfx/backpics/lz/058.lz"
KogaPic: ; 153158
INCBIN "gfx/trainers/lz/014.lz"
MachokeBackpic: ; 1532cf
INCBIN "gfx/backpics/lz/067.lz"
RaichuBackpic: ; 153446
INCBIN "gfx/backpics/lz/026.lz"
PoliwrathBackpic: ; 1535bd
INCBIN "gfx/backpics/lz/062.lz"
SwimmermPic: ; 153733
INCBIN "gfx/trainers/lz/037.lz"
SunkernFrontpic: ; 1538a8
INCBIN "gfx/frontpics/lz/191.lz"
NidorinoBackpic: ; 153a1b
INCBIN "gfx/backpics/lz/033.lz"
MysticalmanPic: ; 153b8e
INCBIN "gfx/trainers/lz/066.lz"
CooltrainerfPic: ; 153d00
INCBIN "gfx/trainers/lz/027.lz"
ElectrodeFrontpic: ; 153e72
INCBIN "gfx/frontpics/lz/101.lz"
; 153fe3


SECTION "bank55",DATA,BANK[$55]

SudowoodoBackpic: ; 154000
INCBIN "gfx/backpics/lz/185.lz"
FlaaffyBackpic: ; 154171
INCBIN "gfx/backpics/lz/180.lz"
SentretFrontpic: ; 1542e2
INCBIN "gfx/frontpics/lz/161.lz"
TogeticBackpic: ; 154453
INCBIN "gfx/backpics/lz/176.lz"
BugsyPic: ; 1545c3
INCBIN "gfx/trainers/lz/002.lz"
MarowakBackpic: ; 154733
INCBIN "gfx/backpics/lz/105.lz"
GeodudeBackpic: ; 1548a3
INCBIN "gfx/backpics/lz/074.lz"
ScytherBackpic: ; 154a12
INCBIN "gfx/backpics/lz/123.lz"
VileplumeBackpic: ; 154b80
INCBIN "gfx/backpics/lz/045.lz"
HitmonchanBackpic: ; 154cee
INCBIN "gfx/backpics/lz/107.lz"
JumpluffBackpic: ; 154e5b
INCBIN "gfx/backpics/lz/189.lz"
CooltrainermPic: ; 154fc7
INCBIN "gfx/trainers/lz/026.lz"
BlastoiseBackpic: ; 155132
INCBIN "gfx/backpics/lz/009.lz"
MisdreavusBackpic: ; 15529d
INCBIN "gfx/backpics/lz/200.lz"
TyrogueBackpic: ; 155407
INCBIN "gfx/backpics/lz/236.lz"
GeodudeFrontpic: ; 155570
INCBIN "gfx/frontpics/lz/074.lz"
ScizorBackpic: ; 1556d9
INCBIN "gfx/backpics/lz/212.lz"
GirafarigBackpic: ; 155842
INCBIN "gfx/backpics/lz/203.lz"
StantlerBackpic: ; 1559aa
INCBIN "gfx/backpics/lz/234.lz"
SmeargleBackpic: ; 155b12
INCBIN "gfx/backpics/lz/235.lz"
CharizardBackpic: ; 155c7a
INCBIN "gfx/backpics/lz/006.lz"
KadabraBackpic: ; 155de2
INCBIN "gfx/backpics/lz/064.lz"
PrimeapeBackpic: ; 155f49
INCBIN "gfx/backpics/lz/057.lz"
FurretBackpic: ; 1560b0
INCBIN "gfx/backpics/lz/162.lz"
WartortleBackpic: ; 156216
INCBIN "gfx/backpics/lz/008.lz"
ExeggcuteBackpic: ; 15637c
INCBIN "gfx/backpics/lz/102.lz"
IgglybuffFrontpic: ; 1564e2
INCBIN "gfx/frontpics/lz/174.lz"
RaticateBackpic: ; 156647
INCBIN "gfx/backpics/lz/020.lz"
VulpixBackpic: ; 1567ac
INCBIN "gfx/backpics/lz/037.lz"
EkansBackpic: ; 156911
INCBIN "gfx/backpics/lz/023.lz"
SeakingBackpic: ; 156a75
INCBIN "gfx/backpics/lz/119.lz"
BurglarPic: ; 156bd9
INCBIN "gfx/trainers/lz/046.lz"
PsyduckBackpic: ; 156d3d
INCBIN "gfx/backpics/lz/054.lz"
PikachuBackpic: ; 156ea1
INCBIN "gfx/backpics/lz/025.lz"
KabutoFrontpic: ; 157003
INCBIN "gfx/frontpics/lz/140.lz"
MareepBackpic: ; 157164
INCBIN "gfx/backpics/lz/179.lz"
RemoraidBackpic: ; 1572c5
INCBIN "gfx/backpics/lz/223.lz"
DittoFrontpic: ; 157426
INCBIN "gfx/frontpics/lz/132.lz"
KingdraBackpic: ; 157586
INCBIN "gfx/backpics/lz/230.lz"
CamperPic: ; 1576e6
INCBIN "gfx/trainers/lz/053.lz"
WooperFrontpic: ; 157846
INCBIN "gfx/frontpics/lz/194.lz"
ClefairyBackpic: ; 1579a6
INCBIN "gfx/backpics/lz/035.lz"
VenonatBackpic: ; 157b05
INCBIN "gfx/backpics/lz/048.lz"
BellossomBackpic: ; 157c64
INCBIN "gfx/backpics/lz/182.lz"
Rival1Pic: ; 157dc2
INCBIN "gfx/trainers/lz/008.lz"
SwinubBackpic: ; 157f20
INCBIN "gfx/backpics/lz/220.lz"
; 158000


SECTION "bank56",DATA,BANK[$56]

MewtwoBackpic: ; 158000
INCBIN "gfx/backpics/lz/150.lz"
PokemonProfPic: ; 15815e
INCBIN "gfx/trainers/lz/009.lz"
CalPic: ; 1582bc
INCBIN "gfx/trainers/lz/011.lz"
SwimmerfPic: ; 158419
INCBIN "gfx/trainers/lz/038.lz"
DiglettFrontpic: ; 158576
INCBIN "gfx/frontpics/lz/050.lz"
OfficerPic: ; 1586d3
INCBIN "gfx/trainers/lz/064.lz"
MukBackpic: ; 15882f
INCBIN "gfx/backpics/lz/089.lz"
DelibirdBackpic: ; 15898a
INCBIN "gfx/backpics/lz/225.lz"
SabrinaPic: ; 158ae5
INCBIN "gfx/trainers/lz/034.lz"
MagikarpBackpic: ; 158c3f
INCBIN "gfx/backpics/lz/129.lz"
AriadosBackpic: ; 158d98
INCBIN "gfx/backpics/lz/168.lz"
SneaselBackpic: ; 158ef1
INCBIN "gfx/backpics/lz/215.lz"
UmbreonBackpic: ; 159049
INCBIN "gfx/backpics/lz/197.lz"
MurkrowBackpic: ; 1591a0
INCBIN "gfx/backpics/lz/198.lz"
IvysaurBackpic: ; 1592f7
INCBIN "gfx/backpics/lz/002.lz"
SlowbroBackpic: ; 15944e
INCBIN "gfx/backpics/lz/080.lz"
PsychicTPic: ; 1595a4
INCBIN "gfx/trainers/lz/051.lz"
GolduckBackpic: ; 1596fa
INCBIN "gfx/backpics/lz/055.lz"
WeezingBackpic: ; 15984f
INCBIN "gfx/backpics/lz/110.lz"
EnteiBackpic: ; 1599a3
INCBIN "gfx/backpics/lz/244.lz"
GruntfPic: ; 159af7
INCBIN "gfx/trainers/lz/065.lz"
HorseaFrontpic: ; 159c4a
INCBIN "gfx/frontpics/lz/116.lz"
PidgeotBackpic: ; 159d9d
INCBIN "gfx/backpics/lz/018.lz"
HoOhBackpic: ; 159ef0
INCBIN "gfx/backpics/lz/250.lz"
PoliwhirlBackpic: ; 15a041
INCBIN "gfx/backpics/lz/061.lz"
MewBackpic: ; 15a191
INCBIN "gfx/backpics/lz/151.lz"
MachopBackpic: ; 15a2e0
INCBIN "gfx/backpics/lz/066.lz"
AbraBackpic: ; 15a42f
INCBIN "gfx/backpics/lz/063.lz"
AerodactylBackpic: ; 15a57e
INCBIN "gfx/backpics/lz/142.lz"
KakunaFrontpic: ; 15a6cc
INCBIN "gfx/frontpics/lz/014.lz"
DugtrioBackpic: ; 15a81a
INCBIN "gfx/backpics/lz/051.lz"
WeepinbellBackpic: ; 15a968
INCBIN "gfx/backpics/lz/070.lz"
NidoranFBackpic: ; 15aab6
INCBIN "gfx/backpics/lz/029.lz"
GravelerBackpic: ; 15ac04
INCBIN "gfx/backpics/lz/075.lz"
AipomBackpic: ; 15ad51
INCBIN "gfx/backpics/lz/190.lz"
EspeonBackpic: ; 15ae9e
INCBIN "gfx/backpics/lz/196.lz"
WeedleFrontpic: ; 15afeb
INCBIN "gfx/frontpics/lz/013.lz"
TotodileBackpic: ; 15b138
INCBIN "gfx/backpics/lz/158.lz"
SnubbullBackpic: ; 15b284
INCBIN "gfx/backpics/lz/209.lz"
KinglerBackpic: ; 15b3cf
INCBIN "gfx/backpics/lz/099.lz"
GengarBackpic: ; 15b51a
INCBIN "gfx/backpics/lz/094.lz"
RattataBackpic: ; 15b664
INCBIN "gfx/backpics/lz/019.lz"
YoungsterPic: ; 15b7ad
INCBIN "gfx/trainers/lz/021.lz"
WillPic: ; 15b8f5
INCBIN "gfx/trainers/lz/010.lz"
SchoolboyPic: ; 15ba3d
INCBIN "gfx/trainers/lz/022.lz"
MagnemiteFrontpic: ; 15bb84
INCBIN "gfx/frontpics/lz/081.lz"
ErikaPic: ; 15bccb
INCBIN "gfx/trainers/lz/020.lz"
JaninePic: ; 15be10
INCBIN "gfx/trainers/lz/025.lz"
MagnemiteBackpic: ; 15bf54
INCBIN "gfx/backpics/lz/081.lz"
; 15bffa


SECTION "bank57",DATA,BANK[$57]

HoothootBackpic: ; 15c000
INCBIN "gfx/backpics/lz/163.lz"
NoctowlBackpic: ; 15c144
INCBIN "gfx/backpics/lz/164.lz"
MortyPic: ; 15c287
INCBIN "gfx/trainers/lz/003.lz"
SlugmaBackpic: ; 15c3ca
INCBIN "gfx/backpics/lz/218.lz"
KabutoBackpic: ; 15c50d
INCBIN "gfx/backpics/lz/140.lz"
VictreebelBackpic: ; 15c650
INCBIN "gfx/backpics/lz/071.lz"
MeowthBackpic: ; 15c792
INCBIN "gfx/backpics/lz/052.lz"
MeganiumBackpic: ; 15c8d4
INCBIN "gfx/backpics/lz/154.lz"
PicnickerPic: ; 15ca16
INCBIN "gfx/trainers/lz/052.lz"
LickitungBackpic: ; 15cb58
INCBIN "gfx/backpics/lz/108.lz"
TogepiFrontpic: ; 15cc99
INCBIN "gfx/frontpics/lz/175.lz"
SuperNerdPic: ; 15cdda
INCBIN "gfx/trainers/lz/040.lz"
HaunterBackpic: ; 15cf1b
INCBIN "gfx/backpics/lz/093.lz"
XatuBackpic: ; 15d05b
INCBIN "gfx/backpics/lz/178.lz"
RedPic: ; 15d19b
INCBIN "gfx/trainers/lz/062.lz"
Porygon2Backpic: ; 15d2db
INCBIN "gfx/backpics/lz/233.lz"
JasminePic: ; 15d41b
INCBIN "gfx/trainers/lz/005.lz"
PinecoBackpic: ; 15d55a
INCBIN "gfx/backpics/lz/204.lz"
MetapodFrontpic: ; 15d699
INCBIN "gfx/frontpics/lz/011.lz"
SeelBackpic: ; 15d7d6
INCBIN "gfx/backpics/lz/086.lz"
QuagsireBackpic: ; 15d913
INCBIN "gfx/backpics/lz/195.lz"
WhitneyPic: ; 15da4f
INCBIN "gfx/trainers/lz/001.lz"
JolteonBackpic: ; 15db8b
INCBIN "gfx/backpics/lz/135.lz"
CaterpieFrontpic: ; 15dcc6
INCBIN "gfx/frontpics/lz/010.lz"
HoppipBackpic: ; 15ddff
INCBIN "gfx/backpics/lz/187.lz"
BluePic: ; 15df37
INCBIN "gfx/trainers/lz/063.lz"
GranbullBackpic: ; 15e06f
INCBIN "gfx/backpics/lz/210.lz"
GentlemanPic: ; 15e1a7
INCBIN "gfx/trainers/lz/031.lz"
ExecutivemPic: ; 15e2dd
INCBIN "gfx/trainers/lz/050.lz"
SpearowBackpic: ; 15e413
INCBIN "gfx/backpics/lz/021.lz"
SunkernBackpic: ; 15e549
INCBIN "gfx/backpics/lz/191.lz"
LaprasBackpic: ; 15e67e
INCBIN "gfx/backpics/lz/131.lz"
MagbyBackpic: ; 15e7b2
INCBIN "gfx/backpics/lz/240.lz"
DragonairBackpic: ; 15e8e6
INCBIN "gfx/backpics/lz/148.lz"
ZapdosBackpic: ; 15ea19
INCBIN "gfx/backpics/lz/145.lz"
ChikoritaBackpic: ; 15eb4c
INCBIN "gfx/backpics/lz/152.lz"
CorsolaBackpic: ; 15ec7f
INCBIN "gfx/backpics/lz/222.lz"
ChinchouBackpic: ; 15edb2
INCBIN "gfx/backpics/lz/170.lz"
ChanseyBackpic: ; 15eee4
INCBIN "gfx/backpics/lz/113.lz"
SkiploomBackpic: ; 15f014
INCBIN "gfx/backpics/lz/188.lz"
SpinarakFrontpic: ; 15f142
INCBIN "gfx/frontpics/lz/167.lz"
Rival2Pic: ; 15f270
INCBIN "gfx/trainers/lz/041.lz"
UnownWFrontpic: ; 15f39e
INCBIN "gfx/frontpics/lz/201w.lz"
CharmanderBackpic: ; 15f4cb
INCBIN "gfx/backpics/lz/004.lz"
RhyhornBackpic: ; 15f5f8
INCBIN "gfx/backpics/lz/111.lz"
UnownCFrontpic: ; 15f724
INCBIN "gfx/frontpics/lz/201c.lz"
MistyPic: ; 15f850
INCBIN "gfx/trainers/lz/017.lz"
BlainePic: ; 15f97c
INCBIN "gfx/trainers/lz/045.lz"
UnownZFrontpic: ; 15faa7
INCBIN "gfx/frontpics/lz/201z.lz"
SwinubFrontpic: ; 15fbd2
INCBIN "gfx/frontpics/lz/220.lz"
LarvitarBackpic: ; 15fcfc
INCBIN "gfx/backpics/lz/246.lz"
PorygonBackpic: ; 15fe26
INCBIN "gfx/backpics/lz/137.lz"
UnownHBackpic: ; 15ff4f
INCBIN "gfx/backpics/lz/201h.lz"
; 15ffff


SECTION "bank58",DATA,BANK[$58]

ParasBackpic: ; 160000
INCBIN "gfx/backpics/lz/046.lz"
VaporeonBackpic: ; 160128
INCBIN "gfx/backpics/lz/134.lz"
TentacoolBackpic: ; 160250
INCBIN "gfx/backpics/lz/072.lz"
ExecutivefPic: ; 160377
INCBIN "gfx/trainers/lz/054.lz"
BulbasaurBackpic: ; 16049b
INCBIN "gfx/backpics/lz/001.lz"
SmoochumBackpic: ; 1605bd
INCBIN "gfx/backpics/lz/238.lz"
PichuBackpic: ; 1606de
INCBIN "gfx/backpics/lz/172.lz"
HoundoomBackpic: ; 1607ff
INCBIN "gfx/backpics/lz/229.lz"
BellsproutBackpic: ; 160920
INCBIN "gfx/backpics/lz/069.lz"
GrimerBackpic: ; 160a3f
INCBIN "gfx/backpics/lz/088.lz"
LanturnBackpic: ; 160b5d
INCBIN "gfx/backpics/lz/171.lz"
PidgeottoBackpic: ; 160c7b
INCBIN "gfx/backpics/lz/017.lz"
StaryuBackpic: ; 160d98
INCBIN "gfx/backpics/lz/120.lz"
MrMimeBackpic: ; 160eb5
INCBIN "gfx/backpics/lz/122.lz"
CaterpieBackpic: ; 160fd2
INCBIN "gfx/backpics/lz/010.lz"
VoltorbFrontpic: ; 1610ee
INCBIN "gfx/frontpics/lz/100.lz"
LugiaBackpic: ; 161208
INCBIN "gfx/backpics/lz/249.lz"
PrycePic: ; 161322
INCBIN "gfx/trainers/lz/004.lz"
BrockPic: ; 16143c
INCBIN "gfx/trainers/lz/016.lz"
UnownGFrontpic: ; 161555
INCBIN "gfx/frontpics/lz/201g.lz"
ArbokBackpic: ; 16166e
INCBIN "gfx/backpics/lz/024.lz"
PolitoedBackpic: ; 161785
INCBIN "gfx/backpics/lz/186.lz"
DragoniteBackpic: ; 16189c
INCBIN "gfx/backpics/lz/149.lz"
HitmonleeBackpic: ; 1619b3
INCBIN "gfx/backpics/lz/106.lz"
NatuFrontpic: ; 161ac9
INCBIN "gfx/frontpics/lz/177.lz"
UrsaringBackpic: ; 161bde
INCBIN "gfx/backpics/lz/217.lz"
SagePic: ; 161cf3
INCBIN "gfx/trainers/lz/055.lz"
TeddiursaBackpic: ; 161e07
INCBIN "gfx/backpics/lz/216.lz"
PhanpyBackpic: ; 161f1b
INCBIN "gfx/backpics/lz/231.lz"
UnownVFrontpic: ; 16202e
INCBIN "gfx/frontpics/lz/201v.lz"
KakunaBackpic: ; 162141
INCBIN "gfx/backpics/lz/014.lz"
WobbuffetBackpic: ; 162254
INCBIN "gfx/backpics/lz/202.lz"
TogepiBackpic: ; 162362
INCBIN "gfx/backpics/lz/175.lz"
CrobatBackpic: ; 162470
INCBIN "gfx/backpics/lz/169.lz"
BlisseyBackpic: ; 16257d
INCBIN "gfx/backpics/lz/242.lz"
AmpharosBackpic: ; 162689
INCBIN "gfx/backpics/lz/181.lz"
IgglybuffBackpic: ; 162793
INCBIN "gfx/backpics/lz/174.lz"
AzumarillBackpic: ; 16289c
INCBIN "gfx/backpics/lz/184.lz"
OctilleryBackpic: ; 1629a4
INCBIN "gfx/backpics/lz/224.lz"
UnownSFrontpic: ; 162aab
INCBIN "gfx/frontpics/lz/201s.lz"
HorseaBackpic: ; 162bb0
INCBIN "gfx/backpics/lz/116.lz"
SentretBackpic: ; 162cb5
INCBIN "gfx/backpics/lz/161.lz"
UnownOFrontpic: ; 162dba
INCBIN "gfx/frontpics/lz/201o.lz"
UnownTFrontpic: ; 162ebe
INCBIN "gfx/frontpics/lz/201t.lz"
WigglytuffBackpic: ; 162fc1
INCBIN "gfx/backpics/lz/040.lz"
ArticunoBackpic: ; 1630c3
INCBIN "gfx/backpics/lz/144.lz"
DittoBackpic: ; 1631c3
INCBIN "gfx/backpics/lz/132.lz"
WeedleBackpic: ; 1632c3
INCBIN "gfx/backpics/lz/013.lz"
UnownHFrontpic: ; 1633c3
INCBIN "gfx/frontpics/lz/201h.lz"
CleffaBackpic: ; 1634c0
INCBIN "gfx/backpics/lz/173.lz"
DrowzeeBackpic: ; 1635bc
INCBIN "gfx/backpics/lz/096.lz"
GastlyBackpic: ; 1636b7
INCBIN "gfx/backpics/lz/092.lz"
FearowBackpic: ; 1637b1
INCBIN "gfx/backpics/lz/022.lz"
MarillBackpic: ; 1638aa
INCBIN "gfx/backpics/lz/183.lz"
DratiniBackpic: ; 1639a3
INCBIN "gfx/backpics/lz/147.lz"
ElectrodeBackpic: ; 163a9c
INCBIN "gfx/backpics/lz/101.lz"
SkarmoryBackpic: ; 163b92
INCBIN "gfx/backpics/lz/227.lz"
MetapodBackpic: ; 163c88
INCBIN "gfx/backpics/lz/011.lz"
JigglypuffBackpic: ; 163d7d
INCBIN "gfx/backpics/lz/039.lz"
OddishBackpic: ; 163e72
INCBIN "gfx/backpics/lz/043.lz"
UnownDBackpic: ; 163f66
INCBIN "gfx/backpics/lz/201d.lz"
; 163ffc


SECTION "bank59",DATA,BANK[$59]

SpinarakBackpic: ; 164000
INCBIN "gfx/backpics/lz/167.lz"
RaikouBackpic: ; 1640f3
INCBIN "gfx/backpics/lz/243.lz"
UnownKFrontpic: ; 1641e6
INCBIN "gfx/frontpics/lz/201k.lz"
HoundourBackpic: ; 1642d7
INCBIN "gfx/backpics/lz/228.lz"
PoliwagBackpic: ; 1643c7
INCBIN "gfx/backpics/lz/060.lz"
SquirtleBackpic: ; 1644b7
INCBIN "gfx/backpics/lz/007.lz"
ShuckleBackpic: ; 1645a6
INCBIN "gfx/backpics/lz/213.lz"
DewgongBackpic: ; 164692
INCBIN "gfx/backpics/lz/087.lz"
UnownBFrontpic: ; 16477e
INCBIN "gfx/frontpics/lz/201b.lz"
SlowpokeBackpic: ; 164869
INCBIN "gfx/backpics/lz/079.lz"
DunsparceBackpic: ; 164954
INCBIN "gfx/backpics/lz/206.lz"
DonphanBackpic: ; 164a3e
INCBIN "gfx/backpics/lz/232.lz"
WooperBackpic: ; 164b27
INCBIN "gfx/backpics/lz/194.lz"
TaurosBackpic: ; 164c10
INCBIN "gfx/backpics/lz/128.lz"
UnownXFrontpic: ; 164cf7
INCBIN "gfx/frontpics/lz/201x.lz"
UnownNFrontpic: ; 164ddd
INCBIN "gfx/frontpics/lz/201n.lz"
TangelaBackpic: ; 164ec3
INCBIN "gfx/backpics/lz/114.lz"
VoltorbBackpic: ; 164fa8
INCBIN "gfx/backpics/lz/100.lz"
UnownJFrontpic: ; 16508d
INCBIN "gfx/frontpics/lz/201j.lz"
MantineBackpic: ; 165172
INCBIN "gfx/backpics/lz/226.lz"
UnownLFrontpic: ; 16524a
INCBIN "gfx/frontpics/lz/201l.lz"
PiloswineBackpic: ; 16531d
INCBIN "gfx/backpics/lz/221.lz"
UnownMFrontpic: ; 1653ef
INCBIN "gfx/frontpics/lz/201m.lz"
UnownFFrontpic: ; 1654bf
INCBIN "gfx/frontpics/lz/201f.lz"
NatuBackpic: ; 16558e
INCBIN "gfx/backpics/lz/177.lz"
UnownAFrontpic: ; 165659
INCBIN "gfx/frontpics/lz/201a.lz"
GolemBackpic: ; 165724
INCBIN "gfx/backpics/lz/076.lz"
UnownUFrontpic: ; 1657ea
INCBIN "gfx/frontpics/lz/201u.lz"
DiglettBackpic: ; 1658aa
INCBIN "gfx/backpics/lz/050.lz"
UnownQFrontpic: ; 165969
INCBIN "gfx/frontpics/lz/201q.lz"
UnownPFrontpic: ; 165a26
INCBIN "gfx/frontpics/lz/201p.lz"
UnownCBackpic: ; 165adf
INCBIN "gfx/backpics/lz/201c.lz"
JynxBackpic: ; 165b93
INCBIN "gfx/backpics/lz/124.lz"
GolbatBackpic: ; 165c46
INCBIN "gfx/backpics/lz/042.lz"
UnownYFrontpic: ; 165cf6
INCBIN "gfx/frontpics/lz/201y.lz"
UnownGBackpic: ; 165da3
INCBIN "gfx/backpics/lz/201g.lz"
UnownIFrontpic: ; 165e47
INCBIN "gfx/frontpics/lz/201i.lz"
UnownVBackpic: ; 165eea
INCBIN "gfx/backpics/lz/201v.lz"
ForretressBackpic: ; 165f86
INCBIN "gfx/backpics/lz/205.lz"
UnownSBackpic: ; 166019
INCBIN "gfx/backpics/lz/201s.lz"
UnownRFrontpic: ; 1660ab
INCBIN "gfx/frontpics/lz/201r.lz"
UnownEBackpic: ; 16613d
INCBIN "gfx/backpics/lz/201e.lz"
UnownJBackpic: ; 1661c9
INCBIN "gfx/backpics/lz/201j.lz"
UnownBBackpic: ; 16624c
INCBIN "gfx/backpics/lz/201b.lz"
UnownOBackpic: ; 1662cf
INCBIN "gfx/backpics/lz/201o.lz"
UnownZBackpic: ; 166351
INCBIN "gfx/backpics/lz/201z.lz"
UnownWBackpic: ; 1663d0
INCBIN "gfx/backpics/lz/201w.lz"
UnownNBackpic: ; 16644e
INCBIN "gfx/backpics/lz/201n.lz"
UnownABackpic: ; 1664c9
INCBIN "gfx/backpics/lz/201a.lz"
UnownMBackpic: ; 166544
INCBIN "gfx/backpics/lz/201m.lz"
UnownKBackpic: ; 1665bd
INCBIN "gfx/backpics/lz/201k.lz"
UnownTBackpic: ; 166632
INCBIN "gfx/backpics/lz/201t.lz"
UnownXBackpic: ; 1666a6
INCBIN "gfx/backpics/lz/201x.lz"
UnownLBackpic: ; 166717
INCBIN "gfx/backpics/lz/201l.lz"
UnownUBackpic: ; 166783
INCBIN "gfx/backpics/lz/201u.lz"
UnownQBackpic: ; 1667ee
INCBIN "gfx/backpics/lz/201q.lz"
UnownYBackpic: ; 166857
INCBIN "gfx/backpics/lz/201y.lz"
UnownPBackpic: ; 1668bd
INCBIN "gfx/backpics/lz/201p.lz"
UnownIBackpic: ; 16691b
INCBIN "gfx/backpics/lz/201i.lz"
UnownRBackpic: ; 166979
INCBIN "gfx/backpics/lz/201r.lz"
; 1669d3


SECTION "bank5A",DATA,BANK[$5A]

INCBIN "baserom.gbc",$168000,$4000

SECTION "bank5B",DATA,BANK[$5B]

INCBIN "baserom.gbc",$16C000,$4000

SECTION "bank5C",DATA,BANK[$5C]

INCBIN "baserom.gbc",$170000,$4000

SECTION "bank5D",DATA,BANK[$5D]

INCBIN "baserom.gbc",$174000,$4000

SECTION "bank5E",DATA,BANK[$5E]

INCBIN "baserom.gbc", $178000, $1f

Music_MobileAdapterMenu: ; 0x17801f
INCLUDE "music/mobileadaptermenu.asm"
; 0x178153

Music_BuenasPassword: ; 0x178153
INCLUDE "music/buenaspassword.asm"
; 0x17843b

Music_LookMysticalMan: ; 0x17843b
INCLUDE "music/lookmysticalman.asm"
; 0x1786e8

Music_CrystalOpening: ; 0x1786e8
INCLUDE "music/crystalopening.asm"
; 0x178889

Music_BattleTowerTheme: ; 0x178889
INCLUDE "music/battletowertheme.asm"
; 0x178b81

Music_SuicuneBattle: ; 0x178b81
INCLUDE "music/suicunebattle.asm"
; 0x17948b

Music_BattleTowerLobby: ; 0x17948b
INCLUDE "music/battletowerlobby.asm"
; 0x17961d

Music_MobileCenter: ; 0x17961d
INCLUDE "music/mobilecenter.asm"
; 0x17982d

INCBIN "baserom.gbc",$17982d, $17b629 - $17982d

SECTION "bank5F",DATA,BANK[$5F]

INCBIN "baserom.gbc",$17C000,$4000

SECTION "bank60",DATA,BANK[$60]

IndigoPlateauPokeCenter1F_MapScriptHeader: ; 0x180000
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x180009, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x18000a
; 0x180009

UnknownScript_0x180009: ; 0x180009
	end
; 0x18000a

UnknownScript_0x18000a: ; 0x18000a
	domaptrigger GROUP_WILLS_ROOM, MAP_WILLS_ROOM, $0
	domaptrigger GROUP_KOGAS_ROOM, MAP_KOGAS_ROOM, $0
	domaptrigger GROUP_BRUNOS_ROOM, MAP_BRUNOS_ROOM, $0
	domaptrigger GROUP_KARENS_ROOM, MAP_KARENS_ROOM, $0
	domaptrigger GROUP_LANCES_ROOM, MAP_LANCES_ROOM, $0
	domaptrigger GROUP_HALL_OF_FAME, MAP_HALL_OF_FAME, $0
	clearbit1 $0309
	clearbit1 $030a
	clearbit1 $030b
	clearbit1 $030c
	clearbit1 $030d
	clearbit1 $030e
	clearbit1 $030f
	clearbit1 $0310
	clearbit1 $0311
	clearbit1 $0312
	clearbit1 $05b8
	clearbit1 $05b9
	clearbit1 $05ba
	clearbit1 $05bb
	clearbit1 $05bc
	setbit1 $075f
	return
; 0x180053

UnknownScript_0x180053: ; 0x180053
	checkbit1 $0319
	iffalse UnknownScript_0x18012b
	checkbit2 $005d
	iftrue UnknownScript_0x18012b
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x18012b
	if_equal TUESDAY, UnknownScript_0x18012b
	if_equal THURSDAY, UnknownScript_0x18012b
	if_equal FRIDAY, UnknownScript_0x18012b
	if_equal SATURDAY, UnknownScript_0x18012b
	moveperson $5, $11, $9
	appear $5
	spriteface $0, $0
	showemote $0, $0, 15
	special $006a
	pause 15
	applymovement $5, MovementData_0x180164
	playmusic $001f
	spriteface $0, $3
	2jump UnknownScript_0x1800ce
; 0x180094

UnknownScript_0x180094: ; 0x180094
	checkbit1 $0319
	iffalse UnknownScript_0x18012b
	checkbit2 $005d
	iftrue UnknownScript_0x18012b
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x18012b
	if_equal TUESDAY, UnknownScript_0x18012b
	if_equal THURSDAY, UnknownScript_0x18012b
	if_equal FRIDAY, UnknownScript_0x18012b
	if_equal SATURDAY, UnknownScript_0x18012b
	appear $5
	spriteface $0, $0
	showemote $0, $0, 15
	special $006a
	pause 15
	applymovement $5, MovementData_0x18016b
	playmusic $001f
	spriteface $0, $2
UnknownScript_0x1800ce: ; 0x1800ce
	loadfont
	2writetext UnknownText_0x1801f5
	closetext
	loadmovesprites
	setbit1 $077b
	checkbit1 $001c
	iftrue UnknownScript_0x1800f3
	checkbit1 $001d
	iftrue UnknownScript_0x180103
	winlosstext UnknownText_0x180295, UnknownText_0x1802fd
	setlasttalked $5
	loadtrainer RIVAL2, 6
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x180113
; 0x1800f3

UnknownScript_0x1800f3: ; 0x1800f3
	winlosstext UnknownText_0x180295, UnknownText_0x1802fd
	setlasttalked $5
	loadtrainer RIVAL2, 4
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x180113
; 0x180103

UnknownScript_0x180103: ; 0x180103
	winlosstext UnknownText_0x180295, UnknownText_0x1802fd
	setlasttalked $5
	loadtrainer RIVAL2, 5
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x180113
; 0x180113

UnknownScript_0x180113: ; 0x180113
	playmusic $0020
	loadfont
	2writetext UnknownText_0x1802a4
	closetext
	loadmovesprites
	spriteface $0, $0
	applymovement $5, MovementData_0x180172
	disappear $5
	dotrigger $0
	playmapmusic
	setbit2 $005d
UnknownScript_0x18012b: ; 0x18012b
	end
; 0x18012c

UnknownScript_0x18012c: ; 0x18012c
	jumpstd $0000
; 0x18012f

UnknownScript_0x18012f: ; 0x18012f
	loadfont
	pokemart $0, $0020
	loadmovesprites
	end
; 0x180136

UnknownScript_0x180136: ; 0x180136
	jumptextfaceplayer UnknownText_0x180178
; 0x180139

UnknownScript_0x180139: ; 0x180139
	faceplayer
	loadfont
	2writetext UnknownText_0x180335
	yesorno
	iffalse UnknownScript_0x180154
	2writetext UnknownText_0x1803e7
	closetext
	loadmovesprites
	playsound $0013
	special $002e
	waitbutton
	warp GROUP_NEW_BARK_TOWN, MAP_NEW_BARK_TOWN, $d, $6
	end
; 0x180154

UnknownScript_0x180154: ; 0x180154
	2writetext UnknownText_0x180411
	closetext
	loadmovesprites
	end
; 0x18015a

UnknownScript_0x18015a: ; 0x18015a
	loadfont
	2writetext UnknownText_0x180433
	cry ABRA
	closetext
	loadmovesprites
	end
; 0x180164

MovementData_0x180164: ; 0x180164
	step_up
	step_up
	step_up
	step_up
	step_up
	turn_head_left
	step_end
; 0x18016b

MovementData_0x18016b: ; 0x18016b
	step_up
	step_up
	step_up
	step_up
	step_up
	turn_head_right
	step_end
; 0x180172

MovementData_0x180172: ; 0x180172
	step_down
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x180178

UnknownText_0x180178: ; 0x180178
	db $0, "At the #MON", $4f
	db "LEAGUE, you'll get", $51
	db "tested by the", $4f
	db "ELITE FOUR.", $51
	db "You have to beat", $4f
	db "them all. If you", $51
	db "lose, you have to", $4f
	db "start all over!", $57
; 0x1801f5

UnknownText_0x1801f5: ; 0x1801f5
	db $0, "Hold it.", $51
	db "You're going to", $4f
	db "take the #MON", $51
	db "LEAGUE challenge", $4f
	db "now?", $51
	db "That's not going", $4f
	db "to happen.", $51
	db "My super-well-", $4f
	db "trained #MON", $51
	db "are going to pound", $4f
	db "you.", $51
	db $52, "!", $4f
	db "I challenge you!", $57
; 0x180295

UnknownText_0x180295: ; 0x180295
	db $0, "…", $51
	db "OK--I lost…", $57
; 0x1802a4

UnknownText_0x1802a4: ; 0x1802a4
	db $0, "…Darn… I still", $4f
	db "can't win…", $51
	db "I… I have to think", $4f
	db "more about my", $55
	db "#MON…", $51
	db "Humph! Try not to", $4f
	db "lose!", $57
; 0x1802fd

UnknownText_0x1802fd: ; 0x1802fd
	db $0, "…", $51
	db "Whew…", $4f
	db "With my partners,", $51
	db "I'm going to be", $4f
	db "the CHAMPION!", $57
; 0x180335

UnknownText_0x180335: ; 0x180335
	db $0, "Ah! You're chal-", $4f
	db "lenging the ELITE", $51
	db "FOUR? Are you sure", $4f
	db "you're ready?", $51
	db "If you need to", $4f
	db "train some more,", $51
	db "my ABRA can help", $4f
	db "you.", $51
	db "It can TELEPORT", $4f
	db "you home.", $51
	db "Would you like to", $4f
	db "go home now?", $57
; 0x1803e7

UnknownText_0x1803e7: ; 0x1803e7
	db $0, "OK, OK. Picture", $4f
	db "your house in your", $55
	db "mind…", $57
; 0x180411

UnknownText_0x180411: ; 0x180411
	db $0, "OK, OK. The best", $4f
	db "of luck to you!", $57
; 0x180433

UnknownText_0x180433: ; 0x180433
	db $0, "ABRA: Aabra…", $57
; 0x180441

IndigoPlateauPokeCenter1F_MapEventHeader: ; 0x180441
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $d, $5, 1, GROUP_ROUTE_23, MAP_ROUTE_23
	warp_def $d, $6, 2, GROUP_ROUTE_23, MAP_ROUTE_23
	warp_def $d, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F
	warp_def $3, $e, 1, GROUP_WILLS_ROOM, MAP_WILLS_ROOM

	; xy triggers
	db 2
	xy_trigger 0, $4, $10, $0, UnknownScript_0x180053, $0, $0
	xy_trigger 0, $4, $11, $0, UnknownScript_0x180094, $0, $0

	; signposts
	db 0

	; people-events
	db 6
	person_event $37, 11, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x18012c, $ffff
	person_event $39, 11, 15, $6, $0, 255, 255, $0, 0, UnknownScript_0x18012f, $ffff
	person_event $23, 15, 15, $2, $22, 255, 255, $0, 0, UnknownScript_0x180136, $ffff
	person_event $4, 13, 20, $7, $0, 255, 255, $0, 0, ObjectEvent, $077b
	person_event $2f, 13, 5, $6, $0, 255, 255, $90, 0, UnknownScript_0x180139, $077c
	person_event $91, 13, 4, $16, $0, 255, 255, $b0, 0, UnknownScript_0x18015a, $077c
; 0x1804b9

WillsRoom_MapScriptHeader: ; 0x1804b9
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1804c6, $0000
	dw UnknownScript_0x1804ca, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x1804cb
; 0x1804c6

UnknownScript_0x1804c6: ; 0x1804c6
	priorityjump UnknownScript_0x1804e0
	end
; 0x1804ca

UnknownScript_0x1804ca: ; 0x1804ca
	end
; 0x1804cb

UnknownScript_0x1804cb: ; 0x1804cb
	checkbit1 $0309
	iffalse UnknownScript_0x1804d5
	changeblock $4, $e, $2a
UnknownScript_0x1804d5: ; 0x1804d5
	checkbit1 $030a
	iffalse UnknownScript_0x1804df
	changeblock $4, $2, $16
UnknownScript_0x1804df: ; 0x1804df
	return
; 0x1804e0

UnknownScript_0x1804e0: ; 0x1804e0
	applymovement $0, MovementData_0x18052c
	refreshscreen $86
	playsound $001b
	earthquake 80
	changeblock $4, $e, $2a
	reloadmappart
	loadmovesprites
	dotrigger $1
	setbit1 $0309
	waitbutton
	end
; 0x1804f8

UnknownScript_0x1804f8: ; 0x1804f8
	faceplayer
	loadfont
	checkbit1 $05b8
	iftrue UnknownScript_0x180526
	2writetext UnknownText_0x180531
	closetext
	loadmovesprites
	winlosstext UnknownText_0x18062c, $0000
	loadtrainer WILL, 1
	startbattle
	returnafterbattle
	setbit1 $05b8
	loadfont
	2writetext UnknownText_0x180644
	closetext
	loadmovesprites
	playsound $001f
	changeblock $4, $2, $16
	reloadmappart
	loadmovesprites
	setbit1 $030a
	waitbutton
	end
; 0x180526

UnknownScript_0x180526: ; 0x180526
	2writetext UnknownText_0x180644
	closetext
	loadmovesprites
	end
; 0x18052c

MovementData_0x18052c: ; 0x18052c
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x180531

UnknownText_0x180531: ; 0x180531
	db $0, "Welcome to #MON", $4f
	db "LEAGUE, ", $52, ".", $51
	db "Allow me to intro-", $4f
	db "duce myself. I am", $55
	db "WILL.", $51
	db "I have trained all", $4f
	db "around the world,", $51
	db "making my psychic", $4f
	db "#MON powerful.", $51
	db "And, at last, I've", $4f
	db "been accepted into", $55
	db "the ELITE FOUR.", $51
	db "I can only keep", $4f
	db "getting better!", $51
	db "Losing is not an", $4f
	db "option!", $57
; 0x18062c

UnknownText_0x18062c: ; 0x18062c
	db $0, "I… I can't…", $4f
	db "believe it…", $57
; 0x180644

UnknownText_0x180644: ; 0x180644
	db $0, "Even though I was", $4f
	db "defeated, I won't", $55
	db "change my course.", $51
	db "I will continue", $4f
	db "battling until I", $51
	db "stand above all", $4f
	db "trainers!", $51
	db "Now, ", $52, ", move", $4f
	db "on and experience", $51
	db "the true ferocity", $4f
	db "of the ELITE FOUR.", $57
; 0x1806f9

WillsRoom_MapEventHeader: ; 0x1806f9
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $11, $5, 4, GROUP_INDIGO_PLATEAU_POKECENTER_1F, MAP_INDIGO_PLATEAU_POKECENTER_1F
	warp_def $2, $4, 1, GROUP_KOGAS_ROOM, MAP_KOGAS_ROOM
	warp_def $2, $5, 2, GROUP_KOGAS_ROOM, MAP_KOGAS_ROOM

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $11, 11, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x1804f8, $ffff
; 0x18071b

KogasRoom_MapScriptHeader: ; 0x18071b
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x180728, $0000
	dw UnknownScript_0x18072c, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x18072d
; 0x180728

UnknownScript_0x180728: ; 0x180728
	priorityjump UnknownScript_0x180742
	end
; 0x18072c

UnknownScript_0x18072c: ; 0x18072c
	end
; 0x18072d

UnknownScript_0x18072d: ; 0x18072d
	checkbit1 $030b
	iffalse UnknownScript_0x180737
	changeblock $4, $e, $2a
UnknownScript_0x180737: ; 0x180737
	checkbit1 $030c
	iffalse UnknownScript_0x180741
	changeblock $4, $2, $16
UnknownScript_0x180741: ; 0x180741
	return
; 0x180742

UnknownScript_0x180742: ; 0x180742
	applymovement $0, MovementData_0x18078e
	refreshscreen $86
	playsound $001b
	earthquake 80
	changeblock $4, $e, $2a
	reloadmappart
	loadmovesprites
	dotrigger $1
	setbit1 $030b
	waitbutton
	end
; 0x18075a

UnknownScript_0x18075a: ; 0x18075a
	faceplayer
	loadfont
	checkbit1 $05b9
	iftrue UnknownScript_0x180788
	2writetext UnknownText_0x180793
	closetext
	loadmovesprites
	winlosstext UnknownText_0x1808a9, $0000
	loadtrainer KOGA, 1
	startbattle
	returnafterbattle
	setbit1 $05b9
	loadfont
	2writetext UnknownText_0x1808ca
	closetext
	loadmovesprites
	playsound $001f
	changeblock $4, $2, $16
	reloadmappart
	loadmovesprites
	setbit1 $030c
	waitbutton
	end
; 0x180788

UnknownScript_0x180788: ; 0x180788
	2writetext UnknownText_0x1808ca
	closetext
	loadmovesprites
	end
; 0x18078e

MovementData_0x18078e: ; 0x18078e
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x180793

UnknownText_0x180793: ; 0x180793
	db $0, "Fwahahahaha!", $51
	db "I am KOGA of the", $4f
	db "ELITE FOUR.", $51
	db "I live in shadows,", $4f
	db "a ninja!", $51
	db "My intricate style", $4f
	db "will confound and", $55
	db "destroy you!", $51
	db "Confusion, sleep,", $4f
	db "poison…", $51
	db "Prepare to be the", $4f
	db "victim of my sin-", $55
	db "ister technique!", $51
	db "Fwahahahaha!", $51
	db "#MON is not", $4f
	db "merely about brute", $51
	db "force--you shall", $4f
	db "see soon enough!", $57
; 0x1808a9

UnknownText_0x1808a9: ; 0x1808a9
	db $0, "Ah!", $4f
	db "You have proven", $55
	db "your worth!", $57
; 0x1808ca

UnknownText_0x1808ca: ; 0x1808ca
	db $0, "I subjected you to", $4f
	db "everything I could", $55
	db "muster.", $51
	db "But my efforts", $4f
	db "failed. I must", $55
	db "hone my skills.", $51
	db "Go on to the next", $4f
	db "room, and put your", $55
	db "abilities to test!", $57
; 0x18095f

KogasRoom_MapEventHeader: ; 0x18095f
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $11, $4, 2, GROUP_WILLS_ROOM, MAP_WILLS_ROOM
	warp_def $11, $5, 3, GROUP_WILLS_ROOM, MAP_WILLS_ROOM
	warp_def $2, $4, 1, GROUP_BRUNOS_ROOM, MAP_BRUNOS_ROOM
	warp_def $2, $5, 2, GROUP_BRUNOS_ROOM, MAP_BRUNOS_ROOM

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $21, 11, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x18075a, $ffff
; 0x180986

BrunosRoom_MapScriptHeader: ; 0x180986
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x180993, $0000
	dw UnknownScript_0x180997, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x180998
; 0x180993

UnknownScript_0x180993: ; 0x180993
	priorityjump UnknownScript_0x1809ad
	end
; 0x180997

UnknownScript_0x180997: ; 0x180997
	end
; 0x180998

UnknownScript_0x180998: ; 0x180998
	checkbit1 $030d
	iffalse UnknownScript_0x1809a2
	changeblock $4, $e, $2a
UnknownScript_0x1809a2: ; 0x1809a2
	checkbit1 $030e
	iffalse UnknownScript_0x1809ac
	changeblock $4, $2, $16
UnknownScript_0x1809ac: ; 0x1809ac
	return
; 0x1809ad

UnknownScript_0x1809ad: ; 0x1809ad
	applymovement $0, MovementData_0x1809f9
	refreshscreen $86
	playsound $001b
	earthquake 80
	changeblock $4, $e, $2a
	reloadmappart
	loadmovesprites
	dotrigger $1
	setbit1 $030d
	waitbutton
	end
; 0x1809c5

UnknownScript_0x1809c5: ; 0x1809c5
	faceplayer
	loadfont
	checkbit1 $05ba
	iftrue UnknownScript_0x1809f3
	2writetext UnknownText_0x1809fe
	closetext
	loadmovesprites
	winlosstext UnknownText_0x180b23, $0000
	loadtrainer BRUNO, 1
	startbattle
	returnafterbattle
	setbit1 $05ba
	loadfont
	2writetext UnknownText_0x180b3c
	closetext
	loadmovesprites
	playsound $001f
	changeblock $4, $2, $16
	reloadmappart
	loadmovesprites
	setbit1 $030e
	waitbutton
	end
; 0x1809f3

UnknownScript_0x1809f3: ; 0x1809f3
	2writetext UnknownText_0x180b3c
	closetext
	loadmovesprites
	end
; 0x1809f9

MovementData_0x1809f9: ; 0x1809f9
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x1809fe

UnknownText_0x1809fe: ; 0x1809fe
	db $0, "I am BRUNO of the", $4f
	db "ELITE FOUR.", $51
	db "I always train to", $4f
	db "the extreme be-", $55
	db "cause I believe in", $55
	db "our potential.", $51
	db "That is how we", $4f
	db "became strong.", $51
	db "Can you withstand", $4f
	db "our power?", $51
	db "Hm? I see no fear", $4f
	db "in you. You look", $51
	db "determined. Per-", $4f
	db "fect for battle!", $51
	db "Ready, ", $52, "?", $4f
	db "You will bow down", $51
	db "to our overwhelm-", $4f
	db "ing power!", $51
	db "Hoo hah!", $57
; 0x180b23

UnknownText_0x180b23: ; 0x180b23
	db $0, "Why? How could we", $4f
	db "lose?", $57
; 0x180b3c

UnknownText_0x180b3c: ; 0x180b3c
	db $0, "Having lost, I", $4f
	db "have no right to", $55
	db "say anything…", $51
	db "Go face your next", $4f
	db "challenge!", $57
; 0x180b88

BrunosRoom_MapEventHeader: ; 0x180b88
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $11, $4, 3, GROUP_KOGAS_ROOM, MAP_KOGAS_ROOM
	warp_def $11, $5, 4, GROUP_KOGAS_ROOM, MAP_KOGAS_ROOM
	warp_def $2, $4, 1, GROUP_KARENS_ROOM, MAP_KARENS_ROOM
	warp_def $2, $5, 2, GROUP_KARENS_ROOM, MAP_KARENS_ROOM

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $1c, 11, 9, $6, $0, 255, 255, $b0, 0, UnknownScript_0x1809c5, $ffff
; 0x180baf

KarensRoom_MapScriptHeader: ; 0x180baf
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x180bbc, $0000
	dw UnknownScript_0x180bc0, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x180bc1
; 0x180bbc

UnknownScript_0x180bbc: ; 0x180bbc
	priorityjump UnknownScript_0x180bd6
	end
; 0x180bc0

UnknownScript_0x180bc0: ; 0x180bc0
	end
; 0x180bc1

UnknownScript_0x180bc1: ; 0x180bc1
	checkbit1 $030f
	iffalse UnknownScript_0x180bcb
	changeblock $4, $e, $2a
UnknownScript_0x180bcb: ; 0x180bcb
	checkbit1 $0310
	iffalse UnknownScript_0x180bd5
	changeblock $4, $2, $16
UnknownScript_0x180bd5: ; 0x180bd5
	return
; 0x180bd6

UnknownScript_0x180bd6: ; 0x180bd6
	applymovement $0, MovementData_0x180c22
	refreshscreen $86
	playsound $001b
	earthquake 80
	changeblock $4, $e, $2a
	reloadmappart
	loadmovesprites
	dotrigger $1
	setbit1 $030f
	waitbutton
	end
; 0x180bee

UnknownScript_0x180bee: ; 0x180bee
	faceplayer
	loadfont
	checkbit1 $05bb
	iftrue UnknownScript_0x180c1c
	2writetext UnknownText_0x180c27
	closetext
	loadmovesprites
	winlosstext UnknownText_0x180cf8, $0000
	loadtrainer KAREN, 1
	startbattle
	returnafterbattle
	setbit1 $05bb
	loadfont
	2writetext UnknownText_0x180d29
	closetext
	loadmovesprites
	playsound $001f
	changeblock $4, $2, $16
	reloadmappart
	loadmovesprites
	setbit1 $0310
	waitbutton
	end
; 0x180c1c

UnknownScript_0x180c1c: ; 0x180c1c
	2writetext UnknownText_0x180d29
	closetext
	loadmovesprites
	end
; 0x180c22

MovementData_0x180c22: ; 0x180c22
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x180c27

UnknownText_0x180c27: ; 0x180c27
	db $0, "I am KAREN of the", $4f
	db "ELITE FOUR.", $51
	db "You're ", $52, "?", $4f
	db "How amusing.", $51
	db "I love dark-type", $4f
	db "#MON.", $51
	db "I find their wild,", $4f
	db "tough image to be", $51
	db "so appealing. And", $4f
	db "they're so strong.", $51
	db "Think you can take", $4f
	db "them? Just try to", $55
	db "entertain me.", $51
	db "Let's go.", $57
; 0x180cf8

UnknownText_0x180cf8: ; 0x180cf8
	db $0, "Well, aren't you", $4f
	db "good. I like that", $55
	db "in a trainer.", $57
; 0x180d29

UnknownText_0x180d29: ; 0x180d29
	db $0, "Strong #MON.", $51
	db "Weak #MON.", $51
	db "That is only the", $4f
	db "selfish perception", $55
	db "of people.", $51
	db "Truly skilled", $4f
	db "trainers should", $51
	db "try to win with", $4f
	db "their favorites.", $51
	db "I like your style.", $4f
	db "You understand", $55
	db "what's important.", $51
	db "Go on--the CHAM-", $4f
	db "PION is waiting.", $57
; 0x180e05

KarensRoom_MapEventHeader: ; 0x180e05
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $11, $4, 3, GROUP_BRUNOS_ROOM, MAP_BRUNOS_ROOM
	warp_def $11, $5, 4, GROUP_BRUNOS_ROOM, MAP_BRUNOS_ROOM
	warp_def $2, $4, 1, GROUP_LANCES_ROOM, MAP_LANCES_ROOM
	warp_def $2, $5, 2, GROUP_LANCES_ROOM, MAP_LANCES_ROOM

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $1b, 11, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x180bee, $ffff
; 0x180e2c

LancesRoom_MapScriptHeader: ; 0x180e2c
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x180e39, $0000
	dw UnknownScript_0x180e3d, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x180e3e
; 0x180e39

UnknownScript_0x180e39: ; 0x180e39
	priorityjump UnknownScript_0x180e53
	end
; 0x180e3d

UnknownScript_0x180e3d: ; 0x180e3d
	end
; 0x180e3e

UnknownScript_0x180e3e: ; 0x180e3e
	checkbit1 $0311
	iffalse UnknownScript_0x180e48
	changeblock $4, $16, $34
UnknownScript_0x180e48: ; 0x180e48
	checkbit1 $0312
	iffalse UnknownScript_0x180e52
	changeblock $4, $0, $b
UnknownScript_0x180e52: ; 0x180e52
	return
; 0x180e53

UnknownScript_0x180e53: ; 0x180e53
	applymovement $0, MovementData_0x180f33
	refreshscreen $86
	playsound $001b
	earthquake 80
	changeblock $4, $16, $34
	reloadmappart
	loadmovesprites
	dotrigger $1
	setbit1 $0311
	end
; 0x180e6a

UnknownScript_0x180e6a: ; 0x180e6a
	special $006a
	applymovement $0, MovementData_0x180f38
	2jump UnknownScript_0x180e7b
; 0x180e74

UnknownScript_0x180e74: ; 0x180e74
	special $006a
	applymovement $0, MovementData_0x180f3c
UnknownScript_0x180e7b: ; 0x180e7b
	spriteface $2, $2
	loadfont
	2writetext UnknownText_0x180f67
	closetext
	loadmovesprites
	winlosstext UnknownText_0x1810a4, $0000
	setlasttalked $2
	loadtrainer CHAMPION, LANCE
	startbattle
	reloadmapmusic
	returnafterbattle
	setbit1 $05bc
	loadfont
	2writetext UnknownText_0x181132
	closetext
	loadmovesprites
	playsound $001f
	changeblock $4, $0, $b
	reloadmappart
	loadmovesprites
	setbit1 $0311
	musicfadeout $0038, $10
	pause 30
	showemote $0, $2, 15
	spriteface $2, $0
	pause 10
	spriteface $0, $0
	appear $3
	applymovement $3, MovementData_0x180f41
	loadfont
	2writetext UnknownText_0x1811dd
	closetext
	loadmovesprites
	appear $4
	applymovement $4, MovementData_0x180f46
	follow $3, $4
	applymovement $3, MovementData_0x180f49
	stopfollow
	spriteface $4, $1
	spriteface $2, $2
	loadfont
	2writetext UnknownText_0x18121b
	closetext
	loadmovesprites
	applymovement $3, MovementData_0x180f4c
	spriteface $0, $2
	loadfont
	2writetext UnknownText_0x18134b
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x180f4f
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x18137b
	closetext
	loadmovesprites
	follow $2, $0
	spriteface $3, $1
	spriteface $4, $1
	applymovement $2, MovementData_0x180f53
	stopfollow
	playsound $0023
	disappear $2
	applymovement $0, MovementData_0x180f55
	playsound $0023
	disappear $0
	applymovement $3, MovementData_0x180f57
	showemote $0, $3, 15
	loadfont
	2writetext UnknownText_0x1813c5
	pause 30
	loadmovesprites
	applymovement $3, MovementData_0x180f5b
	special $002e
	pause 15
	warpfacing $1, GROUP_HALL_OF_FAME, MAP_HALL_OF_FAME, $4, $d
	end
; 0x180f33

MovementData_0x180f33: ; 0x180f33
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x180f38

MovementData_0x180f38: ; 0x180f38
	step_up
	step_up
	turn_head_right
	step_end
; 0x180f3c

MovementData_0x180f3c: ; 0x180f3c
	step_up
	step_left
	step_up
	turn_head_right
	step_end
; 0x180f41

MovementData_0x180f41: ; 0x180f41
	big_step_up
	big_step_up
	big_step_up
	turn_head_down
	step_end
; 0x180f46

MovementData_0x180f46: ; 0x180f46
	step_up
	step_up
	step_end
; 0x180f49

MovementData_0x180f49: ; 0x180f49
	step_left
	turn_head_right
	step_end
; 0x180f4c

MovementData_0x180f4c: ; 0x180f4c
	big_step_up
	turn_head_right
	step_end
; 0x180f4f

MovementData_0x180f4f: ; 0x180f4f
	step_up
	step_left
	turn_head_down
	step_end
; 0x180f53

MovementData_0x180f53: ; 0x180f53
	step_up
	step_end
; 0x180f55

MovementData_0x180f55: ; 0x180f55
	step_up
	step_end
; 0x180f57

MovementData_0x180f57: ; 0x180f57
	step_up
	step_right
	turn_head_up
	step_end
; 0x180f5b

MovementData_0x180f5b: ; 0x180f5b
	big_step_right
	big_step_right
	big_step_left
	big_step_left
	big_step_left
	big_step_right
	big_step_right
	big_step_right
	big_step_left
	big_step_left
	turn_head_up
	step_end
; 0x180f67

UnknownText_0x180f67: ; 0x180f67
	db $0, "LANCE: I've been", $4f
	db "waiting for you.", $51
	db $14, "!", $51
	db "I knew that you,", $4f
	db "with your skills,", $51
	db "would eventually", $4f
	db "reach me here.", $51
	db "There's no need", $4f
	db "for words now.", $51
	db "We will battle to", $4f
	db "determine who is", $51
	db "the stronger of", $4f
	db "the two of us.", $51
	db "As the most power-", $4f
	db "ful trainer and as", $51
	db "the #MON LEAGUE", $4f
	db "CHAMPION…", $51
	db "I, LANCE the drag-", $4f
	db "on master, accept", $55
	db "your challenge!", $57
; 0x1810a4

UnknownText_0x1810a4: ; 0x1810a4
	db $0, "…It's over.", $51
	db "But it's an odd", $4f
	db "feeling.", $51
	db "I'm not angry that", $4f
	db "I lost. In fact, I", $55
	db "feel happy.", $51
	db "Happy that I", $4f
	db "witnessed the rise", $51
	db "of a great new", $4f
	db "CHAMPION!", $57
; 0x181132

UnknownText_0x181132: ; 0x181132
	db $0, "…Whew.", $51
	db "You have become", $4f
	db "truly powerful,", $55
	db $14, ".", $51
	db "Your #MON have", $4f
	db "responded to your", $51
	db "strong and up-", $4f
	db "standing nature.", $51
	db "As a trainer, you", $4f
	db "will continue to", $51
	db "grow strong with", $4f
	db "your #MON.", $57
; 0x1811dd

UnknownText_0x1811dd: ; 0x1811dd
	db $0, "MARY: Oh, no!", $4f
	db "It's all over!", $51
	db "PROF.OAK, if you", $4f
	db "weren't so slow…", $57
; 0x18121b

UnknownText_0x18121b: ; 0x18121b
	db $0, "PROF.OAK: Ah,", $4f
	db $14, "!", $51
	db "It's been a long", $4f
	db "while.", $51
	db "You certainly look", $4f
	db "more impressive.", $51
	db "Your conquest of", $4f
	db "the LEAGUE is just", $55
	db "fantastic!", $51
	db "Your dedication,", $4f
	db "trust and love for", $51
	db "your #MON made", $4f
	db "this happen.", $51
	db "Your #MON were", $4f
	db "outstanding too.", $51
	db "Because they be-", $4f
	db "lieved in you as a", $51
	db "trainer, they per-", $4f
	db "severed.", $51
	db "Congratulations,", $4f
	db $14, "!", $57
; 0x18134b

UnknownText_0x18134b: ; 0x18134b
	db $0, "MARY: Let's inter-", $4f
	db "view the brand new", $55
	db "CHAMPION!", $57
; 0x18137b

UnknownText_0x18137b: ; 0x18137b
	db $0, "LANCE: This is", $4f
	db "getting to be a", $55
	db "bit too noisy…", $51
	db $14, ", could you", $4f
	db "come with me?", $57
; 0x1813c5

UnknownText_0x1813c5: ; 0x1813c5
	db $0, "MARY: Oh, wait!", $4f
	db "We haven't done", $55
	db "the interview!", $57
; 0x1813f4

LancesRoom_MapEventHeader: ; 0x1813f4
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $17, $4, 3, GROUP_KARENS_ROOM, MAP_KARENS_ROOM
	warp_def $17, $5, 4, GROUP_KARENS_ROOM, MAP_KARENS_ROOM
	warp_def $1, $4, 1, GROUP_HALL_OF_FAME, MAP_HALL_OF_FAME
	warp_def $1, $5, 2, GROUP_HALL_OF_FAME, MAP_HALL_OF_FAME

	; xy triggers
	db 2
	xy_trigger 1, $5, $4, $0, UnknownScript_0x180e6a, $0, $0
	xy_trigger 1, $5, $5, $0, UnknownScript_0x180e74, $0, $0

	; signposts
	db 0

	; people-events
	db 3
	person_event $1e, 7, 9, $6, $0, 255, 255, $0, 0, $4e7b, $ffff
	person_event $29, 11, 8, $7, $0, 255, 255, $a0, 0, ObjectEvent, $075f
	person_event $5, 11, 8, $7, $0, 255, 255, $0, 0, ObjectEvent, $075f
; 0x181445

HallOfFame_MapScriptHeader: ; 0x181445
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x18144f, $0000
	dw UnknownScript_0x181453, $0000

	; callback count
	db 0
; 0x18144f

UnknownScript_0x18144f: ; 0x18144f
	priorityjump UnknownScript_0x181454
	end
; 0x181453

UnknownScript_0x181453: ; 0x181453
	end
; 0x181454

UnknownScript_0x181454: ; 0x181454
	follow $2, $0
	applymovement $2, MovementData_0x181499
	stopfollow
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x1814a6
	closetext
	loadmovesprites
	spriteface $2, $1
	applymovement $0, MovementData_0x1814a4
	dotrigger $1
	pause 15
	writebyte $2
	special $003e
	setbit1 $0044
	setbit1 $077c
	setbit1 $06c4
	clearbit1 $0762
	setbit1 $0737
	clearbit1 $0738
	domaptrigger GROUP_SPROUT_TOWER_3F, MAP_SPROUT_TOWER_3F, $1
	special $001b
	checkbit1 $0024
	iftrue UnknownScript_0x181497
	specialphonecall $5
UnknownScript_0x181497: ; 0x181497
	halloffame
	end
; 0x181499

MovementData_0x181499: ; 0x181499
	step_up
	step_up
	step_up
	step_up
	step_up
	step_up
	step_up
	step_up
	step_right
	turn_head_left
	step_end
; 0x1814a4

MovementData_0x1814a4: ; 0x1814a4
	slow_step_up
	step_end
; 0x1814a6

UnknownText_0x1814a6: ; 0x1814a6
	db $0, "LANCE: It's been a", $4f
	db "long time since I", $55
	db "last came here.", $51
	db "This is where we", $4f
	db "honor the LEAGUE", $51
	db "CHAMPIONS for all", $4f
	db "eternity.", $51
	db "Their courageous", $4f
	db "#MON are also", $55
	db "inducted.", $51
	db "Here today, we", $4f
	db "witnessed the rise", $51
	db "of a new LEAGUE", $4f
	db "CHAMPION--a", $51
	db "trainer who feels", $4f
	db "compassion for,", $51
	db "and trust toward,", $4f
	db "all #MON.", $51
	db "A trainer who", $4f
	db "succeeded through", $51
	db "perseverance and", $4f
	db "determination.", $51
	db "The new LEAGUE", $4f
	db "CHAMPION who has", $51
	db "all the makings", $4f
	db "of greatness!", $51
	db $14, ", allow me", $4f
	db "to register you", $51
	db "and your partners", $4f
	db "as CHAMPIONS!", $57
; 0x181678

HallOfFame_MapEventHeader: ; 0x181678
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $d, $4, 3, GROUP_LANCES_ROOM, MAP_LANCES_ROOM
	warp_def $d, $5, 4, GROUP_LANCES_ROOM, MAP_LANCES_ROOM

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $1e, 16, 8, $7, $0, 255, 255, $0, 0, ObjectEvent, $ffff
; 0x181695

BulbasaurPokedexEntry: ; 0x181695
	db "SEED@" ; species name
	dw 204, 150; height, width
	
	db "While it is young,", $4e, "it uses the", $4e, "nutrients that are@"
	db "stored in the", $4e, "seeds on its back", $4e, "in order to grow.@"
; 0x181702

IvysaurPokedexEntry: ; 0x181702
	db "SEED@" ; species name
	dw 303, 290; height, width
	
	db "The bulb on its", $4e, "back grows as it", $4e, "absorbs nutrients.@"
	db "The bulb gives off", $4e, "a pleasant aroma", $4e, "when it blooms.@"
; 0x181773

VenusaurPokedexEntry: ; 0x181773
	db "SEED@" ; species name
	dw 607, 2210; height, width
	
	db "As it warms it-", $4e, "self and absorbs", $4e, "the sunlight, its@"
	db "flower petals", $4e, "release a pleasant", $4e, "fragrance.@"
; 0x1817db

CharmanderPokedexEntry: ; 0x1817db
	db "LIZARD@" ; species name
	dw 200, 190; height, width
	
	db "If it's healthy,", $4e, "the flame on the", $4e, "tip of its tail@"
	db "will burn vigor-", $4e, "ously, even if it", $4e, "gets a bit wet.@"
; 0x18184a

CharmeleonPokedexEntry: ; 0x18184a
	db "FLAME@" ; species name
	dw 307, 420; height, width
	
	db "If it becomes", $4e, "agitated during", $4e, "battle, it spouts@"
	db "intense flames,", $4e, "incinerating its", $4e, "surroundings.@"
; 0x1818b3

CharizardPokedexEntry: ; 0x1818b3
	db "FLAME@" ; species name
	dw 507, 2000; height, width
	
	db "It uses its wings", $4e, "to fly high. The", $4e, "temperature of its@"
	db "fire increases as", $4e, "it gains exper-", $4e, "ience in battle.@"
; 0x181926

SquirtlePokedexEntry: ; 0x181926
	db "TINYTURTLE@" ; species name
	dw 108, 200; height, width
	
	db "When it feels", $4e, "threatened, it", $4e, "draws its legs@"
	db "inside its shell", $4e, "and sprays water", $4e, "from its mouth.@"
; 0x181993

WartortlePokedexEntry: ; 0x181993
	db "TURTLE@" ; species name
	dw 303, 500; height, width
	
	db "Its long, furry", $4e, "tail is a symbol", $4e, "of longevity,@"
	db "making it quite", $4e, "popular among", $4e, "older people.@"
; 0x1819f9

BlastoisePokedexEntry: ; 0x1819f9
	db "SHELLFISH@" ; species name
	dw 503, 1890; height, width
	
	db "It firmly plants", $4e, "its feet on the", $4e, "ground before@"
	db "shooting water", $4e, "from the jets on", $4e, "its back.@"
; 0x181a60

CaterpiePokedexEntry: ; 0x181a60
	db "WORM@" ; species name
	dw 100, 60; height, width
	
	db "It crawls into", $4e, "foliage where it", $4e, "camouflages itself@"
	db "among leaves that", $4e, "are the same color", $4e, "as its body.@"
; 0x181ace

MetapodPokedexEntry: ; 0x181ace
	db "COCOON@" ; species name
	dw 204, 220; height, width
	
	db "This is its pre-", $4e, "evolved form. At", $4e, "this stage, it can@"
	db "only harden, so it", $4e, "remains motionless", $4e, "to avoid attack.@"
; 0x181b45

ButterfreePokedexEntry: ; 0x181b45
	db "BUTTERFLY@" ; species name
	dw 307, 710; height, width
	
	db "It flits from", $4e, "flower to flower,", $4e, "collecting honey.@"
	db "It can even", $4e, "identify distant", $4e, "flowers in bloom.@"
; 0x181bb4

WeedlePokedexEntry: ; 0x181bb4
	db "HAIRY BUG@" ; species name
	dw 100, 70; height, width
	
	db "The barb on top of", $4e, "its head secretes", $4e, "a strong poison.@"
	db "It uses this toxic", $4e, "barb to protect", $4e, "itself.@"
; 0x181c23

KakunaPokedexEntry: ; 0x181c23
	db "COCOON@" ; species name
	dw 200, 220; height, width
	
	db "Nearly incapable", $4e, "of movement, it", $4e, "leans against@"
	db "stout trees while", $4e, "waiting for its", $4e, "evolution.@"
; 0x181c8a

BeedrillPokedexEntry: ; 0x181c8a
	db "POISON BEE@" ; species name
	dw 303, 650; height, width
	
	db "It uses sharp,", $4e, "poisonous stings", $4e, "to defeat prey,@"
	db "then takes the", $4e, "victim back to its", $4e, "nest for food.@"
; 0x181cfa

PidgeyPokedexEntry: ; 0x181cfa
	db "TINY BIRD@" ; species name
	dw 100, 40; height, width
	
	db "It rapidly flaps", $4e, "its wings in the", $4e, "grass, stirring up@"
	db "a dust cloud that", $4e, "drives insect prey", $4e, "out into the open.@"
; 0x181d75

PidgeottoPokedexEntry: ; 0x181d75
	db "BIRD@" ; species name
	dw 307, 660; height, width
	
	db "It slowly flies in", $4e, "a circular pat-", $4e, "tern, all the@"
	db "while keeping a", $4e, "sharp lookout for", $4e, "prey.@"
; 0x181dd7

PidgeotPokedexEntry: ; 0x181dd7
	db "BIRD@" ; species name
	dw 411, 870; height, width
	
	db "Its outstanding", $4e, "vision allows it", $4e, "to spot splashing@"
	db "MAGIKARP, even", $4e, "while flying at", $4e, "3300 feet.@"
; 0x181e3d

RattataPokedexEntry: ; 0x181e3d
	db "RAT@" ; species name
	dw 100, 80; height, width
	
	db "This #MON's", $4e, "impressive vital-", $4e, "ity allows it to@"
	db "live anywhere. It", $4e, "also multiplies", $4e, "very quickly.@"
; 0x181ea3

RaticatePokedexEntry: ; 0x181ea3
	db "RAT@" ; species name
	dw 204, 410; height, width
	
	db "The webs on its", $4e, "hind legs enable", $4e, "it to cross@"
	db "rivers. It search-", $4e, "es wide areas for", $4e, "food.@"
; 0x181f03

SpearowPokedexEntry: ; 0x181f03
	db "TINY BIRD@" ; species name
	dw 100, 40; height, width
	
	db "To protect its", $4e, "territory, it", $4e, "flies around@"
	db "ceaselessly,", $4e, "making high-", $4e, "pitched cries.@"
; 0x181f64

FearowPokedexEntry: ; 0x181f64
	db "BEAK@" ; species name
	dw 311, 840; height, width
	
	db "It uses its long", $4e, "beak to attack. It", $4e, "has a surprisingly@"
	db "long reach, so it", $4e, "must be treated", $4e, "with caution.@"
; 0x181fd4

EkansPokedexEntry: ; 0x181fd4
	db "SNAKE@" ; species name
	dw 607, 150; height, width
	
	db "It flutters the", $4e, "tip of its tongue", $4e, "to seek out the@"
	db "scent of prey,", $4e, "then swallows the", $4e, "prey whole.@"
; 0x18203d

ArbokPokedexEntry: ; 0x18203d
	db "COBRA@" ; species name
	dw 1106, 1430; height, width
	
	db "To intimidate", $4e, "foes, it spreads", $4e, "its chest wide and@"
	db "makes eerie sounds", $4e, "by expelling air", $4e, "from its mouth.@"
; 0x1820ad

PikachuPokedexEntry: ; 0x1820ad
	db "MOUSE@" ; species name
	dw 104, 130; height, width
	
	db "When it is anger-", $4e, "ed, it immediately", $4e, "discharges the@"
	db "energy stored in", $4e, "the pouches in its", $4e, "cheeks.@"
; 0x182117

RaichuPokedexEntry: ; 0x182117
	db "MOUSE@" ; species name
	dw 207, 660; height, width
	
	db "If its electric", $4e, "pouches run empty,", $4e, "it raises its tail@"
	db "to gather electri-", $4e, "city from the", $4e, "atmosphere.@"
; 0x182184

SandshrewPokedexEntry: ; 0x182184
	db "MOUSE@" ; species name
	dw 200, 260; height, width
	
	db "It prefers dry,", $4e, "sandy places", $4e, "because it uses@"
	db "the sand to", $4e, "protect itself", $4e, "when threatened.@"
; 0x1821e7

SandslashPokedexEntry: ; 0x1821e7
	db "MOUSE@" ; species name
	dw 303, 650; height, width
	
	db "Adept at climbing", $4e, "trees, it rolls", $4e, "into a spiny ball,@"
	db "then attacks its", $4e, "enemies from", $4e, "above.@"
; 0x18224b

NidoranFPokedexEntry: ; 0x18224b
	db "POISON PIN@" ; species name
	dw 104, 150; height, width
	
	db "Small and very", $4e, "docile, it pro-", $4e, "tects itself with@"
	db "its small, poison-", $4e, "ous horn when", $4e, "attacked.@"
; 0x1822b6

NidorinaPokedexEntry: ; 0x1822b6
	db "POISON PIN@" ; species name
	dw 207, 440; height, width
	
	db "It has a docile", $4e, "nature. If it is", $4e, "threatened with@"
	db "attack, it raises", $4e, "the barbs that are", $4e, "all over its body.@"
; 0x18232e

NidoqueenPokedexEntry: ; 0x18232e
	db "DRILL@" ; species name
	dw 403, 1320; height, width
	
	db "The hard scales", $4e, "that cover its", $4e, "strong body serve@"
	db "as excellent", $4e, "protection from", $4e, "any attack.@"
; 0x182392

NidoranMPokedexEntry: ; 0x182392
	db "POISON PIN@" ; species name
	dw 108, 200; height, width
	
	db "It constantly", $4e, "moves its large", $4e, "ears in many@"
	db "directions in", $4e, "order to detect", $4e, "danger right away.@"
; 0x1823fd

NidorinoPokedexEntry: ; 0x1823fd
	db "POISON PIN@" ; species name
	dw 211, 430; height, width
	
	db "It is easily", $4e, "agitated and uses", $4e, "its horn for@"
	db "offense as soon as", $4e, "it notices an", $4e, "attacker.@"
; 0x182463

NidokingPokedexEntry: ; 0x182463
	db "DRILL@" ; species name
	dw 407, 1370; height, width
	
	db "It uses its thick", $4e, "arms, legs and", $4e, "tail to attack@"
	db "forcefully. Melee", $4e, "combat is its", $4e, "specialty.@"
; 0x1824c8

ClefairyPokedexEntry: ; 0x1824c8
	db "FAIRY@" ; species name
	dw 200, 170; height, width
	
	db "Though rarely", $4e, "seen, it becomes", $4e, "easier to spot,@"
	db "for some reason,", $4e, "on the night of a ", $4e, "full moon.@"
; 0x182530

ClefablePokedexEntry: ; 0x182530
	db "FAIRY@" ; species name
	dw 403, 880; height, width
	
	db "Said to live in", $4e, "quiet, remote", $4e, "mountains, this@"
	db "type of fairy has", $4e, "a strong aversion", $4e, "to being seen.@"
; 0x18259b

VulpixPokedexEntry: ; 0x18259b
	db "FOX@" ; species name
	dw 200, 220; height, width
	
	db "As its body grows", $4e, "larger, its six", $4e, "warm tails become@"
	db "more beautiful,", $4e, "with a more luxur-", $4e, "ious coat of fur.@"
; 0x18260c

NinetalesPokedexEntry: ; 0x18260c
	db "FOX@" ; species name
	dw 307, 440; height, width
	
	db "It is said to live", $4e, "a thousand years,", $4e, "and each of its@"
	db "tails is loaded", $4e, "with supernatural", $4e, "powers.@"
; 0x182673

JigglypuffPokedexEntry: ; 0x182673
	db "BALLOON@" ; species name
	dw 108, 120; height, width
	
	db "It rolls its cute", $4e, "eyes as it sings a", $4e, "soothing lullaby.@"
	db "Its gentle song", $4e, "puts anyone who", $4e, "hears it to sleep.@"
; 0x1826e9

WigglytuffPokedexEntry: ; 0x1826e9
	db "BALLOON@" ; species name
	dw 303, 260; height, width
	
	db "The rich, fluffy", $4e, "fur that covers", $4e, "its body feels so@"
	db "good that anyone", $4e, "who feels it can't", $4e, "stop touching it.@"
; 0x18275d

ZubatPokedexEntry: ; 0x18275d
	db "BAT@" ; species name
	dw 207, 170; height, width
	
	db "During the day, it", $4e, "gathers with", $4e, "others and hangs@"
	db "from the ceilings", $4e, "of old buildings", $4e, "and caves.@"
; 0x1827c4

GolbatPokedexEntry: ; 0x1827c4
	db "BAT@" ; species name
	dw 503, 1210; height, width
	
	db "When it plunges", $4e, "its fangs into its", $4e, "prey, it instantly@"
	db "draws and gulps", $4e, "down more than ten", $4e, "ounces of blood.@"
; 0x182836

OddishPokedexEntry: ; 0x182836
	db "WEED@" ; species name
	dw 108, 120; height, width
	
	db "During the day, it", $4e, "stays in the cold", $4e, "underground to@"
	db "avoid the sun.", $4e, "It grows by bath-", $4e, "ing in moonlight.@"
; 0x1828a6

GloomPokedexEntry: ; 0x1828a6
	db "WEED@" ; species name
	dw 207, 190; height, width
	
	db "The smell from its", $4e, "drool-like syrup", $4e, "and the pollen on@"
	db "its petals is so", $4e, "bad, it may make", $4e, "opponents faint.@"
; 0x182918

VileplumePokedexEntry: ; 0x182918
	db "FLOWER@" ; species name
	dw 311, 410; height, width
	
	db "By shaking its big", $4e, "petals, it scat-", $4e, "ters toxic pollen@"
	db "into the air,", $4e, "turning the air", $4e, "yellow.@"
; 0x18297f

ParasPokedexEntry: ; 0x18297f
	db "MUSHROOM@" ; species name
	dw 100, 120; height, width
	
	db "The tochukaso", $4e, "growing on this", $4e, "#MON's back@"
	db "orders it to", $4e, "extract juice from", $4e, "tree trunks.@"
; 0x1829e2

ParasectPokedexEntry: ; 0x1829e2
	db "MUSHROOM@" ; species name
	dw 303, 650; height, width
	
	db "When nothing's", $4e, "left to extract", $4e, "from the bug, the@"
	db "mushrooms on its", $4e, "back leave spores", $4e, "on the bug's egg.@"
; 0x182a53

VenonatPokedexEntry: ; 0x182a53
	db "INSECT@" ; species name
	dw 303, 660; height, width
	
	db "The small bugs it", $4e, "eats appear only", $4e, "at night, so it@"
	db "sleeps in a hole", $4e, "in a tree until", $4e, "night falls.@"
; 0x182abf

VenomothPokedexEntry: ; 0x182abf
	db "POISONMOTH@" ; species name
	dw 411, 280; height, width
	
	db "The scales it", $4e, "scatters will", $4e, "paralyze anyone@"
	db "who touches them,", $4e, "making that person", $4e, "unable to stand.@"
; 0x182b30

DiglettPokedexEntry: ; 0x182b30
	db "MOLE@" ; species name
	dw 8, 20; height, width
	
	db "It digs under-", $4e, "ground and chews", $4e, "on tree roots,@"
	db "sticking its head", $4e, "out only when the", $4e, "sun isn't bright.@"
; 0x182b9d

DugtrioPokedexEntry: ; 0x182b9d
	db "MOLE@" ; species name
	dw 204, 730; height, width
	
	db "These DIGLETT", $4e, "triplets dig over", $4e, "60 miles below sea@"
	db "level. No one", $4e, "knows what it's", $4e, "like underground.@"
; 0x182c08

MeowthPokedexEntry: ; 0x182c08
	db "SCRATCHCAT@" ; species name
	dw 104, 90; height, width
	
	db "It loves things", $4e, "that sparkle. When", $4e, "it sees a shiny@"
	db "object, the gold", $4e, "coin on its head", $4e, "shines too.@"
; 0x182c78

PersianPokedexEntry: ; 0x182c78
	db "CLASSY CAT@" ; species name
	dw 303, 710; height, width
	
	db "Behind its lithe,", $4e, "elegant appearance", $4e, "lies a barbaric@"
	db "side. It will tear", $4e, "apart its prey on", $4e, "a mere whim.@"
; 0x182cee

PsyduckPokedexEntry: ; 0x182cee
	db "DUCK@" ; species name
	dw 207, 430; height, width
	
	db "The only time it", $4e, "can use its psy-", $4e, "chic power is when@"
	db "its sleeping brain", $4e, "cells happen to", $4e, "wake.@"
; 0x182d55

GolduckPokedexEntry: ; 0x182d55
	db "DUCK@" ; species name
	dw 507, 1690; height, width
	
	db "It swims grace-", $4e, "fully along on the", $4e, "quiet, slow-moving@"
	db "rivers and lakes", $4e, "of which it is so", $4e, "fond.@"
; 0x182dbd

MankeyPokedexEntry: ; 0x182dbd
	db "PIG MONKEY@" ; species name
	dw 108, 620; height, width
	
	db "It lives in groups", $4e, "in the treetops.", $4e, "If it loses sight@"
	db "of its group, it", $4e, "becomes infuriated", $4e, "by its loneliness.@"
; 0x182e39

PrimeapePokedexEntry: ; 0x182e39
	db "PIG MONKEY@" ; species name
	dw 303, 710; height, width
	
	db "It will beat up", $4e, "anyone who makes", $4e, "it mad, even if it@"
	db "has to chase them", $4e, "until the end of", $4e, "the world.@"
; 0x182eaa

GrowlithePokedexEntry: ; 0x182eaa
	db "PUPPY@" ; species name
	dw 204, 420; height, width
	
	db "It controls a big", $4e, "territory. If it", $4e, "detects an unknown@"
	db "smell, it roars", $4e, "loudly to force", $4e, "out the intruder.@"
; 0x182f1c

ArcaninePokedexEntry: ; 0x182f1c
	db "LEGENDARY@" ; species name
	dw 603, 3420; height, width
	
	db "An ancient picture", $4e, "scroll shows that", $4e, "people were@"
	db "attracted to its", $4e, "movement as it ran", $4e, "through prairies.@"
; 0x182f91

PoliwagPokedexEntry: ; 0x182f91
	db "TADPOLE@" ; species name
	dw 200, 270; height, width
	
	db "The swirl on its", $4e, "belly is its", $4e, "insides showing@"
	db "through the skin.", $4e, "It looks clearer", $4e, "after it eats.@"
; 0x182ffd

PoliwhirlPokedexEntry: ; 0x182ffd
	db "TADPOLE@" ; species name
	dw 303, 440; height, width
	
	db "Though it is", $4e, "skilled at walk-", $4e, "ing, it prefers to@"
	db "live underwater", $4e, "where there is", $4e, "less danger.@"
; 0x183066

PoliwrathPokedexEntry: ; 0x183066
	db "TADPOLE@" ; species name
	dw 403, 1190; height, width
	
	db "It can use its", $4e, "well-developed", $4e, "arms and legs to@"
	db "run on the surface", $4e, "of the water for a", $4e, "split second.@"
; 0x1830d5

AbraPokedexEntry: ; 0x1830d5
	db "PSI@" ; species name
	dw 211, 430; height, width
	
	db "It hypnotizes", $4e, "itself so that it", $4e, "can teleport away@"
	db "when it senses", $4e, "danger, even", $4e, "if it is asleep.@"
; 0x18313c

KadabraPokedexEntry: ; 0x18313c
	db "PSI@" ; species name
	dw 403, 1250; height, width
	
	db "When it closes its", $4e, "eyes, twice as", $4e, "many alpha parti-@"
	db "cles come out of", $4e, "the surface of its", $4e, "body.@"
; 0x1831a2

INCBIN "baserom.gbc",$1831a2,$e5e

SECTION "bank61",DATA,BANK[$61]

CeruleanCity_MapScriptHeader: ; 0x184000
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x184005
; 0x184005

UnknownScript_0x184005: ; 0x184005
	setbit2 $0038
	return
; 0x184009

UnknownScript_0x184009: ; 0x184009
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x184017
	2writetext UnknownText_0x1840bc
	closetext
	loadmovesprites
	end
; 0x184017

UnknownScript_0x184017: ; 0x184017
	2writetext UnknownText_0x184144
	closetext
	loadmovesprites
	end
; 0x18401d

UnknownScript_0x18401d: ; 0x18401d
	jumptextfaceplayer UnknownText_0x1841a8
; 0x184020

UnknownScript_0x184020: ; 0x184020
	loadfont
	2writetext UnknownText_0x1841e9
	cry SLOWBRO
	closetext
	loadmovesprites
	end
; 0x18402a

UnknownScript_0x18402a: ; 0x18402a
	faceplayer
	loadfont
	2writetext UnknownText_0x1841fa
	closetext
	loadmovesprites
	spriteface $5, $2
	loadfont
	2writetext UnknownText_0x184229
	closetext
	loadmovesprites
	loadfont
	2writetext UnknownText_0x1841e9
	cry SLOWBRO
	closetext
	loadmovesprites
	loadfont
	2writetext UnknownText_0x18424b
	closetext
	loadmovesprites
	end
; 0x18404a

UnknownScript_0x18404a: ; 0x18404a
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x184058
	checkbit1 $00cb
	iftrue UnknownScript_0x18405e
UnknownScript_0x184058: ; 0x184058
	2writetext UnknownText_0x18424e
	closetext
	loadmovesprites
	end
; 0x18405e

UnknownScript_0x18405e: ; 0x18405e
	2writetext UnknownText_0x184275
	closetext
	loadmovesprites
	end
; 0x184064

UnknownScript_0x184064: ; 0x184064
	faceplayer
	loadfont
	2writetext UnknownText_0x1842a9
	closetext
	loadmovesprites
	checkbit1 $00fa
	iffalse UnknownScript_0x184072
	end
; 0x184072

UnknownScript_0x184072: ; 0x184072
	waitbutton
	playsound $0012
	waitbutton
	playsound $0022
	waitbutton
	playsound $0012
	waitbutton
	playsound $0022
	waitbutton
	playsound $0012
	waitbutton
	playsound $0022
	waitbutton
	playsound $0012
	waitbutton
	playsound $0022
	waitbutton
	showemote $0, $7, 15
	spriteface $7, $2
	loadfont
	2writetext UnknownText_0x1842ee
	closetext
	loadmovesprites
	end
; 0x1840a1

MapCeruleanCitySignpost0Script: ; 0x1840a1
	jumptext UnknownText_0x184312
; 0x1840a4

MapCeruleanCitySignpost1Script: ; 0x1840a4
	jumptext UnknownText_0x184345
; 0x1840a7

MapCeruleanCitySignpost2Script: ; 0x1840a7
	jumptext UnknownText_0x184381
; 0x1840aa

MapCeruleanCitySignpost3Script: ; 0x1840aa
	jumptext UnknownText_0x1843cc
; 0x1840ad

MapCeruleanCitySignpost4Script: ; 0x1840ad
	jumptext UnknownText_0x18443b
; 0x1840b0

MapCeruleanCitySignpost5Script: ; 0x1840b0
	jumptext UnknownText_0x184450
; 0x1840b3

MapCeruleanCitySignpost6Script: ; 0x1840b3
	jumpstd $0010
; 0x1840b6

MapCeruleanCitySignpost7Script: ; 0x1840b6
	jumpstd $0011
; 0x1840b9

MapCeruleanCitySignpostItem8: ; 0x1840b9
	dw $00fa
	db BERSERK_GENE
	
; 0x1840bc

UnknownText_0x1840bc: ; 0x1840bc
	db $0, "KANTO's POWER", $4f
	db "PLANT?", $51
	db "It's near the end", $4f
	db "of ROUTE 9, the", $51
	db "road that heads", $4f
	db "east from here.", $51
	db "I think there was", $4f
	db "an accident of", $55
	db "some sort there.", $57
; 0x184144

UnknownText_0x184144: ; 0x184144
	db $0, "You're collecting", $4f
	db "every single kind", $55
	db "of #MON?", $51
	db "That must be quite", $4f
	db "a challenge, but", $55
	db "it sounds fun too.", $57
; 0x1841a8

UnknownText_0x1841a8: ; 0x1841a8
	db $0, "The CAPE in the", $4f
	db "north is a good", $51
	db "place for dates.", $4f
	db "Girls like it!", $57
; 0x1841e9

UnknownText_0x1841e9: ; 0x1841e9
	db $0, "SLOWBRO: Yarah?", $57
; 0x1841fa

UnknownText_0x1841fa: ; 0x1841fa
	db $0, "My SLOWBRO and I", $4f
	db "make an awesome", $55
	db "combination!", $57
; 0x184229

UnknownText_0x184229: ; 0x184229
	db $0, "SLOWBRO, show me", $4f
	db "your CONFUSION!", $57
; 0x18424b

UnknownText_0x18424b: ; 0x18424b
	db $0, "…", $57
; 0x18424e

UnknownText_0x18424e: ; 0x18424e
	db $0, "I'm a huge fan of", $4f
	db "CERULEAN GYM's", $55
	db "MISTY.", $57
; 0x184275

UnknownText_0x184275: ; 0x184275
	db $0, "I saw this shady", $4f
	db "guy go off toward", $55
	db "CERULEAN's CAPE.", $57
; 0x1842a9

UnknownText_0x1842a9: ; 0x1842a9
	db $0, "There used to be a", $4f
	db "cave here that had", $51
	db "horribly powerful", $4f
	db "#MON in it.", $57
; 0x1842ee

UnknownText_0x1842ee: ; 0x1842ee
	db $0, "Ayuh?", $51
	db "My ITEMFINDER is", $4f
	db "responding…", $57
; 0x184312

UnknownText_0x184312: ; 0x184312
	db $0, "CERULEAN CITY", $51
	db "A Mysterious Blue", $4f
	db "Aura Surrounds It", $57
; 0x184345

UnknownText_0x184345: ; 0x184345
	db $0, "CERULEAN CITY", $4f
	db "#MON GYM", $55
	db "LEADER: MISTY", $51
	db "The Tomboyish", $4f
	db "Mermaid", $57
; 0x184381

UnknownText_0x184381: ; 0x184381
	db $0, "There's a notice", $4f
	db "here…", $51
	db "The BIKE SHOP has", $4f
	db "moved to GOLDENROD", $55
	db "CITY in JOHTO…", $57
; 0x1843cc

UnknownText_0x1843cc: ; 0x1843cc
	db $0, "There's a notice", $4f
	db "here…", $51
	db "Stamp out thievery", $4f
	db "and make the city", $51
	db "a friendlier, more", $4f
	db "cheerful place!", $51
	db "CERULEAN POLICE", $57
; 0x18443b

UnknownText_0x18443b: ; 0x18443b
	db $0, "CERULEAN CAPE", $4f
	db "AHEAD", $57
; 0x184450

UnknownText_0x184450: ; 0x184450
	db $0, "It's locked…", $57
; 0x18445d

CeruleanCity_MapEventHeader: ; 0x18445d
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $f, $7, 1, GROUP_CERULEAN_GYM_BADGE_SPEECH_HOUSE, MAP_CERULEAN_GYM_BADGE_SPEECH_HOUSE
	warp_def $11, $1c, 1, GROUP_CERULEAN_POLICE_STATION, MAP_CERULEAN_POLICE_STATION
	warp_def $13, $d, 1, GROUP_CERULEAN_TRADE_SPEECH_HOUSE, MAP_CERULEAN_TRADE_SPEECH_HOUSE
	warp_def $15, $13, 1, GROUP_CERULEAN_POKECENTER_1F, MAP_CERULEAN_POKECENTER_1F
	warp_def $17, $1e, 1, GROUP_CERULEAN_GYM, MAP_CERULEAN_GYM
	warp_def $1d, $19, 2, GROUP_CERULEAN_MART, MAP_CERULEAN_MART

	; xy triggers
	db 0

	; signposts
	db 9
	signpost 23, 23, $0, MapCeruleanCitySignpost0Script
	signpost 25, 27, $0, MapCeruleanCitySignpost1Script
	signpost 29, 11, $0, MapCeruleanCitySignpost2Script
	signpost 17, 25, $0, MapCeruleanCitySignpost3Script
	signpost 7, 23, $0, MapCeruleanCitySignpost4Script
	signpost 29, 14, $0, MapCeruleanCitySignpost5Script
	signpost 21, 20, $0, MapCeruleanCitySignpost6Script
	signpost 29, 26, $0, MapCeruleanCitySignpost7Script
	signpost 12, 2, $7, MapCeruleanCitySignpostItem8

	; people-events
	db 6
	person_event $23, 27, 19, $2, $22, 255, 255, $90, 0, UnknownScript_0x184009, $ffff
	person_event $2b, 19, 27, $2, $11, 255, 255, $90, 0, UnknownScript_0x18401d, $ffff
	person_event $45, 28, 24, $1, $0, 255, 255, $0, 0, UnknownScript_0x184020, $ffff
	person_event $24, 28, 25, $8, $0, 255, 255, $a0, 0, UnknownScript_0x18402a, $ffff
	person_event $3a, 30, 34, $5, $1, 255, 255, $80, 0, UnknownScript_0x18404a, $ffff
	person_event $27, 16, 10, $3, $1, 255, 255, $80, 0, UnknownScript_0x184064, $ffff
; 0x1844fc

SproutTower1F_MapScriptHeader: ; 0x1844fc
	; trigger count
	db 0

	; callback count
	db 0
; 0x1844fe

UnknownScript_0x1844fe: ; 0x1844fe
	jumptextfaceplayer UnknownText_0x1845d8
; 0x184501

UnknownScript_0x184501: ; 0x184501
	jumptextfaceplayer UnknownText_0x18460a
; 0x184504

UnknownScript_0x184504: ; 0x184504
	jumptextfaceplayer UnknownText_0x184649
; 0x184507

UnknownScript_0x184507: ; 0x184507
	jumptextfaceplayer UnknownText_0x18469d
; 0x18450a

TrainerSageChow: ; 0x18450a
	; bit/flag number
	dw $411

	; trainer group && trainer id
	db SAGE, CHOW

	; text when seen
	dw SageChowSeenText

	; text when trainer beaten
	dw SageChowBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageChowScript
; 0x184516

SageChowScript: ; 0x184516
	talkaftercancel
	loadfont
	2writetext UnknownText_0x184583
	closetext
	loadmovesprites
	end
; 0x18451e

ItemFragment_0x18451e: ; 0x18451e
	db PARLYZ_HEAL, 1
; 0x184520

MapSproutTower1FSignpost1Script: ; 0x184520
	jumptext UnknownText_0x1846d6
; 0x184523

SageChowSeenText: ; 0x184523
	db $0, "We stand guard in", $4f
	db "this tower.", $51
	db "Here, we express", $4f
	db "our gratitude to", $55
	db "honor all #MON.", $57
; 0x184574

SageChowBeatenText: ; 0x184574
	db $0, "Th-Thank you!", $57
; 0x184583

UnknownText_0x184583: ; 0x184583
	db $0, "All living beings", $4f
	db "coexist through", $55
	db "cooperation.", $51
	db "We must always be", $4f
	db "thankful for this.", $57
; 0x1845d8

UnknownText_0x1845d8: ; 0x1845d8
	db $0, "Only if you reach", $4f
	db "the top will you", $55
	db "obtain an HM.", $57
; 0x18460a

UnknownText_0x18460a: ; 0x18460a
	db $0, "SPROUT TOWER was", $4f
	db "built long ago", $51
	db "as a place for", $4f
	db "#MON training.", $57
; 0x184649

UnknownText_0x184649: ; 0x184649
	db $0, "A BELLSPROUT over", $4f
	db "100 feet tall…", $51
	db "People say that it", $4f
	db "became the center", $55
	db "pillar here.", $57
; 0x18469d

UnknownText_0x18469d: ; 0x18469d
	db $0, "See the pillar", $4f
	db "shaking?", $51
	db "People are train-", $4f
	db "ing upstairs.", $57
; 0x1846d6

UnknownText_0x1846d6: ; 0x1846d6
	db $0, "A #MON statue…", $51
	db "It looks very", $4f
	db "distinguished.", $57
; 0x184703

SproutTower1F_MapEventHeader: ; 0x184703
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $f, $9, 7, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $f, $a, 7, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $4, $6, 1, GROUP_SPROUT_TOWER_2F, MAP_SPROUT_TOWER_2F
	warp_def $6, $2, 2, GROUP_SPROUT_TOWER_2F, MAP_SPROUT_TOWER_2F
	warp_def $3, $11, 3, GROUP_SPROUT_TOWER_2F, MAP_SPROUT_TOWER_2F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 15, 7, $0, MapSproutTower1FSignpost1Script
	signpost 15, 12, $0, MapSproutTower1FSignpost1Script

	; people-events
	db 6
	person_event $3e, 8, 11, $6, $0, 255, 255, $90, 0, UnknownScript_0x1844fe, $ffff
	person_event $3e, 11, 10, $2, $11, 255, 255, $90, 0, UnknownScript_0x184501, $ffff
	person_event $30, 16, 15, $8, $0, 255, 255, $0, 0, UnknownScript_0x184504, $ffff
	person_event $29, 13, 13, $7, $0, 255, 255, $0, 0, UnknownScript_0x184507, $ffff
	person_event $3e, 9, 7, $7, $0, 255, 255, $92, 4, TrainerSageChow, $ffff
	person_event $54, 11, 20, $1, $0, 255, 255, $1, 0, ItemFragment_0x18451e, $0647
; 0x18477a

SproutTower2F_MapScriptHeader: ; 0x18477a
	; trigger count
	db 0

	; callback count
	db 0
; 0x18477c

TrainerSageNico: ; 0x18477c
	; bit/flag number
	dw $412

	; trainer group && trainer id
	db SAGE, NICO

	; text when seen
	dw SageNicoSeenText

	; text when trainer beaten
	dw SageNicoBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageNicoScript
; 0x184788

SageNicoScript: ; 0x184788
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1847ff
	closetext
	loadmovesprites
	end
; 0x184790

TrainerSageEdmond: ; 0x184790
	; bit/flag number
	dw $417

	; trainer group && trainer id
	db SAGE, EDMOND

	; text when seen
	dw SageEdmondSeenText

	; text when trainer beaten
	dw SageEdmondBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageEdmondScript
; 0x18479c

SageEdmondScript: ; 0x18479c
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18486f
	closetext
	loadmovesprites
	end
; 0x1847a4

MapSproutTower2FSignpost0Script: ; 0x1847a4
	jumptext UnknownText_0x1848c8
; 0x1847a7

ItemFragment_0x1847a7: ; 0x1847a7
	db X_ACCURACY, 1
; 0x1847a9

SageNicoSeenText: ; 0x1847a9
	db $0, "However hard we", $4f
	db "battle, the TOWER", $55
	db "will stand strong.", $57
; 0x1847df

SageNicoBeatenText: ; 0x1847df
	db $0, "I fought hard but", $4f
	db "I'm too weak.", $57
; 0x1847ff

UnknownText_0x1847ff: ; 0x1847ff
	db $0, "The flexible pil-", $4f
	db "lar protects the", $51
	db "TOWER, even from", $4f
	db "earthquakes.", $57
; 0x184841

SageEdmondSeenText: ; 0x184841
	db $0, "…Sway like leaves", $4f
	db "in the wind…", $57
; 0x184861

SageEdmondBeatenText: ; 0x184861
	db $0, "Oh, I'm weak!", $57
; 0x18486f

UnknownText_0x18486f: ; 0x18486f
	db $0, "I tried to copy", $4f
	db "BELLSPROUT's", $51
	db "gentle movements", $4f
	db "for battle…", $51
	db "But I didn't train", $4f
	db "well enough.", $57
; 0x1848c8

UnknownText_0x1848c8: ; 0x1848c8
	db $0, "A #MON statue…", $51
	db "It looks very", $4f
	db "distinguished.", $57
; 0x1848f5

SproutTower2F_MapEventHeader: ; 0x1848f5
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $6, 3, GROUP_SPROUT_TOWER_1F, MAP_SPROUT_TOWER_1F
	warp_def $6, $2, 4, GROUP_SPROUT_TOWER_1F, MAP_SPROUT_TOWER_1F
	warp_def $3, $11, 5, GROUP_SPROUT_TOWER_1F, MAP_SPROUT_TOWER_1F
	warp_def $e, $a, 1, GROUP_SPROUT_TOWER_3F, MAP_SPROUT_TOWER_3F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 15, 12, $0, MapSproutTower2FSignpost0Script

	; people-events
	db 3
	person_event $3e, 7, 16, $a, $0, 255, 255, $92, 4, TrainerSageNico, $ffff
	person_event $3e, 18, 13, $8, $0, 255, 255, $92, 5, TrainerSageEdmond, $ffff
	person_event $54, 5, 7, $1, $0, 255, 255, $1, 0, ItemFragment_0x1847a7, $0648
; 0x18493b

SproutTower3F_MapScriptHeader: ; 0x18493b
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x184945, $0000
	dw UnknownScript_0x184946, $0000

	; callback count
	db 0
; 0x184945

UnknownScript_0x184945: ; 0x184945
	end
; 0x184946

UnknownScript_0x184946: ; 0x184946
	end
; 0x184947

UnknownScript_0x184947: ; 0x184947
	spriteface $0, $1
	showemote $0, $0, 15
	special $006a
	playsound $0041
	playsound $006e
	earthquake 79
	pause 15
	playsound $0041
	playsound $006e
	earthquake 79
	applymovement $0, MovementData_0x184a1d
	applymovement $8, MovementData_0x184a22
	loadfont
	2writetext UnknownText_0x184a27
	closetext
	loadmovesprites
	showemote $0, $8, 15
	spriteface $8, $0
	pause 15
	applymovement $8, MovementData_0x184a24
	playmusic $001f
	loadfont
	2writetext UnknownText_0x184aec
	closetext
	loadmovesprites
	spriteface $8, $1
	loadfont
	2writetext UnknownText_0x184bc8
	pause 15
	loadmovesprites
	playsound $0013
	special $0030
	special $0033
	disappear $8
	waitbutton
	special $0032
	dotrigger $1
	special $003d
	end
; 0x1849a6

SageLiScript: ; 0x1849a6
	faceplayer
	loadfont
	checkbit1 $0014
	iftrue UnknownScript_0x1849d1
	2writetext SageLiSeenText
	closetext
	loadmovesprites
	winlosstext SageLiBeatenText, $0000
	loadtrainer SAGE, LI
	startbattle
	returnafterbattle
	loadfont
	2writetext UnknownText_0x184cc2
	keeptextopen
	verbosegiveitem HM_05, 1
	setbit1 $0014
	setbit1 $0419
	2writetext UnknownText_0x184d13
	closetext
	loadmovesprites
	end
; 0x1849d1

UnknownScript_0x1849d1: ; 0x1849d1
	2writetext UnknownText_0x184d88
	closetext
	loadmovesprites
	end
; 0x1849d7

TrainerSageJin: ; 0x1849d7
	; bit/flag number
	dw $413

	; trainer group && trainer id
	db SAGE, JIN

	; text when seen
	dw SageJinSeenText

	; text when trainer beaten
	dw SageJinBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageJinScript
; 0x1849e3

SageJinScript: ; 0x1849e3
	talkaftercancel
	loadfont
	2writetext UnknownText_0x184dfa
	closetext
	loadmovesprites
	end
; 0x1849eb

TrainerSageTroy: ; 0x1849eb
	; bit/flag number
	dw $414

	; trainer group && trainer id
	db SAGE, TROY

	; text when seen
	dw SageTroySeenText

	; text when trainer beaten
	dw SageTroyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageTroyScript
; 0x1849f7

SageTroyScript: ; 0x1849f7
	talkaftercancel
	loadfont
	2writetext UnknownText_0x184ea4
	closetext
	loadmovesprites
	end
; 0x1849ff

TrainerSageNeal: ; 0x1849ff
	; bit/flag number
	dw $418

	; trainer group && trainer id
	db SAGE, NEAL

	; text when seen
	dw SageNealSeenText

	; text when trainer beaten
	dw SageNealBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SageNealScript
; 0x184a0b

SageNealScript: ; 0x184a0b
	talkaftercancel
	loadfont
	2writetext UnknownText_0x184f12
	closetext
	loadmovesprites
	end
; 0x184a13

MapSproutTower3FSignpost3Script: ; 0x184a13
	jumptext UnknownText_0x184f37
; 0x184a16

MapSproutTower3FSignpost5Script: ; 0x184a16
	jumptext UnknownText_0x184f61
; 0x184a19

ItemFragment_0x184a19: ; 0x184a19
	db POTION, 1
; 0x184a1b

ItemFragment_0x184a1b: ; 0x184a1b
	db ESCAPE_ROPE, 1
; 0x184a1d

MovementData_0x184a1d: ; 0x184a1d
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x184a22

MovementData_0x184a22: ; 0x184a22
	step_up
	step_end
; 0x184a24

MovementData_0x184a24: ; 0x184a24
	step_right
	step_down
	step_end
; 0x184a27

UnknownText_0x184a27: ; 0x184a27
	db $0, "ELDER: You are in-", $4f
	db "deed skilled as a", $55
	db "trainer.", $51
	db "As promised, here", $4f
	db "is your HM.", $51
	db "But let me say", $4f
	db "this: You should", $51
	db "treat your", $4f
	db "#MON better.", $51
	db "The way you battle", $4f
	db "is far too harsh.", $51
	db "#MON are not", $4f
	db "tools of war…", $57
; 0x184aec

UnknownText_0x184aec: ; 0x184aec
	db $0, "…", $4f
	db "…Humph!", $51
	db "He claims to be", $4f
	db "the ELDER but", $55
	db "he's weak.", $51
	db "It stands to", $4f
	db "reason.", $51
	db "I'd never lose to", $4f
	db "fools who babble", $51
	db "about being nice", $4f
	db "to #MON.", $51
	db "I only care about", $4f
	db "strong #MON", $55
	db "that can win.", $51
	db "I really couldn't", $4f
	db "care less about", $55
	db "weak #MON.", $57
; 0x184bc8

UnknownText_0x184bc8: ; 0x184bc8
	db $0, $53, " used an", $4f
	db "ESCAPE ROPE!", $57
; 0x184be0

SageLiSeenText: ; 0x184be0
	db $0, "So good of you to", $4f
	db "come here!", $51
	db "SPROUT TOWER is a", $4f
	db "place of training.", $51
	db "People and #MON", $4f
	db "test their bonds", $51
	db "to build a bright", $4f
	db "future together.", $51
	db "I am the final", $4f
	db "test.", $51
	db "Allow me to check", $4f
	db "the ties between", $51
	db "your #MON and", $4f
	db "you!", $57
; 0x184cb2

SageLiBeatenText: ; 0x184cb2
	db $0, "Ah, excellent!", $57
; 0x184cc2

UnknownText_0x184cc2: ; 0x184cc2
	db $0, "You and your #-", $4f
	db "MON should have", $51
	db "no problem using", $4f
	db "this move.", $51
	db "Take this FLASH", $4f
	db "HM.", $57
; 0x184d13

UnknownText_0x184d13: ; 0x184d13
	db $0, "FLASH illuminates", $4f
	db "even the darkest", $55
	db "of all places.", $51
	db "But to use it out", $4f
	db "of battle, you", $51
	db "need the BADGE", $4f
	db "from VIOLET's GYM.", $57
; 0x184d88

UnknownText_0x184d88: ; 0x184d88
	db $0, "I hope you learn", $4f
	db "and grow from your", $55
	db "journey.", $57
; 0x184db6

SageJinSeenText: ; 0x184db6
	db $0, "I train to find", $4f
	db "enlightenment in", $55
	db "#MON!", $57
; 0x184dde

SageJinBeatenText: ; 0x184dde
	db $0, "My training is", $4f
	db "incomplete…", $57
; 0x184dfa

UnknownText_0x184dfa: ; 0x184dfa
	db $0, "As #MON grow", $4f
	db "stronger, so does", $55
	db "the trainer.", $51
	db "No, wait. As the", $4f
	db "trainer grows", $51
	db "stronger, so do", $4f
	db "the #MON.", $57
; 0x184e60

SageTroySeenText: ; 0x184e60
	db $0, "Let me see how", $4f
	db "much you trust", $55
	db "your #MON.", $57
; 0x184e8a

SageTroyBeatenText: ; 0x184e8a
	db $0, "Yes, your trust is", $4f
	db "real!", $57
; 0x184ea4

UnknownText_0x184ea4: ; 0x184ea4
	db $0, "It is not far to", $4f
	db "the ELDER.", $57
; 0x184ec1

SageNealSeenText: ; 0x184ec1
	db $0, "The ELDER's HM", $4f
	db "lights even pitch-", $55
	db "black darkness.", $57
; 0x184ef3

SageNealBeatenText: ; 0x184ef3
	db $0, "It is my head that", $4f
	db "is bright!", $57
; 0x184f12

UnknownText_0x184f12: ; 0x184f12
	db $0, "Let there be light", $4f
	db "on your journey.", $57
; 0x184f37

UnknownText_0x184f37: ; 0x184f37
	db $0, "It's a powerful", $4f
	db "painting of a", $55
	db "BELLSPROUT.", $57
; 0x184f61

UnknownText_0x184f61: ; 0x184f61
	db $0, "A #MON statue…", $51
	db "It looks very", $4f
	db "distinguished.", $57
; 0x184f8e

SproutTower3F_MapEventHeader: ; 0x184f8e
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $e, $a, 4, GROUP_SPROUT_TOWER_2F, MAP_SPROUT_TOWER_2F

	; xy triggers
	db 1
	xy_trigger 0, $9, $b, $0, UnknownScript_0x184947, $0, $0

	; signposts
	db 6
	signpost 1, 8, $0, MapSproutTower3FSignpost5Script
	signpost 1, 11, $0, MapSproutTower3FSignpost5Script
	signpost 0, 9, $0, MapSproutTower3FSignpost3Script
	signpost 0, 10, $0, MapSproutTower3FSignpost3Script
	signpost 15, 5, $0, MapSproutTower3FSignpost5Script
	signpost 15, 14, $0, MapSproutTower3FSignpost5Script

	; people-events
	db 7
	person_event $3e, 17, 12, $9, $0, 255, 255, $92, 3, TrainerSageJin, $ffff
	person_event $3e, 12, 12, $6, $0, 255, 255, $92, 2, TrainerSageTroy, $ffff
	person_event $3e, 6, 14, $6, $0, 255, 255, $90, 0, SageLiScript, $ffff
	person_event $3e, 15, 15, $8, $0, 255, 255, $92, 3, TrainerSageNeal, $ffff
	person_event $54, 18, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x184a19, $0649
	person_event $54, 5, 18, $1, $0, 255, 255, $1, 0, ItemFragment_0x184a1b, $064a
	person_event $4, 8, 14, $7, $0, 255, 255, $0, 0, ObjectEvent, $06c4
; 0x18501a

TinTower1F_MapScriptHeader: ; 0x18501a
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x18502a, $0000
	dw UnknownScript_0x18502e, $0000

	; callback count
	db 2

	; callbacks

	dbw 2, UnknownScript_0x18502f

	dbw 1, UnknownScript_0x185084
; 0x18502a

UnknownScript_0x18502a: ; 0x18502a
	priorityjump UnknownScript_0x18508f
	end
; 0x18502e

UnknownScript_0x18502e: ; 0x18502e
	end
; 0x18502f

UnknownScript_0x18502f: ; 0x18502f
	checkbit1 $0336
	iftrue UnknownScript_0x185047
	checkbit1 $0044
	iffalse UnknownScript_0x185050
	special $0096
	iffalse UnknownScript_0x185050
	clearbit1 $07c5
	setbit1 $07b6
UnknownScript_0x185047: ; 0x185047
	checkbit1 $0317
	iffalse UnknownScript_0x18504f
	appear $5
UnknownScript_0x18504f: ; 0x18504f
	return
; 0x185050

UnknownScript_0x185050: ; 0x185050
	checkbit1 $0335
	iftrue UnknownScript_0x185077
	appear $2
	writebyte RAIKOU
	special $0097
	iftrue UnknownScript_0x185065
	appear $3
	2jump UnknownScript_0x185067
; 0x185065

UnknownScript_0x185065: ; 0x185065
	disappear $3
UnknownScript_0x185067: ; 0x185067
	writebyte ENTEI
	special $0097
	iftrue UnknownScript_0x185074
	appear $4
	2jump UnknownScript_0x185076
; 0x185074

UnknownScript_0x185074: ; 0x185074
	disappear $4
UnknownScript_0x185076: ; 0x185076
	return
; 0x185077

UnknownScript_0x185077: ; 0x185077
	disappear $2
	disappear $3
	disappear $4
	clearbit1 $07b6
	setbit1 $07c5
	return
; 0x185084

UnknownScript_0x185084: ; 0x185084
	checkbit1 $0336
	iftrue UnknownScript_0x18508e
	changeblock $a, $2, $9
UnknownScript_0x18508e: ; 0x18508e
	return
; 0x18508f

UnknownScript_0x18508f: ; 0x18508f
	applymovement $0, MovementData_0x1851cb
	pause 15
	writebyte RAIKOU
	special $0097
	iftrue UnknownScript_0x1850b6
	applymovement $3, MovementData_0x1851d0
	spriteface $0, $2
	cry RAIKOU
	pause 10
	playsound $0014
	applymovement $3, MovementData_0x1851d4
	disappear $3
	playsound $0023
	waitbutton
UnknownScript_0x1850b6: ; 0x1850b6
	writebyte ENTEI
	special $0097
	iftrue UnknownScript_0x1850d7
	applymovement $4, MovementData_0x1851da
	spriteface $0, $3
	cry ENTEI
	pause 10
	playsound $0014
	applymovement $4, MovementData_0x1851de
	disappear $4
	playsound $0023
	waitbutton
UnknownScript_0x1850d7: ; 0x1850d7
	spriteface $0, $1
	pause 10
	applymovement $0, MovementData_0x1851e8
	applymovement $2, MovementData_0x1851e4
	cry SUICUNE
	pause 20
	loadpokedata SUICUNE, 40
	writecode $3, $c
	startbattle
	reloadmapmusic
	disappear $2
	setbit1 $0335
	setbit1 $07af
	domaptrigger GROUP_ROUTE_42, MAP_ROUTE_42, $0
	setbit1 $07b0
	domaptrigger GROUP_ROUTE_36, MAP_ROUTE_36, $0
	setbit1 $07ae
	domaptrigger GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY, $0
	dotrigger $1
	clearbit1 $07b7
	returnafterbattle
	pause 20
	spriteface $0, $0
	playmusic $0061
	playsound $001f
	moveperson $5, $a, $f
	appear $5
	applymovement $5, MovementData_0x1851ec
	playsound $001f
	moveperson $6, $9, $f
	appear $6
	applymovement $6, MovementData_0x1851f5
	playsound $001f
	moveperson $7, $9, $f
	appear $7
	applymovement $7, MovementData_0x1851fb
	playsound $001f
	moveperson $8, $9, $f
	appear $8
	applymovement $8, MovementData_0x1851fe
	moveperson $6, $7, $d
	moveperson $7, $9, $d
	moveperson $8, $b, $d
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x185203
	closetext
	loadmovesprites
	applymovement $5, MovementData_0x1851f1
	playsound $0023
	disappear $5
	waitbutton
	special $006a
	pause 20
	playmapmusic
	end
; 0x185173

UnknownScript_0x185173: ; 0x185173
	jumptextfaceplayer UnknownText_0x185386
; 0x185176

UnknownScript_0x185176: ; 0x185176
	jumptextfaceplayer UnknownText_0x185433
; 0x185179

UnknownScript_0x185179: ; 0x185179
	jumptextfaceplayer UnknownText_0x185544
; 0x18517c

UnknownScript_0x18517c: ; 0x18517c
	checkbit1 $0317
	iftrue UnknownScript_0x185185
	jumptextfaceplayer UnknownText_0x1855ee
; 0x185185

UnknownScript_0x185185: ; 0x185185
	jumptextfaceplayer UnknownText_0x185765
; 0x185188

UnknownScript_0x185188: ; 0x185188
	faceplayer
	loadfont
	checkbit1 $0317
	iftrue UnknownScript_0x1851b6
	checkbit1 $0336
	iftrue UnknownScript_0x1851b0
	2writetext UnknownText_0x185629
	keeptextopen
	verbosegiveitem RAINBOW_WING, 1
	loadmovesprites
	refreshscreen $0
	earthquake 72
	waitbutton
	playsound $001b
	changeblock $a, $2, $20
	reloadmappart
	setbit1 $0336
	loadmovesprites
	loadfont
UnknownScript_0x1851b0: ; 0x1851b0
	2writetext UnknownText_0x18564a
	closetext
	loadmovesprites
	end
; 0x1851b6

UnknownScript_0x1851b6: ; 0x1851b6
	2writetext UnknownText_0x185803
	closetext
	loadmovesprites
	end
; 0x1851bc

UnknownScript_0x1851bc: ; 0x1851bc
	checkbit1 $0317
	iftrue UnknownScript_0x1851c5
	jumptextfaceplayer UnknownText_0x185654
; 0x1851c5

UnknownScript_0x1851c5: ; 0x1851c5
	jumptextfaceplayer UnknownText_0x1858d0
; 0x1851c8

UnknownScript_0x1851c8: ; 0x1851c8
	jumptextfaceplayer UnknownText_0x1856a3
; 0x1851cb

MovementData_0x1851cb: ; 0x1851cb
	slow_step_up
	slow_step_up
	slow_step_up
	slow_step_up
	step_end
; 0x1851d0

MovementData_0x1851d0: ; 0x1851d0
	db $39 ; movement
	fast_jump_step_down
	db $38 ; movement
	step_end
; 0x1851d4

MovementData_0x1851d4: ; 0x1851d4
	db $39 ; movement
	fast_jump_step_down
	fast_jump_step_right
	fast_jump_step_down
	db $38 ; movement
	step_end
; 0x1851da

MovementData_0x1851da: ; 0x1851da
	db $39 ; movement
	fast_jump_step_down
	db $38 ; movement
	step_end
; 0x1851de

MovementData_0x1851de: ; 0x1851de
	db $39 ; movement
	fast_jump_step_down
	fast_jump_step_left
	fast_jump_step_down
	db $38 ; movement
	step_end
; 0x1851e4

MovementData_0x1851e4: ; 0x1851e4
	db $39 ; movement
	fast_jump_step_down
	db $38 ; movement
	step_end
; 0x1851e8

MovementData_0x1851e8: ; 0x1851e8
	fix_facing
	big_step_down
	remove_fixed_facing
	step_end
; 0x1851ec

MovementData_0x1851ec: ; 0x1851ec
	step_up
	step_up
	step_up
	turn_head_left
	step_end
; 0x1851f1

MovementData_0x1851f1: ; 0x1851f1
	step_down
	step_down
	step_down
	step_end
; 0x1851f5

MovementData_0x1851f5: ; 0x1851f5
	step_up
	step_up
	step_left
	step_left
	turn_head_up
	step_end
; 0x1851fb

MovementData_0x1851fb: ; 0x1851fb
	step_up
	step_up
	step_end
; 0x1851fe

MovementData_0x1851fe: ; 0x1851fe
	step_up
	step_right
	step_right
	step_up
	step_end
; 0x185203

UnknownText_0x185203: ; 0x185203
	db $0, "EUSINE: Awesome!", $4f
	db "Too awesome, even!", $51
	db "I've never seen a", $4f
	db "battle that great.", $51
	db "That was truly", $4f
	db "inspiring to see.", $51
	db "SUICUNE was tough,", $4f
	db "but you were even", $51
	db "more incredible,", $4f
	db $52, ".", $51
	db "I heard SUICUNE's", $4f
	db "mystic power", $51
	db "summons a rainbow-", $4f
	db "colored #MON.", $51
	db "Maybe, just maybe,", $4f
	db "what went on today", $51
	db "will cause that", $4f
	db "#MON to appear.", $51
	db "I'm going to study", $4f
	db "the legends more.", $51
	db "Thanks for showing", $4f
	db "me that fantastic", $55
	db "battle.", $51
	db "Later, ", $52, "!", $57
; 0x185386

UnknownText_0x185386: ; 0x185386
	db $0, "According to", $4f
	db "legend…", $51
	db "When the souls of", $4f
	db "#MON and humans", $51
	db "commune, from the", $4f
	db "heavens descends a", $51
	db "#MON of rainbow", $4f
	db "colors…", $51
	db "Could it mean the", $4f
	db "legendary #MON", $51
	db "are testing us", $4f
	db "humans?", $57
; 0x185433

UnknownText_0x185433: ; 0x185433
	db $0, "When the BRASS", $4f
	db "TOWER burned down,", $51
	db "three nameless", $4f
	db "#MON were said", $51
	db "to have perished.", $4f
	db "It was tragic.", $51
	db "However…", $51
	db "A rainbow-colored", $4f
	db "#MON…", $51
	db "In other words…", $51
	db "HO-OH descended", $4f
	db "from the sky and", $51
	db "gave new life to", $4f
	db "the three #MON.", $51
	db "They are…", $51
	db "SUICUNE, ENTEI and", $4f
	db "RAIKOU.", $51
	db "That is what they", $4f
	db "say.", $57
; 0x185544

UnknownText_0x185544: ; 0x185544
	db $0, "The two TOWERS are", $4f
	db "said to have been", $51
	db "built to foster", $4f
	db "friendship and", $51
	db "hope between #-", $4f
	db "MON and people.", $51
	db "That was 700 years", $4f
	db "ago, but the ideal", $51
	db "still remains", $4f
	db "important today.", $57
; 0x1855ee

UnknownText_0x1855ee: ; 0x1855ee
	db $0, "HO-OH appears to", $4f
	db "have descended", $51
	db "upon this, the TIN", $4f
	db "TOWER!", $57
; 0x185629

UnknownText_0x185629: ; 0x185629
	db $0, "This will protect", $4f
	db "you. Take it.", $57
; 0x18564a

UnknownText_0x18564a: ; 0x18564a
	db $0, "Now, go.", $57
; 0x185654

UnknownText_0x185654: ; 0x185654
	db $0, "I believe you are", $4f
	db "being tested.", $51
	db "Free your mind", $4f
	db "from uncertainty,", $55
	db "and advance.", $57
; 0x1856a3

UnknownText_0x1856a3: ; 0x1856a3
	db $0, "I knew it.", $51
	db "I knew you'd get", $4f
	db "to see the #MON", $51
	db "of rainbow colors,", $4f
	db $52, ".", $51
	db "It happened just", $4f
	db "as I envisioned.", $51
	db "My research isn't", $4f
	db "bad, I might say.", $51
	db "I'm going to keep", $4f
	db "studying #MON", $51
	db "to become a famous", $4f
	db "#MANIAC!", $57
; 0x185765

UnknownText_0x185765: ; 0x185765
	db $0, "The legendary", $4f
	db "#MON are said", $51
	db "to embody three", $4f
	db "powers…", $51
	db "The lightning that", $4f
	db "struck the TOWER.", $51
	db "The fire that", $4f
	db "burned the TOWER.", $51
	db "And the rain that", $4f
	db "put out the fire…", $57
; 0x185803

UnknownText_0x185803: ; 0x185803
	db $0, "When the legendary", $4f
	db "#MON appeared…", $51
	db "They struck terror", $4f
	db "in those who saw", $55
	db "their rise.", $51
	db "And…", $51
	db "Some even took to", $4f
	db "futile attacks.", $51
	db "The legendary", $4f
	db "#MON, knowing", $51
	db "their own power,", $4f
	db "fled, ignoring the", $55
	db "frightened people.", $57
; 0x1858d0

UnknownText_0x1858d0: ; 0x1858d0
	db $0, "Of the legendary", $4f
	db "#MON, SUICUNE", $51
	db "is said to be the", $4f
	db "closest to HO-OH.", $51
	db "I hear there may", $4f
	db "also be a link to", $51
	db "#MON known as", $4f
	db "UNOWN.", $51
	db "The #MON UNOWN", $4f
	db "must be sharing a", $51
	db "cooperative bond", $4f
	db "with SUICUNE.", $57
; 0x18598c

TinTower1F_MapEventHeader: ; 0x18598c
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $f, $9, 12, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $f, $a, 12, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $2, $a, 2, GROUP_TIN_TOWER_2F, MAP_TIN_TOWER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 10
	person_event $63, 13, 13, $1, $0, 255, 255, $90, 0, ObjectEvent, $07b2
	person_event $65, 13, 11, $1, $0, 255, 255, $b0, 0, ObjectEvent, $07b4
	person_event $64, 13, 16, $1, $0, 255, 255, $80, 0, ObjectEvent, $07b3
	person_event $2b, 7, 12, $3, $0, 255, 255, $90, 0, UnknownScript_0x1851c8, $07b5
	person_event $3e, 13, 9, $3, $0, 255, 255, $0, 0, UnknownScript_0x185173, $07b6
	person_event $3e, 15, 15, $3, $0, 255, 255, $0, 0, UnknownScript_0x185176, $07b6
	person_event $3e, 10, 18, $3, $0, 255, 255, $0, 0, UnknownScript_0x185179, $07b6
	person_event $3e, 6, 8, $4, $10, 255, 255, $0, 0, UnknownScript_0x18517c, $07c5
	person_event $3e, 5, 13, $6, $0, 255, 255, $0, 0, UnknownScript_0x185188, $07c5
	person_event $3e, 6, 18, $5, $1, 255, 255, $0, 0, UnknownScript_0x1851bc, $07c5
; 0x185a23

TinTower2F_MapScriptHeader: ; 0x185a23
	; trigger count
	db 0

	; callback count
	db 0
; 0x185a25

TinTower2F_MapEventHeader: ; 0x185a25
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $e, $a, 1, GROUP_TIN_TOWER_3F, MAP_TIN_TOWER_3F
	warp_def $2, $a, 3, GROUP_TIN_TOWER_1F, MAP_TIN_TOWER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x185a35

TinTower3F_MapScriptHeader: ; 0x185a35
	; trigger count
	db 0

	; callback count
	db 0
; 0x185a37

ItemFragment_0x185a37: ; 0x185a37
	db FULL_HEAL, 1
; 0x185a39

TinTower3F_MapEventHeader: ; 0x185a39
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $e, $a, 1, GROUP_TIN_TOWER_2F, MAP_TIN_TOWER_2F
	warp_def $2, $10, 2, GROUP_TIN_TOWER_4F, MAP_TIN_TOWER_4F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $54, 18, 7, $1, $0, 255, 255, $1, 0, ItemFragment_0x185a37, $064b
; 0x185a56

TinTower4F_MapScriptHeader: ; 0x185a56
	; trigger count
	db 0

	; callback count
	db 0
; 0x185a58

ItemFragment_0x185a58: ; 0x185a58
	db ULTRA_BALL, 1
; 0x185a5a

ItemFragment_0x185a5a: ; 0x185a5a
	db PP_UP, 1
; 0x185a5c

ItemFragment_0x185a5c: ; 0x185a5c
	db ESCAPE_ROPE, 1
; 0x185a5e

MapTinTower4FSignpostItem0: ; 0x185a5e
	dw $007d
	db MAX_POTION
	
; 0x185a61

TinTower4F_MapEventHeader: ; 0x185a61
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $2, 2, GROUP_TIN_TOWER_5F, MAP_TIN_TOWER_5F
	warp_def $2, $10, 2, GROUP_TIN_TOWER_3F, MAP_TIN_TOWER_3F
	warp_def $e, $2, 3, GROUP_TIN_TOWER_5F, MAP_TIN_TOWER_5F
	warp_def $f, $11, 4, GROUP_TIN_TOWER_5F, MAP_TIN_TOWER_5F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 6, 11, $7, MapTinTower4FSignpostItem0

	; people-events
	db 3
	person_event $54, 14, 18, $1, $0, 255, 255, $1, 0, ItemFragment_0x185a58, $064c
	person_event $54, 18, 21, $1, $0, 255, 255, $1, 0, ItemFragment_0x185a5a, $064d
	person_event $54, 16, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x185a5c, $064e
; 0x185aa7

TinTower5F_MapScriptHeader: ; 0x185aa7
	; trigger count
	db 0

	; callback count
	db 0
; 0x185aa9

ItemFragment_0x185aa9: ; 0x185aa9
	db RARE_CANDY, 1
; 0x185aab

MapTinTower5FSignpostItem0: ; 0x185aab
	dw $007e
	db FULL_RESTORE
	
; 0x185aae

MapTinTower5FSignpostItem1: ; 0x185aae
	dw $007f
	db CARBOS
	
; 0x185ab1

TinTower5F_MapEventHeader: ; 0x185ab1
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $f, $b, 2, GROUP_TIN_TOWER_6F, MAP_TIN_TOWER_6F
	warp_def $4, $2, 1, GROUP_TIN_TOWER_4F, MAP_TIN_TOWER_4F
	warp_def $e, $2, 3, GROUP_TIN_TOWER_4F, MAP_TIN_TOWER_4F
	warp_def $f, $11, 4, GROUP_TIN_TOWER_4F, MAP_TIN_TOWER_4F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 14, 16, $7, MapTinTower5FSignpostItem0
	signpost 15, 3, $7, MapTinTower5FSignpostItem1

	; people-events
	db 1
	person_event $54, 13, 13, $1, $0, 255, 255, $1, 0, ItemFragment_0x185aa9, $064f
; 0x185ae2

TinTower6F_MapScriptHeader: ; 0x185ae2
	; trigger count
	db 0

	; callback count
	db 0
; 0x185ae4

ItemFragment_0x185ae4: ; 0x185ae4
	db MAX_POTION, 1
; 0x185ae6

TinTower6F_MapEventHeader: ; 0x185ae6
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $9, $3, 1, GROUP_TIN_TOWER_7F, MAP_TIN_TOWER_7F
	warp_def $f, $b, 1, GROUP_TIN_TOWER_5F, MAP_TIN_TOWER_5F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $54, 12, 12, $1, $0, 255, 255, $1, 0, ItemFragment_0x185ae4, $07c6
; 0x185b03

TinTower7F_MapScriptHeader: ; 0x185b03
	; trigger count
	db 0

	; callback count
	db 0
; 0x185b05

ItemFragment_0x185b05: ; 0x185b05
	db MAX_REVIVE, 1
; 0x185b07

TinTower7F_MapEventHeader: ; 0x185b07
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $9, $3, 1, GROUP_TIN_TOWER_6F, MAP_TIN_TOWER_6F
	warp_def $f, $a, 1, GROUP_TIN_TOWER_8F, MAP_TIN_TOWER_8F
	warp_def $7, $c, 4, GROUP_TIN_TOWER_7F, MAP_TIN_TOWER_7F
	warp_def $3, $8, 3, GROUP_TIN_TOWER_7F, MAP_TIN_TOWER_7F
	warp_def $9, $6, 5, GROUP_TIN_TOWER_9F, MAP_TIN_TOWER_9F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $54, 5, 20, $1, $0, 255, 255, $1, 0, ItemFragment_0x185b05, $0650
; 0x185b33

TinTower8F_MapScriptHeader: ; 0x185b33
	; trigger count
	db 0

	; callback count
	db 0
; 0x185b35

ItemFragment_0x185b35: ; 0x185b35
	db NUGGET, 1
; 0x185b37

ItemFragment_0x185b37: ; 0x185b37
	db MAX_ELIXER, 1
; 0x185b39

ItemFragment_0x185b39: ; 0x185b39
	db FULL_RESTORE, 1
; 0x185b3b

TinTower8F_MapEventHeader: ; 0x185b3b
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $5, $2, 2, GROUP_TIN_TOWER_7F, MAP_TIN_TOWER_7F
	warp_def $b, $2, 1, GROUP_TIN_TOWER_9F, MAP_TIN_TOWER_9F
	warp_def $7, $10, 2, GROUP_TIN_TOWER_9F, MAP_TIN_TOWER_9F
	warp_def $3, $a, 3, GROUP_TIN_TOWER_9F, MAP_TIN_TOWER_9F
	warp_def $f, $e, 6, GROUP_TIN_TOWER_9F, MAP_TIN_TOWER_9F
	warp_def $9, $6, 7, GROUP_TIN_TOWER_9F, MAP_TIN_TOWER_9F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $54, 17, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x185b35, $0651
	person_event $54, 10, 15, $1, $0, 255, 255, $1, 0, ItemFragment_0x185b37, $0652
	person_event $54, 5, 7, $1, $0, 255, 255, $1, 0, ItemFragment_0x185b39, $0653
; 0x185b86

TinTower9F_MapScriptHeader: ; 0x185b86
	; trigger count
	db 0

	; callback count
	db 0
; 0x185b88

ItemFragment_0x185b88: ; 0x185b88
	db HP_UP, 1
; 0x185b8a

UnknownText_0x185b8a: ; 0x185b8a
	db $0, "HO-OH: Shaoooh!", $57
; 0x185b9b

UnknownText_0x185b9b: ; 0x185b9b
	db $0, "LUGIA: Gyaaan!", $57
; 0x185bab

TinTower9F_MapEventHeader: ; 0x185bab
	; filler
	db 0, 0

	; warps
	db 7
	warp_def $3, $c, 2, GROUP_TIN_TOWER_8F, MAP_TIN_TOWER_8F
	warp_def $5, $2, 3, GROUP_TIN_TOWER_8F, MAP_TIN_TOWER_8F
	warp_def $7, $c, 4, GROUP_TIN_TOWER_8F, MAP_TIN_TOWER_8F
	warp_def $9, $7, 1, GROUP_TIN_TOWER_ROOF, MAP_TIN_TOWER_ROOF
	warp_def $7, $10, 5, GROUP_TIN_TOWER_7F, MAP_TIN_TOWER_7F
	warp_def $d, $6, 5, GROUP_TIN_TOWER_8F, MAP_TIN_TOWER_8F
	warp_def $d, $8, 6, GROUP_TIN_TOWER_8F, MAP_TIN_TOWER_8F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $54, 5, 13, $1, $0, 255, 255, $1, 0, ItemFragment_0x185b88, $07c7
; 0x185be1

BurnedTower1F_MapScriptHeader: ; 0x185be1
	; trigger count
	db 3

	; triggers
	dw UnknownScript_0x185bf2, $0000
	dw UnknownScript_0x185bf6, $0000
	dw UnknownScript_0x185bf7, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x185bf8
; 0x185bf2

UnknownScript_0x185bf2: ; 0x185bf2
	priorityjump UnknownScript_0x185c0d
	end
; 0x185bf6

UnknownScript_0x185bf6: ; 0x185bf6
	end
; 0x185bf7

UnknownScript_0x185bf7: ; 0x185bf7
	end
; 0x185bf8

UnknownScript_0x185bf8: ; 0x185bf8
	checkbit1 $0332
	iftrue UnknownScript_0x185c02
	changeblock $a, $8, $32
UnknownScript_0x185c02: ; 0x185c02
	checkbit1 $007b
	iftrue UnknownScript_0x185c0c
	changeblock $6, $e, $9
UnknownScript_0x185c0c: ; 0x185c0c
	return
; 0x185c0d

UnknownScript_0x185c0d: ; 0x185c0d
	spriteface $3, $0
	showemote $0, $3, 15
	applymovement $3, MovementData_0x185cd3
	loadfont
	2writetext UnknownText_0x185ecc
	closetext
	loadmovesprites
	moveperson $3, $9, $e
	dotrigger $1
	end
; 0x185c25

UnknownScript_0x185c25: ; 0x185c25
	showemote $0, $4, 15
	special $006a
	pause 15
	spriteface $4, $3
	pause 15
	applymovement $0, MovementData_0x185ccd
	applymovement $4, MovementData_0x185ccf
	playmusic $001f
	loadfont
	2writetext UnknownText_0x185cd9
	closetext
	loadmovesprites
	checkbit1 $001c
	iftrue UnknownScript_0x185c60
	checkbit1 $001d
	iftrue UnknownScript_0x185c70
	winlosstext UnknownText_0x185d9b, UnknownText_0x185e2c
	setlasttalked $4
	loadtrainer RIVAL1, RIVAL1_9
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x185c80
; 0x185c60

UnknownScript_0x185c60: ; 0x185c60
	winlosstext UnknownText_0x185d9b, UnknownText_0x185e2c
	setlasttalked $4
	loadtrainer RIVAL1, RIVAL1_7
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x185c80
; 0x185c70

UnknownScript_0x185c70: ; 0x185c70
	winlosstext UnknownText_0x185d9b, UnknownText_0x185e2c
	setlasttalked $4
	loadtrainer RIVAL1, RIVAL1_8
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x185c80
; 0x185c80

UnknownScript_0x185c80: ; 0x185c80
	playmusic $0020
	loadfont
	2writetext UnknownText_0x185de2
	closetext
	loadmovesprites
	dotrigger $2
	setbit1 $06c5
	special $006a
	pause 15
	earthquake 50
	showemote $0, $0, 15
	playsound $001f
	waitbutton
	changeblock $a, $8, $25
	reloadmappart
	pause 15
	applymovement $0, MovementData_0x185cd1
	playsound $002f
	showemote $0, $4, 20
	loadfont
	2writetext UnknownText_0x185e75
	closetext
	loadmovesprites
	setbit1 $0332
	pause 15
	warpcheck
	end
; 0x185cbc

UnknownScript_0x185cbc: ; 0x185cbc
	jumptextfaceplayer UnknownText_0x185f99
; 0x185cbf

UnknownScript_0x185cbf: ; 0x185cbf
	jumptextfaceplayer UnknownText_0x186002
; 0x185cc2

UnknownScript_0x185cc2: ; 0x185cc2
	jumpstd $000f
; 0x185cc5

MapBurnedTower1FSignpostItem0: ; 0x185cc5
	dw $0080
	db ETHER
	
; 0x185cc8

MapBurnedTower1FSignpostItem1: ; 0x185cc8
	dw $00ff
	db ULTRA_BALL
	
; 0x185ccb

ItemFragment_0x185ccb: ; 0x185ccb
	db HP_UP, 1
; 0x185ccd

MovementData_0x185ccd: ; 0x185ccd
	step_left
	step_end
; 0x185ccf

MovementData_0x185ccf: ; 0x185ccf
	step_right
	step_end
; 0x185cd1

MovementData_0x185cd1: ; 0x185cd1
	db $59 ; movement
	step_end
; 0x185cd3

MovementData_0x185cd3: ; 0x185cd3
	step_down
	step_left
	step_left
	step_left
	step_down
	step_end
; 0x185cd9

UnknownText_0x185cd9: ; 0x185cd9
	db $0, $56, " ", $56, " ", $56, $51
	db "…Oh, it's you.", $51
	db "I came looking for", $4f
	db "some legendary", $51
	db "#MON that they", $4f
	db "say roosts here.", $51
	db "But there's", $4f
	db "nothing here!", $51
	db "Nothing after all", $4f
	db "the trouble of", $51
	db "coming to this", $4f
	db "dump? No way!", $51
	db "It's all your", $4f
	db "fault!", $57
; 0x185d9b

UnknownText_0x185d9b: ; 0x185d9b
	db $0, "…Humph!", $51
	db "This is why I hate", $4f
	db "battling wimps.", $51
	db "There's no", $4f
	db "challenge in it.", $57
; 0x185de2

UnknownText_0x185de2: ; 0x185de2
	db $0, "…Aw, whatever.", $51
	db "You would never be", $4f
	db "able to catch a", $51
	db "legendary #MON", $4f
	db "anyway.", $57
; 0x185e2c

UnknownText_0x185e2c: ; 0x185e2c
	db $0, "…Humph!", $51
	db "This is why I hate", $4f
	db "battling wimps.", $51
	db "It's just a waste", $4f
	db "of my time.", $57
; 0x185e75

UnknownText_0x185e75: ; 0x185e75
	db $0, "Humph!", $51
	db "What are you doing", $4f
	db "falling into a", $51
	db "hole? Some genius", $4f
	db "you are!", $51
	db "Serves you right!", $57
; 0x185ecc

UnknownText_0x185ecc: ; 0x185ecc
	db $0, "EUSINE: My name's", $4f
	db "EUSINE.", $51
	db "I'm on the trail", $4f
	db "of a #MON named", $55
	db "SUICUNE.", $51
	db "And you are…?", $51
	db $52, "? Glad to", $4f
	db "meet you!", $51
	db "I heard rumors", $4f
	db "that SUICUNE is in", $51
	db "this BURNED TOWER,", $4f
	db "so I came to look.", $51
	db "But where exactly", $4f
	db "could it be?", $57
; 0x185f99

UnknownText_0x185f99: ; 0x185f99
	db $0, "EUSINE: I heard", $4f
	db "that SUICUNE is in", $51
	db "this BURNED TOWER,", $4f
	db "so I came to look.", $51
	db "But where exactly", $4f
	db "could it be?", $57
; 0x186002

UnknownText_0x186002: ; 0x186002
	db $0, "MORTY: ECRUTEAK's", $4f
	db "GYM LEADER has to", $51
	db "study what are", $4f
	db "said to be the", $51
	db "legendary #MON", $4f
	db "--SUICUNE, ENTEI", $55
	db "and RAIKOU.", $51
	db "EUSINE is here, so", $4f
	db "I've decided to", $51
	db "investigate the", $4f
	db "TOWER with him.", $57
; 0x1860b2

BurnedTower1F_MapEventHeader: ; 0x1860b2
	; filler
	db 0, 0

	; warps
	db 14
	warp_def $f, $9, 13, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $f, $a, 13, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $9, $a, 1, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $5, $5, 1, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $6, $5, 1, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $6, $4, 1, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $4, $f, 2, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $5, $f, 2, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $7, $a, 3, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $e, $5, 4, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $e, $4, 4, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $e, $e, 5, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $e, $f, 5, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F
	warp_def $f, $7, 6, GROUP_BURNED_TOWER_B1F, MAP_BURNED_TOWER_B1F

	; xy triggers
	db 1
	xy_trigger 1, $9, $b, $0, UnknownScript_0x185c25, $0, $0

	; signposts
	db 2
	signpost 7, 8, $7, MapBurnedTower1FSignpostItem0
	signpost 11, 13, $7, MapBurnedTower1FSignpostItem1

	; people-events
	db 5
	person_event $59, 8, 19, $18, $0, 255, 255, $0, 0, UnknownScript_0x185cc2, $ffff
	person_event $2b, 16, 16, $3, $0, 255, 255, $90, 0, UnknownScript_0x185cbc, $0765
	person_event $4, 13, 12, $8, $0, 255, 255, $2, 3, ObjectEvent, $06c5
	person_event $15, 18, 18, $2, $11, 255, 255, $b0, 0, UnknownScript_0x185cbf, $0764
	person_event $54, 6, 18, $1, $0, 255, 255, $1, 0, ItemFragment_0x185ccb, $0656
; 0x186151

BurnedTowerB1F_MapScriptHeader: ; 0x186151
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x18615e, $0000
	dw UnknownScript_0x18615f, $0000

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x186160
; 0x18615e

UnknownScript_0x18615e: ; 0x18615e
	end
; 0x18615f

UnknownScript_0x18615f: ; 0x18615f
	end
; 0x186160

UnknownScript_0x186160: ; 0x186160
	checkbit1 $007b
	iftrue UnknownScript_0x18616a
	changeblock $6, $e, $2
UnknownScript_0x18616a: ; 0x18616a
	return
; 0x18616b

UnknownScript_0x18616b: ; 0x18616b
	playmusic $0000
	pause 30
	appear $3
	spriteface $0, $1
	pause 5
	disappear $6
	pause 15
	cry RAIKOU
	appear $4
	spriteface $0, $1
	pause 5
	disappear $7
	pause 15
	cry ENTEI
	appear $5
	spriteface $0, $1
	pause 5
	disappear $8
	pause 15
	cry SUICUNE
	pause 15
	playsound $0014
	spriteface $0, $2
	applymovement $3, MovementData_0x186236
	disappear $3
	waitbutton
	playsound $0014
	spriteface $0, $3
	applymovement $4, MovementData_0x18623b
	disappear $4
	waitbutton
	pause 15
	playsound $0014
	spriteface $0, $1
	applymovement $5, MovementData_0x186241
	playsound $0014
	spriteface $0, $0
	applymovement $5, MovementData_0x186248
	spriteface $0, $1
	pause 20
	cry SUICUNE
	pause 30
	playsound $0014
	applymovement $5, MovementData_0x186253
	spriteface $0, $0
	disappear $5
	waitbutton
	special $003d
	dotrigger $1
	setbit1 $007b
	special $0069
	domaptrigger GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM, $1
	domaptrigger GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY, $1
	clearbit1 $07ae
	setbit1 $07a8
	clearbit1 $07a9
	setbit1 $0764
	setbit1 $0765
	appear $a
	refreshscreen $0
	changeblock $6, $e, $1b
	reloadmappart
	loadmovesprites
	dotrigger $1
	end
; 0x186212

UnknownScript_0x186212: ; 0x186212
	faceplayer
	loadfont
	2writetext UnknownText_0x18626a
	closetext
	loadmovesprites
	checkcode $9
	if_equal $1, UnknownScript_0x186226
	applymovement $a, MovementData_0x186263
	2jump UnknownScript_0x18622a
; 0x186226

UnknownScript_0x186226: ; 0x186226
	applymovement $a, MovementData_0x18625c
UnknownScript_0x18622a: ; 0x18622a
	disappear $a
	playsound $0023
	waitbutton
	end
; 0x186231

ItemFragment_0x186231: ; 0x186231
	db TM_20, 1
; 0x186233

UnknownScript_0x186233: ; 0x186233
	jumpstd $000e
; 0x186236

MovementData_0x186236: ; 0x186236
	db $39 ; movement
	fast_jump_step_down
	fast_jump_step_left
	db $38 ; movement
	step_end
; 0x18623b

MovementData_0x18623b: ; 0x18623b
	db $39 ; movement
	fast_jump_step_right
	fast_jump_step_down
	fast_jump_step_right
	db $38 ; movement
	step_end
; 0x186241

MovementData_0x186241: ; 0x186241
	db $39 ; movement
	fast_jump_step_right
	fast_jump_step_down
	fast_jump_step_down
	fast_jump_step_left
	db $38 ; movement
	step_end
; 0x186248

MovementData_0x186248: ; 0x186248
	db $39 ; movement
	fast_jump_step_left
	fast_jump_step_up
	big_step_up
	fast_jump_step_right
	db $38 ; movement
	step_end
; 0x18624f

MovementData_0x18624f: ; 0x18624f
	db $39 ; movement
	big_step_down
	db $38 ; movement
	step_end
; 0x186253

MovementData_0x186253: ; 0x186253
	db $39 ; movement
	big_step_up
	fast_jump_step_right
	fast_jump_step_down
	fast_jump_step_down
	fast_jump_step_down
	fast_jump_step_down
	db $38 ; movement
	step_end
; 0x18625c

MovementData_0x18625c: ; 0x18625c
	step_left
	step_left
	step_down
	step_down
	step_left
	step_down
	step_end
; 0x186263

MovementData_0x186263: ; 0x186263
	step_down
	step_left
	step_left
	step_left
	step_down
	step_down
	step_end
; 0x18626a

UnknownText_0x18626a: ; 0x18626a
	db $0, "EUSINE: I dug a", $4f
	db "hole here, too…", $51
	db "I was shocked!", $51
	db "SUICUNE raced by", $4f
	db "like a blur, right", $51
	db "in front of my", $4f
	db "eyes!", $51
	db "For ten years I", $4f
	db "chased SUICUNE,", $51
	db "and I finally got", $4f
	db "to see it.", $51
	db "I'm all choked up!", $51
	db $52, ", I owe", $4f
	db "this all to you!", $51
	db "Thank you!", $51
	db "I heard that the", $4f
	db "legendary #MON", $51
	db "of ECRUTEAK test", $4f
	db "chosen humans by", $51
	db "allowing them to", $4f
	db "get close.", $51
	db "I'm going to track", $4f
	db "SUICUNE.", $51
	db $52, ", let's", $4f
	db "meet again!", $51
	db "Farewell!", $57
; 0x1863de

BurnedTowerB1F_MapEventHeader: ; 0x1863de
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $9, $a, 3, GROUP_BURNED_TOWER_1F, MAP_BURNED_TOWER_1F
	warp_def $7, $11, 7, GROUP_BURNED_TOWER_1F, MAP_BURNED_TOWER_1F
	warp_def $8, $a, 9, GROUP_BURNED_TOWER_1F, MAP_BURNED_TOWER_1F
	warp_def $d, $3, 10, GROUP_BURNED_TOWER_1F, MAP_BURNED_TOWER_1F
	warp_def $e, $11, 12, GROUP_BURNED_TOWER_1F, MAP_BURNED_TOWER_1F
	warp_def $f, $7, 14, GROUP_BURNED_TOWER_1F, MAP_BURNED_TOWER_1F

	; xy triggers
	db 1
	xy_trigger 0, $6, $a, $0, UnknownScript_0x18616b, $0, $0

	; signposts
	db 0

	; people-events
	db 9
	person_event $5a, 12, 21, $19, $0, 255, 255, $0, 0, UnknownScript_0x186233, $ffff
	person_event $65, 7, 11, $16, $0, 255, 255, $b0, 0, ObjectEvent, $074a
	person_event $64, 7, 16, $16, $0, 255, 255, $80, 0, ObjectEvent, $074a
	person_event $63, 8, 14, $16, $0, 255, 255, $90, 0, ObjectEvent, $074a
	person_event $65, 7, 11, $6, $0, 255, 255, $d0, 0, ObjectEvent, $074b
	person_event $64, 7, 16, $6, $0, 255, 255, $d0, 0, ObjectEvent, $074b
	person_event $63, 8, 14, $6, $0, 255, 255, $d0, 0, ObjectEvent, $074b
	person_event $54, 8, 20, $1, $0, 255, 255, $1, 0, ItemFragment_0x186231, $0657
	person_event $2b, 16, 14, $7, $0, 255, 255, $90, 0, UnknownScript_0x186212, $07aa
; 0x18647f

SECTION "bank62",DATA,BANK[$62]

CeruleanGymBadgeSpeechHouse_MapScriptHeader: ; 0x188000
	; trigger count
	db 0

	; callback count
	db 0
; 0x188002

UnknownScript_0x188002: ; 0x188002
	jumptextfaceplayer UnknownText_0x188005
; 0x188005

UnknownText_0x188005: ; 0x188005
	db $0, "Are you collecting", $4f
	db "KANTO GYM BADGES?", $57
; 0x18802b

CeruleanGymBadgeSpeechHouse_MapEventHeader: ; 0x18802b
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY
	warp_def $7, $3, 1, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $2d, 7, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x188002, $ffff
; 0x188048

CeruleanPoliceStation_MapScriptHeader: ; 0x188048
	; trigger count
	db 0

	; callback count
	db 0
; 0x18804a

UnknownScript_0x18804a: ; 0x18804a
	jumptextfaceplayer UnknownText_0x18805a
; 0x18804d

UnknownScript_0x18804d: ; 0x18804d
	jumptextfaceplayer UnknownText_0x1880c3
; 0x188050

UnknownScript_0x188050: ; 0x188050
	loadfont
	2writetext UnknownText_0x1880e7
	cry DIGLETT
	closetext
	loadmovesprites
	end
; 0x18805a

UnknownText_0x18805a: ; 0x18805a
	db $0, "I heard that some", $4f
	db "shady character is", $55
	db "skulking about.", $51
	db "I won't stand for", $4f
	db "it if he turns out", $55
	db "to be a thief.", $57
; 0x1880c3

UnknownText_0x1880c3: ; 0x1880c3
	db $0, "We were held up by", $4f
	db "robbers before.", $57
; 0x1880e7

UnknownText_0x1880e7: ; 0x1880e7
	db $0, "DIGLETT: Dug dug.", $57
; 0x1880fa

CeruleanPoliceStation_MapEventHeader: ; 0x1880fa
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY
	warp_def $7, $3, 2, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $3b, 5, 9, $7, $0, 255, 255, $a0, 0, UnknownScript_0x18804a, $ffff
	person_event $2e, 8, 9, $8, $0, 255, 255, $90, 0, UnknownScript_0x18804d, $ffff
	person_event $8c, 9, 7, $16, $0, 255, 255, $b0, 0, UnknownScript_0x188050, $ffff
; 0x188131

CeruleanTradeSpeechHouse_MapScriptHeader: ; 0x188131
	; trigger count
	db 0

	; callback count
	db 0
; 0x188133

UnknownScript_0x188133: ; 0x188133
	jumptextfaceplayer UnknownText_0x18814d
; 0x188136

UnknownScript_0x188136: ; 0x188136
	jumptextfaceplayer UnknownText_0x18818a
; 0x188139

UnknownScript_0x188139: ; 0x188139
	loadfont
	2writetext UnknownText_0x18819c
	cry KANGASKHAN
	closetext
	loadmovesprites
	end
; 0x188143

UnknownScript_0x188143: ; 0x188143
	loadfont
	2writetext UnknownText_0x1881b5
	cry ZUBAT
	closetext
	loadmovesprites
	end
; 0x18814d

UnknownText_0x18814d: ; 0x18814d
	db $0, "My husband lives", $4f
	db "happily with #-", $55
	db "MON he got through", $55
	db "trades.", $57
; 0x18818a

UnknownText_0x18818a: ; 0x18818a
	db $0, "Ah… I'm so happy…", $57
; 0x18819c

UnknownText_0x18819c: ; 0x18819c
	db $0, "KANGASKHAN: Garu", $4f
	db "garuu.", $57
; 0x1881b5

UnknownText_0x1881b5: ; 0x1881b5
	db $0, "ZUBAT: Zuba zubaa.", $57
; 0x1881c9

CeruleanTradeSpeechHouse_MapEventHeader: ; 0x1881c9
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY
	warp_def $7, $3, 3, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $30, 8, 6, $9, $0, 255, 255, $90, 0, UnknownScript_0x188133, $ffff
	person_event $2f, 6, 5, $2, $0, 255, 255, $a0, 0, UnknownScript_0x188136, $ffff
	person_event $9d, 6, 9, $16, $0, 255, 255, $b0, 0, UnknownScript_0x188139, $ffff
	person_event $87, 10, 9, $16, $0, 255, 255, $0, 0, UnknownScript_0x188143, $ffff
; 0x18820d

CeruleanPokeCenter1F_MapScriptHeader: ; 0x18820d
	; trigger count
	db 0

	; callback count
	db 0
; 0x18820f

UnknownScript_0x18820f: ; 0x18820f
	jumpstd $0000
; 0x188212

UnknownScript_0x188212: ; 0x188212
	special $00a0
	iftrue UnknownScript_0x18821b
	jumptextfaceplayer UnknownText_0x188221
; 0x18821b

UnknownScript_0x18821b: ; 0x18821b
	jumptextfaceplayer UnknownText_0x18828c
; 0x18821e

UnknownScript_0x18821e: ; 0x18821e
	jumptextfaceplayer UnknownText_0x1882ff
; 0x188221

UnknownText_0x188221: ; 0x188221
	db $0, "For battles, I'd", $4f
	db "much rather use", $51
	db "#MON I've been", $4f
	db "raising, even if", $51
	db "they're weaker", $4f
	db "than some newly", $55
	db "caught #MON.", $57
; 0x18828c

UnknownText_0x18828c: ; 0x18828c
	db $0, "Do you battle by", $4f
	db "mobile phone?", $51
	db "If time runs out", $4f
	db "during a battle,", $51
	db "waiting to see who", $4f
	db "won is really", $55
	db "nerve wracking.", $57
; 0x1882ff

UnknownText_0x1882ff: ; 0x1882ff
	db $0, "The MAGNET TRAIN", $4f
	db "travels at over", $51
	db "340 mph. It goes", $4f
	db "between KANTO and", $51
	db "JOHTO in almost no", $4f
	db "time at all.", $51
	db "It really makes", $4f
	db "JOHTO accessible.", $57
; 0x188386

CeruleanPokeCenter1F_MapEventHeader: ; 0x188386
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 4, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY
	warp_def $7, $4, 4, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x18820f, $ffff
	person_event $2b, 8, 12, $5, $1, 255, 255, $0, 0, UnknownScript_0x188212, $ffff
	person_event $48, 9, 5, $2, $11, 255, 255, $a0, 0, UnknownScript_0x18821e, $ffff
; 0x1883c2

CeruleanPokeCenter2FBeta_MapScriptHeader: ; 0x1883c2
	; trigger count
	db 0

	; callback count
	db 0
; 0x1883c4

CeruleanPokeCenter2FBeta_MapEventHeader: ; 0x1883c4
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 1, GROUP_CERULEAN_POKECENTER_1F, MAP_CERULEAN_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x1883cf

CeruleanGym_MapScriptHeader: ; 0x1883cf
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1883d9, $0000
	dw UnknownScript_0x1883da, $0000

	; callback count
	db 0
; 0x1883d9

UnknownScript_0x1883d9: ; 0x1883d9
	end
; 0x1883da

UnknownScript_0x1883da: ; 0x1883da
	priorityjump UnknownScript_0x1883de
	end
; 0x1883de

UnknownScript_0x1883de: ; 0x1883de
	applymovement $2, MovementData_0x1884e3
	playsound $0041
	applymovement $2, MovementData_0x1884eb
	playmusic $0039
	loadfont
	2writetext UnknownText_0x1884fb
	closetext
	loadmovesprites
	showemote $0, $2, 15
	applymovement $2, MovementData_0x1884f7
	loadfont
	2writetext UnknownText_0x188574
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x1884f5
	loadfont
	2writetext UnknownText_0x1885a5
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x1884e8
	playsound $0023
	disappear $2
	setbit1 $00cb
	clearbit1 $076c
	clearbit1 $076e
	dotrigger $0
	domaptrigger GROUP_ROUTE_25, MAP_ROUTE_25, $1
	domaptrigger GROUP_POWER_PLANT, MAP_POWER_PLANT, $0
	waitbutton
	special $003d
	pause 15
	spriteface $0, $0
	pause 15
	end
; 0x188432

UnknownScript_0x188432: ; 0x188432
	faceplayer
	loadfont
	checkbit2 $0024
	iftrue UnknownScript_0x188460
	2writetext UnknownText_0x188674
	closetext
	loadmovesprites
	winlosstext UnknownText_0x18870c, $0000
	loadtrainer MISTY, 1
	startbattle
	returnafterbattle
	setbit1 $04c6
	setbit1 $03f9
	setbit1 $03fa
	setbit1 $05a8
	loadfont
	2writetext UnknownText_0x188768
	playsound $009c
	waitbutton
	setbit2 $0024
UnknownScript_0x188460: ; 0x188460
	2writetext UnknownText_0x188782
	closetext
	loadmovesprites
	end
; 0x188466

TrainerSwimmerfDiana: ; 0x188466
	; bit/flag number
	dw $3f9

	; trainer group && trainer id
	db SWIMMERF, DIANA

	; text when seen
	dw SwimmerfDianaSeenText

	; text when trainer beaten
	dw SwimmerfDianaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfDianaScript
; 0x188472

SwimmerfDianaScript: ; 0x188472
	talkaftercancel
	loadfont
	2writetext UnknownText_0x188856
	closetext
	loadmovesprites
	end
; 0x18847a

TrainerSwimmerfBriana: ; 0x18847a
	; bit/flag number
	dw $3fa

	; trainer group && trainer id
	db SWIMMERF, BRIANA

	; text when seen
	dw SwimmerfBrianaSeenText

	; text when trainer beaten
	dw SwimmerfBrianaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfBrianaScript
; 0x188486

SwimmerfBrianaScript: ; 0x188486
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1888c0
	closetext
	loadmovesprites
	end
; 0x18848e

TrainerSwimmermParker: ; 0x18848e
	; bit/flag number
	dw $5a8

	; trainer group && trainer id
	db SWIMMERM, PARKER

	; text when seen
	dw SwimmermParkerSeenText

	; text when trainer beaten
	dw SwimmermParkerBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermParkerScript
; 0x18849a

SwimmermParkerScript: ; 0x18849a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x188943
	closetext
	loadmovesprites
	end
; 0x1884a2

CeruleanGymGuyScript: ; 0x1884a2
	faceplayer
	loadfont
	checkbit1 $04c6
	iftrue .CeruleanGymGuyWinScript
	2writetext CeruleanGymGuyText
	closetext
	loadmovesprites
	end

.CeruleanGymGuyWinScript
	2writetext CeruleanGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x1884b6

MapCeruleanGymSignpostItem0: ; 0x1884b6
	dw $00fb
	db MACHINE_PART
	
; 0x1884b9

MapCeruleanGymSignpost1Script: ; 0x1884b9
	checkbit1 $076f
	iffalse UnknownScript_0x1884d3
	loadfont
	2writetext UnknownText_0x188610
	closetext
	loadmovesprites
	end
; 0x1884c6

MapCeruleanGymSignpost2Script: ; 0x1884c6
	checkbit1 $076f
	iffalse UnknownScript_0x1884d3
	loadfont
	2writetext UnknownText_0x188642
	closetext
	loadmovesprites
	end
; 0x1884d3

UnknownScript_0x1884d3: ; 0x1884d3
	checkbit2 $0024
	iftrue UnknownScript_0x1884dc
	jumpstd $002d
; 0x1884dc

UnknownScript_0x1884dc: ; 0x1884dc
	trainertotext MISTY, 1, $1
	jumpstd $002e
; 0x1884e3

MovementData_0x1884e3: ; 0x1884e3
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	step_end
; 0x1884e8

MovementData_0x1884e8: ; 0x1884e8
	big_step_right
	big_step_down
	step_end
; 0x1884eb

MovementData_0x1884eb: ; 0x1884eb
	fix_facing
	db $39 ; movement
	jump_step_up
	db $38 ; movement
	remove_fixed_facing
	accelerate_last
	accelerate_last
	step_down
	step_down
	step_end
; 0x1884f5

MovementData_0x1884f5: ; 0x1884f5
	big_step_down
	step_end
; 0x1884f7

MovementData_0x1884f7: ; 0x1884f7
	fix_facing
	slow_step_up
	remove_fixed_facing
	step_end
; 0x1884fb

UnknownText_0x1884fb: ; 0x1884fb
	db $0, "Oops! I so sorry!", $4f
	db "You not hurt,", $55
	db "okay?", $51
	db "I very busy.", $4f
	db "No time for talk-", $55
	db "ing with you. Not", $55
	db "good for me if", $55
	db "seen by somebody.", $57
; 0x188574

UnknownText_0x188574: ; 0x188574
	db $0, "Oh no! You seen", $4f
	db "me already! I make", $55
	db "big mistake!", $57
; 0x1885a5

UnknownText_0x1885a5: ; 0x1885a5
	db $0, "Hey, you! Forget", $4f
	db "you see me, okay?", $51
	db "You see, hear,", $4f
	db "know nothing,", $51
	db "okay?", $4f
	db "Bye, kid! Nothing!", $51
	db "Bye-bye a go-go!", $57
; 0x188610

UnknownText_0x188610: ; 0x188610
	db $0, "Sorry, I'll be out", $4f
	db "for a while.", $55
	db "MISTY, GYM LEADER", $57
; 0x188642

UnknownText_0x188642: ; 0x188642
	db $0, "Since MISTY's out,", $4f
	db "we'll be away too.", $55
	db "GYM TRAINERS", $57
; 0x188674

UnknownText_0x188674: ; 0x188674
	db $0, "MISTY: I was ex-", $4f
	db "pecting you, you", $55
	db "pest!", $51
	db "You may have a", $4f
	db "lot of JOHTO GYM", $51
	db "BADGES, but you'd", $4f
	db "better not take me", $55
	db "too lightly.", $51
	db "My water-type", $4f
	db "#MON are tough!", $57
; 0x18870c

UnknownText_0x18870c: ; 0x18870c
	db $0, "MISTY: You really", $4f
	db "are good…", $51
	db "I'll admit that", $4f
	db "you are skilled…", $51
	db "Here you go. It's", $4f
	db "CASCADEBADGE.", $57
; 0x188768

UnknownText_0x188768: ; 0x188768
	db $0, $52, " received", $4f
	db "CASCADEBADGE.", $57
; 0x188782

UnknownText_0x188782: ; 0x188782
	db $0, "MISTY: Are there", $4f
	db "many strong train-", $55
	db "ers in JOHTO? Like", $55
	db "you, I mean.", $51
	db "I'm going to", $4f
	db "travel one day, so", $51
	db "I can battle some", $4f
	db "skilled trainers.", $57
; 0x18880a

SwimmerfDianaSeenText: ; 0x18880a
	db $0, "Sorry about being", $4f
	db "away. Let's get on", $55
	db "with it!", $57
; 0x188838

SwimmerfDianaBeatenText: ; 0x188838
	db $0, "I give up! You're", $4f
	db "the winner!", $57
; 0x188856

UnknownText_0x188856: ; 0x188856
	db $0, "I'll be swimming", $4f
	db "quietly.", $57
; 0x188870

SwimmerfBrianaSeenText: ; 0x188870
	db $0, "Don't let my ele-", $4f
	db "gant swimming un-", $55
	db "nerve you.", $57
; 0x18889f

SwimmerfBrianaBeatenText: ; 0x18889f
	db $0, "Ooh, you calmly", $4f
	db "disposed of me…", $57
; 0x1888c0

UnknownText_0x1888c0: ; 0x1888c0
	db $0, "Don't be too smug", $4f
	db "about beating me.", $51
	db "MISTY will destroy", $4f
	db "you if you get", $55
	db "complacent.", $57
; 0x188912

SwimmermParkerSeenText: ; 0x188912
	db $0, "Glub…", $51
	db "I'm first! Come", $4f
	db "and get me!", $57
; 0x188934

SwimmermParkerBeatenText: ; 0x188934
	db $0, "This can't be…", $57
; 0x188943

UnknownText_0x188943: ; 0x188943
	db $0, "MISTY has gotten", $4f
	db "much better in the", $55
	db "past few years.", $51
	db "Don't let your", $4f
	db "guard down, or", $55
	db "you'll be crushed!", $57
; 0x1889a7

CeruleanGymGuyText: ; 0x1889a7
	db $0, "Yo! CHAMP in", $4f
	db "making!", $51
	db "Since MISTY was", $4f
	db "away, I went out", $51
	db "for some fun too.", $4f
	db "He-he-he.", $57
; 0x1889fa

CeruleanGymGuyWinText: ; 0x1889fa
	db $0, "Hoo, you showed me", $4f
	db "how tough you are.", $51
	db "As always, that", $4f
	db "was one heck of a", $55
	db "great battle!", $57
; 0x188a51

CeruleanGym_MapEventHeader: ; 0x188a51
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $f, $4, 5, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY
	warp_def $f, $5, 5, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 8, 3, $7, MapCeruleanGymSignpostItem0
	signpost 13, 2, $0, MapCeruleanGymSignpost1Script
	signpost 13, 6, $0, MapCeruleanGymSignpost2Script

	; people-events
	db 6
	person_event $35, 14, 8, $6, $0, 255, 255, $0, 0, ObjectEvent, $076d
	person_event $1d, 7, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x188432, $076f
	person_event $32, 10, 8, $9, $0, 255, 255, $a2, 3, TrainerSwimmerfDiana, $076f
	person_event $32, 13, 5, $9, $0, 255, 255, $a2, 1, TrainerSwimmerfBriana, $076f
	person_event $31, 13, 12, $8, $0, 255, 255, $82, 3, TrainerSwimmermParker, $076f
	person_event $48, 17, 11, $6, $0, 255, 255, $90, 0, CeruleanGymGuyScript, $076f
; 0x188abe

CeruleanMart_MapScriptHeader: ; 0x188abe
	; trigger count
	db 0

	; callback count
	db 0
; 0x188ac0

UnknownScript_0x188ac0: ; 0x188ac0
	loadfont
	pokemart $0, $0014
	loadmovesprites
	end
; 0x188ac7

UnknownScript_0x188ac7: ; 0x188ac7
	jumptextfaceplayer UnknownText_0x188acd
; 0x188aca

UnknownScript_0x188aca: ; 0x188aca
	jumptextfaceplayer UnknownText_0x188b46
; 0x188acd

UnknownText_0x188acd: ; 0x188acd
	db $0, "You'll run into", $4f
	db "many trainers on", $51
	db "the way to CERU-", $4f
	db "LEAN's CAPE.", $51
	db "They want to see", $4f
	db "how they stack", $51
	db "up against other", $4f
	db "trainers.", $57
; 0x188b46

UnknownText_0x188b46: ; 0x188b46
	db $0, "MISTY is about the", $4f
	db "only person in", $51
	db "town who can beat", $4f
	db "the trainers at", $55
	db "CERULEAN's CAPE.", $57
; 0x188b9b

CeruleanMart_MapEventHeader: ; 0x188b9b
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 6, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY
	warp_def $7, $3, 6, GROUP_CERULEAN_CITY, MAP_CERULEAN_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x188ac0, $ffff
	person_event $23, 10, 5, $6, $0, 255, 255, $a0, 0, UnknownScript_0x188ac7, $ffff
	person_event $24, 6, 11, $5, $2, 255, 255, $80, 0, UnknownScript_0x188aca, $ffff
; 0x188bd2

Route10PokeCenter1F_MapScriptHeader: ; 0x188bd2
	; trigger count
	db 0

	; callback count
	db 0
; 0x188bd4

UnknownScript_0x188bd4: ; 0x188bd4
	jumpstd $0000
; 0x188bd7

UnknownScript_0x188bd7: ; 0x188bd7
	jumptextfaceplayer UnknownText_0x188bf1
; 0x188bda

UnknownScript_0x188bda: ; 0x188bda
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x188be8
	2writetext UnknownText_0x188c26
	closetext
	loadmovesprites
	end
; 0x188be8

UnknownScript_0x188be8: ; 0x188be8
	2writetext UnknownText_0x188c9e
	closetext
	loadmovesprites
	end
; 0x188bee

UnknownScript_0x188bee: ; 0x188bee
	jumptextfaceplayer UnknownText_0x188d0c
; 0x188bf1

UnknownText_0x188bf1: ; 0x188bf1
	db $0, "A #MON CENTER", $4f
	db "near a cave?", $51
	db "That's mighty", $4f
	db "convenient.", $57
; 0x188c26

UnknownText_0x188c26: ; 0x188c26
	db $0, "The POWER PLANT's", $4f
	db "MANAGER is looking", $51
	db "for a strong #-", $4f
	db "MON trainer.", $51
	db "He needs help", $4f
	db "getting back", $51
	db "something that", $4f
	db "was stolen.", $57
; 0x188c9e

UnknownText_0x188c9e: ; 0x188c9e
	db $0, "I hear TEAM ROCKET", $4f
	db "got back together", $51
	db "in JOHTO but fell", $4f
	db "apart right away.", $51
	db "I didn't know any-", $4f
	db "thing about that.", $57
; 0x188d0c

UnknownText_0x188d0c: ; 0x188d0c
	db $0, "When you go out-", $4f
	db "side, you can see", $51
	db "the roof of a big", $4f
	db "building.", $51
	db "That's the POWER", $4f
	db "PLANT.", $57
; 0x188d63

Route10PokeCenter1F_MapEventHeader: ; 0x188d63
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_ROUTE_10_NORTH, MAP_ROUTE_10_NORTH
	warp_def $7, $4, 1, GROUP_ROUTE_10_NORTH, MAP_ROUTE_10_NORTH
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x188bd4, $ffff
	person_event $40, 10, 11, $5, $1, 255, 255, $80, 0, UnknownScript_0x188bd7, $ffff
	person_event $48, 6, 11, $3, $0, 255, 255, $a0, 0, UnknownScript_0x188bda, $ffff
	person_event $24, 7, 5, $6, $0, 255, 255, $0, 0, UnknownScript_0x188bee, $ffff
; 0x188dac

Route10PokeCenter2FBeta_MapScriptHeader: ; 0x188dac
	; trigger count
	db 0

	; callback count
	db 0
; 0x188dae

Route10PokeCenter2FBeta_MapEventHeader: ; 0x188dae
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 3, GROUP_ROUTE_10_POKECENTER_1F, MAP_ROUTE_10_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x188db9

PowerPlant_MapScriptHeader: ; 0x188db9
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x188dc3, $0000
	dw UnknownScript_0x188dc4, $0000

	; callback count
	db 0
; 0x188dc3

UnknownScript_0x188dc3: ; 0x188dc3
	end
; 0x188dc4

UnknownScript_0x188dc4: ; 0x188dc4
	end
; 0x188dc5

UnknownScript_0x188dc5: ; 0x188dc5
	playsound $006a
	showemote $0, $2, 15
	waitbutton
	pause 30
	applymovement $2, MovementData_0x188ed5
	spriteface $3, $0
	spriteface $4, $0
	loadfont
	2writetext UnknownText_0x188f22
	closetext
	loadmovesprites
	spriteface $2, $2
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x188f7f
	closetext
	loadmovesprites
	spriteface $0, $0
	applymovement $2, MovementData_0x188eda
	dotrigger $0
	end
; 0x188df5

UnknownScript_0x188df5: ; 0x188df5
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x188e0f
	checkbit1 $00ca
	iftrue UnknownScript_0x188e09
	2writetext UnknownText_0x188ee0
	closetext
	loadmovesprites
	end
; 0x188e09

UnknownScript_0x188e09: ; 0x188e09
	2writetext UnknownText_0x188f7f
	closetext
	loadmovesprites
	end
; 0x188e0f

UnknownScript_0x188e0f: ; 0x188e0f
	2writetext UnknownText_0x188fa2
	closetext
	loadmovesprites
	end
; 0x188e15

UnknownScript_0x188e15: ; 0x188e15
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x188e23
	2writetext UnknownText_0x188fcf
	closetext
	loadmovesprites
	end
; 0x188e23

UnknownScript_0x188e23: ; 0x188e23
	2writetext UnknownText_0x189038
	closetext
	loadmovesprites
	end
; 0x188e29

UnknownScript_0x188e29: ; 0x188e29
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x188e37
	2writetext UnknownText_0x189079
	closetext
	loadmovesprites
	end
; 0x188e37

UnknownScript_0x188e37: ; 0x188e37
	2writetext UnknownText_0x1890ef
	closetext
	loadmovesprites
	end
; 0x188e3d

UnknownScript_0x188e3d: ; 0x188e3d
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x188e4b
	2writetext UnknownText_0x18910e
	closetext
	loadmovesprites
	end
; 0x188e4b

UnknownScript_0x188e4b: ; 0x188e4b
	2writetext UnknownText_0x18917f
	closetext
	loadmovesprites
	end
; 0x188e51

UnknownScript_0x188e51: ; 0x188e51
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x188e5f
	2writetext UnknownText_0x1891c2
	closetext
	loadmovesprites
	end
; 0x188e5f

UnknownScript_0x188e5f: ; 0x188e5f
	2writetext UnknownText_0x189225
	closetext
	loadmovesprites
	end
; 0x188e65

UnknownScript_0x188e65: ; 0x188e65
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x188eac
	checkitem MACHINE_PART
	iftrue UnknownScript_0x188e93
	checkbit1 $00ca
	iftrue UnknownScript_0x188e8d
	2writetext UnknownText_0x189264
	closetext
	loadmovesprites
	setbit1 $00ca
	clearbit1 $076d
	clearbit1 $00fb
	domaptrigger GROUP_CERULEAN_GYM, MAP_CERULEAN_GYM, $1
	dotrigger $1
	end
; 0x188e8d

UnknownScript_0x188e8d: ; 0x188e8d
	2writetext UnknownText_0x189308
	closetext
	loadmovesprites
	end
; 0x188e93

UnknownScript_0x188e93: ; 0x188e93
	2writetext UnknownText_0x18936e
	keeptextopen
	takeitem MACHINE_PART, 1
	setbit1 $00c9
	clearbit1 $0772
	setbit1 $0771
	setbit1 $076c
	setbit1 $00cd
	clearbit1 $0749
UnknownScript_0x188eac: ; 0x188eac
	checkbit1 $00df
	iftrue UnknownScript_0x188ec5
	2writetext UnknownText_0x1893c4
	keeptextopen
	verbosegiveitem TM_07, 1
	iffalse UnknownScript_0x188ec3
	setbit1 $00df
	2writetext UnknownText_0x1893f4
	closetext
UnknownScript_0x188ec3: ; 0x188ec3
	loadmovesprites
	end
; 0x188ec5

UnknownScript_0x188ec5: ; 0x188ec5
	2writetext UnknownText_0x189475
	closetext
	loadmovesprites
	end
; 0x188ecb

UnknownScript_0x188ecb: ; 0x188ecb
	faceplayer
	loadfont
	trade $6
	closetext
	loadmovesprites
	end
; 0x188ed2

MapPowerPlantSignpost1Script: ; 0x188ed2
	jumpstd $0001
; 0x188ed5

MovementData_0x188ed5: ; 0x188ed5
	step_right
	step_right
	step_up
	step_up
	step_end
; 0x188eda

MovementData_0x188eda: ; 0x188eda
	step_down
	step_down
	step_left
	step_left
	turn_head_down
	step_end
; 0x188ee0

UnknownText_0x188ee0: ; 0x188ee0
	db $0, "A thief broke into", $4f
	db "the POWER PLANT…", $51
	db "What is the world", $4f
	db "coming to?", $57
; 0x188f22

UnknownText_0x188f22: ; 0x188f22
	db $0, "I just got word", $4f
	db "from CERULEAN.", $51
	db "It appears that a", $4f
	db "shady character", $51
	db "has been loitering", $4f
	db "around.", $57
; 0x188f7f

UnknownText_0x188f7f: ; 0x188f7f
	db $0, "Could I ask for", $4f
	db "your cooperation?", $57
; 0x188fa2

UnknownText_0x188fa2: ; 0x188fa2
	db $0, "We'll have to beef", $4f
	db "up our security", $55
	db "presence.", $57
; 0x188fcf

UnknownText_0x188fcf: ; 0x188fcf
	db $0, "Someone made off", $4f
	db "with a part that's", $51
	db "essential for the", $4f
	db "generator.", $51
	db "Without it, the", $4f
	db "new generator's", $55
	db "useless!", $57
; 0x189038

UnknownText_0x189038: ; 0x189038
	db $0, "The generator's up", $4f
	db "and running. It's", $51
	db "making electricity", $4f
	db "to spare.", $57
; 0x189079

UnknownText_0x189079: ; 0x189079
	db $0, "This POWER PLANT", $4f
	db "had been abandoned", $55
	db "in the past.", $51
	db "We got it back up", $4f
	db "and running to", $51
	db "provide power to", $4f
	db "the MAGNET TRAIN.", $57
; 0x1890ef

UnknownText_0x1890ef: ; 0x1890ef
	db $0, "The generator's", $4f
	db "running again!", $57
; 0x18910e

UnknownText_0x18910e: ; 0x18910e
	db $0, "The POWER PLANT's", $4f
	db "MANAGER is up", $55
	db "ahead.", $51
	db "But since someone", $4f
	db "wrecked the gener-", $55
	db "ator, he's been", $55
	db "both sad and", $55
	db "furious…", $57
; 0x18917f

UnknownText_0x18917f: ; 0x18917f
	db $0, "Since the gener-", $4f
	db "ator's been fixed,", $51
	db "the MANAGER has", $4f
	db "been cheerful.", $57
; 0x1891c2

UnknownText_0x1891c2: ; 0x1891c2
	db $0, "The MAGNET TRAIN", $4f
	db "consumes a lot of", $55
	db "electricity.", $51
	db "It can't move if", $4f
	db "the new generator", $55
	db "isn't operating.", $57
; 0x189225

UnknownText_0x189225: ; 0x189225
	db $0, "All right! We can", $4f
	db "finally get the", $51
	db "MAGNET TRAIN", $4f
	db "running again.", $57
; 0x189264

UnknownText_0x189264: ; 0x189264
	db $0, "MANAGER: I, I, I'm", $4f
	db "ready to blast", $55
	db "someone!", $51
	db "Who would dare", $4f
	db "ruin my generator?", $51
	db "I spent so much", $4f
	db "time on it!", $51
	db "If I catch him,", $4f
	db "he's going to get", $51
	db "a taste of my ZAP", $4f
	db "CANNON!", $57
; 0x189308

UnknownText_0x189308: ; 0x189308
	db $0, "MANAGER: I won't", $4f
	db "forgive him!", $51
	db "The culprit can", $4f
	db "cry and apologize,", $51
	db "but I'll still", $4f
	db "hammer him!", $51
	db "Gahahahah!", $57
; 0x18936e

UnknownText_0x18936e: ; 0x18936e
	db $0, "MANAGER: Ah! Yeah!", $51
	db "That's the missing", $4f
	db "PART from my be-", $55
	db "loved generator!", $55
	db "You found it?", $57
; 0x1893c4

UnknownText_0x1893c4: ; 0x1893c4
	db $0, "Wahah! Thanks!", $51
	db "Here! Take this TM", $4f
	db "as a reward!", $57
; 0x1893f4

UnknownText_0x1893f4: ; 0x1893f4
	db $0, "MANAGER: TM07 is", $4f
	db "my ZAP CANNON.", $51
	db "It's a powerful", $4f
	db "technique!", $51
	db "It's not what any-", $4f
	db "one would consider", $51
	db "accurate, but it", $4f
	db "packs a wallop!", $57
; 0x189475

UnknownText_0x189475: ; 0x189475
	db $0, "MANAGER: My be-", $4f
	db "loved generator!", $51
	db "Keep pumping the", $4f
	db "electricity out!", $57
; 0x1894b9

PowerPlant_MapEventHeader: ; 0x1894b9
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $11, $2, 2, GROUP_ROUTE_10_NORTH, MAP_ROUTE_10_NORTH
	warp_def $11, $3, 2, GROUP_ROUTE_10_NORTH, MAP_ROUTE_10_NORTH

	; xy triggers
	db 1
	xy_trigger 1, $c, $5, $0, UnknownScript_0x188dc5, $0, $0

	; signposts
	db 2
	signpost 1, 0, $0, MapPowerPlantSignpost1Script
	signpost 1, 1, $0, MapPowerPlantSignpost1Script

	; people-events
	db 7
	person_event $43, 18, 8, $6, $0, 255, 255, $a0, 0, UnknownScript_0x188df5, $ffff
	person_event $48, 13, 6, $3, $0, 255, 255, $90, 0, UnknownScript_0x188e15, $ffff
	person_event $48, 15, 10, $7, $0, 255, 255, $90, 0, UnknownScript_0x188e29, $ffff
	person_event $43, 7, 13, $8, $0, 255, 255, $a0, 0, UnknownScript_0x188e3d, $ffff
	person_event $48, 6, 11, $5, $1, 255, 255, $90, 0, UnknownScript_0x188e51, $ffff
	person_event $3a, 14, 18, $7, $0, 255, 255, $80, 0, UnknownScript_0x188e65, $ffff
	person_event $48, 9, 9, $7, $0, 255, 255, $90, 0, UnknownScript_0x188ecb, $ffff
; 0x189536

BillsHouse_MapScriptHeader: ; 0x189536
	; trigger count
	db 0

	; callback count
	db 0
; 0x189538

UnknownScript_0x189538: ; 0x189538
	faceplayer
	loadfont
	checkbit1 $0000
	iftrue UnknownScript_0x1896ba
	checkbit1 $0324
	iftrue UnknownScript_0x1896c0
	checkbit1 $031a
	iftrue UnknownScript_0x189553
	2writetext UnknownText_0x1896ce
	keeptextopen
	setbit1 $031a
UnknownScript_0x189553: ; 0x189553
	checkbit1 $031f
	iftrue UnknownScript_0x189697
	checkbit1 $031e
	iftrue UnknownScript_0x189680
	checkbit1 $031d
	iftrue UnknownScript_0x189669
	checkbit1 $031c
	iftrue UnknownScript_0x189652
	checkbit1 $031b
	iftrue UnknownScript_0x18963b
	2writetext UnknownText_0x1898c0
	keeptextopen
	2writetext UnknownText_0x189732
	yesorno
	iffalse UnknownScript_0x1896aa
	2call UnknownScript_0x1896a5
	special $004d
	iffalse UnknownScript_0x1896aa
	if_not_equal LICKITUNG, UnknownScript_0x1896c6
	2call UnknownScript_0x1896b0
	setbit1 $031b
	2jump UnknownScript_0x18963b
; 0x189592

UnknownScript_0x189592: ; 0x189592
	2writetext UnknownText_0x1898ff
	keeptextopen
	2writetext UnknownText_0x189732
	yesorno
	iffalse UnknownScript_0x1896aa
	2call UnknownScript_0x1896a5
	special $004d
	iffalse UnknownScript_0x1896aa
	if_not_equal ODDISH, UnknownScript_0x1896c6
	2call UnknownScript_0x1896b0
	setbit1 $031c
	2jump UnknownScript_0x189652
; 0x1895b3

UnknownScript_0x1895b3: ; 0x1895b3
	2writetext UnknownText_0x189953
	keeptextopen
	2writetext UnknownText_0x189732
	yesorno
	iffalse UnknownScript_0x1896aa
	2call UnknownScript_0x1896a5
	special $004d
	iffalse UnknownScript_0x1896aa
	if_not_equal STARYU, UnknownScript_0x1896c6
	2call UnknownScript_0x1896b0
	setbit1 $031d
	2jump UnknownScript_0x189669
; 0x1895d4

UnknownScript_0x1895d4: ; 0x1895d4
	checkver
	iftrue UnknownScript_0x1895f9
	2writetext UnknownText_0x1899fe
	keeptextopen
	2writetext UnknownText_0x189732
	yesorno
	iffalse UnknownScript_0x1896aa
	2call UnknownScript_0x1896a5
	special $004d
	iffalse UnknownScript_0x1896aa
	if_not_equal GROWLITHE, UnknownScript_0x1896c6
	2call UnknownScript_0x1896b0
	setbit1 $031e
	2jump UnknownScript_0x189680
; 0x1895f9

UnknownScript_0x1895f9: ; 0x1895f9
	2writetext UnknownText_0x189a57
	keeptextopen
	2writetext UnknownText_0x189732
	yesorno
	iffalse UnknownScript_0x1896aa
	2call UnknownScript_0x1896a5
	special $004d
	iffalse UnknownScript_0x1896aa
	if_not_equal VULPIX, UnknownScript_0x1896c6
	2call UnknownScript_0x1896b0
	setbit1 $031e
	2jump UnknownScript_0x189680
; 0x18961a

UnknownScript_0x18961a: ; 0x18961a
	2writetext UnknownText_0x189ab1
	keeptextopen
	2writetext UnknownText_0x189732
	yesorno
	iffalse UnknownScript_0x1896aa
	2call UnknownScript_0x1896a5
	special $004d
	iffalse UnknownScript_0x1896aa
	if_not_equal PICHU, UnknownScript_0x1896c6
	2call UnknownScript_0x1896b0
	setbit1 $031f
	2jump UnknownScript_0x189697
; 0x18963b

UnknownScript_0x18963b: ; 0x18963b
	checkbit1 $0320
	iftrue UnknownScript_0x189592
	2call UnknownScript_0x1896b5
	verbosegiveitem EVERSTONE, 1
	iffalse UnknownScript_0x1896cc
	setbit1 $0320
	setbit1 $0000
	loadmovesprites
	end
; 0x189652

UnknownScript_0x189652: ; 0x189652
	checkbit1 $0321
	iftrue UnknownScript_0x1895b3
	2call UnknownScript_0x1896b5
	verbosegiveitem LEAF_STONE, 1
	iffalse UnknownScript_0x1896cc
	setbit1 $0321
	setbit1 $0000
	loadmovesprites
	end
; 0x189669

UnknownScript_0x189669: ; 0x189669
	checkbit1 $0322
	iftrue UnknownScript_0x1895d4
	2call UnknownScript_0x1896b5
	verbosegiveitem WATER_STONE, 1
	iffalse UnknownScript_0x1896cc
	setbit1 $0322
	setbit1 $0000
	loadmovesprites
	end
; 0x189680

UnknownScript_0x189680: ; 0x189680
	checkbit1 $0323
	iftrue UnknownScript_0x18961a
	2call UnknownScript_0x1896b5
	verbosegiveitem FIRE_STONE, 1
	iffalse UnknownScript_0x1896cc
	setbit1 $0323
	setbit1 $0000
	loadmovesprites
	end
; 0x189697

UnknownScript_0x189697: ; 0x189697
	2call UnknownScript_0x1896b5
	verbosegiveitem THUNDERSTONE, 1
	iffalse UnknownScript_0x1896cc
	setbit1 $0324
	loadmovesprites
	end
; 0x1896a5

UnknownScript_0x1896a5: ; 0x1896a5
	2writetext UnknownText_0x189760
	keeptextopen
	end
; 0x1896aa

UnknownScript_0x1896aa: ; 0x1896aa
	2writetext UnknownText_0x189784
	closetext
	loadmovesprites
	end
; 0x1896b0

UnknownScript_0x1896b0: ; 0x1896b0
	2writetext UnknownText_0x1897a6
	keeptextopen
	end
; 0x1896b5

UnknownScript_0x1896b5: ; 0x1896b5
	2writetext UnknownText_0x1897e1
	keeptextopen
	end
; 0x1896ba

UnknownScript_0x1896ba: ; 0x1896ba
	2writetext UnknownText_0x18980e
	closetext
	loadmovesprites
	end
; 0x1896c0

UnknownScript_0x1896c0: ; 0x1896c0
	2writetext UnknownText_0x18982a
	closetext
	loadmovesprites
	end
; 0x1896c6

UnknownScript_0x1896c6: ; 0x1896c6
	2writetext UnknownText_0x189891
	closetext
	loadmovesprites
	end
; 0x1896cc

UnknownScript_0x1896cc: ; 0x1896cc
	loadmovesprites
	end
; 0x1896ce

UnknownText_0x1896ce: ; 0x1896ce
	db $0, "Hm? You know BILL?", $4f
	db "He's my grandson.", $51
	db "He's in JOHTO. He", $4f
	db "does something", $51
	db "with PCs, so I'm", $4f
	db "house-sitting.", $57
; 0x189732

UnknownText_0x189732: ; 0x189732
	db $0, "If you have that", $4f
	db "#MON, may I see", $55
	db "it, please?", $57
; 0x189760

UnknownText_0x189760: ; 0x189760
	db $0, "You will show me?", $4f
	db "How good of you!", $57
; 0x189784

UnknownText_0x189784: ; 0x189784
	db $0, "You don't have it?", $4f
	db "That's too bad…", $57
; 0x1897a6

UnknownText_0x1897a6: ; 0x1897a6
	db $0, "Ah, so that is", $4f
	db "@"
	text_from_ram $d099
	db $0, "?", $51
	db "Isn't it cute!", $4f
	db "That's so kind of", $55
	db "you.", $57
; 0x1897e1

UnknownText_0x1897e1: ; 0x1897e1
	db $0, "Thanks!", $51
	db "This is a token of", $4f
	db "my appreciation.", $57
; 0x18980e

UnknownText_0x18980e: ; 0x18980e
	db $0, "Come visit again", $4f
	db "sometime.", $57
; 0x18982a

UnknownText_0x18982a: ; 0x18982a
	db $0, "Thanks for showing", $4f
	db "me so many cute", $55
	db "#MON.", $51
	db "I really enjoyed", $4f
	db "myself. I'm glad", $51
	db "I've lived such a", $4f
	db "long life.", $57
; 0x189891

UnknownText_0x189891: ; 0x189891
	db $0, "Hm?", $51
	db "That's not the", $4f
	db "#MON that I was", $55
	db "told about.", $57
; 0x1898c0

UnknownText_0x1898c0: ; 0x1898c0
	db $0, "My grandson BILL", $4f
	db "told me about a", $51
	db "#MON that has a", $4f
	db "long tongue.", $57
; 0x1898ff

UnknownText_0x1898ff: ; 0x1898ff
	db $0, "Ah, my grandson", $4f
	db "mentioned a round,", $51
	db "green #MON that", $4f
	db "has leaves growing", $55
	db "on its head.", $57
; 0x189953

UnknownText_0x189953: ; 0x189953
	db $0, "Do you know of a", $4f
	db "sea #MON that", $51
	db "has a red sphere", $4f
	db "in its body?", $51
	db "You know, the one", $4f
	db "that's shaped like", $55
	db "a star?", $51
	db "I heard that it", $4f
	db "appears at night.", $51
	db "I would surely", $4f
	db "like to see it.", $57
; 0x1899fe

UnknownText_0x1899fe: ; 0x1899fe
	db $0, "BILL told me about", $4f
	db "a #MON that is", $51
	db "very loyal to its", $4f
	db "trainer.", $51
	db "It's supposed to", $4f
	db "ROAR well.", $57
; 0x189a57

UnknownText_0x189a57: ; 0x189a57
	db $0, "I heard about a", $4f
	db "cute #MON that", $55
	db "has six tails.", $51
	db "I would love to", $4f
	db "hug a cute #MON", $55
	db "like that.", $57
; 0x189ab1

UnknownText_0x189ab1: ; 0x189ab1
	db $0, "Do you know that", $4f
	db "hugely popular", $55
	db "#MON?", $51
	db "The #MON that", $4f
	db "has a yellow body", $55
	db "and red cheeks.", $51
	db "I would love to", $4f
	db "see what it looks", $51
	db "like before it", $4f
	db "evolves.", $57
; 0x189b42

BillsHouse_MapEventHeader: ; 0x189b42
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_ROUTE_25, MAP_ROUTE_25
	warp_def $7, $3, 1, GROUP_ROUTE_25, MAP_ROUTE_25

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $2f, 7, 6, $7, $20, 255, 255, $90, 0, UnknownScript_0x189538, $ffff
; 0x189b5f

FightingDojo_MapScriptHeader: ; 0x189b5f
	; trigger count
	db 0

	; callback count
	db 0
; 0x189b61

UnknownScript_0x189b61: ; 0x189b61
	jumptextfaceplayer UnknownText_0x189b6c
; 0x189b64

MapFightingDojoSignpost0Script: ; 0x189b64
	jumptext UnknownText_0x189bc0
; 0x189b67

MapFightingDojoSignpost1Script: ; 0x189b67
	jumptext UnknownText_0x189be0
; 0x189b6a

ItemFragment_0x189b6a: ; 0x189b6a
	db FOCUS_BAND, 1
; 0x189b6c

UnknownText_0x189b6c: ; 0x189b6c
	db $0, "Hello!", $51
	db "KARATE KING, the", $4f
	db "FIGHTING DOJO's", $51
	db "master, is in a", $4f
	db "cave in JOHTO for", $55
	db "training.", $57
; 0x189bc0

UnknownText_0x189bc0: ; 0x189bc0
	db $0, "What goes around", $4f
	db "comes around!", $57
; 0x189be0

UnknownText_0x189be0: ; 0x189be0
	db $0, "Enemies on every", $4f
	db "side!", $57
; 0x189bf8

FightingDojo_MapEventHeader: ; 0x189bf8
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $b, $4, 1, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $b, $5, 1, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 4, $0, MapFightingDojoSignpost0Script
	signpost 0, 5, $0, MapFightingDojoSignpost1Script

	; people-events
	db 2
	person_event $41, 8, 8, $6, $0, 255, 255, $90, 0, UnknownScript_0x189b61, $ffff
	person_event $54, 5, 7, $1, $0, 255, 255, $1, 0, ItemFragment_0x189b6a, $077d
; 0x189c2c

SaffronGym_MapScriptHeader: ; 0x189c2c
	; trigger count
	db 0

	; callback count
	db 0
; 0x189c2e

UnknownScript_0x189c2e: ; 0x189c2e
	faceplayer
	loadfont
	checkbit2 $0028
	iftrue UnknownScript_0x189c65
	2writetext UnknownText_0x189cdf
	closetext
	loadmovesprites
	winlosstext UnknownText_0x189df4, $0000
	loadtrainer SABRINA, 1
	startbattle
	returnafterbattle
	setbit1 $04ca
	setbit1 $0590
	setbit1 $0591
	setbit1 $043b
	setbit1 $0444
	loadfont
	2writetext UnknownText_0x189e95
	playsound $009c
	waitbutton
	setbit2 $0028
	2writetext UnknownText_0x189ead
	closetext
	loadmovesprites
	end
; 0x189c65

UnknownScript_0x189c65: ; 0x189c65
	2writetext UnknownText_0x189f6c
	closetext
	loadmovesprites
	end
; 0x189c6b

TrainerMediumRebecca: ; 0x189c6b
	; bit/flag number
	dw $590

	; trainer group && trainer id
	db MEDIUM, REBECCA

	; text when seen
	dw MediumRebeccaSeenText

	; text when trainer beaten
	dw MediumRebeccaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw MediumRebeccaScript
; 0x189c77

MediumRebeccaScript: ; 0x189c77
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18a034
	closetext
	loadmovesprites
	end
; 0x189c7f

TrainerPsychicFranklin: ; 0x189c7f
	; bit/flag number
	dw $43b

	; trainer group && trainer id
	db PSYCHIC_T, FRANKLIN

	; text when seen
	dw PsychicFranklinSeenText

	; text when trainer beaten
	dw PsychicFranklinBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicFranklinScript
; 0x189c8b

PsychicFranklinScript: ; 0x189c8b
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18a0a6
	closetext
	loadmovesprites
	end
; 0x189c93

TrainerMediumDoris: ; 0x189c93
	; bit/flag number
	dw $591

	; trainer group && trainer id
	db MEDIUM, DORIS

	; text when seen
	dw MediumDorisSeenText

	; text when trainer beaten
	dw MediumDorisBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw MediumDorisScript
; 0x189c9f

MediumDorisScript: ; 0x189c9f
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18a136
	closetext
	loadmovesprites
	end
; 0x189ca7

TrainerPsychicJared: ; 0x189ca7
	; bit/flag number
	dw $444

	; trainer group && trainer id
	db PSYCHIC_T, JARED

	; text when seen
	dw PsychicJaredSeenText

	; text when trainer beaten
	dw PsychicJaredBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicJaredScript
; 0x189cb3

PsychicJaredScript: ; 0x189cb3
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18a1b3
	closetext
	loadmovesprites
	end
; 0x189cbb

SaffronGymGuyScript: ; 0x189cbb
	faceplayer
	loadfont
	checkbit1 $04ca
	iftrue .SaffronGymGuyWinScript
	2writetext SaffronGymGuyText
	closetext
	loadmovesprites
	end

.SaffronGymGuyWinScript
	2writetext SaffronGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x189ccf

MapSaffronGymSignpost0Script: ; 0x189ccf
	checkbit2 $0028
	iftrue UnknownScript_0x189cd8
	jumpstd $002d
; 0x189cd8

UnknownScript_0x189cd8: ; 0x189cd8
	trainertotext SABRINA, 1, $1
	jumpstd $002e
; 0x189cdf

UnknownText_0x189cdf: ; 0x189cdf
	db $0, "SABRINA: I knew", $4f
	db "you were coming…", $51
	db "Three years ago I", $4f
	db "had a vision of", $55
	db "your arrival.", $51
	db "You're after my", $4f
	db "BADGE.", $51
	db "I don't enjoy bat-", $4f
	db "tling, but it's my", $51
	db "duty as a LEADER", $4f
	db "to confer BADGES", $51
	db "on anyone who has", $4f
	db "proven him- or", $55
	db "herself worthy.", $51
	db "Since you wish it,", $4f
	db "I will show you my", $55
	db "psychic powers!", $57
; 0x189df4

UnknownText_0x189df4: ; 0x189df4
	db $0, "SABRINA: Your", $4f
	db "power…", $51
	db "It far exceeds", $4f
	db "what I foresaw…", $51
	db "Maybe it isn't", $4f
	db "possible to fully", $51
	db "predict what the", $4f
	db "future holds…", $51
	db "OK, you win. You", $4f
	db "earned yourself", $55
	db "MARSHBADGE.", $57
; 0x189e95

UnknownText_0x189e95: ; 0x189e95
	db $0, $52, " received", $4f
	db "MARSHBADGE.", $57
; 0x189ead

UnknownText_0x189ead: ; 0x189ead
	db $0, "SABRINA: MARSH-", $4f
	db "BADGE draws out", $51
	db "your subliminal", $4f
	db "powers…", $51
	db "Although I failed", $4f
	db "to accurately pre-", $55
	db "dict your power,", $55
	db "this much I know", $55
	db "to be true.", $51
	db "You will become a", $4f
	db "celebrated and", $55
	db "beloved CHAMPION!", $57
; 0x189f6c

UnknownText_0x189f6c: ; 0x189f6c
	db $0, "SABRINA: Your love", $4f
	db "for your #MON", $51
	db "overwhelmed my", $4f
	db "psychic power…", $51
	db "The power of love,", $4f
	db "I think, is also a", $51
	db "kind of psychic", $4f
	db "power…", $57
; 0x189fe9

MediumRebeccaSeenText: ; 0x189fe9
	db $0, "The power of all", $4f
	db "those you defeated", $55
	db "comes to me!", $57
; 0x18a01b

MediumRebeccaBeatenText: ; 0x18a01b
	db $0, "Strong…", $4f
	db "Far too strong…", $57
; 0x18a034

UnknownText_0x18a034: ; 0x18a034
	db $0, "What is the source", $4f
	db "of your power?", $57
; 0x18a057

PsychicFranklinSeenText: ; 0x18a057
	db $0, "Psychic power is", $4f
	db "the power of your", $55
	db "soul.", $57
; 0x18a081

PsychicFranklinBeatenText: ; 0x18a081
	db $0, "Your soul has more", $4f
	db "power than mine!", $57
; 0x18a0a6

UnknownText_0x18a0a6: ; 0x18a0a6
	db $0, "You made your soul", $4f
	db "stronger, not just", $55
	db "your abilities.", $57
; 0x18a0dd

MediumDorisSeenText: ; 0x18a0dd
	db $0, "Fufufufu…", $4f
	db "I see it clearly.", $51
	db "I can see into", $4f
	db "your soul!", $57
; 0x18a114

MediumDorisBeatenText: ; 0x18a114
	db $0, "Though I read you,", $4f
	db "I still lost…", $57
; 0x18a136

UnknownText_0x18a136: ; 0x18a136
	db $0, "Darn! I forgot", $4f
	db "that I predicted I", $55
	db "would lose to you.", $57
; 0x18a16c

PsychicJaredSeenText: ; 0x18a16c
	db $0, "The FIGHTING DOJO", $4f
	db "next door was once", $55
	db "this city's GYM.", $57
; 0x18a1a2

PsychicJaredBeatenText: ; 0x18a1a2
	db $0, "I was no match…", $57
; 0x18a1b3

UnknownText_0x18a1b3: ; 0x18a1b3
	db $0, "KARATE KING, the", $4f
	db "master of the", $51
	db "FIGHTING DOJO, was", $4f
	db "just destroyed by", $55
	db "SABRINA.", $57
; 0x18a201

SaffronGymGuyText: ; 0x18a201
	db $0, "Yo, CHAMP in", $4f
	db "making!", $51
	db "A trainer as", $4f
	db "skilled as you", $51
	db "doesn't need to be", $4f
	db "told how to deal", $51
	db "with psychic-type", $4f
	db "#MON, right?", $51
	db "I expect great", $4f
	db "things from you!", $51
	db "Good luck!", $57
; 0x18a2a0

SaffronGymGuyWinText: ; 0x18a2a0
	db $0, "That was another", $4f
	db "fantastic battle!", $57
; 0x18a2c4

SaffronGym_MapEventHeader: ; 0x18a2c4
	; filler
	db 0, 0

	; warps
	db 32
	warp_def $11, $8, 2, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $11, $9, 2, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $f, $b, 18, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $f, $13, 19, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $b, $13, 20, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $b, $1, 21, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $3, $5, 22, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $5, $b, 23, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $f, $1, 24, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $3, $13, 25, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $11, $f, 26, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $11, $5, 27, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $9, $5, 28, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $3, $9, 29, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $9, $f, 30, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $5, $f, 31, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $5, $1, 32, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $11, $13, 3, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $9, $13, 4, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $9, $1, 5, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $5, $5, 6, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $3, $b, 7, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $11, $1, 8, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $5, $13, 9, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $f, $f, 10, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $f, $5, 11, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $b, $5, 12, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $5, $9, 13, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $b, $f, 14, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $3, $f, 15, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $3, $1, 16, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $9, $b, 17, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 15, 8, $0, MapSaffronGymSignpost0Script

	; people-events
	db 6
	person_event $22, 12, 13, $6, $0, 255, 255, $80, 0, UnknownScript_0x189c2e, $ffff
	person_event $30, 20, 21, $a, $0, 255, 255, $b2, 3, TrainerMediumRebecca, $ffff
	person_event $27, 20, 7, $a, $0, 255, 255, $92, 3, TrainerPsychicFranklin, $ffff
	person_event $30, 8, 7, $a, $0, 255, 255, $b2, 2, TrainerMediumDoris, $ffff
	person_event $27, 8, 21, $a, $0, 255, 255, $92, 2, TrainerPsychicJared, $ffff
	person_event $48, 18, 13, $6, $0, 255, 255, $90, 0, SaffronGymGuyScript, $ffff
; 0x18a3bd

SaffronMart_MapScriptHeader: ; 0x18a3bd
	; trigger count
	db 0

	; callback count
	db 0
; 0x18a3bf

UnknownScript_0x18a3bf: ; 0x18a3bf
	loadfont
	pokemart $0, $001e
	loadmovesprites
	end
; 0x18a3c6

UnknownScript_0x18a3c6: ; 0x18a3c6
	jumptextfaceplayer UnknownText_0x18a3cc
; 0x18a3c9

UnknownScript_0x18a3c9: ; 0x18a3c9
	jumptextfaceplayer UnknownText_0x18a3f3
; 0x18a3cc

UnknownText_0x18a3cc: ; 0x18a3cc
	db $0, "There's a big", $4f
	db "RADIO TOWER in", $55
	db "LAVENDER.", $57
; 0x18a3f3

UnknownText_0x18a3f3: ; 0x18a3f3
	db $0, "I want to become", $4f
	db "stronger, but I'm", $55
	db "not good yet…", $51
	db "Could you show me", $4f
	db "how sometime?", $57
; 0x18a444

SaffronMart_MapEventHeader: ; 0x18a444
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $7, $3, 3, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x18a3bf, $ffff
	person_event $23, 6, 11, $3, $0, 255, 255, $b0, 0, UnknownScript_0x18a3c6, $ffff
	person_event $24, 10, 11, $5, $1, 255, 255, $a0, 0, UnknownScript_0x18a3c9, $ffff
; 0x18a47b

SaffronPokeCenter1F_MapScriptHeader: ; 0x18a47b
	; trigger count
	db 0

	; callback count
	db 0
; 0x18a47d

UnknownScript_0x18a47d: ; 0x18a47d
	jumpstd $0000
; 0x18a480

UnknownScript_0x18a480: ; 0x18a480
	special $00a0
	iftrue UnknownScript_0x18a489
	jumptextfaceplayer UnknownText_0x18a4a3
; 0x18a489

UnknownScript_0x18a489: ; 0x18a489
	jumptextfaceplayer UnknownText_0x18a532
; 0x18a48c

UnknownScript_0x18a48c: ; 0x18a48c
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x18a49a
	2writetext UnknownText_0x18a5d3
	closetext
	loadmovesprites
	end
; 0x18a49a

UnknownScript_0x18a49a: ; 0x18a49a
	2writetext UnknownText_0x18a62e
	closetext
	loadmovesprites
	end
; 0x18a4a0

UnknownScript_0x18a4a0: ; 0x18a4a0
	jumptextfaceplayer UnknownText_0x18a6c5
; 0x18a4a3

UnknownText_0x18a4a3: ; 0x18a4a3
	db $0, "What are JOHTO's", $4f
	db "#MON CENTERS", $55
	db "like?", $51
	db "…Oh, I see. So", $4f
	db "they're not much", $51
	db "different from the", $4f
	db "ones in KANTO.", $51
	db "I can go to JOHTO", $4f
	db "without worrying,", $55
	db "then!", $57
; 0x18a532

UnknownText_0x18a532: ; 0x18a532
	db $0, "What are JOHTO's", $4f
	db "#MON CENTERS", $55
	db "like?", $51
	db "…Oh, I see.", $4f
	db "So they let you", $51
	db "link with people", $4f
	db "far away?", $51
	db "Then I'll get my", $4f
	db "friend in JOHTO to", $51
	db "catch a MARILL and", $4f
	db "trade it to me!", $57
; 0x18a5d3

UnknownText_0x18a5d3: ; 0x18a5d3
	db $0, "I just happened to", $4f
	db "come through ROCK", $51
	db "TUNNEL. There was", $4f
	db "some commotion at", $55
	db "the POWER PLANT.", $57
; 0x18a62e

UnknownText_0x18a62e: ; 0x18a62e
	db $0, "Caves collapse", $4f
	db "easily.", $51
	db "Several caves have", $4f
	db "disappeared in the", $51
	db "past few years,", $4f
	db "like the one out-", $55
	db "side CERULEAN.", $51
	db "As a pro HIKER,", $4f
	db "that's common", $55
	db "knowledge.", $57
; 0x18a6c5

UnknownText_0x18a6c5: ; 0x18a6c5
	db $0, "SILPH CO.'s HEAD", $4f
	db "OFFICE and the", $51
	db "MAGNET TRAIN STA-", $4f
	db "TION--they're the", $51
	db "places to see in", $4f
	db "SAFFRON.", $57
; 0x18a722

SaffronPokeCenter1F_MapEventHeader: ; 0x18a722
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 4, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $7, $4, 4, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x18a47d, $ffff
	person_event $29, 6, 11, $2, $11, 255, 255, $a0, 0, UnknownScript_0x18a480, $ffff
	person_event $3a, 10, 12, $8, $0, 255, 255, $80, 0, UnknownScript_0x18a48c, $ffff
	person_event $27, 8, 5, $3, $0, 255, 255, $90, 0, UnknownScript_0x18a4a0, $ffff
; 0x18a76b

SaffronPokeCenter2FBeta_MapScriptHeader: ; 0x18a76b
	; trigger count
	db 0

	; callback count
	db 0
; 0x18a76d

SaffronPokeCenter2FBeta_MapEventHeader: ; 0x18a76d
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 3, GROUP_SAFFRON_POKECENTER_1F, MAP_SAFFRON_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x18a778

MrPsychicsHouse_MapScriptHeader: ; 0x18a778
	; trigger count
	db 0

	; callback count
	db 0
; 0x18a77a

UnknownScript_0x18a77a: ; 0x18a77a
	faceplayer
	loadfont
	checkbit1 $00e3
	iftrue UnknownScript_0x18a78f
	2writetext UnknownText_0x18a798
	keeptextopen
	verbosegiveitem TM_29, 1
	iffalse UnknownScript_0x18a793
	setbit1 $00e3
UnknownScript_0x18a78f: ; 0x18a78f
	2writetext UnknownText_0x18a7bb
	closetext
UnknownScript_0x18a793: ; 0x18a793
	loadmovesprites
	end
; 0x18a795

MapMrPsychicsHouseSignpost1Script: ; 0x18a795
	jumpstd $0001
; 0x18a798

UnknownText_0x18a798: ; 0x18a798
	db $0, "…", $51
	db "…", $51
	db "…", $51
	db "…I got it!", $51
	db "You wanted this!", $57
; 0x18a7bb

UnknownText_0x18a7bb: ; 0x18a7bb
	db $0, "TM29 is PSYCHIC.", $51
	db "It may lower the", $4f
	db "target's SPCL.DEF.", $57
; 0x18a7f0

MrPsychicsHouse_MapEventHeader: ; 0x18a7f0
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 5, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $7, $3, 5, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapMrPsychicsHouseSignpost1Script
	signpost 1, 1, $0, MapMrPsychicsHouseSignpost1Script

	; people-events
	db 1
	person_event $3b, 7, 9, $8, $0, 255, 255, $a0, 0, UnknownScript_0x18a77a, $ffff
; 0x18a817

SaffronTrainStation_MapScriptHeader: ; 0x18a817
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x18a81d, $0000

	; callback count
	db 0
; 0x18a81d

UnknownScript_0x18a81d: ; 0x18a81d
	end
; 0x18a81e

UnknownScript_0x18a81e: ; 0x18a81e
	faceplayer
	loadfont
	checkbit1 $00cd
	iftrue UnknownScript_0x18a82c
	2writetext UnknownText_0x18a8a9
	closetext
	loadmovesprites
	end
; 0x18a82c

UnknownScript_0x18a82c: ; 0x18a82c
	2writetext UnknownText_0x18a8dd
	yesorno
	iffalse UnknownScript_0x18a85c
	checkitem PASS
	iffalse UnknownScript_0x18a856
	2writetext UnknownText_0x18a917
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x18a88f
	applymovement $0, MovementData_0x18a898
	writebyte $1
	special $0023
	warpcheck
	newloadmap $f9
	applymovement $0, MovementData_0x18a854
	unknown0xa8 $14
	end
; 0x18a854

MovementData_0x18a854: ; 0x18a854
	turn_head_down
	step_end
; 0x18a856

UnknownScript_0x18a856: ; 0x18a856
	2writetext UnknownText_0x18a956
	closetext
	loadmovesprites
	end
; 0x18a85c

UnknownScript_0x18a85c: ; 0x18a85c
	2writetext UnknownText_0x18a978
	closetext
	loadmovesprites
	end
; 0x18a862

UnknownScript_0x18a862: ; 0x18a862
	applymovement $2, MovementData_0x18a88f
	applymovement $0, MovementData_0x18a8a1
	applymovement $2, MovementData_0x18a894
	loadfont
	2writetext UnknownText_0x18a993
	closetext
	loadmovesprites
	end
; 0x18a875

UnknownScript_0x18a875: ; 0x18a875
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x18a883
	2writetext UnknownText_0x18a9ca
	closetext
	loadmovesprites
	end
; 0x18a883

UnknownScript_0x18a883: ; 0x18a883
	2writetext UnknownText_0x18aa61
	closetext
	loadmovesprites
	end
; 0x18a889

UnknownScript_0x18a889: ; 0x18a889
	jumptextfaceplayer UnknownText_0x18aaab
; 0x18a88c

UnknownScript_0x18a88c: ; 0x18a88c
	jumptextfaceplayer UnknownText_0x18ab20
; 0x18a88f

MovementData_0x18a88f: ; 0x18a88f
	step_up
	step_up
	step_right
	turn_head_left
	step_end
; 0x18a894

MovementData_0x18a894: ; 0x18a894
	step_left
	step_down
	step_down
	step_end
; 0x18a898

MovementData_0x18a898: ; 0x18a898
	step_up
	step_up
	step_up
	step_left
	step_left
	step_left
	step_up
	step_up
	step_end
; 0x18a8a1

MovementData_0x18a8a1: ; 0x18a8a1
	step_left
	step_left
	step_down
	step_down
	step_down
	step_down
	turn_head_up
	step_end
; 0x18a8a9

UnknownText_0x18a8a9: ; 0x18a8a9
	db $0, "I'm sorry, but the", $4f
	db "MAGNET TRAIN isn't", $55
	db "operating now.", $57
; 0x18a8dd

UnknownText_0x18a8dd: ; 0x18a8dd
	db $0, "We'll soon depart", $4f
	db "for GOLDENROD.", $51
	db "Are you coming on", $4f
	db "board?", $57
; 0x18a917

UnknownText_0x18a917: ; 0x18a917
	db $0, "May I see your", $4f
	db "rail PASS, please?", $51
	db "OK. Right this", $4f
	db "way, please.", $57
; 0x18a956

UnknownText_0x18a956: ; 0x18a956
	db $0, "Sorry, but you", $4f
	db "don't have a PASS.", $57
; 0x18a978

UnknownText_0x18a978: ; 0x18a978
	db $0, "We hope to see you", $4f
	db "again.", $57
; 0x18a993

UnknownText_0x18a993: ; 0x18a993
	db $0, "We have arrived in", $4f
	db "SAFFRON.", $51
	db "We hope to see you", $4f
	db "again.", $57
; 0x18a9ca

UnknownText_0x18a9ca: ; 0x18a9ca
	db $0, "The MAGNET TRAIN", $4f
	db "is a super-modern", $51
	db "rail liner that", $4f
	db "uses electricity", $51
	db "and magnets to", $4f
	db "attain incredible", $55
	db "speed.", $51
	db "However, if there", $4f
	db "isn't any elec-", $55
	db "tricity…", $57
; 0x18aa61

UnknownText_0x18aa61: ; 0x18aa61
	db $0, "Whew…", $51
	db "How many times", $4f
	db "have I gone back", $51
	db "and forth between", $4f
	db "KANTO and JOHTO?", $57
; 0x18aaab

UnknownText_0x18aaab: ; 0x18aaab
	db $0, "Before the MAGNET", $4f
	db "TRAIN STATION was", $51
	db "built, there was a", $4f
	db "house there.", $51
	db "A little girl", $4f
	db "named COPYCAT used", $55
	db "to live there.", $57
; 0x18ab20

UnknownText_0x18ab20: ; 0x18ab20
	db $0, "Hi. Do you have a", $4f
	db "rail PASS? I have", $51
	db "one. All the peo-", $4f
	db "ple in SAFFRON who", $51
	db "ride the MAGNET", $4f
	db "TRAIN have PASSES.", $57
; 0x18ab8d

SaffronTrainStation_MapEventHeader: ; 0x18ab8d
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $11, $8, 6, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $11, $9, 6, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $5, $6, 4, GROUP_GOLDENROD_MAGNET_TRAIN_STATION, MAP_GOLDENROD_MAGNET_TRAIN_STATION
	warp_def $5, $b, 3, GROUP_GOLDENROD_MAGNET_TRAIN_STATION, MAP_GOLDENROD_MAGNET_TRAIN_STATION

	; xy triggers
	db 1
	xy_trigger 0, $6, $b, $0, UnknownScript_0x18a862, $0, $0

	; signposts
	db 0

	; people-events
	db 4
	person_event $43, 13, 13, $6, $0, 255, 255, $0, 0, UnknownScript_0x18a81e, $ffff
	person_event $48, 18, 14, $2, $11, 255, 255, $0, 0, UnknownScript_0x18a875, $ffff
	person_event $29, 15, 10, $9, $0, 255, 255, $0, 0, UnknownScript_0x18a889, $0772
	person_event $28, 14, 10, $7, $0, 255, 255, $a0, 0, UnknownScript_0x18a88c, $0772
; 0x18abe3

SilphCo1F_MapScriptHeader: ; 0x18abe3
	; trigger count
	db 0

	; callback count
	db 0
; 0x18abe5

UnknownScript_0x18abe5: ; 0x18abe5
	jumptextfaceplayer UnknownText_0x18ac03
; 0x18abe8

UnknownScript_0x18abe8: ; 0x18abe8
	faceplayer
	loadfont
	checkbit1 $00de
	iftrue UnknownScript_0x18abfd
	2writetext UnknownText_0x18ac36
	keeptextopen
	verbosegiveitem UP_GRADE, 1
	iffalse UnknownScript_0x18ac01
	setbit1 $00de
UnknownScript_0x18abfd: ; 0x18abfd
	2writetext UnknownText_0x18aca8
	closetext
UnknownScript_0x18ac01: ; 0x18ac01
	loadmovesprites
	end
; 0x18ac03

UnknownText_0x18ac03: ; 0x18ac03
	db $0, "Welcome. This is", $4f
	db "SILPH CO.'s HEAD", $55
	db "OFFICE BUILDING.", $57
; 0x18ac36

UnknownText_0x18ac36: ; 0x18ac36
	db $0, "Only employees are", $4f
	db "permitted to go", $55
	db "upstairs.", $51
	db "But since you came", $4f
	db "such a long way,", $51
	db "have this neat", $4f
	db "little souvenir.", $57
; 0x18aca8

UnknownText_0x18aca8: ; 0x18aca8
	db $0, "It's SILPH CO.'s", $4f
	db "latest product.", $51
	db "It's not for sale", $4f
	db "anywhere yet.", $57
; 0x18ace7

SilphCo1F_MapEventHeader: ; 0x18ace7
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 7, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $7, $3, 7, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $42, 6, 8, $6, $0, 255, 255, $90, 0, UnknownScript_0x18abe5, $ffff
	person_event $43, 5, 17, $6, $0, 255, 255, $90, 0, UnknownScript_0x18abe8, $ffff
; 0x18ad11

CopycatsHouse1F_MapScriptHeader: ; 0x18ad11
	; trigger count
	db 0

	; callback count
	db 0
; 0x18ad13

UnknownScript_0x18ad13: ; 0x18ad13
	jumptextfaceplayer UnknownText_0x18ad34
; 0x18ad16

UnknownScript_0x18ad16: ; 0x18ad16
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x18ad24
	2writetext UnknownText_0x18ad95
	closetext
	loadmovesprites
	end
; 0x18ad24

UnknownScript_0x18ad24: ; 0x18ad24
	2writetext UnknownText_0x18add3
	closetext
	loadmovesprites
	end
; 0x18ad2a

UnknownScript_0x18ad2a: ; 0x18ad2a
	loadfont
	2writetext UnknownText_0x18ae4b
	cry BLISSEY
	closetext
	loadmovesprites
	end
; 0x18ad34

UnknownText_0x18ad34: ; 0x18ad34
	db $0, "My daughter likes", $4f
	db "to mimic people.", $51
	db "Her mimicry has", $4f
	db "earned her the", $51
	db "nickname COPYCAT", $4f
	db "around here.", $57
; 0x18ad95

UnknownText_0x18ad95: ; 0x18ad95
	db $0, "My daughter is so", $4f
	db "self-centered…", $51
	db "She only has a few", $4f
	db "friends.", $57
; 0x18add3

UnknownText_0x18add3: ; 0x18add3
	db $0, "She recently lost", $4f
	db "the # DOLL that", $51
	db "a boy gave her", $4f
	db "three years ago.", $51
	db "Ever since then,", $4f
	db "she's gotten even", $55
	db "better at mimicry…", $57
; 0x18ae4b

UnknownText_0x18ae4b: ; 0x18ae4b
	db $0, "BLISSEY: Bliisii!", $57
; 0x18ae5e

CopycatsHouse1F_MapEventHeader: ; 0x18ae5e
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $2, 8, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $7, $3, 8, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $0, $2, 1, GROUP_COPYCATS_HOUSE_2F, MAP_COPYCATS_HOUSE_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $2d, 7, 6, $6, $0, 255, 255, $0, 0, UnknownScript_0x18ad13, $ffff
	person_event $2e, 8, 9, $8, $0, 255, 255, $a0, 0, UnknownScript_0x18ad16, $ffff
	person_event $8f, 10, 10, $16, $0, 255, 255, $0, 0, UnknownScript_0x18ad2a, $ffff
; 0x18ae9a

CopycatsHouse2F_MapScriptHeader: ; 0x18ae9a
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x18ae9f
; 0x18ae9f

UnknownScript_0x18ae9f: ; 0x18ae9f
	checkbit2 $0063
	iftrue UnknownScript_0x18aeac
	disappear $7
	appear $2
	2jump UnknownScript_0x18aeb0
; 0x18aeac

UnknownScript_0x18aeac: ; 0x18aeac
	disappear $2
	appear $7
UnknownScript_0x18aeb0: ; 0x18aeb0
	return
; 0x18aeb1

UnknownScript_0x18aeb1: ; 0x18aeb1
	faceplayer
	checkbit1 $00d1
	iftrue UnknownScript_0x18af6f
	checkbit1 $00d0
	iftrue UnknownScript_0x18af5b
	checkitem LOST_ITEM
	iftrue UnknownScript_0x18af4a
	checkbit2 $0063
	iftrue UnknownScript_0x18aed4
	applymovement $2, MovementData_0x18afd0
	faceplayer
	variablesprite $b, $1
	2jump UnknownScript_0x18aedc
; 0x18aed4

UnknownScript_0x18aed4: ; 0x18aed4
	applymovement $7, MovementData_0x18afd0
	faceplayer
	variablesprite $b, $60
UnknownScript_0x18aedc: ; 0x18aedc
	special $005e
	checkbit1 $00c9
	iftrue UnknownScript_0x18af16
	loadfont
	checkbit2 $0063
	iftrue UnknownScript_0x18aef2
	2writetext UnknownText_0x18afda
	2jump UnknownScript_0x18aef5
; 0x18aef2

UnknownScript_0x18aef2: ; 0x18aef2
	2writetext UnknownText_0x18b316
UnknownScript_0x18aef5: ; 0x18aef5
	closetext
	loadmovesprites
	checkbit2 $0063
	iftrue UnknownScript_0x18af04
	applymovement $2, MovementData_0x18afd0
	2jump UnknownScript_0x18af08
; 0x18af04

UnknownScript_0x18af04: ; 0x18af04
	applymovement $7, MovementData_0x18afd0
UnknownScript_0x18af08: ; 0x18af08
	faceplayer
	variablesprite $b, $28
	special $005e
	loadfont
	2writetext UnknownText_0x18b028
	closetext
	loadmovesprites
	end
; 0x18af16

UnknownScript_0x18af16: ; 0x18af16
	loadfont
	checkbit2 $0063
	iftrue UnknownScript_0x18af23
	2writetext UnknownText_0x18b064
	2jump UnknownScript_0x18af26
; 0x18af23

UnknownScript_0x18af23: ; 0x18af23
	2writetext UnknownText_0x18b366
UnknownScript_0x18af26: ; 0x18af26
	closetext
	loadmovesprites
	checkbit2 $0063
	iftrue UnknownScript_0x18af35
	applymovement $2, MovementData_0x18afd0
	2jump UnknownScript_0x18af39
; 0x18af35

UnknownScript_0x18af35: ; 0x18af35
	applymovement $7, MovementData_0x18afd0
UnknownScript_0x18af39: ; 0x18af39
	faceplayer
	variablesprite $b, $28
	special $005e
	loadfont
	2writetext UnknownText_0x18b116
	closetext
	loadmovesprites
	setbit1 $00cf
	end
; 0x18af4a

UnknownScript_0x18af4a: ; 0x18af4a
	loadfont
	2writetext UnknownText_0x18b17f
	keeptextopen
	takeitem LOST_ITEM, 1
	setbit1 $00d0
	clearbit1 $0773
	2jump UnknownScript_0x18af5c
; 0x18af5b

UnknownScript_0x18af5b: ; 0x18af5b
	loadfont
UnknownScript_0x18af5c: ; 0x18af5c
	2writetext UnknownText_0x18b1e2
	keeptextopen
	verbosegiveitem PASS, 1
	iffalse UnknownScript_0x18afba
	setbit1 $00d1
	2writetext UnknownText_0x18b214
	closetext
	loadmovesprites
	end
; 0x18af6f

UnknownScript_0x18af6f: ; 0x18af6f
	checkbit2 $0063
	iftrue UnknownScript_0x18af80
	applymovement $2, MovementData_0x18afd0
	faceplayer
	variablesprite $b, $1
	2jump UnknownScript_0x18af88
; 0x18af80

UnknownScript_0x18af80: ; 0x18af80
	applymovement $7, MovementData_0x18afd0
	faceplayer
	variablesprite $b, $60
UnknownScript_0x18af88: ; 0x18af88
	special $005e
	loadfont
	checkbit2 $0063
	iftrue UnknownScript_0x18af98
	2writetext UnknownText_0x18b298
	2jump UnknownScript_0x18af9b
; 0x18af98

UnknownScript_0x18af98: ; 0x18af98
	2writetext UnknownText_0x18b415
UnknownScript_0x18af9b: ; 0x18af9b
	closetext
	loadmovesprites
	checkbit2 $0063
	iftrue UnknownScript_0x18afaa
	applymovement $2, MovementData_0x18afd0
	2jump UnknownScript_0x18afae
; 0x18afaa

UnknownScript_0x18afaa: ; 0x18afaa
	applymovement $7, MovementData_0x18afd0
UnknownScript_0x18afae: ; 0x18afae
	faceplayer
	variablesprite $b, $28
	special $005e
	loadfont
	2writetext UnknownText_0x18b2f5
	closetext
UnknownScript_0x18afba: ; 0x18afba
	loadmovesprites
	end
; 0x18afbc

UnknownScript_0x18afbc: ; 0x18afbc
	loadfont
	2writetext UnknownText_0x18b476
	cry DODRIO
	keeptextopen
	2writetext UnknownText_0x18b489
	closetext
	loadmovesprites
	end
; 0x18afca

UnknownScript_0x18afca: ; 0x18afca
	jumptext UnknownText_0x18b4c4
; 0x18afcd

MapCopycatsHouse2FSignpost1Script: ; 0x18afcd
	jumpstd $0002
; 0x18afd0

MovementData_0x18afd0: ; 0x18afd0
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	step_end
; 0x18afda

UnknownText_0x18afda: ; 0x18afda
	db $0, $52, ": Hi! Do", $4f
	db "you like #MON?", $51
	db $52, ": Uh, no, I", $4f
	db "just asked you.", $51
	db $52, ": Huh?", $4f
	db "You're strange!", $57
; 0x18b028

UnknownText_0x18b028: ; 0x18b028
	db $0, "COPYCAT: Hmm?", $4f
	db "Quit mimicking?", $51
	db "But that's my", $4f
	db "favorite hobby!", $57
; 0x18b064

UnknownText_0x18b064: ; 0x18b064
	db $0, $52, ": Hi!", $4f
	db "I heard that you", $51
	db "lost your favorite", $4f
	db "# DOLL.", $51
	db $52, ": If I find", $4f
	db "it, you'll give me", $55
	db "a rail PASS?", $51
	db $52, ": I'll go", $4f
	db "find it for you.", $51
	db "You think you lost", $4f
	db "it when you went", $55
	db "to VERMILION CITY?", $57
; 0x18b116

UnknownText_0x18b116: ; 0x18b116
	db $0, "COPYCAT: Pardon?", $51
	db "I shouldn't decide", $4f
	db "what you should", $55
	db "do?", $51
	db "But I'm really", $4f
	db "worried… What if", $55
	db "someone finds it?", $57
; 0x18b17f

UnknownText_0x18b17f: ; 0x18b17f
	db $0, "COPYCAT: Yay!", $4f
	db "That's my CLEFAIRY", $55
	db "# DOLL!", $51
	db "See the tear where", $4f
	db "the right leg is", $51
	db "sewn on? That's", $4f
	db "proof!", $57
; 0x18b1e2

UnknownText_0x18b1e2: ; 0x18b1e2
	db $0, "OK. Here's the", $4f
	db "MAGNET TRAIN PASS", $55
	db "like I promised!", $57
; 0x18b214

UnknownText_0x18b214: ; 0x18b214
	db $0, "COPYCAT: That's", $4f
	db "the PASS for the", $55
	db "MAGNET TRAIN.", $51
	db "The rail company", $4f
	db "man gave me that", $51
	db "when they tore", $4f
	db "down our old house", $55
	db "for the STATION.", $57
; 0x18b298

UnknownText_0x18b298: ; 0x18b298
	db $0, $52, ": Hi!", $4f
	db "Thanks a lot for", $55
	db "the rail PASS!", $51
	db $52, ": Pardon?", $51
	db $52, ": Is it", $4f
	db "that fun to mimic", $55
	db "my every move?", $57
; 0x18b2f5

UnknownText_0x18b2f5: ; 0x18b2f5
	db $0, "COPYCAT: You bet!", $4f
	db "It's a scream!", $57
; 0x18b316

UnknownText_0x18b316: ; 0x18b316
	db $0, $52, ": Hi. You", $4f
	db "must like #MON.", $51
	db $52, ": No, not", $4f
	db "me. I asked you.", $51
	db $52, ": Pardon?", $4f
	db "You're weird!", $57
; 0x18b366

UnknownText_0x18b366: ; 0x18b366
	db $0, $52, ": Hi. Did", $4f
	db "you really lose", $55
	db "your # DOLL?", $51
	db $52, ": You'll", $4f
	db "really give me a", $51
	db "rail PASS if I", $4f
	db "find it for you?", $51
	db $52, ": Sure,", $4f
	db "I'll look for it!", $51
	db "You think you lost", $4f
	db "it when you were", $55
	db "in VERMILION?", $57
; 0x18b415

UnknownText_0x18b415: ; 0x18b415
	db $0, $52, ": Thank you", $4f
	db "for the rail PASS!", $51
	db $52, ": …Pardon?", $51
	db $52, ": Is it", $4f
	db "really that fun to", $51
	db "copy what I say", $4f
	db "and do?", $57
; 0x18b476

UnknownText_0x18b476: ; 0x18b476
	db $0, "DODRIO: Gii giii!", $57
; 0x18b489

UnknownText_0x18b489: ; 0x18b489
	db $0, "MIRROR, MIRROR ON", $4f
	db "THE WALL, WHO'S", $51
	db "THE FAIREST ONE OF", $4f
	db "ALL?", $57
; 0x18b4c4

UnknownText_0x18b4c4: ; 0x18b4c4
	db $0, "This is a rare", $4f
	db "#MON! Huh?", $51
	db "It's only a doll…", $57
; 0x18b4f0

CopycatsHouse2F_MapEventHeader: ; 0x18b4f0
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $0, $3, 3, GROUP_COPYCATS_HOUSE_1F, MAP_COPYCATS_HOUSE_1F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapCopycatsHouse2FSignpost1Script
	signpost 1, 1, $0, MapCopycatsHouse2FSignpost1Script

	; people-events
	db 6
	person_event $fb, 7, 8, $8, $0, 255, 255, $80, 0, UnknownScript_0x18aeb1, $06ee
	person_event $9e, 8, 10, $16, $0, 255, 255, $b0, 0, UnknownScript_0x18afbc, $ffff
	person_event $4d, 5, 10, $6, $0, 255, 255, $80, 0, UnknownScript_0x18afca, $0773
	person_event $4c, 5, 6, $6, $0, 255, 255, $a0, 0, UnknownScript_0x18afca, $ffff
	person_event $4e, 5, 11, $6, $0, 255, 255, $90, 0, UnknownScript_0x18afca, $ffff
	person_event $fb, 7, 8, $8, $0, 255, 255, $90, 0, UnknownScript_0x18aeb1, $06ef
; 0x18b553

Route5UndergroundEntrance_MapScriptHeader: ; 0x18b553
	; trigger count
	db 0

	; callback count
	db 0
; 0x18b555

UnknownScript_0x18b555: ; 0x18b555
	jumptextfaceplayer UnknownText_0x18b558
; 0x18b558

UnknownText_0x18b558: ; 0x18b558
	db $0, "Many cities in", $4f
	db "JOHTO have long", $51
	db "histories. I'd", $4f
	db "love to visit!", $57
; 0x18b595

Route5UndergroundEntrance_MapEventHeader: ; 0x18b595
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_ROUTE_5, MAP_ROUTE_5
	warp_def $7, $4, 1, GROUP_ROUTE_5, MAP_ROUTE_5
	warp_def $3, $4, 1, GROUP_UNDERGROUND, MAP_UNDERGROUND

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $29, 6, 6, $2, $11, 255, 255, $a0, 0, UnknownScript_0x18b555, $ffff
; 0x18b5b7

Route5SaffronCityGate_MapScriptHeader: ; 0x18b5b7
	; trigger count
	db 0

	; callback count
	db 0
; 0x18b5b9

UnknownScript_0x18b5b9: ; 0x18b5b9
	jumptextfaceplayer UnknownText_0x18b5bc
; 0x18b5bc

UnknownText_0x18b5bc: ; 0x18b5bc
	db $0, "You're from JOHTO,", $4f
	db "aren't you?", $51
	db "How do you like", $4f
	db "KANTO? It's nice,", $55
	db "don't you agree?", $57
; 0x18b60b

Route5SaffronCityGate_MapEventHeader: ; 0x18b60b
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 2, GROUP_ROUTE_5, MAP_ROUTE_5
	warp_def $0, $5, 3, GROUP_ROUTE_5, MAP_ROUTE_5
	warp_def $7, $4, 9, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $7, $5, 9, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 8, 4, $9, $0, 255, 255, $90, 0, UnknownScript_0x18b5b9, $ffff
; 0x18b632

Route5CleanseTagSpeechHouse_MapScriptHeader: ; 0x18b632
	; trigger count
	db 0

	; callback count
	db 0
; 0x18b634

UnknownScript_0x18b634: ; 0x18b634
	faceplayer
	loadfont
	checkbit1 $00db
	iftrue UnknownScript_0x18b649
	2writetext UnknownText_0x18b655
	keeptextopen
	verbosegiveitem CLEANSE_TAG, 1
	iffalse UnknownScript_0x18b64d
	setbit1 $00db
UnknownScript_0x18b649: ; 0x18b649
	2writetext UnknownText_0x18b6a7
	closetext
UnknownScript_0x18b64d: ; 0x18b64d
	loadmovesprites
	end
; 0x18b64f

UnknownScript_0x18b64f: ; 0x18b64f
	jumptextfaceplayer UnknownText_0x18b6de
; 0x18b652

MapRoute5CleanseTagSpeechHouseSignpost1Script: ; 0x18b652
	jumpstd $0001
; 0x18b655

UnknownText_0x18b655: ; 0x18b655
	db $0, "Eeyaaaah!", $51
	db "I sense a sinister", $4f
	db "shadow hovering", $55
	db "over you.", $51
	db "Take this to ward", $4f
	db "it off!", $57
; 0x18b6a7

UnknownText_0x18b6a7: ; 0x18b6a7
	db $0, "You were in mortal", $4f
	db "danger, but you", $55
	db "are protected now.", $57
; 0x18b6de

UnknownText_0x18b6de: ; 0x18b6de
	db $0, "My grandma is into", $4f
	db "warding off what", $51
	db "she believes to be", $4f
	db "evil spirits.", $51
	db "I'm sorry that she", $4f
	db "startled you.", $57
; 0x18b744

Route5CleanseTagSpeechHouse_MapEventHeader: ; 0x18b744
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_ROUTE_5, MAP_ROUTE_5
	warp_def $7, $3, 4, GROUP_ROUTE_5, MAP_ROUTE_5

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapRoute5CleanseTagSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapRoute5CleanseTagSpeechHouseSignpost1Script

	; people-events
	db 2
	person_event $30, 9, 6, $1f, $0, 255, 255, $b0, 0, UnknownScript_0x18b634, $ffff
	person_event $29, 7, 9, $8, $0, 255, 255, $80, 0, UnknownScript_0x18b64f, $ffff
; 0x18b778

SECTION "bank63",DATA,BANK[$63]

PewterCity_MapScriptHeader: ; 0x18c000
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x18c005
; 0x18c005

UnknownScript_0x18c005: ; 0x18c005
	setbit2 $0037
	return
; 0x18c009

UnknownScript_0x18c009: ; 0x18c009
	jumptextfaceplayer UnknownText_0x18c042
; 0x18c00c

UnknownScript_0x18c00c: ; 0x18c00c
	jumptextfaceplayer UnknownText_0x18c080
; 0x18c00f

UnknownScript_0x18c00f: ; 0x18c00f
	faceplayer
	loadfont
	checkbit1 $0079
	iftrue UnknownScript_0x18c023
	2writetext UnknownText_0x18c0c6
	keeptextopen
	verbosegiveitem SILVER_WING, 1
	setbit1 $0079
	loadmovesprites
	end
; 0x18c023

UnknownScript_0x18c023: ; 0x18c023
	2writetext UnknownText_0x18c1aa
	closetext
	loadmovesprites
	end
; 0x18c029

MapPewterCitySignpost0Script: ; 0x18c029
	jumptext UnknownText_0x18c1ff
; 0x18c02c

MapPewterCitySignpost1Script: ; 0x18c02c
	jumptext UnknownText_0x18c21e
; 0x18c02f

MapPewterCitySignpost2Script: ; 0x18c02f
	jumptext UnknownText_0x18c25e
; 0x18c032

MapPewterCitySignpost3Script: ; 0x18c032
	jumptext UnknownText_0x18c2a9
; 0x18c035

MapPewterCitySignpost4Script: ; 0x18c035
	jumptext UnknownText_0x18c2dc
; 0x18c038

MapPewterCitySignpost5Script: ; 0x18c038
	jumpstd $0010
; 0x18c03b

MapPewterCitySignpost6Script: ; 0x18c03b
	jumpstd $0011
; 0x18c03e

UnknownScript_0x18c03e: ; 0x18c03e
	fruittree $1c
; 0x18c040

UnknownScript_0x18c040: ; 0x18c040
	fruittree $1d
; 0x18c042

UnknownText_0x18c042: ; 0x18c042
	db $0, "Have you visited", $4f
	db "PEWTER GYM?", $51
	db "The LEADER uses", $4f
	db "rock-type #MON.", $57
; 0x18c080

UnknownText_0x18c080: ; 0x18c080
	db $0, "At night, CLEFAIRY", $4f
	db "come out to play", $55
	db "at MT.MOON.", $51
	db "But not every", $4f
	db "night.", $57
; 0x18c0c6

UnknownText_0x18c0c6: ; 0x18c0c6
	db $0, "Ah, you came all", $4f
	db "the way out here", $55
	db "from JOHTO?", $51
	db "That brings back", $4f
	db "memories. When I", $51
	db "was young, I went", $4f
	db "to JOHTO to train.", $51
	db "You remind me so", $4f
	db "much of what I was", $51
	db "like as a young", $4f
	db "man.", $51
	db "Here. I want you", $4f
	db "to have this item", $55
	db "I found in JOHTO.", $57
; 0x18c1aa

UnknownText_0x18c1aa: ; 0x18c1aa
	db $0, "Going to new, un-", $4f
	db "known places and", $55
	db "seeing new people…", $51
	db "Those are the joys", $4f
	db "of travel.", $57
; 0x18c1ff

UnknownText_0x18c1ff: ; 0x18c1ff
	db $0, "PEWTER CITY", $4f
	db "A Stone Gray City", $57
; 0x18c21e

UnknownText_0x18c21e: ; 0x18c21e
	db $0, "PEWTER CITY", $4f
	db "#MON GYM", $55
	db "LEADER: BROCK", $51
	db "The Rock Solid", $4f
	db "#MON Trainer", $57
; 0x18c25e

UnknownText_0x18c25e: ; 0x18c25e
	db $0, "There's a notice", $4f
	db "here…", $51
	db "PEWTER MUSEUM OF", $4f
	db "SCIENCE is closed", $55
	db "for renovations…", $57
; 0x18c2a9

UnknownText_0x18c2a9: ; 0x18c2a9
	db $0, "There's a notice", $4f
	db "here…", $51
	db "MT.MOON GIFT SHOP", $4f
	db "NOW OPEN!", $57
; 0x18c2dc

UnknownText_0x18c2dc: ; 0x18c2dc
	db $0, "WELCOME TO", $4f
	db "PEWTER CITY!", $57
; 0x18c2f5

PewterCity_MapEventHeader: ; 0x18c2f5
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $d, $1d, 1, GROUP_PEWTER_NIDORAN_SPEECH_HOUSE, MAP_PEWTER_NIDORAN_SPEECH_HOUSE
	warp_def $11, $10, 1, GROUP_PEWTER_GYM, MAP_PEWTER_GYM
	warp_def $11, $17, 2, GROUP_PEWTER_MART, MAP_PEWTER_MART
	warp_def $19, $d, 1, GROUP_PEWTER_POKECENTER_1F, MAP_PEWTER_POKECENTER_1F
	warp_def $1d, $7, 1, GROUP_PEWTER_SNOOZE_SPEECH_HOUSE, MAP_PEWTER_SNOOZE_SPEECH_HOUSE

	; xy triggers
	db 0

	; signposts
	db 7
	signpost 23, 25, $0, MapPewterCitySignpost0Script
	signpost 17, 11, $0, MapPewterCitySignpost1Script
	signpost 9, 15, $0, MapPewterCitySignpost2Script
	signpost 19, 33, $0, MapPewterCitySignpost3Script
	signpost 29, 19, $0, MapPewterCitySignpost4Script
	signpost 25, 14, $0, MapPewterCitySignpost5Script
	signpost 17, 24, $0, MapPewterCitySignpost6Script

	; people-events
	db 5
	person_event $24, 15, 23, $2, $22, 255, 255, $a0, 0, UnknownScript_0x18c009, $ffff
	person_event $25, 33, 18, $2, $22, 255, 255, $80, 0, UnknownScript_0x18c00c, $ffff
	person_event $2f, 21, 33, $5, $2, 255, 255, $90, 0, UnknownScript_0x18c00f, $ffff
	person_event $5d, 7, 36, $1, $0, 255, 255, $0, 0, UnknownScript_0x18c03e, $ffff
	person_event $5d, 7, 34, $1, $0, 255, 255, $0, 0, UnknownScript_0x18c040, $ffff
; 0x18c378

WhirlIslandNW_MapScriptHeader: ; 0x18c378
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c37a

WhirlIslandNW_MapEventHeader: ; 0x18c37a
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $7, $5, 1, GROUP_ROUTE_41, MAP_ROUTE_41
	warp_def $3, $5, 1, GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F
	warp_def $f, $3, 4, GROUP_WHIRL_ISLAND_SW, MAP_WHIRL_ISLAND_SW
	warp_def $f, $7, 2, GROUP_WHIRL_ISLAND_CAVE, MAP_WHIRL_ISLAND_CAVE

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x18c394

WhirlIslandNE_MapScriptHeader: ; 0x18c394
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c396

ItemFragment_0x18c396: ; 0x18c396
	db ULTRA_BALL, 1
; 0x18c398

WhirlIslandNE_MapEventHeader: ; 0x18c398
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $d, $3, 2, GROUP_ROUTE_41, MAP_ROUTE_41
	warp_def $3, $11, 2, GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F
	warp_def $b, $d, 3, GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $54, 15, 15, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c396, $068f
; 0x18c3ba

WhirlIslandSW_MapScriptHeader: ; 0x18c3ba
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c3bc

ItemFragment_0x18c3bc: ; 0x18c3bc
	db ULTRA_BALL, 1
; 0x18c3be

WhirlIslandSW_MapEventHeader: ; 0x18c3be
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $7, $5, 3, GROUP_ROUTE_41, MAP_ROUTE_41
	warp_def $3, $11, 5, GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F
	warp_def $3, $3, 4, GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F
	warp_def $f, $3, 3, GROUP_WHIRL_ISLAND_NW, MAP_WHIRL_ISLAND_NW
	warp_def $f, $11, 4, GROUP_WHIRL_ISLAND_B2F, MAP_WHIRL_ISLAND_B2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $54, 6, 19, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c3bc, $0690
; 0x18c3ea

WhirlIslandCave_MapScriptHeader: ; 0x18c3ea
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c3ec

WhirlIslandCave_MapEventHeader: ; 0x18c3ec
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $5, $7, 9, GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F
	warp_def $d, $3, 4, GROUP_WHIRL_ISLAND_NW, MAP_WHIRL_ISLAND_NW

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x18c3fc

WhirlIslandSE_MapScriptHeader: ; 0x18c3fc
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c3fe

WhirlIslandSE_MapEventHeader: ; 0x18c3fe
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $d, $5, 4, GROUP_ROUTE_41, MAP_ROUTE_41
	warp_def $3, $5, 6, GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x18c40e

WhirlIslandB1F_MapScriptHeader: ; 0x18c40e
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c410

ItemFragment_0x18c410: ; 0x18c410
	db FULL_RESTORE, 1
; 0x18c412

ItemFragment_0x18c412: ; 0x18c412
	db CARBOS, 1
; 0x18c414

ItemFragment_0x18c414: ; 0x18c414
	db CALCIUM, 1
; 0x18c416

ItemFragment_0x18c416: ; 0x18c416
	db NUGGET, 1
; 0x18c418

ItemFragment_0x18c418: ; 0x18c418
	db ESCAPE_ROPE, 1
; 0x18c41a

UnknownScript_0x18c41a: ; 0x18c41a
	jumpstd $000e
; 0x18c41d

MapWhirlIslandB1FSignpostItem0: ; 0x18c41d
	dw $0097
	db RARE_CANDY
	
; 0x18c420

MapWhirlIslandB1FSignpostItem1: ; 0x18c420
	dw $0098
	db ULTRA_BALL
	
; 0x18c423

MapWhirlIslandB1FSignpostItem2: ; 0x18c423
	dw $0099
	db FULL_RESTORE
	
; 0x18c426

WhirlIslandB1F_MapEventHeader: ; 0x18c426
	; filler
	db 0, 0

	; warps
	db 9
	warp_def $5, $5, 2, GROUP_WHIRL_ISLAND_NW, MAP_WHIRL_ISLAND_NW
	warp_def $3, $23, 2, GROUP_WHIRL_ISLAND_NE, MAP_WHIRL_ISLAND_NE
	warp_def $9, $1d, 3, GROUP_WHIRL_ISLAND_NE, MAP_WHIRL_ISLAND_NE
	warp_def $1f, $9, 3, GROUP_WHIRL_ISLAND_SW, MAP_WHIRL_ISLAND_SW
	warp_def $1f, $17, 2, GROUP_WHIRL_ISLAND_SW, MAP_WHIRL_ISLAND_SW
	warp_def $1d, $1f, 2, GROUP_WHIRL_ISLAND_SE, MAP_WHIRL_ISLAND_SE
	warp_def $15, $19, 1, GROUP_WHIRL_ISLAND_B2F, MAP_WHIRL_ISLAND_B2F
	warp_def $1b, $d, 2, GROUP_WHIRL_ISLAND_B2F, MAP_WHIRL_ISLAND_B2F
	warp_def $15, $11, 1, GROUP_WHIRL_ISLAND_CAVE, MAP_WHIRL_ISLAND_CAVE

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 4, 30, $7, MapWhirlIslandB1FSignpostItem0
	signpost 18, 36, $7, MapWhirlIslandB1FSignpostItem1
	signpost 23, 2, $7, MapWhirlIslandB1FSignpostItem2

	; people-events
	db 6
	person_event $54, 17, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c410, $0691
	person_event $54, 22, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c412, $0692
	person_event $54, 27, 37, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c414, $0693
	person_event $54, 12, 21, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c416, $0694
	person_event $54, 30, 23, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c418, $0695
	person_event $5a, 30, 27, $19, $0, 255, 255, $0, 0, UnknownScript_0x18c41a, $ffff
; 0x18c4b6

WhirlIslandB2F_MapScriptHeader: ; 0x18c4b6
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c4b8

ItemFragment_0x18c4b8: ; 0x18c4b8
	db FULL_RESTORE, 1
; 0x18c4ba

ItemFragment_0x18c4ba: ; 0x18c4ba
	db MAX_REVIVE, 1
; 0x18c4bc

ItemFragment_0x18c4bc: ; 0x18c4bc
	db MAX_ELIXER, 1
; 0x18c4be

WhirlIslandB2F_MapEventHeader: ; 0x18c4be
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $5, $b, 7, GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F
	warp_def $b, $7, 8, GROUP_WHIRL_ISLAND_B1F, MAP_WHIRL_ISLAND_B1F
	warp_def $19, $7, 1, GROUP_WHIRL_ISLAND_LUGIA_CHAMBER, MAP_WHIRL_ISLAND_LUGIA_CHAMBER
	warp_def $1f, $d, 5, GROUP_WHIRL_ISLAND_SW, MAP_WHIRL_ISLAND_SW

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $54, 15, 14, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c4b8, $0696
	person_event $54, 8, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c4ba, $0697
	person_event $54, 16, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c4bc, $0698
; 0x18c4ff

WhirlIslandLugiaChamber_MapScriptHeader: ; 0x18c4ff
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x18c504
; 0x18c504

UnknownScript_0x18c504: ; 0x18c504
	checkbit1 $0318
	iftrue UnknownScript_0x18c515
	checkitem SILVER_WING
	iftrue UnknownScript_0x18c512
	2jump UnknownScript_0x18c515
; 0x18c512

UnknownScript_0x18c512: ; 0x18c512
	appear $2
	return
; 0x18c515

UnknownScript_0x18c515: ; 0x18c515
	disappear $2
	return
; 0x18c518

UnknownScript_0x18c518: ; 0x18c518
	faceplayer
	loadfont
	2writetext UnknownText_0x18c531
	cry LUGIA
	pause 15
	loadmovesprites
	setbit1 $0318
	writecode $3, $a
	loadpokedata LUGIA, 60
	startbattle
	disappear $2
	returnafterbattle
	end
; 0x18c531

UnknownText_0x18c531: ; 0x18c531
	db $0, "Gyaaas!", $57
; 0x18c53a

WhirlIslandLugiaChamber_MapEventHeader: ; 0x18c53a
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $d, $9, 3, GROUP_WHIRL_ISLAND_B2F, MAP_WHIRL_ISLAND_B2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $a1, 9, 13, $16, $0, 255, 255, $90, 0, UnknownScript_0x18c518, $073d
; 0x18c552

SilverCaveRoom1_MapScriptHeader: ; 0x18c552
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c554

ItemFragment_0x18c554: ; 0x18c554
	db MAX_ELIXER, 1
; 0x18c556

ItemFragment_0x18c556: ; 0x18c556
	db PROTEIN, 1
; 0x18c558

ItemFragment_0x18c558: ; 0x18c558
	db ESCAPE_ROPE, 1
; 0x18c55a

ItemFragment_0x18c55a: ; 0x18c55a
	db ULTRA_BALL, 1
; 0x18c55c

MapSilverCaveRoom1SignpostItem0: ; 0x18c55c
	dw $009a
	db DIRE_HIT
	
; 0x18c55f

MapSilverCaveRoom1SignpostItem1: ; 0x18c55f
	dw $009b
	db ULTRA_BALL
	
; 0x18c562

SilverCaveRoom1_MapEventHeader: ; 0x18c562
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $21, $9, 2, GROUP_SILVER_CAVE_OUTSIDE, MAP_SILVER_CAVE_OUTSIDE
	warp_def $1, $f, 1, GROUP_SILVER_CAVE_ROOM_2, MAP_SILVER_CAVE_ROOM_2

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 23, 16, $7, MapSilverCaveRoom1SignpostItem0
	signpost 12, 17, $7, MapSilverCaveRoom1SignpostItem1

	; people-events
	db 4
	person_event $54, 13, 8, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c554, $0699
	person_event $54, 33, 19, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c556, $069a
	person_event $54, 34, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c558, $069b
	person_event $54, 22, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c55a, $07c1
; 0x18c5b0

SilverCaveRoom2_MapScriptHeader: ; 0x18c5b0
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c5b2

ItemFragment_0x18c5b2: ; 0x18c5b2
	db CALCIUM, 1
; 0x18c5b4

ItemFragment_0x18c5b4: ; 0x18c5b4
	db ULTRA_BALL, 1
; 0x18c5b6

ItemFragment_0x18c5b6: ; 0x18c5b6
	db PP_UP, 1
; 0x18c5b8

MapSilverCaveRoom2SignpostItem0: ; 0x18c5b8
	dw $009c
	db MAX_POTION
	
; 0x18c5bb

SilverCaveRoom2_MapEventHeader: ; 0x18c5bb
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $1f, $11, 2, GROUP_SILVER_CAVE_ROOM_1, MAP_SILVER_CAVE_ROOM_1
	warp_def $5, $b, 1, GROUP_SILVER_CAVE_ROOM_3, MAP_SILVER_CAVE_ROOM_3
	warp_def $15, $d, 1, GROUP_SILVER_CAVE_ITEM_ROOMS, MAP_SILVER_CAVE_ITEM_ROOMS
	warp_def $3, $17, 2, GROUP_SILVER_CAVE_ITEM_ROOMS, MAP_SILVER_CAVE_ITEM_ROOMS

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 31, 14, $7, MapSilverCaveRoom2SignpostItem0

	; people-events
	db 3
	person_event $54, 14, 28, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c5b2, $07c2
	person_event $54, 28, 26, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c5b4, $07c3
	person_event $54, 24, 8, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c5b6, $07c4
; 0x18c601

SilverCaveRoom3_MapScriptHeader: ; 0x18c601
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c603

UnknownScript_0x18c603: ; 0x18c603
	special $006a
	faceplayer
	loadfont
	2writetext UnknownText_0x18c637
	closetext
	loadmovesprites
	winlosstext UnknownText_0x18c63c, UnknownText_0x18c63c
	loadtrainer RED, 1
	startbattle
	reloadmapmusic
	returnafterbattle
	special $006a
	loadfont
	2writetext UnknownText_0x18c63f
	closetext
	loadmovesprites
	special $0030
	special $0033
	disappear $2
	pause 15
	special $0032
	pause 30
	special $001b
	refreshscreen $0
	credits
	end
; 0x18c637

UnknownText_0x18c637: ; 0x18c637
	db $0, $56, $4f
	db $56, $57
; 0x18c63c

UnknownText_0x18c63c: ; 0x18c63c
	db $0, "…", $57
; 0x18c63f

UnknownText_0x18c63f: ; 0x18c63f
	db $0, $56, $4f
	db $56, $57
; 0x18c644

SilverCaveRoom3_MapEventHeader: ; 0x18c644
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $21, $9, 2, GROUP_SILVER_CAVE_ROOM_2, MAP_SILVER_CAVE_ROOM_2

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $6, 14, 13, $7, $0, 255, 255, $80, 0, UnknownScript_0x18c603, $0762
; 0x18c65c

SilverCaveItemRooms_MapScriptHeader: ; 0x18c65c
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c65e

ItemFragment_0x18c65e: ; 0x18c65e
	db MAX_REVIVE, 1
; 0x18c660

ItemFragment_0x18c660: ; 0x18c660
	db FULL_RESTORE, 1
; 0x18c662

SilverCaveItemRooms_MapEventHeader: ; 0x18c662
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $d, 3, GROUP_SILVER_CAVE_ROOM_2, MAP_SILVER_CAVE_ROOM_2
	warp_def $f, $7, 4, GROUP_SILVER_CAVE_ROOM_2, MAP_SILVER_CAVE_ROOM_2

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $54, 7, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c65e, $069c
	person_event $54, 15, 19, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c660, $069d
; 0x18c68c

DarkCaveVioletEntrance_MapScriptHeader: ; 0x18c68c
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c68e

ItemFragment_0x18c68e: ; 0x18c68e
	db POTION, 1
; 0x18c690

ItemFragment_0x18c690: ; 0x18c690
	db FULL_HEAL, 1
; 0x18c692

ItemFragment_0x18c692: ; 0x18c692
	db HYPER_POTION, 1
; 0x18c694

ItemFragment_0x18c694: ; 0x18c694
	db DIRE_HIT, 1
; 0x18c696

UnknownScript_0x18c696: ; 0x18c696
	jumpstd $000f
; 0x18c699

MapDarkCaveVioletEntranceSignpostItem0: ; 0x18c699
	dw $009d
	db ELIXER
	
; 0x18c69c

DarkCaveVioletEntrance_MapEventHeader: ; 0x18c69c
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $f, $3, 3, GROUP_ROUTE_31, MAP_ROUTE_31
	warp_def $1, $11, 2, GROUP_DARK_CAVE_BLACKTHORN_ENTRANCE, MAP_DARK_CAVE_BLACKTHORN_ENTRANCE
	warp_def $21, $23, 3, GROUP_ROUTE_46, MAP_ROUTE_46

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 3, 26, $7, MapDarkCaveVioletEntranceSignpostItem0

	; people-events
	db 8
	person_event $54, 12, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c68e, $069e
	person_event $59, 18, 20, $18, $0, 255, 255, $0, 0, UnknownScript_0x18c696, $ffff
	person_event $59, 10, 31, $18, $0, 255, 255, $0, 0, UnknownScript_0x18c696, $ffff
	person_event $59, 18, 11, $18, $0, 255, 255, $0, 0, UnknownScript_0x18c696, $ffff
	person_event $59, 35, 40, $18, $0, 255, 255, $0, 0, UnknownScript_0x18c696, $ffff
	person_event $54, 26, 40, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c690, $069f
	person_event $54, 13, 39, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c692, $06a0
	person_event $54, 32, 34, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c694, $07ce
; 0x18c71e

DarkCaveBlackthornEntrance_MapScriptHeader: ; 0x18c71e
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c720

UnknownScript_0x18c720: ; 0x18c720
	faceplayer
	loadfont
	checkbit1 $0072
	iftrue UnknownScript_0x18c735
	2writetext UnknownText_0x18c73f
	keeptextopen
	verbosegiveitem BLACKGLASSES, 1
	iffalse UnknownScript_0x18c739
	setbit1 $0072
UnknownScript_0x18c735: ; 0x18c735
	2writetext UnknownText_0x18c80c
	closetext
UnknownScript_0x18c739: ; 0x18c739
	loadmovesprites
	end
; 0x18c73b

ItemFragment_0x18c73b: ; 0x18c73b
	db REVIVE, 1
; 0x18c73d

ItemFragment_0x18c73d: ; 0x18c73d
	db TM_13, 1
; 0x18c73f

UnknownText_0x18c73f: ; 0x18c73f
	db $0, "Whoa! You startled", $4f
	db "me there!", $51
	db "I had my BLACK-", $4f
	db "GLASSES on, so I", $51
	db "didn't notice you", $4f
	db "at all.", $51
	db "What am I doing", $4f
	db "here?", $51
	db "Hey, don't you", $4f
	db "worry about it.", $51
	db "I'll give you a", $4f
	db "pair of BLACK-", $55
	db "GLASSES, so forget", $55
	db "you saw me, OK?", $57
; 0x18c80c

UnknownText_0x18c80c: ; 0x18c80c
	db $0, "BLACKGLASSES ups", $4f
	db "the power of dark-", $55
	db "type moves.", $57
; 0x18c83d

DarkCaveBlackthornEntrance_MapEventHeader: ; 0x18c83d
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $17, 1, GROUP_ROUTE_45, MAP_ROUTE_45
	warp_def $19, $3, 2, GROUP_DARK_CAVE_VIOLET_ENTRANCE, MAP_DARK_CAVE_VIOLET_ENTRANCE

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $4b, 7, 11, $3, $0, 255, 255, $0, 0, UnknownScript_0x18c720, $ffff
	person_event $54, 28, 25, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c73b, $06a1
	person_event $54, 26, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c73d, $06a2
; 0x18c874

DragonsDen1F_MapScriptHeader: ; 0x18c874
	; trigger count
	db 0

	; callback count
	db 0
; 0x18c876

DragonsDen1F_MapEventHeader: ; 0x18c876
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $5, $3, 8, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $3, $3, 4, GROUP_DRAGONS_DEN_1F, MAP_DRAGONS_DEN_1F
	warp_def $f, $5, 1, GROUP_DRAGONS_DEN_B1F, MAP_DRAGONS_DEN_B1F
	warp_def $d, $5, 2, GROUP_DRAGONS_DEN_1F, MAP_DRAGONS_DEN_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x18c890

DragonsDenB1F_MapScriptHeader: ; 0x18c890
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x18c89d, $0000
	dw UnknownScript_0x18c89e, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x18c89f
; 0x18c89d

UnknownScript_0x18c89d: ; 0x18c89d
	end
; 0x18c89e

UnknownScript_0x18c89e: ; 0x18c89e
	end
; 0x18c89f

UnknownScript_0x18c89f: ; 0x18c89f
	checkbit1 $0319
	iftrue UnknownScript_0x18c8a8
	disappear $4
	return
; 0x18c8a8

UnknownScript_0x18c8a8: ; 0x18c8a8
	checkcode $b
	if_equal TUESDAY, UnknownScript_0x18c8b5
	if_equal THURSDAY, UnknownScript_0x18c8b5
	disappear $4
	return
; 0x18c8b5

UnknownScript_0x18c8b5: ; 0x18c8b5
	appear $4
	return
; 0x18c8b8

UnknownScript_0x18c8b8: ; 0x18c8b8
	appear $3
	loadfont
	2writetext UnknownText_0x18c9b8
	pause 30
	loadmovesprites
	showemote $0, $0, 15
	spriteface $0, $2
	playmusic $005d
	applymovement $3, MovementData_0x18c9ae
	loadfont
	2writetext UnknownText_0x18c9bf
	keeptextopen
	giveitem TM_24, $1
	iffalse UnknownScript_0x18c8f4
	itemtotext TM_24, $0
	2writetext UnknownText_0x18c9fb
	playsound $0001
	waitbutton
	itemnotify
	setbit1 $000f
	2writetext UnknownText_0x18ca0d
	keeptextopen
	2writetext UnknownText_0x18caf1
	closetext
	loadmovesprites
	2jump UnknownScript_0x18c8f9
; 0x18c8f4

UnknownScript_0x18c8f4: ; 0x18c8f4
	2writetext UnknownText_0x18ca8b
	closetext
	loadmovesprites
UnknownScript_0x18c8f9: ; 0x18c8f9
	applymovement $3, MovementData_0x18c9b3
	special $006a
	pause 30
	special $003d
	disappear $3
	dotrigger $0
	end
; 0x18c90a

TrainerCooltrainermDarin: ; 0x18c90a
	; bit/flag number
	dw $5bd

	; trainer group && trainer id
	db COOLTRAINERM, DARIN

	; text when seen
	dw CooltrainermDarinSeenText

	; text when trainer beaten
	dw CooltrainermDarinBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermDarinScript
; 0x18c916

CooltrainermDarinScript: ; 0x18c916
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18cd82
	closetext
	loadmovesprites
	end
; 0x18c91e

TrainerCooltrainerfCara: ; 0x18c91e
	; bit/flag number
	dw $5be

	; trainer group && trainer id
	db COOLTRAINERF, CARA

	; text when seen
	dw CooltrainerfCaraSeenText

	; text when trainer beaten
	dw CooltrainerfCaraBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfCaraScript
; 0x18c92a

CooltrainerfCaraScript: ; 0x18c92a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18ce11
	closetext
	loadmovesprites
	end
; 0x18c932

INCBIN "baserom.gbc",$18c932,$14

TrainerTwinsLeaandpia1: ; 0x18c946
	; bit/flag number
	dw $5bf

	; trainer group && trainer id
	db TWINS, LEAANDPIA1

	; text when seen
	dw TwinsLeaandpia1SeenText

	; text when trainer beaten
	;dw TwinsLeaandpia1BeatenText
	dw $4f06

	; script when lost
	dw $0000

	; script when talk again
	dw TwinsLeaandpia1Script
; 0x18c952

TwinsLeaandpia1Script: ; 0x18c952
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18cf0f
	closetext
	loadmovesprites
	end
; 0x18c95a

UnknownScript_0x18c95a: ; 0x18c95a
	giveitem DRAGON_FANG, $1
	iffalse UnknownScript_0x18c970
	disappear $2
	loadfont
	itemtotext DRAGON_FANG, $0
	2writetext UnknownText_0x18cf41
	playsound $0001
	waitbutton
	itemnotify
	loadmovesprites
	end
; 0x18c970

UnknownScript_0x18c970: ; 0x18c970
	loadfont
	itemtotext DRAGON_FANG, $0
	2writetext UnknownText_0x18cf41
	keeptextopen
	2writetext UnknownText_0x18cf51
	closetext
	loadmovesprites
	end
; 0x18c97e

UnknownScript_0x18c97e: ; 0x18c97e
	playmusic $001f
	faceplayer
	loadfont
	checkbit1 $0000
	iftrue UnknownScript_0x18c995
	2writetext UnknownText_0x18cc83
	closetext
	loadmovesprites
	setbit1 $0000
	special $003d
	end
; 0x18c995

UnknownScript_0x18c995: ; 0x18c995
	2writetext UnknownText_0x18cd2d
	closetext
	loadmovesprites
	special $003d
	end
; 0x18c99e

MapDragonsDenB1FSignpost0Script: ; 0x18c99e
	jumptext UnknownText_0x18cc2e
; 0x18c9a1

ItemFragment_0x18c9a1: ; 0x18c9a1
	db CALCIUM, 1
; 0x18c9a3

ItemFragment_0x18c9a3: ; 0x18c9a3
	db MAX_ELIXER, 1
; 0x18c9a5

MapDragonsDenB1FSignpostItem1: ; 0x18c9a5
	dw $00a0
	db REVIVE
; 0x18c9a8

MapDragonsDenB1FSignpostItem2: ; 0x18c9a8
	dw $00a1
	db MAX_POTION
; 0x18c9ab

MapDragonsDenB1FSignpostItem3: ; 0x18c9ab
	dw $00a2
	db MAX_ELIXER
; 0x18c9ae

MovementData_0x18c9ae: ; 0x18c9ae
	slow_step_right
	slow_step_right
	slow_step_right
	slow_step_right
	step_end
; 0x18c9b3

MovementData_0x18c9b3: ; 0x18c9b3
	slow_step_left
	slow_step_left
	slow_step_left
	slow_step_left
	step_end
; 0x18c9b8

UnknownText_0x18c9b8: ; 0x18c9b8
	db $0, "Wait!", $57
; 0x18c9bf

UnknownText_0x18c9bf: ; 0x18c9bf
	db $0, "CLAIR: I'm sorry", $4f
	db "about this.", $51
	db "Here, take this as", $4f
	db "my apology.", $57
; 0x18c9fb

UnknownText_0x18c9fb: ; 0x18c9fb
	db $0, $52, " received", $4f
	db "TM24.", $57
; 0x18ca0d

UnknownText_0x18ca0d: ; 0x18ca0d
	db $0, "That contains", $4f
	db "DRAGONBREATH.", $51
	db "No, it doesn't", $4f
	db "have anything to", $55
	db "do with my breath.", $51
	db "If you don't want", $4f
	db "it, you don't have", $55
	db "to take it.", $57
; 0x18ca8b

UnknownText_0x18ca8b: ; 0x18ca8b
	db $0, "Oh? You don't have", $4f
	db "any room for this.", $51
	db "I'm going back to", $4f
	db "the GYM, so make", $51
	db "room, then come", $4f
	db "see me there.", $57
; 0x18caf1

UnknownText_0x18caf1: ; 0x18caf1
	db $0, "CLAIR: What's the", $4f
	db "matter? Aren't you", $51
	db "going on to the", $4f
	db "#MON LEAGUE?", $51
	db "Do you know how to", $4f
	db "get there?", $51
	db "From here, go to", $4f
	db "NEW BARK TOWN.", $51
	db "Then SURF east to", $4f
	db "#MON LEAGUE.", $51
	db "The route there is", $4f
	db "very tough.", $51
	db "Don't you dare", $4f
	db "lose at the #-", $55
	db "MON LEAGUE!", $51
	db "If you do, I'll", $4f
	db "feel even worse", $51
	db "about having lost", $4f
	db "to you!", $51
	db "Give it everything", $4f
	db "you've got.", $57
; 0x18cc2e

UnknownText_0x18cc2e: ; 0x18cc2e
	db $0, "DRAGON SHRINE", $51
	db "A shrine honoring", $4f
	db "the dragon #MON", $51
	db "said to have lived", $4f
	db "in DRAGON'S DEN.", $57
; 0x18cc83

UnknownText_0x18cc83: ; 0x18cc83
	db $0, "…", $4f
	db "What? ", $52, "?", $51
	db "…No, I won't", $4f
	db "battle you now…", $51
	db "My #MON aren't", $4f
	db "ready to beat you.", $51
	db "I can't push them", $4f
	db "too hard now.", $51
	db "I have to be dis-", $4f
	db "ciplined to become", $51
	db "the greatest #-", $4f
	db "MON trainer…", $57
; 0x18cd2d

UnknownText_0x18cd2d: ; 0x18cd2d
	db $0, "…", $51
	db "Whew…", $51
	db "Learn to stay out", $4f
	db "of my way…", $57
; 0x18cd53

CooltrainermDarinSeenText: ; 0x18cd53
	db $0, "You! How dare you", $4f
	db "enter uninvited!", $57
; 0x18cd77

CooltrainermDarinBeatenText: ; 0x18cd77
	db $0, "S-strong!", $57
; 0x18cd82

UnknownText_0x18cd82: ; 0x18cd82
	db $0, "The SHRINE ahead", $4f
	db "is home to the", $51
	db "MASTER of our", $4f
	db "dragon-user clan.", $51
	db "You're not allowed", $4f
	db "to just go in!", $57
; 0x18cde4

CooltrainerfCaraSeenText: ; 0x18cde4
	db $0, "You shouldn't be", $4f
	db "in here!", $57
; 0x18cdfe

CooltrainerfCaraBeatenText: ; 0x18cdfe
	db $0, "Oh yikes, I lost!", $57
; 0x18ce11

UnknownText_0x18ce11: ; 0x18ce11
	db $0, "Soon I'm going to", $4f
	db "get permission", $51
	db "from our MASTER to", $4f
	db "use dragons.", $51
	db "When I do, I'm", $4f
	db "going to become an", $51
	db "admirable dragon", $4f
	db "trainer and gain", $51
	db "our MASTER's", $4f
	db "approval.", $57
; 0x18ceab

UnknownText_0x18ceab: ; 0x18ceab
	db $0, "It's a stranger we", $4f
	db "don't know.", $57
; 0x18cec9

TwinsLeaandpia1BeatenText: ; 0x18cec9
	db $0, "Ouchies.", $57
; 0x18ced3

UnknownText_0x18ced3: ; 0x18ced3
	db $0, "It was like having", $4f
	db "to battle LANCE.", $57
; 0x18cef8

TwinsLeaandpia1SeenText: ; 0x18cef8
	db $0, "Who are you?", $57
; 0x18cf06

UnknownText_0x18cf06: ; 0x18cf06
	db $0, "Meanie.", $57
; 0x18cf0f

UnknownText_0x18cf0f: ; 0x18cf0f
	db $0, "We'll tell on you.", $51
	db "MASTER will be", $4f
	db "angry with you.", $57
; 0x18cf41

UnknownText_0x18cf41: ; 0x18cf41
	db $0, $52, " found", $4f
	db "@"
	text_from_ram $d099
	db $0, "!", $57
; 0x18cf51

UnknownText_0x18cf51: ; 0x18cf51
	db $0, "But ", $52, " can't", $4f
	db "carry any more", $55
	db "items.", $57
; 0x18cf73

DragonsDenB1F_MapEventHeader: ; 0x18cf73
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $14, 3, GROUP_DRAGONS_DEN_1F, MAP_DRAGONS_DEN_1F
	warp_def $1d, $13, 1, GROUP_DRAGON_SHRINE, MAP_DRAGON_SHRINE

	; xy triggers
	db 1
	xy_trigger 1, $1e, $13, $0, UnknownScript_0x18c8b8, $0, $0

	; signposts
	db 4
	signpost 24, 18, $0, MapDragonsDenB1FSignpost0Script
	signpost 29, 33, $7, MapDragonsDenB1FSignpostItem1
	signpost 17, 21, $7, MapDragonsDenB1FSignpostItem2
	signpost 15, 31, $7, MapDragonsDenB1FSignpostItem3

	; people-events
	db 9
	person_event $54, 20, 39, $1, $0, 255, 255, $0, 0, UnknownScript_0x18c95a, $06a8
	person_event $19, 34, 18, $7, $0, 255, 255, $90, 0, ObjectEvent, $06d8
	person_event $4, 27, 24, $2, $22, 255, 255, $0, 0, UnknownScript_0x18c97e, $06c6
	person_event $23, 12, 24, $7, $0, 255, 255, $82, 4, TrainerCooltrainermDarin, $ffff
	person_event $24, 12, 12, $6, $0, 255, 255, $82, 3, TrainerCooltrainerfCara, $ffff
	person_event $26, 21, 8, $9, $0, 255, 255, $82, 1, $4932, $ffff
	person_event $26, 22, 8, $9, $0, 255, 255, $82, 1, TrainerTwinsLeaandpia1, $ffff
	person_event $54, 8, 34, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c9a1, $07bf
	person_event $54, 24, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x18c9a3, $07c0
; 0x18d014

DragonShrine_MapScriptHeader: ; 0x18d014
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x18d01e, $0000
	dw UnknownScript_0x18d022, $0000

	; callback count
	db 0
; 0x18d01e

UnknownScript_0x18d01e: ; 0x18d01e
	priorityjump UnknownScript_0x18d023
	end
; 0x18d022

UnknownScript_0x18d022: ; 0x18d022
	end
; 0x18d023

UnknownScript_0x18d023: ; 0x18d023
	applymovement $0, MovementData_0x18d2bf
	applymovement $2, MovementData_0x18d2c7
	loadfont
	2writetext UnknownText_0x18d2ea
	keeptextopen
UnknownScript_0x18d030: ; 0x18d030
	setbit1 $0001
	2writetext UnknownText_0x18d3bc
	keeptextopen
	loadmenudata $5215
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x18d0a9
	if_equal $2, UnknownScript_0x18d0cb
	if_equal $3, UnknownScript_0x18d0a9
	end
; 0x18d049

UnknownScript_0x18d049: ; 0x18d049
	setbit1 $0002
	2writetext UnknownText_0x18d3d3
	keeptextopen
	loadmenudata $5234
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x18d0a9
	if_equal $2, UnknownScript_0x18d0a9
	if_equal $3, UnknownScript_0x18d0cb
UnknownScript_0x18d061: ; 0x18d061
	setbit1 $0003
	2writetext UnknownText_0x18d3f3
	keeptextopen
	loadmenudata $5258
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x18d0cb
	if_equal $2, UnknownScript_0x18d0a9
	if_equal $3, UnknownScript_0x18d0a9
UnknownScript_0x18d079: ; 0x18d079
	setbit1 $0004
	2writetext UnknownText_0x18d420
	keeptextopen
	loadmenudata $5283
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x18d0a9
	if_equal $2, UnknownScript_0x18d0cb
	if_equal $3, UnknownScript_0x18d0a9
UnknownScript_0x18d091: ; 0x18d091
	setbit1 $0005
	2writetext UnknownText_0x18d44a
	keeptextopen
	loadmenudata $52a5
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x18d0cb
	if_equal $2, UnknownScript_0x18d0a9
	if_equal $3, UnknownScript_0x18d0cb
UnknownScript_0x18d0a9: ; 0x18d0a9
	checkbit1 $0005
	iftrue UnknownScript_0x18d100
	2writetext UnknownText_0x18d82d
	keeptextopen
	checkbit1 $0004
	iftrue UnknownScript_0x18d091
	checkbit1 $0003
	iftrue UnknownScript_0x18d079
	checkbit1 $0002
	iftrue UnknownScript_0x18d061
	checkbit1 $0001
	iftrue UnknownScript_0x18d049
UnknownScript_0x18d0cb: ; 0x18d0cb
	loadmovesprites
	spriteface $2, $2
	loadfont
	2writetext UnknownText_0x18d7f6
	closetext
	loadmovesprites
	spriteface $2, $0
	loadfont
	2writetext UnknownText_0x18d816
	closetext
	loadmovesprites
	setbit1 $00c1
	loadfont
	checkbit1 $0005
	iftrue UnknownScript_0x18d091
	checkbit1 $0004
	iftrue UnknownScript_0x18d079
	checkbit1 $0003
	iftrue UnknownScript_0x18d061
	checkbit1 $0002
	iftrue UnknownScript_0x18d049
	checkbit1 $0001
	iftrue UnknownScript_0x18d030
UnknownScript_0x18d100: ; 0x18d100
	2writetext UnknownText_0x18d47c
	closetext
	loadmovesprites
	playsound $001f
	showemote $0, $0, 15
	playmusic $005d
	appear $5
	waitbutton
	spriteface $0, $0
	pause 30
	applymovement $5, MovementData_0x18d2d4
	spriteface $5, $3
	spriteface $0, $2
	spriteface $2, $2
	loadfont
	2writetext UnknownText_0x18d916
	closetext
	loadmovesprites
	special $006a
	applymovement $5, MovementData_0x18d2da
	loadfont
	2writetext UnknownText_0x18d974
	closetext
	loadmovesprites
	applymovement $5, MovementData_0x18d2dd
	loadfont
	2writetext UnknownText_0x18d983
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x18d2c9
	spriteface $5, $1
	loadfont
	2writetext UnknownText_0x18d520
	closetext
	loadmovesprites
	showemote $0, $5, 15
	loadfont
	2writetext UnknownText_0x18d9ae
	closetext
	loadmovesprites
	applymovement $5, MovementData_0x18d2e0
	loadfont
	2writetext UnknownText_0x18d9bf
	closetext
	setbit2 $0022
	playsound $009c
	waitbutton
	special $003d
	specialphonecall $8
	dotrigger $1
	domaptrigger GROUP_DRAGONS_DEN_B1F, MAP_DRAGONS_DEN_B1F, $1
	2writetext UnknownText_0x18d9f2
	keeptextopen
	2writetext UnknownText_0x18da0b
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x18d2ce
	spriteface $5, $1
	applymovement $2, MovementData_0x18d2d1
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x18d5a3
	closetext
	loadmovesprites
	loadfont
	2writetext UnknownText_0x18dab4
	closetext
	loadmovesprites
	applymovement $5, MovementData_0x18d2e3
	playsound $001f
	disappear $5
	waitbutton
	setbit1 $0000
	end
; 0x18d1a5

UnknownScript_0x18d1a5: ; 0x18d1a5
	faceplayer
	loadfont
	checkbit1 $0000
	iftrue UnknownScript_0x18d1f9
	checkbit1 $0006
	iftrue UnknownScript_0x18d1ff
	checkbit1 $00bd
	iffalse UnknownScript_0x18d1c5
	checkbit1 $0319
	iftrue UnknownScript_0x18d1f3
	2writetext UnknownText_0x18d724
	closetext
	loadmovesprites
	end
; 0x18d1c5

UnknownScript_0x18d1c5: ; 0x18d1c5
	2writetext UnknownText_0x18d604
	closetext
	checkcode $1
	if_equal $6, UnknownScript_0x18d1ed
	2writetext UnknownText_0x18d697
	playsound $0002
	waitbutton
	givepoke DRATINI, 15, 0, 0
	checkbit1 $00c1
	special $0094
	setbit1 $00bd
	setbit1 $0006
	2writetext UnknownText_0x18d6ca
	closetext
	loadmovesprites
	end
; 0x18d1ed

UnknownScript_0x18d1ed: ; 0x18d1ed
	2writetext UnknownText_0x18d6ac
	closetext
	loadmovesprites
	end
; 0x18d1f3

UnknownScript_0x18d1f3: ; 0x18d1f3
	2writetext UnknownText_0x18d782
	closetext
	loadmovesprites
	end
; 0x18d1f9

UnknownScript_0x18d1f9: ; 0x18d1f9
	2writetext UnknownText_0x18d5e5
	closetext
	loadmovesprites
	end
; 0x18d1ff

UnknownScript_0x18d1ff: ; 0x18d1ff
	2writetext UnknownText_0x18d6ca
	closetext
	loadmovesprites
	end
; 0x18d205

UnknownScript_0x18d205: ; 0x18d205
	faceplayer
	loadfont
	2writetext UnknownText_0x18d840
	closetext
	loadmovesprites
	end
; 0x18d20d

UnknownScript_0x18d20d: ; 0x18d20d
	faceplayer
	loadfont
	2writetext UnknownText_0x18d8b1
	closetext
	loadmovesprites
	end
; 0x18d215

INCBIN "baserom.gbc",$18d215,$aa

MovementData_0x18d2bf: ; 0x18d2bf
	slow_step_up
	slow_step_up
	slow_step_up
	slow_step_right
	slow_step_up
	slow_step_up
	slow_step_up
	step_end
; 0x18d2c7

MovementData_0x18d2c7: ; 0x18d2c7
	slow_step_down
	step_end
; 0x18d2c9

MovementData_0x18d2c9: ; 0x18d2c9
	slow_step_left
	slow_step_left
	slow_step_left
	turn_head_down
	step_end
; 0x18d2ce

MovementData_0x18d2ce: ; 0x18d2ce
	slow_step_right
	slow_step_right
	step_end
; 0x18d2d1

MovementData_0x18d2d1: ; 0x18d2d1
	slow_step_right
	turn_head_down
	step_end
; 0x18d2d4

MovementData_0x18d2d4: ; 0x18d2d4
	slow_step_up
	slow_step_up
	slow_step_up
	slow_step_up
	slow_step_up
	step_end
; 0x18d2da

MovementData_0x18d2da: ; 0x18d2da
	fix_facing
	big_step_left
	step_end
; 0x18d2dd

MovementData_0x18d2dd: ; 0x18d2dd
	slow_step_left
	remove_fixed_facing
	step_end
; 0x18d2e0

MovementData_0x18d2e0: ; 0x18d2e0
	slow_step_right
	slow_step_right
	step_end
; 0x18d2e3

MovementData_0x18d2e3: ; 0x18d2e3
	step_down
	step_down
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x18d2ea

UnknownText_0x18d2ea: ; 0x18d2ea
	db $0, "Hm… Good to see", $4f
	db "you here.", $51
	db "No need to explain", $4f
	db "why you came.", $51
	db "CLAIR sent you", $4f
	db "here, didn't she?", $51
	db "That girl is a", $4f
	db "handful…", $51
	db "I am sorry, but I", $4f
	db "must test you.", $51
	db "Not to worry, you", $4f
	db "are to answer only", $55
	db "a few questions.", $51
	db "Ready?", $57
; 0x18d3bc

UnknownText_0x18d3bc: ; 0x18d3bc
	db $0, "What are #MON", $4f
	db "to you?", $57
; 0x18d3d3

UnknownText_0x18d3d3: ; 0x18d3d3
	db $0, "What helps you to", $4f
	db "win battles?", $57
; 0x18d3f3

UnknownText_0x18d3f3: ; 0x18d3f3
	db $0, "What kind of", $4f
	db "trainer do you", $55
	db "wish to battle?", $57
; 0x18d420

UnknownText_0x18d420: ; 0x18d420
	db $0, "What is most", $4f
	db "important for", $55
	db "raising #MON?", $57
; 0x18d44a

UnknownText_0x18d44a: ; 0x18d44a
	db $0, "Strong #MON.", $4f
	db "Weak #MON.", $51
	db "Which is more", $4f
	db "important?", $57
; 0x18d47c

UnknownText_0x18d47c: ; 0x18d47c
	db $0, "Hm… I see…", $51
	db "You care deeply", $4f
	db "for #MON.", $51
	db "Very commendable.", $51
	db "That conviction is", $4f
	db "what is important!", $51
	db $52, ", don't", $4f
	db "lose that belief.", $51
	db "It will see you", $4f
	db "through at the", $55
	db "#MON LEAGUE.", $57
; 0x18d520

UnknownText_0x18d520: ; 0x18d520
	db $0, "CLAIR!", $51
	db "This child is", $4f
	db "impeccable, in", $55
	db "skill and spirit!", $51
	db "Admit defeat and", $4f
	db "confer the RISING-", $55
	db "BADGE!", $51
	db "…Or must I inform", $4f
	db "LANCE of this?", $57
; 0x18d5a3

UnknownText_0x18d5a3: ; 0x18d5a3
	db $0, "CLAIR…", $51
	db "Reflect upon what", $4f
	db "it is that you", $51
	db "lack and this", $4f
	db "child has.", $57
; 0x18d5e5

UnknownText_0x18d5e5: ; 0x18d5e5
	db $0, "Come again, if you", $4f
	db "so desire.", $57
; 0x18d604

UnknownText_0x18d604: ; 0x18d604
	db $0, "Hm… Good to see", $4f
	db "you here.", $51
	db "Your arrival is", $4f
	db "most fortunate.", $51
	db "I have something", $4f
	db "for you.", $51
	db "Take this DRATINI", $4f
	db "as proof that I", $51
	db "have recognized", $4f
	db "your worth.", $57
; 0x18d697

UnknownText_0x18d697: ; 0x18d697
	db $0, $52, " received", $4f
	db "DRATINI!", $57
; 0x18d6ac

UnknownText_0x18d6ac: ; 0x18d6ac
	db $0, "Hm? Your #MON", $4f
	db "party is full.", $57
; 0x18d6ca

UnknownText_0x18d6ca: ; 0x18d6ca
	db $0, "Dragon #MON are", $4f
	db "symbolic of our", $55
	db "clan.", $51
	db "You have shown", $4f
	db "that you can be", $51
	db "entrusted with", $4f
	db "one.", $57
; 0x18d724

UnknownText_0x18d724: ; 0x18d724
	db $0, "CLAIR appears to", $4f
	db "have learned an", $51
	db "invaluable lesson", $4f
	db "from you.", $51
	db "I thank you as her", $4f
	db "grandfather.", $57
; 0x18d782

UnknownText_0x18d782: ; 0x18d782
	db $0, "A boy close to", $4f
	db "your age is in", $55
	db "training here.", $51
	db "He is much like", $4f
	db "CLAIR when she was", $51
	db "younger. It is a", $4f
	db "little worrisome…", $57
; 0x18d7f6

UnknownText_0x18d7f6: ; 0x18d7f6
	db $0, "Hah? I didn't", $4f
	db "quite catch that…", $57
; 0x18d816

UnknownText_0x18d816: ; 0x18d816
	db $0, "What was it you", $4f
	db "said?", $57
; 0x18d82d

UnknownText_0x18d82d: ; 0x18d82d
	db $0, "Oh, I understand…", $57
; 0x18d840

UnknownText_0x18d840: ; 0x18d840
	db $0, "It's been quite", $4f
	db "some time since a", $51
	db "trainer has gained", $4f
	db "our MASTER's rare", $55
	db "approval.", $51
	db "In fact, not since", $4f
	db "Master LANCE.", $57
; 0x18d8b1

UnknownText_0x18d8b1: ; 0x18d8b1
	db $0, "You know young", $4f
	db "Master LANCE?", $51
	db "He looks so much", $4f
	db "like our MASTER", $55
	db "did in his youth.", $51
	db "It's in their", $4f
	db "blood.", $57
; 0x18d916

UnknownText_0x18d916: ; 0x18d916
	db $0, "So how did it go?", $51
	db "I guess there's no", $4f
	db "point in asking.", $51
	db "You did fail?", $51
	db $56, $56, $56, $56, $56, $56, $51
	db "…What? You passed?", $57
; 0x18d974

UnknownText_0x18d974: ; 0x18d974
	db $0, "That can't be!", $57
; 0x18d983

UnknownText_0x18d983: ; 0x18d983
	db $0, "You're lying!", $51
	db "Even I haven't", $4f
	db "been approved!", $57
; 0x18d9ae

UnknownText_0x18d9ae: ; 0x18d9ae
	db $0, "I-I understand…", $57
; 0x18d9bf

UnknownText_0x18d9bf: ; 0x18d9bf
	db $0, "Here, this is the", $4f
	db "RISINGBADGE…", $51
	db "Hurry up! Take it!", $57
; 0x18d9f2

UnknownText_0x18d9f2: ; 0x18d9f2
	db $0, $52, " received", $4f
	db "RISINGBADGE.", $57
; 0x18da0b

UnknownText_0x18da0b: ; 0x18da0b
	db $0, "RISINGBADGE will", $4f
	db "enable your", $51
	db "#MON to use the", $4f
	db "move for climbing", $55
	db "waterfalls.", $51
	db "Also, all #MON", $4f
	db "will recognize you", $51
	db "as a trainer and", $4f
	db "obey your every", $51
	db "command without", $4f
	db "question.", $57
; 0x18dab4

UnknownText_0x18dab4: ; 0x18dab4
	db $0, $56, $56, $56, $56, $56, $56, $57
; 0x18dabc

DragonShrine_MapEventHeader: ; 0x18dabc
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $9, $4, 2, GROUP_DRAGONS_DEN_B1F, MAP_DRAGONS_DEN_B1F
	warp_def $9, $5, 2, GROUP_DRAGONS_DEN_B1F, MAP_DRAGONS_DEN_B1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $9, 5, 9, $6, $0, 255, 255, $0, 0, UnknownScript_0x18d1a5, $0000
	person_event $9, 8, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x18d205, $0000
	person_event $9, 8, 11, $8, $0, 255, 255, $0, 0, UnknownScript_0x18d20d, $0000
	person_event $19, 12, 8, $7, $0, 255, 255, $90, 0, ObjectEvent, $0790
; 0x18db00

TohjoFalls_MapScriptHeader: ; 0x18db00
	; trigger count
	db 0

	; callback count
	db 0
; 0x18db02

ItemFragment_0x18db02: ; 0x18db02
	db MOON_STONE, 1
; 0x18db04

TohjoFalls_MapEventHeader: ; 0x18db04
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $f, $d, 2, GROUP_ROUTE_27, MAP_ROUTE_27
	warp_def $f, $19, 3, GROUP_ROUTE_27, MAP_ROUTE_27

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $54, 10, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x18db02, $06a9
; 0x18db21

AzaleaPokeCenter1F_MapScriptHeader: ; 0x18db21
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x18db27, $0000

	; callback count
	db 0
; 0x18db27

UnknownScript_0x18db27: ; 0x18db27
	end
; 0x18db28

UnknownScript_0x18db28: ; 0x18db28
	jumpstd $0000
; 0x18db2b

UnknownScript_0x18db2b: ; 0x18db2b
	jumptextfaceplayer UnknownText_0x18db34
; 0x18db2e

UnknownScript_0x18db2e: ; 0x18db2e
	jumptextfaceplayer UnknownText_0x18dbee
; 0x18db31

UnknownScript_0x18db31: ; 0x18db31
	jumptextfaceplayer UnknownText_0x18dc19
; 0x18db34

UnknownText_0x18db34: ; 0x18db34
	db $0, "Do your #MON", $4f
	db "know HM moves?", $51
	db "Those moves can", $4f
	db "be used even if", $51
	db "your #MON has", $4f
	db "fainted.", $57
; 0x18db88

UnknownText_0x18db88: ; 0x18db88
	db $0, "This BILL guy", $4f
	db "created the system", $51
	db "for storing", $4f
	db "#MON in a PC.", $51
	db "BILL's PC can", $4f
	db "store up to 20", $55
	db "#MON per BOX.", $57
; 0x18dbee

UnknownText_0x18dbee: ; 0x18dbee
	db $0, "BILL's PC can", $4f
	db "store up to 20", $55
	db "#MON per BOX.", $57
; 0x18dc19

UnknownText_0x18dc19: ; 0x18dc19
	db $0, "Do you know about", $4f
	db "APRICORNS?", $51
	db "Crack one open,", $4f
	db "hollow it out and", $51
	db "fit it with a", $4f
	db "special device.", $51
	db "Then you can catch", $4f
	db "#MON with it.", $51
	db "Before # BALLS", $4f
	db "were invented,", $51
	db "everyone used", $4f
	db "APRICORNS.", $57
; 0x18dccf

AzaleaPokeCenter1F_MapEventHeader: ; 0x18dccf
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN
	warp_def $7, $4, 1, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x18db28, $ffff
	person_event $40, 10, 13, $4, $10, 255, 255, $0, 0, UnknownScript_0x18db2b, $ffff
	person_event $3b, 5, 10, $6, $0, 255, 255, $0, 0, UnknownScript_0x18db2e, $ffff
	person_event $2e, 8, 5, $2, $21, 255, 255, $0, 0, UnknownScript_0x18db31, $ffff
; 0x18dd18

CharcoalKiln_MapScriptHeader: ; 0x18dd18
	; trigger count
	db 0

	; callback count
	db 0
; 0x18dd1a

UnknownScript_0x18dd1a: ; 0x18dd1a
	faceplayer
	loadfont
	checkbit1 $0010
	iftrue UnknownScript_0x18dd34
	checkbit1 $002b
	iftrue UnknownScript_0x18dd2e
	2writetext UnknownText_0x18dd74
	closetext
	loadmovesprites
	end
; 0x18dd2e

UnknownScript_0x18dd2e: ; 0x18dd2e
	2writetext UnknownText_0x18ddfd
	closetext
	loadmovesprites
	end
; 0x18dd34

UnknownScript_0x18dd34: ; 0x18dd34
	2writetext UnknownText_0x18de73
	closetext
	loadmovesprites
	end
; 0x18dd3a

UnknownScript_0x18dd3a: ; 0x18dd3a
	faceplayer
	loadfont
	checkbit1 $005e
	iftrue UnknownScript_0x18dd5d
	checkbit1 $0010
	iftrue UnknownScript_0x18dd4e
	2writetext UnknownText_0x18dee0
	closetext
	loadmovesprites
	end
; 0x18dd4e

UnknownScript_0x18dd4e: ; 0x18dd4e
	2writetext UnknownText_0x18df25
	keeptextopen
	verbosegiveitem CHARCOAL, 1
	iffalse UnknownScript_0x18dd61
	setbit1 $005e
	loadmovesprites
	end
; 0x18dd5d

UnknownScript_0x18dd5d: ; 0x18dd5d
	2writetext UnknownText_0x18df93
	closetext
UnknownScript_0x18dd61: ; 0x18dd61
	loadmovesprites
	end
; 0x18dd63

UnknownScript_0x18dd63: ; 0x18dd63
	faceplayer
	loadfont
	2writetext UnknownText_0x18dfe5
	cry FARFETCH_D
	closetext
	loadmovesprites
	end
; 0x18dd6e

MapCharcoalKilnSignpost1Script: ; 0x18dd6e
	jumpstd $0003
; 0x18dd71

MapCharcoalKilnSignpost2Script: ; 0x18dd71
	jumpstd $000c
; 0x18dd74

UnknownText_0x18dd74: ; 0x18dd74
	db $0, "All the SLOWPOKE", $4f
	db "have disappeared", $55
	db "from the town.", $51
	db "The forest's pro-", $4f
	db "tector may be", $55
	db "angry with us…", $51
	db "It may be a bad", $4f
	db "omen. We should", $55
	db "stay in.", $57
; 0x18ddfd

UnknownText_0x18ddfd: ; 0x18ddfd
	db $0, "The SLOWPOKE have", $4f
	db "returned…", $51
	db "But my APPRENTICE", $4f
	db "hasn't come back", $55
	db "from ILEX FOREST.", $51
	db "Where in the world", $4f
	db "is that lazy guy?", $57
; 0x18de73

UnknownText_0x18de73: ; 0x18de73
	db $0, "You chased off", $4f
	db "TEAM ROCKET and", $51
	db "went to ILEX", $4f
	db "FOREST alone?", $51
	db "That takes guts!", $4f
	db "I like that. Come", $55
	db "train with us.", $57
; 0x18dee0

UnknownText_0x18dee0: ; 0x18dee0
	db $0, "Where have all the", $4f
	db "SLOWPOKE gone?", $51
	db "Are they out play-", $4f
	db "ing somewhere?", $57
; 0x18df25

UnknownText_0x18df25: ; 0x18df25
	db $0, "I'm sorry--I for-", $4f
	db "got to thank you.", $51
	db "This is CHARCOAL", $4f
	db "that I made.", $51
	db "Fire-type #MON", $4f
	db "would be happy to", $55
	db "hold that.", $57
; 0x18df93

UnknownText_0x18df93: ; 0x18df93
	db $0, "The SLOWPOKE came", $4f
	db "back, and you even", $55
	db "found FARFETCH'D.", $51
	db "You're the cool-", $4f
	db "est, man!", $57
; 0x18dfe5

UnknownText_0x18dfe5: ; 0x18dfe5
	db $0, "FARFETCH'D: Kwaa!", $57
; 0x18dff8

CharcoalKiln_MapEventHeader: ; 0x18dff8
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN
	warp_def $7, $3, 2, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 1, 0, $0, MapCharcoalKilnSignpost1Script
	signpost 1, 1, $0, MapCharcoalKilnSignpost1Script
	signpost 1, 7, $0, MapCharcoalKilnSignpost2Script

	; people-events
	db 3
	person_event $41, 7, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x18dd1a, $06f7
	person_event $27, 7, 9, $2, $11, 255, 255, $0, 0, UnknownScript_0x18dd3a, $06f6
	person_event $9e, 10, 9, $16, $22, 255, 255, $b0, 0, UnknownScript_0x18dd63, $06f5
; 0x18e03e

AzaleaMart_MapScriptHeader: ; 0x18e03e
	; trigger count
	db 0

	; callback count
	db 0
; 0x18e040

UnknownScript_0x18e040: ; 0x18e040
	loadfont
	pokemart $0, $0003
	loadmovesprites
	end
; 0x18e047

UnknownScript_0x18e047: ; 0x18e047
	jumptextfaceplayer UnknownText_0x18e04d
; 0x18e04a

UnknownScript_0x18e04a: ; 0x18e04a
	jumptextfaceplayer UnknownText_0x18e0b6
; 0x18e04d

UnknownText_0x18e04d: ; 0x18e04d
	db $0, "There's no GREAT", $4f
	db "BALL here. #", $51
	db "BALLS will have", $4f
	db "to do.", $51
	db "I wish KURT would", $4f
	db "make me some of", $55
	db "his custom BALLS.", $57
; 0x18e0b6

UnknownText_0x18e0b6: ; 0x18e0b6
	db $0, "A GREAT BALL is", $4f
	db "better for catch-", $55
	db "ing #MON than a", $55
	db "# BALL.", $51
	db "But KURT's might", $4f
	db "be better some-", $55
	db "times.", $57
; 0x18e118

AzaleaMart_MapEventHeader: ; 0x18e118
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN
	warp_def $7, $3, 3, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x18e040, $ffff
	person_event $23, 9, 6, $7, $0, 255, 255, $0, 0, UnknownScript_0x18e047, $ffff
	person_event $25, 6, 11, $5, $2, 255, 255, $80, 0, UnknownScript_0x18e04a, $ffff
; 0x18e14f

KurtsHouse_MapScriptHeader: ; 0x18e14f
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x18e154
; 0x18e154

UnknownScript_0x18e154: ; 0x18e154
	checkbit1 $002b
	iffalse UnknownScript_0x18e177
	checkbit1 $00c0
	iftrue UnknownScript_0x18e177
	checkbit2 $0050
	iftrue UnknownScript_0x18e16f
	disappear $5
	appear $2
	disappear $6
	appear $3
	return
; 0x18e16f

UnknownScript_0x18e16f: ; 0x18e16f
	disappear $2
	appear $5
	disappear $3
	appear $6
UnknownScript_0x18e177: ; 0x18e177
	return
; 0x18e178

UnknownScript_0x18e178: ; 0x18e178
	faceplayer
	loadfont
	checkbit1 $0035
	iftrue UnknownScript_0x18e1cc
	checkbit1 $002b
	iftrue UnknownScript_0x18e1bf
	2writetext UnknownText_0x18e473
	closetext
	loadmovesprites
	special $006a
	setbit1 $06fa
	checkcode $9
	if_equal $1, UnknownScript_0x18e1ab
	spriteface $0, $0
	playsound $0018
	applymovement $2, MovementData_0x18e466
	playsound $0023
	disappear $2
	waitbutton
	special $003d
	end
; 0x18e1ab

UnknownScript_0x18e1ab: ; 0x18e1ab
	spriteface $0, $0
	playsound $0018
	applymovement $2, MovementData_0x18e46c
	playsound $0023
	disappear $2
	waitbutton
	special $003d
	end
; 0x18e1bf

UnknownScript_0x18e1bf: ; 0x18e1bf
	2writetext UnknownText_0x18e615
	keeptextopen
	verbosegiveitem LURE_BALL, 1
	iffalse UnknownScript_0x18e2b2
	setbit1 $0035
UnknownScript_0x18e1cc: ; 0x18e1cc
	checkbit1 $0000
	iftrue UnknownScript_0x18e29f
	checkbit1 $0258
	iftrue UnknownScript_0x18e2b4
	checkbit1 $0259
	iftrue UnknownScript_0x18e2ca
	checkbit1 $025a
	iftrue UnknownScript_0x18e2e0
	checkbit1 $025b
	iftrue UnknownScript_0x18e2f6
	checkbit1 $025c
	iftrue UnknownScript_0x18e30c
	checkbit1 $025d
	iftrue UnknownScript_0x18e322
	checkbit1 $025e
	iftrue UnknownScript_0x18e338
	checkbit1 $00be
	iftrue UnknownScript_0x18e34e
UnknownScript_0x18e202: ; 0x18e202
	checkbit1 $0001
	iftrue UnknownScript_0x18e212
	checkbit1 $0002
	iftrue UnknownScript_0x18e212
	2writetext UnknownText_0x18e6c9
	closetext
UnknownScript_0x18e212: ; 0x18e212
	checkitem RED_APRICORN
	iftrue UnknownScript_0x18e249
	checkitem BLU_APRICORN
	iftrue UnknownScript_0x18e249
	checkitem YLW_APRICORN
	iftrue UnknownScript_0x18e249
	checkitem GRN_APRICORN
	iftrue UnknownScript_0x18e249
	checkitem WHT_APRICORN
	iftrue UnknownScript_0x18e249
	checkitem BLK_APRICORN
	iftrue UnknownScript_0x18e249
	checkitem PNK_APRICORN
	iftrue UnknownScript_0x18e249
	checkbit1 $0001
	iftrue UnknownScript_0x18e2ae
	checkbit1 $0002
	iftrue UnknownScript_0x18e243
	loadmovesprites
	end
; 0x18e243

UnknownScript_0x18e243: ; 0x18e243
	2writetext UnknownText_0x18e6c9
	closetext
	loadmovesprites
	end
; 0x18e249

UnknownScript_0x18e249: ; 0x18e249
	2writetext UnknownText_0x18e736
	keeptextopen
	setbit1 $0002
	special $0056
	if_equal $0, UnknownScript_0x18e2a5
	if_equal $59, UnknownScript_0x18e275
	if_equal $5c, UnknownScript_0x18e27b
	if_equal $5d, UnknownScript_0x18e281
	if_equal $61, UnknownScript_0x18e287
	if_equal $63, UnknownScript_0x18e28d
	if_equal $65, UnknownScript_0x18e293
	setbit1 $0258
	2jump UnknownScript_0x18e299
; 0x18e275

UnknownScript_0x18e275: ; 0x18e275
	setbit1 $0259
	2jump UnknownScript_0x18e299
; 0x18e27b

UnknownScript_0x18e27b: ; 0x18e27b
	setbit1 $025a
	2jump UnknownScript_0x18e299
; 0x18e281

UnknownScript_0x18e281: ; 0x18e281
	setbit1 $025b
	2jump UnknownScript_0x18e299
; 0x18e287

UnknownScript_0x18e287: ; 0x18e287
	setbit1 $025c
	2jump UnknownScript_0x18e299
; 0x18e28d

UnknownScript_0x18e28d: ; 0x18e28d
	setbit1 $025d
	2jump UnknownScript_0x18e299
; 0x18e293

UnknownScript_0x18e293: ; 0x18e293
	setbit1 $025e
	2jump UnknownScript_0x18e299
; 0x18e299

UnknownScript_0x18e299: ; 0x18e299
	setbit1 $0000
	setbit2 $0050
UnknownScript_0x18e29f: ; 0x18e29f
	2writetext UnknownText_0x18e779
	closetext
	loadmovesprites
	end
; 0x18e2a5

UnknownScript_0x18e2a5: ; 0x18e2a5
	2writetext UnknownText_0x18e7bc
	closetext
	loadmovesprites
	end
; 0x18e2ab

UnknownScript_0x18e2ab: ; 0x18e2ab
	setbit1 $0001
UnknownScript_0x18e2ae: ; 0x18e2ae
	2writetext UnknownText_0x18e82a
	closetext
UnknownScript_0x18e2b2: ; 0x18e2b2
	loadmovesprites
	end
; 0x18e2b4

UnknownScript_0x18e2b4: ; 0x18e2b4
	checkbit2 $0050
	iftrue UnknownScript_0x18e3c5
	2writetext UnknownText_0x18e7fb
	keeptextopen
	verbosegiveitem2 LEVEL_BALL
	addvar $8
	unknown0xb2 $62
UnknownScript_0x18e2c4: ; 0x18e2c4
	clearbit1 $0258
	2jump UnknownScript_0x18e2ab
; 0x18e2ca

UnknownScript_0x18e2ca: ; 0x18e2ca
	checkbit2 $0050
	iftrue UnknownScript_0x18e3c5
	2writetext UnknownText_0x18e7fb
	keeptextopen
	verbosegiveitem2 LURE_BALL
	addvar $8
	unknown0xb2 $62
UnknownScript_0x18e2da: ; 0x18e2da
	clearbit1 $0259
	2jump UnknownScript_0x18e2ab
; 0x18e2e0

UnknownScript_0x18e2e0: ; 0x18e2e0
	checkbit2 $0050
	iftrue UnknownScript_0x18e3c5
	2writetext UnknownText_0x18e7fb
	keeptextopen
	verbosegiveitem2 MOON_BALL
	addvar $8
	unknown0xb2 $62
UnknownScript_0x18e2f0: ; 0x18e2f0
	clearbit1 $025a
	2jump UnknownScript_0x18e2ab
; 0x18e2f6

UnknownScript_0x18e2f6: ; 0x18e2f6
	checkbit2 $0050
	iftrue UnknownScript_0x18e3c5
	2writetext UnknownText_0x18e7fb
	keeptextopen
	verbosegiveitem2 FRIEND_BALL
	addvar $8
	unknown0xb2 $62
UnknownScript_0x18e306: ; 0x18e306
	clearbit1 $025b
	2jump UnknownScript_0x18e2ab
; 0x18e30c

UnknownScript_0x18e30c: ; 0x18e30c
	checkbit2 $0050
	iftrue UnknownScript_0x18e3c5
	2writetext UnknownText_0x18e7fb
	keeptextopen
	verbosegiveitem2 FAST_BALL
	addvar $8
	unknown0xb2 $62
UnknownScript_0x18e31c: ; 0x18e31c
	clearbit1 $025c
	2jump UnknownScript_0x18e2ab
; 0x18e322

UnknownScript_0x18e322: ; 0x18e322
	checkbit2 $0050
	iftrue UnknownScript_0x18e3c5
	2writetext UnknownText_0x18e7fb
	keeptextopen
	verbosegiveitem2 HEAVY_BALL
	addvar $8
	unknown0xb2 $62
UnknownScript_0x18e332: ; 0x18e332
	clearbit1 $025d
	2jump UnknownScript_0x18e2ab
; 0x18e338

UnknownScript_0x18e338: ; 0x18e338
	checkbit2 $0050
	iftrue UnknownScript_0x18e3c5
	2writetext UnknownText_0x18e7fb
	keeptextopen
	verbosegiveitem2 LOVE_BALL
	addvar $8
	unknown0xb2 $62
UnknownScript_0x18e348: ; 0x18e348
	clearbit1 $025e
	2jump UnknownScript_0x18e2ab
; 0x18e34e

UnknownScript_0x18e34e: ; 0x18e34e
	checkbit1 $00bf
	iftrue UnknownScript_0x18e368
	checkitem GS_BALL
	iffalse UnknownScript_0x18e202
	2writetext UnknownText_0x18e8ab
	closetext
	loadmovesprites
	setbit1 $00bf
	takeitem GS_BALL, 1
	setbit2 $0050
	end
; 0x18e368

UnknownScript_0x18e368: ; 0x18e368
	checkbit2 $0050
	iffalse UnknownScript_0x18e378
	2writetext UnknownText_0x18e934
	closetext
	2writetext UnknownText_0x18e949
	closetext
	loadmovesprites
	end
; 0x18e378

UnknownScript_0x18e378: ; 0x18e378
	2writetext UnknownText_0x18e95c
	closetext
	loadmovesprites
	setbit1 $00c0
	clearbit1 $00be
	clearbit1 $00bf
	special $006a
	pause 20
	showemote $0, $2, 30
	checkcode $9
	if_equal $1, UnknownScript_0x18e3a2
	spriteface $0, $0
	playsound $0018
	applymovement $2, MovementData_0x18e466
	2jump UnknownScript_0x18e3ac
; 0x18e3a2

UnknownScript_0x18e3a2: ; 0x18e3a2
	spriteface $0, $0
	playsound $0018
	applymovement $2, MovementData_0x18e46c
UnknownScript_0x18e3ac: ; 0x18e3ac
	playsound $0023
	disappear $2
	clearbit1 $07a4
	waitbutton
	special $003d
	domaptrigger GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN, $2
	end
; 0x18e3bd

UnknownScript_0x18e3bd: ; 0x18e3bd
	faceplayer
	loadfont
	checkbit1 $00bf
	iftrue UnknownScript_0x18e3e0
UnknownScript_0x18e3c5: ; 0x18e3c5
	checkbit1 $00bb
	iffalse UnknownScript_0x18e3d4
	2writetext UnknownText_0x18e7d8
	closetext
	loadmovesprites
	spriteface $5, $1
	end
; 0x18e3d4

UnknownScript_0x18e3d4: ; 0x18e3d4
	2writetext UnknownText_0x18e863
	closetext
	loadmovesprites
	spriteface $5, $1
	setbit1 $00bb
	end
; 0x18e3e0

UnknownScript_0x18e3e0: ; 0x18e3e0
	2writetext UnknownText_0x18e934
	closetext
	spriteface $5, $1
	2writetext UnknownText_0x18e949
	closetext
	loadmovesprites
	end
; 0x18e3ed

UnknownScript_0x18e3ed: ; 0x18e3ed
	faceplayer
	checkbit1 $0000
	iftrue UnknownScript_0x18e42f
	checkbit1 $0001
	iftrue UnknownScript_0x18e448
	checkbit1 $00c0
	iftrue UnknownScript_0x18e420
	checkbit1 $0030
	iftrue UnknownScript_0x18e427
	checkbit1 $002b
	iftrue UnknownScript_0x18e419
	checkbit1 $06fa
	iftrue UnknownScript_0x18e420
	loadfont
	2writetext UnknownText_0x18e9b5
	closetext
	loadmovesprites
	end
; 0x18e419

UnknownScript_0x18e419: ; 0x18e419
	loadfont
	2writetext UnknownText_0x18ea0f
	closetext
	loadmovesprites
	end
; 0x18e420

UnknownScript_0x18e420: ; 0x18e420
	loadfont
	2writetext UnknownText_0x18e9f1
	closetext
	loadmovesprites
	end
; 0x18e427

UnknownScript_0x18e427: ; 0x18e427
	loadfont
	2writetext UnknownText_0x18ea55
	closetext
	loadmovesprites
	end
; 0x18e42e

UnknownScript_0x18e42e: ; 0x18e42e
	faceplayer
UnknownScript_0x18e42f: ; 0x18e42f
	loadfont
	checkbit1 $00bf
	iftrue UnknownScript_0x18e43f
	2writetext UnknownText_0x18eab2
	closetext
	loadmovesprites
	spriteface $6, $3
	end
; 0x18e43f

UnknownScript_0x18e43f: ; 0x18e43f
	2writetext UnknownText_0x18eb14
	closetext
	loadmovesprites
	spriteface $6, $3
	end
; 0x18e448

UnknownScript_0x18e448: ; 0x18e448
	loadfont
	2writetext UnknownText_0x18eafc
	closetext
	loadmovesprites
	end
; 0x18e44f

UnknownScript_0x18e44f: ; 0x18e44f
	faceplayer
	loadfont
	2writetext UnknownText_0x18eb56
	cry SLOWPOKE
	closetext
	loadmovesprites
	end
; 0x18e45a

MapKurtsHouseSignpost2Script: ; 0x18e45a
	jumptext UnknownText_0x18eb69
; 0x18e45d

MapKurtsHouseSignpost6Script: ; 0x18e45d
	jumptext UnknownText_0x18eb7e
; 0x18e460

MapKurtsHouseSignpost5Script: ; 0x18e460
	jumpstd $0001
; 0x18e463

MapKurtsHouseSignpost0Script: ; 0x18e463
	jumpstd $000c
; 0x18e466

MovementData_0x18e466: ; 0x18e466
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	step_end
; 0x18e46c

MovementData_0x18e46c: ; 0x18e46c
	big_step_right
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	big_step_down
	step_end
; 0x18e473

UnknownText_0x18e473: ; 0x18e473
	db $0, "Hm? Who are you?", $51
	db $52, ", eh? You", $4f
	db "want me to make", $55
	db "some BALLS?", $51
	db "Sorry, but that'll", $4f
	db "have to wait.", $51
	db "Do you know TEAM", $4f
	db "ROCKET? Ah, don't", $51
	db "worry. I'll tell", $4f
	db "you anyhow.", $51
	db "TEAM ROCKET's an", $4f
	db "evil gang that", $51
	db "uses #MON for", $4f
	db "their dirty work.", $51
	db "They're supposed", $4f
	db "to have disbanded", $55
	db "three years ago.", $51
	db "Anyway, they're at", $4f
	db "the WELL, cutting", $51
	db "off SLOWPOKETAILS", $4f
	db "for sale!", $51
	db "So I'm going to", $4f
	db "go give them a", $55
	db "lesson in pain!", $51
	db "Hang on, SLOWPOKE!", $4f
	db "Old KURT is on his", $55
	db "way!", $57
; 0x18e615

UnknownText_0x18e615: ; 0x18e615
	db $0, "KURT: Hi, ", $52, "!", $51
	db "You handled your-", $4f
	db "self like a real", $55
	db "hero at the WELL.", $51
	db "I like your style!", $51
	db "I would be honored", $4f
	db "to make BALLS for", $51
	db "a trainer like", $4f
	db "you.", $51
	db "This is all I have", $4f
	db "now, but take it.", $57
; 0x18e6c9

UnknownText_0x18e6c9: ; 0x18e6c9
	db $0, "KURT: I make BALLS", $4f
	db "from APRICORNS.", $51
	db "Collect them from", $4f
	db "trees and bring", $55
	db "'em to me.", $51
	db "I'll make BALLS", $4f
	db "out of them.", $57
; 0x18e736

UnknownText_0x18e736: ; 0x18e736
	db $0, "KURT: You have an", $4f
	db "APRICORN for me?", $51
	db "Fine! I'll turn it", $4f
	db "into a BALL.", $57
; 0x18e779

UnknownText_0x18e779: ; 0x18e779
	db $0, "KURT: It'll take a", $4f
	db "day to make you a", $51
	db "BALL. Come back", $4f
	db "for it later.", $57
; 0x18e7bc

UnknownText_0x18e7bc: ; 0x18e7bc
	db $0, "KURT: Oh…", $4f
	db "That's a letdown.", $57
; 0x18e7d8

UnknownText_0x18e7d8: ; 0x18e7d8
	db $0, "KURT: I'm working!", $4f
	db "Don't bother me!", $57
; 0x18e7fb

UnknownText_0x18e7fb: ; 0x18e7fb
	db $0, "KURT: Ah, ", $52, "!", $4f
	db "I just finished", $55
	db "your BALL. Here!", $57
; 0x18e82a

UnknownText_0x18e82a: ; 0x18e82a
	db $0, "KURT: That turned", $4f
	db "out great.", $51
	db "Try catching", $4f
	db "#MON with it.", $57
; 0x18e863

UnknownText_0x18e863: ; 0x18e863
	db $0, "KURT: Now that my", $4f
	db "granddaughter is", $51
	db "helping me, I can", $4f
	db "work much faster.", $57
; 0x18e8ab

UnknownText_0x18e8ab: ; 0x18e8ab
	db $0, "Wh-what is that?", $51
	db "I've never seen", $4f
	db "one before.", $51
	db "It looks a lot", $4f
	db "like a # BALL,", $51
	db "but it appears to", $4f
	db "be something else.", $51
	db "Let me check it", $4f
	db "for you.", $57
; 0x18e934

UnknownText_0x18e934: ; 0x18e934
	db $0, "I'm checking it", $4f
	db "now.", $57
; 0x18e949

UnknownText_0x18e949: ; 0x18e949
	db $0, "Ah-ha! I see!", $4f
	db "So…", $57
; 0x18e95c

UnknownText_0x18e95c: ; 0x18e95c
	db $0, $52, "!", $51
	db "This BALL started", $4f
	db "to shake while I", $55
	db "was checking it.", $51
	db "There must be", $4f
	db "something to this!", $57
; 0x18e9b5

UnknownText_0x18e9b5: ; 0x18e9b5
	db $0, "The SLOWPOKE are", $4f
	db "gone… Were they", $51
	db "taken away by bad", $4f
	db "people?", $57
; 0x18e9f1

UnknownText_0x18e9f1: ; 0x18e9f1
	db $0, "Grandpa's gone…", $4f
	db "I'm so lonely…", $57
; 0x18ea0f

UnknownText_0x18ea0f: ; 0x18ea0f
	db $0, "The SLOWPOKE my", $4f
	db "dad gave me came", $51
	db "back! Its TAIL is", $4f
	db "growing back too!", $57
; 0x18ea55

UnknownText_0x18ea55: ; 0x18ea55
	db $0, "Dad works at SILPH", $4f
	db "where he studies", $55
	db "# BALLS.", $51
	db "I have to stay", $4f
	db "home with Grandpa", $55
	db "and SLOWPOKE.", $57
; 0x18eab2

UnknownText_0x18eab2: ; 0x18eab2
	db $0, "I get to help", $4f
	db "Grandpa now!", $51
	db "We'll make good", $4f
	db "BALLS for you, so", $55
	db "please wait!", $57
; 0x18eafc

UnknownText_0x18eafc: ; 0x18eafc
	db $0, "It's fun to make", $4f
	db "BALLS!", $57
; 0x18eb14

UnknownText_0x18eb14: ; 0x18eb14
	db $0, "Grandpa's checking", $4f
	db "a BALL right now.", $51
	db "So I'm waiting", $4f
	db "till he's done.", $57
; 0x18eb56

UnknownText_0x18eb56: ; 0x18eb56
	db $0, "SLOWPOKE: …", $4f
	db "Yawn?", $57
; 0x18eb69

UnknownText_0x18eb69: ; 0x18eb69
	db $0, "…A young PROF.", $4f
	db "OAK?", $57
; 0x18eb7e

UnknownText_0x18eb7e: ; 0x18eb7e
	db $0, "It's a statue of", $4f
	db "the forest's pro-", $55
	db "tector.", $57
; 0x18eba8

KurtsHouse_MapEventHeader: ; 0x18eba8
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $3, 4, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN
	warp_def $7, $4, 4, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN

	; xy triggers
	db 0

	; signposts
	db 7
	signpost 1, 6, $0, MapKurtsHouseSignpost0Script
	signpost 0, 8, $0, MapKurtsHouseSignpost2Script
	signpost 0, 9, $0, MapKurtsHouseSignpost2Script
	signpost 1, 5, $0, MapKurtsHouseSignpost5Script
	signpost 1, 2, $0, MapKurtsHouseSignpost5Script
	signpost 1, 3, $0, MapKurtsHouseSignpost5Script
	signpost 1, 4, $0, MapKurtsHouseSignpost6Script

	; people-events
	db 5
	person_event $b, 6, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x18e178, $073e
	person_event $26, 7, 9, $3, $0, 255, 255, $0, 0, UnknownScript_0x18e3ed, $078c
	person_event $45, 7, 10, $1, $0, 255, 255, $0, 0, UnknownScript_0x18e44f, $06fd
	person_event $b, 7, 18, $7, $0, 255, 255, $0, 0, UnknownScript_0x18e3bd, $073f
	person_event $26, 8, 15, $9, $0, 255, 255, $0, 0, UnknownScript_0x18e42e, $078d
; 0x18ec1c

AzaleaGym_MapScriptHeader: ; 0x18ec1c
	; trigger count
	db 0

	; callback count
	db 0
; 0x18ec1e

UnknownScript_0x18ec1e: ; 0x18ec1e
	faceplayer
	loadfont
	checkbit1 $04be
	iftrue UnknownScript_0x18ec48
	2writetext UnknownText_0x18ed0b
	closetext
	loadmovesprites
	winlosstext UnknownText_0x18edae, $0000
	loadtrainer BUGSY, 1
	startbattle
	returnafterbattle
	setbit1 $04be
	loadfont
	2writetext UnknownText_0x18ee14
	playsound $009c
	waitbutton
	setbit2 $001c
	checkcode $7
	2call UnknownScript_0x18ec73
UnknownScript_0x18ec48: ; 0x18ec48
	checkbit1 $0009
	iftrue UnknownScript_0x18ec6d
	setbit1 $0464
	setbit1 $053c
	setbit1 $053d
	setbit1 $053e
	2writetext UnknownText_0x18ee2b
	keeptextopen
	verbosegiveitem TM_49, 1
	iffalse UnknownScript_0x18ec71
	setbit1 $0009
	2writetext UnknownText_0x18eefa
	closetext
	loadmovesprites
	end
; 0x18ec6d

UnknownScript_0x18ec6d: ; 0x18ec6d
	2writetext UnknownText_0x18ef98
	closetext
UnknownScript_0x18ec71: ; 0x18ec71
	loadmovesprites
	end
; 0x18ec73

UnknownScript_0x18ec73: ; 0x18ec73
	if_equal $7, UnknownScript_0x18ec7f
	if_equal $6, UnknownScript_0x18ec7c
	end
; 0x18ec7c

UnknownScript_0x18ec7c: ; 0x18ec7c
	jumpstd $0012
; 0x18ec7f

UnknownScript_0x18ec7f: ; 0x18ec7f
	jumpstd $0013
; 0x18ec82

TrainerTwinsAmyandmay1: ; 0x18ec82
	; bit/flag number
	dw $464

	; trainer group && trainer id
	db TWINS, AMYANDMAY1

	; text when seen
	dw TwinsAmyandmay1SeenText

	; text when trainer beaten
	dw TwinsAmyandmay1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TwinsAmyandmay1Script
; 0x18ec8e

TwinsAmyandmay1Script: ; 0x18ec8e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18f1fc
	closetext
	loadmovesprites
	end
; 0x18ec96

TrainerTwinsAmyandmay2: ; 0x18ec96
	; bit/flag number
	dw $464

	; trainer group && trainer id
	db TWINS, AMYANDMAY2

	; text when seen
	dw TwinsAmyandmay2SeenText

	; text when trainer beaten
	dw TwinsAmyandmay2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TwinsAmyandmay2Script
; 0x18eca2

TwinsAmyandmay2Script: ; 0x18eca2
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18f269
	closetext
	loadmovesprites
	end
; 0x18ecaa

TrainerBug_catcherBug_catcher_benny: ; 0x18ecaa
	; bit/flag number
	dw $53c

	; trainer group && trainer id
	db BUG_CATCHER, BUG_CATCHER_BENNY

	; text when seen
	dw Bug_catcherBug_catcher_bennySeenText

	; text when trainer beaten
	dw Bug_catcherBug_catcher_bennyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherBug_catcher_bennyScript
; 0x18ecb6

Bug_catcherBug_catcher_bennyScript: ; 0x18ecb6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18f053
	closetext
	loadmovesprites
	end
; 0x18ecbe

TrainerBug_catcherAl: ; 0x18ecbe
	; bit/flag number
	dw $53d

	; trainer group && trainer id
	db BUG_CATCHER, AL

	; text when seen
	dw Bug_catcherAlSeenText

	; text when trainer beaten
	dw Bug_catcherAlBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherAlScript
; 0x18ecca

Bug_catcherAlScript: ; 0x18ecca
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18f0d3
	closetext
	loadmovesprites
	end
; 0x18ecd2

TrainerBug_catcherJosh: ; 0x18ecd2
	; bit/flag number
	dw $53e

	; trainer group && trainer id
	db BUG_CATCHER, JOSH

	; text when seen
	dw Bug_catcherJoshSeenText

	; text when trainer beaten
	dw Bug_catcherJoshBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherJoshScript
; 0x18ecde

Bug_catcherJoshScript: ; 0x18ecde
	talkaftercancel
	loadfont
	2writetext UnknownText_0x18f17e
	closetext
	loadmovesprites
	end
; 0x18ece6

AzaleaGymGuyScript: ; 0x18ece6
	faceplayer
	checkbit1 $04be
	iftrue .AzaleaGymGuyWinScript
	loadfont
	2writetext AzaleaGymGuyText
	closetext
	loadmovesprites
	end

.AzaleaGymGuyWinScript
	loadfont
	2writetext AzaleaGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x18ecfb

MapAzaleaGymSignpost1Script: ; 0x18ecfb
	checkbit2 $001c
	iftrue UnknownScript_0x18ed04
	jumpstd $002d
; 0x18ed04

UnknownScript_0x18ed04: ; 0x18ed04
	trainertotext BUGSY, 1, $1
	jumpstd $002e
; 0x18ed0b

UnknownText_0x18ed0b: ; 0x18ed0b
	db $0, "I'm BUGSY!", $4f
	db "I never lose when", $51
	db "it comes to bug", $4f
	db "#MON.", $51
	db "My research is", $4f
	db "going to make me", $51
	db "the authority on", $4f
	db "bug #MON!", $51
	db "Let me demonstrate", $4f
	db "what I've learned", $55
	db "from my studies.", $57
; 0x18edae

UnknownText_0x18edae: ; 0x18edae
	db $0, "Whoa, amazing!", $4f
	db "You're an expert", $55
	db "on #MON!", $51
	db "My research isn't", $4f
	db "complete yet.", $51
	db "OK, you win. Take", $4f
	db "this BADGE.", $57
; 0x18ee14

UnknownText_0x18ee14: ; 0x18ee14
	db $0, $52, " received", $4f
	db "HIVEBADGE.", $57
; 0x18ee2b

UnknownText_0x18ee2b: ; 0x18ee2b
	db $0, "Do you know the", $4f
	db "benefits of HIVE-", $55
	db "BADGE?", $51
	db "If you have it,", $4f
	db "#MON up to L30", $51
	db "will obey you,", $4f
	db "even traded ones.", $51
	db "#MON that know", $4f
	db "CUT will be able", $51
	db "to use it outside", $4f
	db "of battle too.", $51
	db "Here, I also want", $4f
	db "you to have this.", $57
; 0x18eefa

UnknownText_0x18eefa: ; 0x18eefa
	db $0, "TM49 contains", $4f
	db "FURY CUTTER.", $51
	db "If you don't miss,", $4f
	db "it gets stronger", $55
	db "every turn.", $51
	db "The longer your", $4f
	db "battle goes, the", $55
	db "better it gets.", $51
	db "Isn't that great?", $4f
	db "I discovered it!", $57
; 0x18ef98

UnknownText_0x18ef98: ; 0x18ef98
	db $0, "Bug #MON are", $4f
	db "deep. There are", $51
	db "many mysteries to", $4f
	db "be explored.", $51
	db "Study your favor-", $4f
	db "ites thoroughly.", $57
; 0x18eff8

Bug_catcherBug_catcher_bennySeenText: ; 0x18eff8
	db $0, "Bug #MON evolve", $4f
	db "young. So they get", $51
	db "stronger that much", $4f
	db "faster.", $57
; 0x18f037

Bug_catcherBug_catcher_bennyBeatenText: ; 0x18f037
	db $0, "Just evolving", $4f
	db "isn't enough!", $57
; 0x18f053

UnknownText_0x18f053: ; 0x18f053
	db $0, "#MON become", $4f
	db "stronger if they", $55
	db "evolve. Really!", $57
; 0x18f081

Bug_catcherAlSeenText: ; 0x18f081
	db $0, "Bug #MON are", $4f
	db "cool and tough!", $51
	db "I'll prove it to", $4f
	db "you!", $57
; 0x18f0b4

Bug_catcherAlBeatenText: ; 0x18f0b4
	db $0, "You proved how", $4f
	db "tough you are…", $57
; 0x18f0d3

UnknownText_0x18f0d3: ; 0x18f0d3
	db $0, "They're so cool,", $4f
	db "but most girls", $51
	db "don't like bug", $4f
	db "#MON.", $51
	db "I don't know why…", $57
; 0x18f118

Bug_catcherJoshSeenText: ; 0x18f118
	db $0, "You saved all the", $4f
	db "SLOWPOKE? Whew,", $55
	db "you're mighty!", $51
	db "But my grown-up", $4f
	db "#MON are pretty", $55
	db "tough too!", $57
; 0x18f174

Bug_catcherJoshBeatenText: ; 0x18f174
	db $0, "Urrgggh!", $57
; 0x18f17e

UnknownText_0x18f17e: ; 0x18f17e
	db $0, "I guess I should", $4f
	db "teach them better", $55
	db "moves…", $57
; 0x18f1a9

TwinsAmyandmay1SeenText: ; 0x18f1a9
	db $0, "AMY: Hi! Are you", $4f
	db "challenging the", $55
	db "LEADER? No way!", $57
; 0x18f1db

TwinsAmyandmay1BeatenText: ; 0x18f1db
	db $0, "AMY & MAY: Oh,", $4f
	db "double goodness!", $57
; 0x18f1fc

UnknownText_0x18f1fc: ; 0x18f1fc
	db $0, "AMY: You're", $4f
	db "really strong!", $57
; 0x18f217

TwinsAmyandmay2SeenText: ; 0x18f217
	db $0, "MAY: You want to", $4f
	db "see the LEADER?", $55
	db "We come first!", $57
; 0x18f248

TwinsAmyandmay2BeatenText: ; 0x18f248
	db $0, "AMY & MAY: Oh,", $4f
	db "double goodness!", $57
; 0x18f269

UnknownText_0x18f269: ; 0x18f269
	db $0, "MAY: Our bug #-", $4f
	db "MON lost! Oh, what", $55
	db "a shame.", $57
; 0x18f296

AzaleaGymGuyText: ; 0x18f296
	db $0, "Yo, challenger!", $51
	db "BUGSY's young, but", $4f
	db "his knowledge of", $51
	db "bug #MON is for", $4f
	db "real.", $51
	db "It's going to be", $4f
	db "tough without my", $55
	db "advice.", $51
	db "Let's see… Bug", $4f
	db "#MON don't like", $55
	db "fire.", $51
	db "Flying-type moves", $4f
	db "are super-effec-", $55
	db "tive too.", $57
; 0x18f359

AzaleaGymGuyWinText: ; 0x18f359
	db $0, "Well done! That", $4f
	db "was a great clash", $51
	db "of talented young", $4f
	db "trainers.", $51
	db "With people like", $4f
	db "you, the future of", $55
	db "#MON is bright!", $57
; 0x18f3cc

AzaleaGym_MapEventHeader: ; 0x18f3cc
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $f, $4, 5, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN
	warp_def $f, $5, 5, GROUP_AZALEA_TOWN, MAP_AZALEA_TOWN

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 13, 3, $0, MapAzaleaGymSignpost1Script
	signpost 13, 6, $0, MapAzaleaGymSignpost1Script

	; people-events
	db 7
	person_event $14, 11, 9, $3, $0, 255, 255, $a0, 0, UnknownScript_0x18ec1e, $ffff
	person_event $25, 7, 9, $a, $0, 255, 255, $b2, 2, TrainerBug_catcherBug_catcher_benny, $ffff
	person_event $25, 12, 12, $6, $0, 255, 255, $b2, 3, TrainerBug_catcherAl, $ffff
	person_event $25, 6, 4, $6, $0, 255, 255, $b2, 3, TrainerBug_catcherJosh, $ffff
	person_event $26, 14, 8, $6, $0, 255, 255, $82, 1, TrainerTwinsAmyandmay1, $ffff
	person_event $26, 14, 9, $6, $0, 255, 255, $82, 1, TrainerTwinsAmyandmay2, $ffff
	person_event $48, 17, 11, $6, $0, 255, 255, $80, 0, AzaleaGymGuyScript, $ffff
; 0x18f441

SECTION "bank64",DATA,BANK[$64]

MahoganyTown_MapScriptHeader: ; 0x190000
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x19000d, $0000
	dw UnknownScript_0x19000e, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x19000f
; 0x19000d

UnknownScript_0x19000d: ; 0x19000d
	end
; 0x19000e

UnknownScript_0x19000e: ; 0x19000e
	end
; 0x19000f

UnknownScript_0x19000f: ; 0x19000f
	setbit2 $0049
	return
; 0x190013

UnknownScript_0x190013: ; 0x190013
	showemote $0, $2, 15
	applymovement $2, MovementData_0x1900a9
	follow $0, $2
	applymovement $0, MovementData_0x1900a7
	stopfollow
	spriteface $0, $3
	2call UnknownScript_0x19002f
	applymovement $2, MovementData_0x1900ad
	end
; 0x19002e

UnknownScript_0x19002e: ; 0x19002e
	faceplayer
UnknownScript_0x19002f: ; 0x19002f
	checkbit1 $0022
	iftrue UnknownScript_0x190039
	2call UnknownScript_0x190040
	end
; 0x190039

UnknownScript_0x190039: ; 0x190039
	loadfont
	2writetext UnknownText_0x1901a6
	closetext
	loadmovesprites
	end
; 0x190040

UnknownScript_0x190040: ; 0x190040
	loadfont
	2writetext UnknownText_0x1900b0
	special $0051
	yesorno
	iffalse UnknownScript_0x190072
	checkmoney $0, 300
	if_equal $2, UnknownScript_0x19006c
	giveitem RAGECANDYBAR, $1
	iffalse UnknownScript_0x190078
	waitbutton
	playsound $0022
	takemoney $0, 300
	special $0051
	2writetext UnknownText_0x19014a
	closetext
	loadmovesprites
	end
; 0x19006c

UnknownScript_0x19006c: ; 0x19006c
	2writetext UnknownText_0x19015b
	closetext
	loadmovesprites
	end
; 0x190072

UnknownScript_0x190072: ; 0x190072
	2writetext UnknownText_0x190178
	closetext
	loadmovesprites
	end
; 0x190078

UnknownScript_0x190078: ; 0x190078
	2writetext UnknownText_0x190188
	closetext
	loadmovesprites
	end
; 0x19007e

UnknownScript_0x19007e: ; 0x19007e
	faceplayer
	loadfont
	checkbit1 $0022
	iftrue UnknownScript_0x19008c
	2writetext UnknownText_0x1901e5
	closetext
	loadmovesprites
	end
; 0x19008c

UnknownScript_0x19008c: ; 0x19008c
	2writetext UnknownText_0x19021d
	closetext
	loadmovesprites
	end
; 0x190092

UnknownScript_0x190092: ; 0x190092
	jumptextfaceplayer UnknownText_0x190276
; 0x190095

UnknownScript_0x190095: ; 0x190095
	jumptextfaceplayer UnknownText_0x1902f2
; 0x190098

MapMahoganyTownSignpost0Script: ; 0x190098
	jumptext UnknownText_0x19032e
; 0x19009b

MapMahoganyTownSignpost1Script: ; 0x19009b
	jumptext UnknownText_0x19035e
; 0x19009e

MapMahoganyTownSignpost2Script: ; 0x19009e
	jumptext UnknownText_0x190391
; 0x1900a1

MapMahoganyTownSignpost3Script: ; 0x1900a1
	jumpstd $0010
; 0x1900a4

MovementData_0x1900a4: ; 0x1900a4
	step_down
	big_step_up
	turn_head_down
MovementData_0x1900a7: ; 0x1900a7
	step_left
	step_end
; 0x1900a9

MovementData_0x1900a9: ; 0x1900a9
	step_right
	step_down
	turn_head_left
	step_end
; 0x1900ad

MovementData_0x1900ad: ; 0x1900ad
	step_up
	turn_head_down
	step_end
; 0x1900b0

UnknownText_0x1900b0: ; 0x1900b0
	db $0, "Hiya, kid!", $51
	db "I see you're new", $4f
	db "in MAHOGANY TOWN.", $51
	db "Since you're new,", $4f
	db "you should try a", $51
	db "yummy RAGECANDY-", $4f
	db "BAR!", $51
	db "Right now, it can", $4f
	db "be yours for just", $55
	db "¥300! Want one?", $57
; 0x19014a

UnknownText_0x19014a: ; 0x19014a
	db $0, "Good! Savor it!", $57
; 0x19015b

UnknownText_0x19015b: ; 0x19015b
	db $0, "You don't have", $4f
	db "enough money.", $57
; 0x190178

UnknownText_0x190178: ; 0x190178
	db $0, "Oh, fine then…", $57
; 0x190188

UnknownText_0x190188: ; 0x190188
	db $0, "You don't have", $4f
	db "room for this.", $57
; 0x1901a6

UnknownText_0x1901a6: ; 0x1901a6
	db $0, "RAGECANDYBAR's", $4f
	db "sold out.", $51
	db "I'm packing up.", $4f
	db "Don't bother me,", $55
	db "kiddo.", $57
; 0x1901e5

UnknownText_0x1901e5: ; 0x1901e5
	db $0, "Are you off to see", $4f
	db "the GYARADOS ram-", $55
	db "page at the LAKE?", $57
; 0x19021d

UnknownText_0x19021d: ; 0x19021d
	db $0, "MAGIKARP have", $4f
	db "returned to LAKE", $55
	db "OF RAGE.", $51
	db "That should be", $4f
	db "good news for the", $55
	db "anglers there.", $57
; 0x190276

UnknownText_0x190276: ; 0x190276
	db $0, "Since you came", $4f
	db "this far, take the", $51
	db "time to do some", $4f
	db "sightseeing.", $51
	db "You should head", $4f
	db "north and check", $51
	db "out LAKE OF RAGE", $4f
	db "right now.", $57
; 0x1902f2

UnknownText_0x1902f2: ; 0x1902f2
	db $0, "Visit Grandma's", $4f
	db "shop. She sells", $51
	db "stuff that nobody", $4f
	db "else has.", $57
; 0x19032e

UnknownText_0x19032e: ; 0x19032e
	db $0, "MAHOGANY TOWN", $51
	db "Welcome to the", $4f
	db "Home of the Ninja", $57
; 0x19035e

UnknownText_0x19035e: ; 0x19035e
	db $0, "While visiting", $4f
	db "MAHOGANY TOWN, try", $55
	db "a RAGECANDYBAR!", $57
; 0x190391

UnknownText_0x190391: ; 0x190391
	db $0, "MAHOGANY TOWN", $4f
	db "#MON GYM", $55
	db "LEADER: PRYCE", $51
	db "The Teacher of", $4f
	db "Winter's Harshness", $57
; 0x1903d8

MahoganyTown_MapEventHeader: ; 0x1903d8
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $7, $b, 1, GROUP_MAHOGANY_MART_1F, MAP_MAHOGANY_MART_1F
	warp_def $7, $11, 1, GROUP_MAHOGANY_RED_GYARADOS_SPEECH_HOUSE, MAP_MAHOGANY_RED_GYARADOS_SPEECH_HOUSE
	warp_def $d, $6, 1, GROUP_MAHOGANY_GYM, MAP_MAHOGANY_GYM
	warp_def $d, $f, 1, GROUP_MAHOGANY_POKECENTER_1F, MAP_MAHOGANY_POKECENTER_1F
	warp_def $1, $9, 3, GROUP_ROUTE_43_MAHOGANY_GATE, MAP_ROUTE_43_MAHOGANY_GATE

	; xy triggers
	db 2
	xy_trigger 0, $8, $13, $0, UnknownScript_0x190013, $0, $0
	xy_trigger 0, $9, $13, $0, UnknownScript_0x190013, $0, $0

	; signposts
	db 4
	signpost 5, 1, $0, MapMahoganyTownSignpost0Script
	signpost 7, 9, $0, MapMahoganyTownSignpost1Script
	signpost 13, 3, $0, MapMahoganyTownSignpost2Script
	signpost 13, 16, $0, MapMahoganyTownSignpost3Script

	; people-events
	db 4
	person_event $2d, 12, 23, $6, $0, 255, 255, $0, 0, UnknownScript_0x19002e, $0756
	person_event $2f, 13, 10, $5, $1, 255, 255, $0, 0, UnknownScript_0x19007e, $ffff
	person_event $3a, 18, 10, $6, $0, 255, 255, $a0, 0, UnknownScript_0x190092, $0757
	person_event $28, 12, 16, $6, $0, 255, 255, $0, 0, UnknownScript_0x190095, $0736
; 0x19044f

Route32_MapScriptHeader: ; 0x19044f
	; trigger count
	db 3

	; triggers
	dw UnknownScript_0x190460, $0000
	dw UnknownScript_0x190461, $0000
	dw UnknownScript_0x190462, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x190463
; 0x190460

UnknownScript_0x190460: ; 0x190460
	end
; 0x190461

UnknownScript_0x190461: ; 0x190461
	end
; 0x190462

UnknownScript_0x190462: ; 0x190462
	end
; 0x190463

UnknownScript_0x190463: ; 0x190463
	checkcode $b
	if_equal FRIDAY, UnknownScript_0x19046c
	disappear $e
	return
; 0x19046c

UnknownScript_0x19046c: ; 0x19046c
	appear $e
	return
; 0x19046f

UnknownScript_0x19046f: ; 0x19046f
	faceplayer
UnknownScript_0x190470: ; 0x190470
	loadfont
	checkbit1 $005d
	iftrue UnknownScript_0x1904a5
	checkbit2 $001b
	iffalse UnknownScript_0x19049f
	checkbit1 $002d
	iftrue UnknownScript_0x19048f
	2writetext UnknownText_0x1907ab
	closetext
	loadmovesprites
	end
; 0x190489

UnknownScript_0x190489: ; 0x190489
	2writetext UnknownText_0x190820
	closetext
	loadmovesprites
	end
; 0x19048f

UnknownScript_0x19048f: ; 0x19048f
	2writetext UnknownText_0x190925
	keeptextopen
	verbosegiveitem MIRACLE_SEED, 1
	iffalse UnknownScript_0x1904a9
	setbit1 $005d
	2jump UnknownScript_0x1904a5
; 0x19049f

UnknownScript_0x19049f: ; 0x19049f
	2writetext UnknownText_0x1908b0
	closetext
	loadmovesprites
	end
; 0x1904a5

UnknownScript_0x1904a5: ; 0x1904a5
	2writetext UnknownText_0x190a15
	closetext
UnknownScript_0x1904a9: ; 0x1904a9
	loadmovesprites
	end
; 0x1904ab

UnknownScript_0x1904ab: ; 0x1904ab
	spriteface $9, $2
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x190790
	closetext
	loadmovesprites
	follow $0, $9
	applymovement $0, MovementData_0x190789
	stopfollow
	spriteface $0, $0
	2call UnknownScript_0x190470
	applymovement $9, MovementData_0x19078c
	applymovement $9, MovementData_0x19078e
	end
; 0x1904ce

UnknownScript_0x1904ce: ; 0x1904ce
	faceplayer
	loadfont
	checkbit1 $004e
	iftrue UnknownScript_0x1904e3
	2writetext UnknownText_0x191133
	keeptextopen
	verbosegiveitem TM_05, 1
	iffalse UnknownScript_0x1904e7
	setbit1 $004e
UnknownScript_0x1904e3: ; 0x1904e3
	2writetext UnknownText_0x19118c
	closetext
UnknownScript_0x1904e7: ; 0x1904e7
	loadmovesprites
	end
; 0x1904e9

UnknownScript_0x1904e9: ; 0x1904e9
	spriteface $b, $0
	spriteface $0, $1
	2jump UnknownScript_0x1904f3
; 0x1904f2

UnknownScript_0x1904f2: ; 0x1904f2
	faceplayer
UnknownScript_0x1904f3: ; 0x1904f3
	dotrigger $2
	loadfont
	2writetext UnknownText_0x190a59
	yesorno
	iffalse UnknownScript_0x190503
	2writetext UnknownText_0x190acf
	closetext
	loadmovesprites
	end
; 0x190503

UnknownScript_0x190503: ; 0x190503
	2writetext UnknownText_0x190afc
	closetext
	loadmovesprites
	end
; 0x190509

TrainerCamperRoland: ; 0x190509
	; bit/flag number
	dw $41a

	; trainer group && trainer id
	db CAMPER, ROLAND

	; text when seen
	dw CamperRolandSeenText

	; text when trainer beaten
	dw CamperRolandBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperRolandScript
; 0x190515

CamperRolandScript: ; 0x190515
	talkaftercancel
	loadfont
	2writetext UnknownText_0x190faa
	closetext
	loadmovesprites
	end
; 0x19051d

TrainerFisherJustin: ; 0x19051d
	; bit/flag number
	dw $44e

	; trainer group && trainer id
	db FISHER, JUSTIN

	; text when seen
	dw FisherJustinSeenText

	; text when trainer beaten
	dw FisherJustinBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherJustinScript
; 0x190529

FisherJustinScript: ; 0x190529
	talkaftercancel
	loadfont
	2writetext UnknownText_0x190b4e
	closetext
	loadmovesprites
	end
; 0x190531

TrainerFisherRalph1: ; 0x190531
	; bit/flag number
	dw $44f

	; trainer group && trainer id
	db FISHER, RALPH1

	; text when seen
	dw FisherRalph1SeenText

	; text when trainer beaten
	dw FisherRalph1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherRalph1Script
; 0x19053d

FisherRalph1Script: ; 0x19053d
	writecode $17, $11
	talkaftercancel
	loadfont
	checkbit2 $006d
	iftrue UnknownScript_0x19057d
	checkbit2 $0052
	iftrue UnknownScript_0x1905f1
	checkcellnum $11
	iftrue UnknownScript_0x190603
	checkbit1 $0277
	iftrue UnknownScript_0x190566
	2writetext UnknownText_0x190bf8
	keeptextopen
	setbit1 $0277
	2call UnknownScript_0x1905f7
	2jump UnknownScript_0x190569
; 0x190566

UnknownScript_0x190566: ; 0x190566
	2call UnknownScript_0x1905fb
UnknownScript_0x190569: ; 0x190569
	askforphonenumber $11
	if_equal $1, UnknownScript_0x19060b
	if_equal $2, UnknownScript_0x190607
	trainertotext FISHER, RALPH1, $0
	2call UnknownScript_0x1905ff
	2jump UnknownScript_0x190603
; 0x19057d

UnknownScript_0x19057d: ; 0x19057d
	2call UnknownScript_0x19060f
	winlosstext FisherRalph1BeatenText, $0000
	copybytetovar $d9fb
	if_equal $4, UnknownScript_0x19059c
	if_equal $3, UnknownScript_0x1905a2
	if_equal $2, UnknownScript_0x1905a8
	if_equal $1, UnknownScript_0x1905ae
	if_equal $0, UnknownScript_0x1905b4
UnknownScript_0x19059c: ; 0x19059c
	checkbit1 $00cd
	iftrue UnknownScript_0x1905e8
UnknownScript_0x1905a2: ; 0x1905a2
	checkbit1 $0044
	iftrue UnknownScript_0x1905db
UnknownScript_0x1905a8: ; 0x1905a8
	checkbit2 $004a
	iftrue UnknownScript_0x1905ce
UnknownScript_0x1905ae: ; 0x1905ae
	checkbit2 $0048
	iftrue UnknownScript_0x1905c1
UnknownScript_0x1905b4: ; 0x1905b4
	loadtrainer FISHER, RALPH1
	startbattle
	returnafterbattle
	loadvar $d9fb, $1
	clearbit2 $006d
	end
; 0x1905c1

UnknownScript_0x1905c1: ; 0x1905c1
	loadtrainer FISHER, RALPH2
	startbattle
	returnafterbattle
	loadvar $d9fb, $2
	clearbit2 $006d
	end
; 0x1905ce

UnknownScript_0x1905ce: ; 0x1905ce
	loadtrainer FISHER, RALPH3
	startbattle
	returnafterbattle
	loadvar $d9fb, $3
	clearbit2 $006d
	end
; 0x1905db

UnknownScript_0x1905db: ; 0x1905db
	loadtrainer FISHER, RALPH4
	startbattle
	returnafterbattle
	loadvar $d9fb, $4
	clearbit2 $006d
	end
; 0x1905e8

UnknownScript_0x1905e8: ; 0x1905e8
	loadtrainer FISHER, RALPH5
	startbattle
	returnafterbattle
	clearbit2 $006d
	end
; 0x1905f1

UnknownScript_0x1905f1: ; 0x1905f1
	2writetext UnknownText_0x190c37
	closetext
	loadmovesprites
	end
; 0x1905f7

UnknownScript_0x1905f7: ; 0x1905f7
	jumpstd $0019
	end
; 0x1905fb

UnknownScript_0x1905fb: ; 0x1905fb
	jumpstd $001a
	end
; 0x1905ff

UnknownScript_0x1905ff: ; 0x1905ff
	jumpstd $001b
	end
; 0x190603

UnknownScript_0x190603: ; 0x190603
	jumpstd $001c
	end
; 0x190607

UnknownScript_0x190607: ; 0x190607
	jumpstd $001d
	end
; 0x19060b

UnknownScript_0x19060b: ; 0x19060b
	jumpstd $001e
	end
; 0x19060f

UnknownScript_0x19060f: ; 0x19060f
	jumpstd $001f
	end
; 0x190613

TrainerFisherHenry: ; 0x190613
	; bit/flag number
	dw $452

	; trainer group && trainer id
	db FISHER, HENRY

	; text when seen
	dw FisherHenrySeenText

	; text when trainer beaten
	dw FisherHenryBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherHenryScript
; 0x19061f

FisherHenryScript: ; 0x19061f
	talkaftercancel
	loadfont
	2writetext UnknownText_0x190df2
	closetext
	loadmovesprites
	end
; 0x190627

TrainerPicnickerLiz1: ; 0x190627
	; bit/flag number
	dw $47e

	; trainer group && trainer id
	db PICNICKER, LIZ1

	; text when seen
	dw PicnickerLiz1SeenText

	; text when trainer beaten
	dw PicnickerLiz1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerLiz1Script
; 0x190633

PicnickerLiz1Script: ; 0x190633
	writecode $17, $12
	talkaftercancel
	loadfont
	checkbit2 $006e
	iftrue UnknownScript_0x19066d
	checkcellnum $12
	iftrue UnknownScript_0x1906ed
	checkbit1 $0279
	iftrue UnknownScript_0x190656
	2writetext UnknownText_0x191060
	keeptextopen
	setbit1 $0279
	2call UnknownScript_0x1906e1
	2jump UnknownScript_0x190659
; 0x190656

UnknownScript_0x190656: ; 0x190656
	2call UnknownScript_0x1906e5
UnknownScript_0x190659: ; 0x190659
	askforphonenumber $12
	if_equal $1, UnknownScript_0x1906f5
	if_equal $2, UnknownScript_0x1906f1
	trainertotext PICNICKER, LIZ1, $0
	2call UnknownScript_0x1906e9
	2jump UnknownScript_0x1906ed
; 0x19066d

UnknownScript_0x19066d: ; 0x19066d
	2call UnknownScript_0x1906f9
	winlosstext PicnickerLiz1BeatenText, $0000
	copybytetovar $d9fc
	if_equal $4, UnknownScript_0x19068c
	if_equal $3, UnknownScript_0x190692
	if_equal $2, UnknownScript_0x190698
	if_equal $1, UnknownScript_0x19069e
	if_equal $0, UnknownScript_0x1906a4
UnknownScript_0x19068c: ; 0x19068c
	checkbit1 $0044
	iftrue UnknownScript_0x1906d8
UnknownScript_0x190692: ; 0x190692
	checkbit1 $0021
	iftrue UnknownScript_0x1906cb
UnknownScript_0x190698: ; 0x190698
	checkbit1 $0022
	iftrue UnknownScript_0x1906be
UnknownScript_0x19069e: ; 0x19069e
	checkbit2 $0048
	iftrue UnknownScript_0x1906b1
UnknownScript_0x1906a4: ; 0x1906a4
	loadtrainer PICNICKER, LIZ1
	startbattle
	returnafterbattle
	loadvar $d9fc, $1
	clearbit2 $006e
	end
; 0x1906b1

UnknownScript_0x1906b1: ; 0x1906b1
	loadtrainer PICNICKER, LIZ2
	startbattle
	returnafterbattle
	loadvar $d9fc, $2
	clearbit2 $006e
	end
; 0x1906be

UnknownScript_0x1906be: ; 0x1906be
	loadtrainer PICNICKER, LIZ3
	startbattle
	returnafterbattle
	loadvar $d9fc, $3
	clearbit2 $006e
	end
; 0x1906cb

UnknownScript_0x1906cb: ; 0x1906cb
	loadtrainer PICNICKER, LIZ4
	startbattle
	returnafterbattle
	loadvar $d9fc, $4
	clearbit2 $006e
	end
; 0x1906d8

UnknownScript_0x1906d8: ; 0x1906d8
	loadtrainer PICNICKER, LIZ5
	startbattle
	returnafterbattle
	clearbit2 $006e
	end
; 0x1906e1

UnknownScript_0x1906e1: ; 0x1906e1
	jumpstd $0023
	end
; 0x1906e5

UnknownScript_0x1906e5: ; 0x1906e5
	jumpstd $0024
	end
; 0x1906e9

UnknownScript_0x1906e9: ; 0x1906e9
	jumpstd $0025
	end
; 0x1906ed

UnknownScript_0x1906ed: ; 0x1906ed
	jumpstd $0026
	end
; 0x1906f1

UnknownScript_0x1906f1: ; 0x1906f1
	jumpstd $0027
	end
; 0x1906f5

UnknownScript_0x1906f5: ; 0x1906f5
	jumpstd $0028
	end
; 0x1906f9

UnknownScript_0x1906f9: ; 0x1906f9
	jumpstd $0029
	end
; 0x1906fd

TrainerYoungsterAlbert: ; 0x1906fd
	; bit/flag number
	dw $5ab

	; trainer group && trainer id
	db YOUNGSTER, ALBERT

	; text when seen
	dw YoungsterAlbertSeenText

	; text when trainer beaten
	dw YoungsterAlbertBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterAlbertScript
; 0x190709

YoungsterAlbertScript: ; 0x190709
	talkaftercancel
	loadfont
	2writetext UnknownText_0x190e82
	closetext
	loadmovesprites
	end
; 0x190711

TrainerYoungsterGordon: ; 0x190711
	; bit/flag number
	dw $5ac

	; trainer group && trainer id
	db YOUNGSTER, GORDON

	; text when seen
	dw YoungsterGordonSeenText

	; text when trainer beaten
	dw YoungsterGordonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterGordonScript
; 0x19071d

YoungsterGordonScript: ; 0x19071d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x190f49
	closetext
	loadmovesprites
	end
; 0x190725

TrainerBird_keeperPeter: ; 0x190725
	; bit/flag number
	dw $407

	; trainer group && trainer id
	db BIRD_KEEPER, PETER

	; text when seen
	dw Bird_keeperPeterSeenText

	; text when trainer beaten
	dw Bird_keeperPeterBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperPeterScript
; 0x190731

Bird_keeperPeterScript: ; 0x190731
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1910d4
	closetext
	loadmovesprites
	end
; 0x190739

UnknownScript_0x190739: ; 0x190739
	faceplayer
	loadfont
	checkbit1 $0063
	iftrue UnknownScript_0x190767
	checkcode $b
	if_not_equal FRIDAY, UnknownScript_0x19076d
	checkbit1 $0062
	iftrue UnknownScript_0x190754
	2writetext UnknownText_0x1911c1
	keeptextopen
	setbit1 $0062
UnknownScript_0x190754: ; 0x190754
	2writetext UnknownText_0x191204
	keeptextopen
	verbosegiveitem POISON_BARB, 1
	iffalse UnknownScript_0x19076b
	setbit1 $0063
	2writetext UnknownText_0x191222
	closetext
	loadmovesprites
	end
; 0x190767

UnknownScript_0x190767: ; 0x190767
	2writetext UnknownText_0x19129a
	closetext
UnknownScript_0x19076b: ; 0x19076b
	loadmovesprites
	end
; 0x19076d

UnknownScript_0x19076d: ; 0x19076d
	2writetext UnknownText_0x1912ff
	closetext
	loadmovesprites
	end
; 0x190773

ItemFragment_0x190773: ; 0x190773
	db GREAT_BALL, 1
; 0x190775

ItemFragment_0x190775: ; 0x190775
	db REPEL, 1
; 0x190777

MapRoute32Signpost0Script: ; 0x190777
	jumptext UnknownText_0x19133a
; 0x19077a

MapRoute32Signpost1Script: ; 0x19077a
	jumptext UnknownText_0x19135e
; 0x19077d

MapRoute32Signpost2Script: ; 0x19077d
	jumptext UnknownText_0x19137b
; 0x190780

MapRoute32Signpost3Script: ; 0x190780
	jumpstd $0010
; 0x190783

MapRoute32SignpostItem4: ; 0x190783
	dw $00a5
	db GREAT_BALL
	
; 0x190786

MapRoute32SignpostItem5: ; 0x190786
	dw $00a6
	db SUPER_POTION
	
; 0x190789

MovementData_0x190789: ; 0x190789
	step_up
	step_up
	step_end
; 0x19078c

MovementData_0x19078c: ; 0x19078c
	step_down
	step_end
; 0x19078e

MovementData_0x19078e: ; 0x19078e
	step_right
	step_end
; 0x190790

UnknownText_0x190790: ; 0x190790
	db $0, "Wait up!", $4f
	db "What's the hurry?", $57
; 0x1907ab

UnknownText_0x1907ab: ; 0x1907ab
	db $0, $52, ", right?", $4f
	db "Some guy wearing", $51
	db "glasses was look-", $4f
	db "ing for you.", $51
	db "See for yourself.", $4f
	db "He's waiting for", $51
	db "you at the #MON", $4f
	db "CENTER.", $57
; 0x190820

; might not be referenced anywhere
UnknownText_0x190820: ; 0x190820
	db $0, "Have you gone to", $4f
	db "SPROUT TOWER?", $51
	db "If you ever visit", $4f
	db "VIOLET CITY, ", $51
	db "they'll expect you", $4f
	db "to train there.", $51
	db "That's basic for", $4f
	db "trainers. Go to", $55
	db "SPROUT TOWER!", $57
; 0x1908b0

UnknownText_0x1908b0: ; 0x1908b0
	db $0, "Have you gone to", $4f
	db "the #MON GYM?", $51
	db "You can test your", $4f
	db "#MON and your-", $55
	db "self there.", $51
	db "It's a rite of", $4f
	db "passage for all", $55
	db "trainers!", $57
; 0x190925

UnknownText_0x190925: ; 0x190925
	db $0, "You have some good", $4f
	db "#MON there.", $51
	db "It must be from", $4f
	db "the training you", $51
	db "gave them around", $4f
	db "VIOLET CITY.", $51
	db "The training at", $4f
	db "the GYM must have", $51
	db "been especially", $4f
	db "helpful.", $51
	db "As a souvenir of", $4f
	db "VIOLET CITY, take", $55
	db "this.", $51
	db "It increases the", $4f
	db "power of grass-", $55
	db "type moves.", $57
; 0x190a15

UnknownText_0x190a15: ; 0x190a15
	db $0, "Your experiences", $4f
	db "in VIOLET CITY", $51
	db "should be useful", $4f
	db "for your journey.", $57
; 0x190a59

UnknownText_0x190a59: ; 0x190a59
	db $0, "How would you like", $4f
	db "to have this", $51
	db "tasty, nutritious", $4f
	db "SLOWPOKETAIL?", $51
	db "For you right now,", $4f
	db "just ¥1,000,000!", $51
	db "You'll want this!", $57
; 0x190acf

UnknownText_0x190acf: ; 0x190acf
	db $0, "Tch! I thought", $4f
	db "kids these days", $55
	db "were loaded…", $57
; 0x190afc

UnknownText_0x190afc: ; 0x190afc
	db $0, "You don't want it?", $4f
	db "Then scram. Shoo!", $57
; 0x190b21

FisherJustinSeenText: ; 0x190b21
	db $0, "Whoa!", $51
	db "You made me lose", $4f
	db "that fish!", $57
; 0x190b44

FisherJustinBeatenText: ; 0x190b44
	db $0, "Sploosh!", $57
; 0x190b4e

UnknownText_0x190b4e: ; 0x190b4e
	db $0, "Calm, collected…", $4f
	db "The essence of", $51
	db "fishing and #-", $4f
	db "MON is the same.", $57
; 0x190b8f

FisherRalph1SeenText: ; 0x190b8f
	db $0, "I'm really good at", $4f
	db "both fishing and", $55
	db "#MON.", $51
	db "I'm not about to", $4f
	db "lose to any kid!", $57
; 0x190bda

FisherRalph1BeatenText: ; 0x190bda
	db $0, "Tch! I tried to", $4f
	db "rush things…", $57
; 0x190bf8

UnknownText_0x190bf8: ; 0x190bf8
	db $0, "Fishing is a life-", $4f
	db "long passion.", $51
	db "#MON are life-", $4f
	db "long friends!", $57
; 0x190c37

UnknownText_0x190c37: ; 0x190c37
	db $0, "One, two, three…", $4f
	db "Muahahaha, what a", $51
	db "great haul!", $4f
	db "I'm done! Go ahead", $51
	db "and catch as many", $4f
	db "as you can, kid!", $57
; 0x190c9c

; --- start a segment of possibly unused texts

UnknownText_0x190c9c: ; 0x190c9c
	db $0, "I keep catching", $4f
	db "the same #MON…", $51
	db "Maybe a battle", $4f
	db "will turn things", $55
	db "around for me.", $57
; 0x190ceb

UnknownText_0x190ceb: ; 0x190ceb
	db $0, "Nothing ever goes", $4f
	db "right for me now…", $57
; 0x190d10

UnknownText_0x190d10: ; 0x190d10
	db $0, "How come the guy", $4f
	db "next to me catches", $55
	db "good #MON?", $57
; 0x190d40

UnknownText_0x190d40: ; 0x190d40
	db $0, "Heh, I'm on a roll", $4f
	db "today. How about a", $55
	db "battle, kid?", $57
; 0x190d73

UnknownText_0x190d73: ; 0x190d73
	db $0, "Oof. I wasn't", $4f
	db "lucky that time.", $57
; 0x190d92

UnknownText_0x190d92: ; 0x190d92
	db $0, "You have to have a", $4f
	db "good ROD if you", $51
	db "want to catch good", $4f
	db "#MON.", $57
; 0x190dcf

; --- end a segment of possibly unused texts

FisherHenrySeenText: ; 0x190dcf
	db $0, "My #MON?", $4f
	db "Freshly caught!", $57
; 0x190de9

FisherHenryBeatenText: ; 0x190de9
	db $0, "SPLASH?", $57
; 0x190df2

UnknownText_0x190df2: ; 0x190df2
	db $0, "Freshly caught", $4f
	db "#MON are no", $51
	db "match for properly", $4f
	db "raised ones.", $57
; 0x190e2e

YoungsterAlbertSeenText: ; 0x190e2e
	db $0, "I haven't seen you", $4f
	db "around before.", $51
	db "So you think you", $4f
	db "are pretty tough?", $57
; 0x190e73

YoungsterAlbertBeatenText: ; 0x190e73
	db $0, "You're strong!", $57
; 0x190e82

UnknownText_0x190e82: ; 0x190e82
	db $0, "I'm going to try", $4f
	db "to be the best", $55
	db "with my favorites.", $51
	db "I'm not using the", $4f
	db "same tough #MON", $55
	db "as everyone else.", $57
; 0x190ee8

YoungsterGordonSeenText: ; 0x190ee8
	db $0, "I found some good", $4f
	db "#MON in the", $55
	db "grass!", $51
	db "I think they'll do", $4f
	db "it for me!", $57
; 0x190f2b

YoungsterGordonBeatenText: ; 0x190f2b
	db $0, "Darn. I thought I", $4f
	db "could win.", $57
; 0x190f49

UnknownText_0x190f49: ; 0x190f49
	db $0, "The grass is full", $4f
	db "of clingy things.", $57
; 0x190f6e

CamperRolandSeenText: ; 0x190f6e
	db $0, "That glance…", $4f
	db "It's intriguing.", $57
; 0x190f8c

CamperRolandBeatenText: ; 0x190f8c
	db $0, "Hmmm. This is", $4f
	db "disappointing.", $57
; 0x190faa

UnknownText_0x190faa: ; 0x190faa
	db $0, "If you don't want", $4f
	db "to battle, just", $55
	db "avoid eye contact.", $57
; 0x190fdf

PicnickerLiz1SeenText: ; 0x190fdf
	db $0, "Uh-huh. Yeah, and", $4f
	db "you know…", $51
	db "Pardon? Battle?", $4f
	db "I'm on the phone.", $51
	db "Oh, all right. But", $4f
	db "make it fast.", $57
; 0x19103e

PicnickerLiz1BeatenText: ; 0x19103e
	db $0, "Oh! I've got to", $4f
	db "relieve my anger!", $57
; 0x191060

UnknownText_0x191060: ; 0x191060
	db $0, "I was having a", $4f
	db "nice chat too.", $57
; 0x19107f

Bird_keeperPeterSeenText: ; 0x19107f
	db $0, "That BADGE! It's", $4f
	db "from VIOLET CITY!", $51
	db "You beat FALKNER?", $57
; 0x1910b4

Bird_keeperPeterBeatenText: ; 0x1910b4
	db $0, "I know what my", $4f
	db "weaknesses are.", $57
; 0x1910d4

UnknownText_0x1910d4: ; 0x1910d4
	db $0, "I should train", $4f
	db "again at the GYM", $55
	db "in VIOLET CITY.", $57
; 0x191105

; possibly unused
UnknownText_0x191105: ; 0x191105
	db $0, "The fishermen", $4f
	db "yelled at me for", $55
	db "bugging them…", $57
; 0x191133

UnknownText_0x191133: ; 0x191133
	db $0, "WROOOOAR!", $4f
	db "PEOPLE RUN WHEN I", $51
	db "ROAR! BUT YOU", $4f
	db "CAME LOOKING!", $51
	db "THAT PLEASES ME!", $4f
	db "NOW TAKE THIS!", $57
; 0x19118c

UnknownText_0x19118c: ; 0x19118c
	db $0, "WROOOAR!", $4f
	db "IT'S ROAR!", $51
	db "EVEN #MON RUN", $4f
	db "FROM A GOOD ROAR!", $57
; 0x1911c1

UnknownText_0x1911c1: ; 0x1911c1
	db $0, "FRIEDA: Yahoo!", $4f
	db "It's Friday!", $51
	db "I'm FRIEDA of", $4f
	db "Friday!", $51
	db "Nice to meet you!", $57
; 0x191204

UnknownText_0x191204: ; 0x191204
	db $0, "Here's a POISON", $4f
	db "BARB for you!", $57
; 0x191222

UnknownText_0x191222: ; 0x191222
	db $0, "FRIEDA: Give it to", $4f
	db "a #MON that has", $55
	db "poison-type moves.", $51
	db "Oh!", $51
	db "It's wicked!", $51
	db "You'll be shocked", $4f
	db "how good it makes", $55
	db "poison moves!", $57
; 0x19129a

UnknownText_0x19129a: ; 0x19129a
	db $0, "FRIEDA: Hiya! What", $4f
	db "day do you like?", $51
	db "I love Friday. No", $4f
	db "doubt about it!", $51
	db "Don't you think", $4f
	db "it's great too?", $57
; 0x1912ff

UnknownText_0x1912ff: ; 0x1912ff
	db $0, "FRIEDA: Isn't it", $4f
	db "Friday today?", $51
	db "It's so boring", $4f
	db "when it's not!", $57
; 0x19133a

UnknownText_0x19133a: ; 0x19133a
	db $0, "ROUTE 32", $51
	db "VIOLET CITY -", $4f
	db "AZALEA TOWN", $57
; 0x19135e

UnknownText_0x19135e: ; 0x19135e
	db $0, "RUINS OF ALPH", $4f
	db "EAST ENTRANCE", $57
; 0x19137b

UnknownText_0x19137b: ; 0x19137b
	db $0, "UNION CAVE", $4f
	db "AHEAD", $57
; 0x19138d

Route32_MapEventHeader: ; 0x19138d
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $49, $b, 1, GROUP_ROUTE_32_POKECENTER_1F, MAP_ROUTE_32_POKECENTER_1F
	warp_def $2, $4, 3, GROUP_ROUTE_32_RUINS_OF_ALPH_GATE, MAP_ROUTE_32_RUINS_OF_ALPH_GATE
	warp_def $3, $4, 4, GROUP_ROUTE_32_RUINS_OF_ALPH_GATE, MAP_ROUTE_32_RUINS_OF_ALPH_GATE
	warp_def $4f, $6, 4, GROUP_UNION_CAVE_1F, MAP_UNION_CAVE_1F

	; xy triggers
	db 2
	xy_trigger 0, $8, $12, $0, UnknownScript_0x1904ab, $0, $0
	xy_trigger 1, $47, $7, $0, UnknownScript_0x1904e9, $0, $0

	; signposts
	db 6
	signpost 5, 13, $0, MapRoute32Signpost0Script
	signpost 1, 9, $0, MapRoute32Signpost1Script
	signpost 84, 10, $0, MapRoute32Signpost2Script
	signpost 73, 12, $0, MapRoute32Signpost3Script
	signpost 67, 12, $7, MapRoute32SignpostItem4
	signpost 40, 11, $7, MapRoute32SignpostItem5

	; people-events
	db 14
	person_event $3a, 53, 12, $6, $0, 255, 255, $a2, 1, TrainerFisherJustin, $ffff
	person_event $3a, 60, 16, $7, $0, 255, 255, $a2, 3, TrainerFisherRalph1, $ffff
	person_event $3a, 52, 10, $8, $0, 255, 255, $a2, 1, TrainerFisherHenry, $ffff
	person_event $27, 26, 16, $9, $0, 255, 255, $92, 3, TrainerYoungsterAlbert, $ffff
	person_event $27, 67, 8, $a, $0, 255, 255, $92, 3, TrainerYoungsterGordon, $ffff
	person_event $27, 49, 7, $7, $0, 255, 255, $a2, 3, TrainerCamperRoland, $ffff
	person_event $28, 34, 14, $8, $0, 255, 255, $a2, 1, TrainerPicnickerLiz1, $ffff
	person_event $23, 12, 23, $8, $0, 255, 255, $0, 0, UnknownScript_0x19046f, $ffff
	person_event $27, 86, 15, $7, $0, 255, 255, $92, 3, TrainerBird_keeperPeter, $ffff
	person_event $3a, 74, 11, $6, $0, 255, 255, $0, 0, UnknownScript_0x1904f2, $06fc
	person_event $54, 57, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x190773, $06b0
	person_event $3a, 17, 19, $9, $0, 255, 255, $0, 0, UnknownScript_0x1904ce, $ffff
	person_event $28, 71, 16, $8, $0, 255, 255, $0, 0, UnknownScript_0x190739, $0758
	person_event $54, 34, 7, $1, $0, 255, 255, $1, 0, ItemFragment_0x190775, $06b1
; 0x19148b

VermilionHouseFishingSpeechHouse_MapScriptHeader: ; 0x19148b
	; trigger count
	db 0

	; callback count
	db 0
; 0x19148d

UnknownScript_0x19148d: ; 0x19148d
	jumptextfaceplayer UnknownText_0x191496
; 0x191490

MapVermilionHouseFishingSpeechHouseSignpost0Script: ; 0x191490
	jumptext UnknownText_0x1915a3
; 0x191493

UnknownScript_0x191493: ; 0x191493
	jumpstd $0002
; 0x191496

UnknownText_0x191496: ; 0x191496
	db $0, "I am the FISHING", $4f
	db "DUDE, the elder of", $55
	db "the FISHING BROS.", $51
	db "Have you met the", $4f
	db "FISHING GURU at", $55
	db "LAKE OF RAGE?", $51
	db "He dreams about", $4f
	db "seeing the world's", $55
	db "greatest MAGIKARP.", $51
	db "If you don't mind,", $4f
	db "could you show him", $51
	db "any MAGIKARP you", $4f
	db "catch?", $51
	db "Who knows, you may", $4f
	db "catch the MAGIKARP", $55
	db "of his dreams.", $57
; 0x1915a3

UnknownText_0x1915a3: ; 0x1915a3
	db $0, "It's a photo of", $4f
	db "people fishing…", $51
	db "They're having a", $4f
	db "great time…", $57
; 0x1915df

VermilionHouseFishingSpeechHouse_MapEventHeader: ; 0x1915df
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $7, $3, 1, GROUP_VERMILION_CITY, MAP_VERMILION_CITY

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 0, 3, $0, MapVermilionHouseFishingSpeechHouseSignpost0Script

	; people-events
	db 1
	person_event $3b, 8, 6, $6, $0, 255, 255, $a0, 0, UnknownScript_0x19148d, $ffff
; 0x191601

VermilionPokeCenter1F_MapScriptHeader: ; 0x191601
	; trigger count
	db 0

	; callback count
	db 0
; 0x191603

UnknownScript_0x191603: ; 0x191603
	jumpstd $0000
; 0x191606

UnknownScript_0x191606: ; 0x191606
	faceplayer
	loadfont
	checkbit1 $0750
	iftrue UnknownScript_0x191614
	2writetext UnknownText_0x191620
	closetext
	loadmovesprites
	end
; 0x191614

UnknownScript_0x191614: ; 0x191614
	2writetext UnknownText_0x191698
	closetext
	loadmovesprites
	end
; 0x19161a

UnknownScript_0x19161a: ; 0x19161a
	jumptextfaceplayer UnknownText_0x1916fe
; 0x19161d

UnknownScript_0x19161d: ; 0x19161d
	jumptextfaceplayer UnknownText_0x19173b
; 0x191620

UnknownText_0x191620: ; 0x191620
	db $0, "A sleeping #MON", $4f
	db "is lying in front", $55
	db "of DIGLETT'S CAVE.", $51
	db "It's a fantastic", $4f
	db "opportunity to get", $51
	db "it, but how do you", $4f
	db "wake it up?", $57
; 0x191698

UnknownText_0x191698: ; 0x191698
	db $0, "There used to be a", $4f
	db "sleeping #MON", $51
	db "lying in front of", $4f
	db "DIGLETT'S CAVE.", $51
	db "But it seems to", $4f
	db "have disappeared.", $57
; 0x1916fe

UnknownText_0x1916fe: ; 0x1916fe
	db $0, "The FAST SHIP is a", $4f
	db "great place to", $51
	db "meet and battle", $4f
	db "trainers.", $57
; 0x19173b

UnknownText_0x19173b: ; 0x19173b
	db $0, "Oh? You have some", $4f
	db "BADGES I've never", $55
	db "seen before.", $51
	db "Oh, I get it. You", $4f
	db "got them in JOHTO.", $57
; 0x191791

VermilionPokeCenter1F_MapEventHeader: ; 0x191791
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 2, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $7, $4, 2, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x191603, $ffff
	person_event $3b, 6, 11, $6, $0, 255, 255, $80, 0, UnknownScript_0x191606, $ffff
	person_event $49, 9, 10, $4, $10, 255, 255, $90, 0, UnknownScript_0x19161a, $ffff
	person_event $25, 9, 5, $3, $0, 255, 255, $a0, 0, UnknownScript_0x19161d, $ffff
; 0x1917da

VermilionPokeCenter2FBeta_MapScriptHeader: ; 0x1917da
	; trigger count
	db 0

	; callback count
	db 0
; 0x1917dc

VermilionPokeCenter2FBeta_MapEventHeader: ; 0x1917dc
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 3, GROUP_VERMILION_POKECENTER_1F, MAP_VERMILION_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x1917e7

PokemonFanClub_MapScriptHeader: ; 0x1917e7
	; trigger count
	db 0

	; callback count
	db 0
; 0x1917e9

UnknownScript_0x1917e9: ; 0x1917e9
	faceplayer
	loadfont
	checkbit1 $00d4
	iftrue UnknownScript_0x191815
	checkbit1 $00d3
	iftrue UnknownScript_0x191802
	2writetext UnknownText_0x191881
	yesorno
	iffalse UnknownScript_0x19181b
	2writetext UnknownText_0x191911
	keeptextopen
UnknownScript_0x191802: ; 0x191802
	2writetext UnknownText_0x191a3d
	keeptextopen
	verbosegiveitem RARE_CANDY, 1
	iffalse UnknownScript_0x19181f
	setbit1 $00d4
	2writetext UnknownText_0x191a72
	closetext
	loadmovesprites
	end
; 0x191815

UnknownScript_0x191815: ; 0x191815
	2writetext UnknownText_0x191ae0
	closetext
	loadmovesprites
	end
; 0x19181b

UnknownScript_0x19181b: ; 0x19181b
	2writetext UnknownText_0x191b38
	closetext
UnknownScript_0x19181f: ; 0x19181f
	loadmovesprites
	end
; 0x191821

UnknownScript_0x191821: ; 0x191821
	jumptextfaceplayer UnknownText_0x191b6d
; 0x191824

UnknownScript_0x191824: ; 0x191824
	faceplayer
	loadfont
	checkbit1 $00d2
	iftrue UnknownScript_0x19185f
	checkbit1 $00c9
	iftrue UnknownScript_0x191838
	2writetext UnknownText_0x191ba0
	closetext
	loadmovesprites
	end
; 0x191838

UnknownScript_0x191838: ; 0x191838
	2writetext UnknownText_0x191bff
	checkbit1 $00cf
	iftrue UnknownScript_0x191844
	closetext
	loadmovesprites
	end
; 0x191844

UnknownScript_0x191844: ; 0x191844
	keeptextopen
	2writetext UnknownText_0x191c5a
	keeptextopen
	waitbutton
	giveitem LOST_ITEM, $1
	iffalse UnknownScript_0x191865
	disappear $6
	2writetext UnknownText_0x191d0a
	playsound $0091
	waitbutton
	itemnotify
	setbit1 $00d2
	loadmovesprites
	end
; 0x19185f

UnknownScript_0x19185f: ; 0x19185f
	2writetext UnknownText_0x191d1e
	closetext
	loadmovesprites
	end
; 0x191865

UnknownScript_0x191865: ; 0x191865
	2writetext UnknownText_0x191d58
	closetext
	loadmovesprites
	end
; 0x19186b

UnknownScript_0x19186b: ; 0x19186b
	jumptextfaceplayer UnknownText_0x191d73
; 0x19186e

UnknownScript_0x19186e: ; 0x19186e
	jumptext UnknownText_0x191db1
; 0x191871

UnknownScript_0x191871: ; 0x191871
	loadfont
	2writetext UnknownText_0x191de9
	cry BAYLEEF
	closetext
	loadmovesprites
	end
; 0x19187b

MapPokemonFanClubSignpost0Script: ; 0x19187b
	jumptext UnknownText_0x191dfc
; 0x19187e

MapPokemonFanClubSignpost1Script: ; 0x19187e
	jumptext UnknownText_0x191e29
; 0x191881

UnknownText_0x191881: ; 0x191881
	db $0, "I'm the CHAIRMAN", $4f
	db "of the #MON FAN", $55
	db "CLUB.", $51
	db "I've raised over", $4f
	db "150 #MON.", $51
	db "I'm very fussy", $4f
	db "when it comes to", $55
	db "#MON.", $51
	db "Did you visit just", $4f
	db "to hear about my", $55
	db "#MON?", $57
; 0x191911

UnknownText_0x191911: ; 0x191911
	db $0, "Good!", $4f
	db "Then listen up!", $51
	db "So… my favorite", $4f
	db "RAPIDASH…", $51
	db "It… cute… lovely…", $4f
	db "smart… unbearably…", $55
	db "plus… amazing… oh…", $55
	db "you think so?…", $55
	db "Too much… wild…", $55
	db "beautiful… kindly…", $55
	db "love it!", $51
	db "Hug it… when…", $4f
	db "sleeping… warm and", $55
	db "cuddly… Oh, and…", $55
	db "spectacular…", $55
	db "ravishing… simply", $55
	db "divine…", $55
	db "Oops! Look at the", $55
	db "time! I've kept", $55
	db "you too long!", $57
; 0x191a3d

UnknownText_0x191a3d: ; 0x191a3d
	db $0, "Thanks for hearing", $4f
	db "me out. I want you", $55
	db "to have this!", $57
; 0x191a72

UnknownText_0x191a72: ; 0x191a72
	db $0, "It's a RARE CANDY", $4f
	db "that makes #MON", $55
	db "stronger.", $51
	db "I prefer making my", $4f
	db "#MON stronger", $51
	db "by battling, so", $4f
	db "you can have it.", $57
; 0x191ae0

UnknownText_0x191ae0: ; 0x191ae0
	db $0, "Hello, ", $14, "!", $51
	db "Did you come see", $4f
	db "me about my #-", $55
	db "MON again?", $51
	db "No? Oh… I had more", $4f
	db "tales to tell…", $57
; 0x191b38

UnknownText_0x191b38: ; 0x191b38
	db $0, "How disappointing…", $51
	db "Come back if you", $4f
	db "want to listen.", $57
; 0x191b6d

UnknownText_0x191b6d: ; 0x191b6d
	db $0, "Our CHAIRMAN is", $4f
	db "very vocal when it", $55
	db "comes to #MON…", $57
; 0x191ba0

UnknownText_0x191ba0: ; 0x191ba0
	db $0, "I love the way", $4f
	db "CLEFAIRY waggles", $51
	db "its finger when", $4f
	db "it's trying to use", $51
	db "METRONOME.", $4f
	db "It's so adorable!", $57
; 0x191bff

UnknownText_0x191bff: ; 0x191bff
	db $0, "I love CLEFAIRY,", $4f
	db "but I could never", $51
	db "catch one. So I'm", $4f
	db "making do with a", $51
	db "# DOLL that I", $4f
	db "found.", $57
; 0x191c5a

UnknownText_0x191c5a: ; 0x191c5a
	db $0, "Oh, I see now. The", $4f
	db "girl who lost this", $51
	db "# DOLL is sad…", $51
	db "OK. Could you take", $4f
	db "this # DOLL", $51
	db "back to that poor", $4f
	db "little girl?", $51
	db "I'll befriend a", $4f
	db "real CLEFAIRY on", $51
	db "my own one day.", $4f
	db "No worries!", $57
; 0x191d0a

UnknownText_0x191d0a: ; 0x191d0a
	db $0, $52, " received", $4f
	db "# DOLL.", $57
; 0x191d1e

UnknownText_0x191d1e: ; 0x191d1e
	db $0, "You watch. I'm", $4f
	db "going to get a", $51
	db "real CLEFAIRY as", $4f
	db "my friend.", $57
; 0x191d58

UnknownText_0x191d58: ; 0x191d58
	db $0, "Your PACK is", $4f
	db "jammed full.", $57
; 0x191d73

UnknownText_0x191d73: ; 0x191d73
	db $0, "Look at my darling", $4f
	db "BAYLEEF!", $51
	db "The leaf on its", $4f
	db "head is so cute!", $57
; 0x191db1

UnknownText_0x191db1: ; 0x191db1
	db $0, "It's a CLEFAIRY!", $4f
	db "Huh?", $51
	db "Oh, right. It's a", $4f
	db "CLEFAIRY #", $55
	db "DOLL.", $57
; 0x191de9

UnknownText_0x191de9: ; 0x191de9
	db $0, "BAYLEEF: Li liif!", $57
; 0x191dfc

UnknownText_0x191dfc: ; 0x191dfc
	db $0, "Let's all listen", $4f
	db "politely to other", $55
	db "trainers.", $57
; 0x191e29

UnknownText_0x191e29: ; 0x191e29
	db $0, "If someone brags,", $4f
	db "brag right back!", $57
; 0x191e4d

PokemonFanClub_MapEventHeader: ; 0x191e4d
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $7, $3, 3, GROUP_VERMILION_CITY, MAP_VERMILION_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 0, 7, $0, MapPokemonFanClubSignpost0Script
	signpost 0, 9, $0, MapPokemonFanClubSignpost1Script

	; people-events
	db 6
	person_event $40, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x1917e9, $ffff
	person_event $42, 5, 8, $6, $0, 255, 255, $a0, 0, UnknownScript_0x191821, $ffff
	person_event $3a, 7, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x191824, $ffff
	person_event $29, 6, 11, $8, $0, 255, 255, $0, 0, UnknownScript_0x19186b, $ffff
	person_event $4d, 8, 6, $6, $0, 255, 255, $0, 0, UnknownScript_0x19186e, $0774
	person_event $85, 7, 11, $16, $0, 255, 255, $a0, 0, UnknownScript_0x191871, $ffff
; 0x191eb5

VermilionMagnetTrainSpeechHouse_MapScriptHeader: ; 0x191eb5
	; trigger count
	db 0

	; callback count
	db 0
; 0x191eb7

UnknownScript_0x191eb7: ; 0x191eb7
	jumptextfaceplayer UnknownText_0x191ec0
; 0x191eba

UnknownScript_0x191eba: ; 0x191eba
	jumptextfaceplayer UnknownText_0x191f16
; 0x191ebd

MapVermilionMagnetTrainSpeechHouseSignpost1Script: ; 0x191ebd
	jumpstd $0002
; 0x191ec0

UnknownText_0x191ec0: ; 0x191ec0
	db $0, "Do you know about", $4f
	db "the MAGNET TRAIN?", $51
	db "It's a railway", $4f
	db "that goes to GOL-", $55
	db "DENROD in JOHTO.", $57
; 0x191f16

UnknownText_0x191f16: ; 0x191f16
	db $0, "I want to go to", $4f
	db "SAFFRON to see", $55
	db "the MAGNET TRAIN.", $57
; 0x191f48

VermilionMagnetTrainSpeechHouse_MapEventHeader: ; 0x191f48
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $7, $3, 4, GROUP_VERMILION_CITY, MAP_VERMILION_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapVermilionMagnetTrainSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapVermilionMagnetTrainSpeechHouseSignpost1Script

	; people-events
	db 2
	person_event $2e, 7, 6, $8, $0, 255, 255, $0, 0, UnknownScript_0x191eb7, $ffff
	person_event $27, 7, 4, $a, $0, 255, 255, $a0, 0, UnknownScript_0x191eba, $ffff
; 0x191f7c

VermilionMart_MapScriptHeader: ; 0x191f7c
	; trigger count
	db 0

	; callback count
	db 0
; 0x191f7e

UnknownScript_0x191f7e: ; 0x191f7e
	loadfont
	pokemart $0, $0016
	loadmovesprites
	end
; 0x191f85

UnknownScript_0x191f85: ; 0x191f85
	jumptextfaceplayer UnknownText_0x191f8b
; 0x191f88

UnknownScript_0x191f88: ; 0x191f88
	jumptextfaceplayer UnknownText_0x191fca
; 0x191f8b

UnknownText_0x191f8b: ; 0x191f8b
	db $0, "TEAM ROCKET is no", $4f
	db "longer in KANTO.", $51
	db "That alone makes", $4f
	db "me happy.", $57
; 0x191fca

UnknownText_0x191fca: ; 0x191fca
	db $0, "I'm thinking about", $4f
	db "going shopping in", $55
	db "SAFFRON.", $57
; 0x191ff8

VermilionMart_MapEventHeader: ; 0x191ff8
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 5, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $7, $3, 5, GROUP_VERMILION_CITY, MAP_VERMILION_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x191f7e, $ffff
	person_event $2b, 6, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x191f85, $ffff
	person_event $2a, 10, 12, $5, $1, 255, 255, $a0, 0, UnknownScript_0x191f88, $ffff
; 0x19202f

VermilionHouseDiglettsCaveSpeechHouse_MapScriptHeader: ; 0x19202f
	; trigger count
	db 0

	; callback count
	db 0
; 0x192031

UnknownScript_0x192031: ; 0x192031
	jumptextfaceplayer UnknownText_0x192034
; 0x192034

UnknownText_0x192034: ; 0x192034
	db $0, "Over many years,", $4f
	db "DIGLETT dug a", $55
	db "large tunnel.", $51
	db "That tunnel goes", $4f
	db "to a distant town.", $57
; 0x192086

VermilionHouseDiglettsCaveSpeechHouse_MapEventHeader: ; 0x192086
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 6, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $7, $3, 6, GROUP_VERMILION_CITY, MAP_VERMILION_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $40, 7, 5, $4, $10, 255, 255, $80, 0, UnknownScript_0x192031, $ffff
; 0x1920a3

VermilionGym_MapScriptHeader: ; 0x1920a3
	; trigger count
	db 0

	; callback count
	db 0
; 0x1920a5

UnknownScript_0x1920a5: ; 0x1920a5
	faceplayer
	loadfont
	checkbit2 $0025
	iftrue UnknownScript_0x1920d9
	2writetext UnknownText_0x192142
	closetext
	loadmovesprites
	winlosstext UnknownText_0x192238, $0000
	loadtrainer LT_SURGE, 1
	startbattle
	returnafterbattle
	setbit1 $04c7
	setbit1 $049c
	setbit1 $0494
	setbit1 $0497
	loadfont
	2writetext UnknownText_0x192277
	playsound $009c
	waitbutton
	setbit2 $0025
	2writetext UnknownText_0x192291
	closetext
	loadmovesprites
	end
; 0x1920d9

UnknownScript_0x1920d9: ; 0x1920d9
	2writetext UnknownText_0x192303
	closetext
	loadmovesprites
	end
; 0x1920df

TrainerGentlemanGregory: ; 0x1920df
	; bit/flag number
	dw $49c

	; trainer group && trainer id
	db GENTLEMAN, GREGORY

	; text when seen
	dw GentlemanGregorySeenText

	; text when trainer beaten
	dw GentlemanGregoryBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GentlemanGregoryScript
; 0x1920eb

GentlemanGregoryScript: ; 0x1920eb
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1923b0
	closetext
	loadmovesprites
	end
; 0x1920f3

TrainerGuitaristVincent: ; 0x1920f3
	; bit/flag number
	dw $494

	; trainer group && trainer id
	db GUITARIST, VINCENT

	; text when seen
	dw GuitaristVincentSeenText

	; text when trainer beaten
	dw GuitaristVincentBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw GuitaristVincentScript
; 0x1920ff

GuitaristVincentScript: ; 0x1920ff
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19244b
	closetext
	loadmovesprites
	end
; 0x192107

TrainerJugglerHorton: ; 0x192107
	; bit/flag number
	dw $497

	; trainer group && trainer id
	db JUGGLER, HORTON

	; text when seen
	dw JugglerHortonSeenText

	; text when trainer beaten
	dw JugglerHortonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw JugglerHortonScript
; 0x192113

JugglerHortonScript: ; 0x192113
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1924d6
	closetext
	loadmovesprites
	end
; 0x19211b

VermilionGymGuyScript: ; 0x19211b
	faceplayer
	loadfont
	checkbit1 $04c7
	iftrue .VermilionGymGuyWinScript
	2writetext VermilionGymGuyText
	closetext
	loadmovesprites
	end

.VermilionGymGuyWinScript
	2writetext VermilionGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x19212f

MapVermilionGymSignpost14Script: ; 0x19212f
	jumptext UnknownText_0x19261e
; 0x192132

MapVermilionGymSignpost16Script: ; 0x192132
	checkbit2 $0025
	iftrue UnknownScript_0x19213b
	jumpstd $002d
; 0x19213b

UnknownScript_0x19213b: ; 0x19213b
	trainertotext LT_SURGE, 1, $1
	jumpstd $002e
; 0x192142

UnknownText_0x192142: ; 0x192142
	db $0, "SURGE: Hey, you", $4f
	db "little tyke!", $51
	db "I have to hand it", $4f
	db "to you. It may not", $51
	db "be very smart to", $4f
	db "challenge me, but", $55
	db "it takes guts!", $51
	db "When it comes to", $4f
	db "electric #MON,", $55
	db "I'm number one!", $51
	db "I've never lost on", $4f
	db "the battlefield.", $51
	db "I'll zap you just", $4f
	db "like I did my", $55
	db "enemies in war!", $57
; 0x192238

UnknownText_0x192238: ; 0x192238
	db $0, "SURGE: Arrrgh!", $4f
	db "You are strong!", $51
	db "OK, kid. You get", $4f
	db "THUNDERBADGE!", $57
; 0x192277

UnknownText_0x192277: ; 0x192277
	db $0, $52, " received", $4f
	db "THUNDERBADGE.", $57
; 0x192291

UnknownText_0x192291: ; 0x192291
	db $0, "SURGE: THUNDER-", $4f
	db "BADGE increases", $55
	db "#MON's speed. ", $51
	db "Consider it proof", $4f
	db "that you defeated", $51
	db "me. You wear it", $4f
	db "proudly, hear?", $57
; 0x192303

UnknownText_0x192303: ; 0x192303
	db $0, "SURGE: Hey, kid!", $4f
	db "Still slugging and", $55
	db "chugging away?", $51
	db "My #MON and I", $4f
	db "are still at it!", $57
; 0x192356

GentlemanGregorySeenText: ; 0x192356
	db $0, "You're here to", $4f
	db "defeat LT.SURGE?", $51
	db "Not if I can help", $4f
	db "it!", $57
; 0x19238c

GentlemanGregoryBeatenText: ; 0x19238c
	db $0, "Sorry I failed", $4f
	db "you, LT.SURGE,", $55
	db "sir!", $57
; 0x1923b0

UnknownText_0x1923b0: ; 0x1923b0
	db $0, "When I was still", $4f
	db "in the army, LT.", $51
	db "SURGE saved my", $4f
	db "life.", $57
; 0x1923e8

GuitaristVincentSeenText: ; 0x1923e8
	db $0, "LT.SURGE recog-", $4f
	db "nized my potential", $51
	db "with electric", $4f
	db "#MON.", $51
	db "Think you can beat", $4f
	db "me?", $57
; 0x192437

GuitaristVincentBeatenText: ; 0x192437
	db $0, "Ooh, how shocking!", $57
; 0x19244b

UnknownText_0x19244b: ; 0x19244b
	db $0, "If the GYM's traps", $4f
	db "were working, you", $51
	db "would have been", $4f
	db "toast…", $57
; 0x192487

JugglerHortonSeenText: ; 0x192487
	db $0, "I'm going to take", $4f
	db "you down! Prepare", $55
	db "to be shocked!", $57
; 0x1924ba

JugglerHortonBeatenText: ; 0x1924ba
	db $0, "Gwaaah!", $4f
	db "I was overpowered…", $57
; 0x1924d6

UnknownText_0x1924d6: ; 0x1924d6
	db $0, "Don't get too com-", $4f
	db "fortable about", $51
	db "beating me…", $4f
	db "LT.SURGE is tough.", $57
; 0x192517

VermilionGymGuyText: ; 0x192517
	db $0, "Yo! CHAMP in", $4f
	db "making!", $51
	db "You lucked out", $4f
	db "this time.", $51
	db "LT.SURGE is very", $4f
	db "cautious. He has", $51
	db "traps set all over", $4f
	db "the GYM.", $51
	db "But--he-heh--the", $4f
	db "traps aren't", $55
	db "active right now.", $51
	db "You'll have no", $4f
	db "problem getting to", $55
	db "LT.SURGE.", $57
; 0x1925df

VermilionGymGuyWinText: ; 0x1925df
	db $0, "Whew! That was an", $4f
	db "electrifying bout!", $51
	db "It sure made me", $4f
	db "nervous.", $57
; 0x19261e

UnknownText_0x19261e: ; 0x19261e
	db $0, "Nope! Nothing here", $4f
	db "but trash.", $57
; 0x19263d

VermilionGym_MapEventHeader: ; 0x19263d
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $11, $4, 7, GROUP_VERMILION_CITY, MAP_VERMILION_CITY
	warp_def $11, $5, 7, GROUP_VERMILION_CITY, MAP_VERMILION_CITY

	; xy triggers
	db 0

	; signposts
	db 17
	signpost 7, 1, $0, MapVermilionGymSignpost14Script
	signpost 7, 3, $0, MapVermilionGymSignpost14Script
	signpost 7, 5, $0, MapVermilionGymSignpost14Script
	signpost 7, 7, $0, MapVermilionGymSignpost14Script
	signpost 7, 9, $0, MapVermilionGymSignpost14Script
	signpost 9, 1, $0, MapVermilionGymSignpost14Script
	signpost 9, 3, $0, MapVermilionGymSignpost14Script
	signpost 9, 5, $0, MapVermilionGymSignpost14Script
	signpost 9, 7, $0, MapVermilionGymSignpost14Script
	signpost 9, 9, $0, MapVermilionGymSignpost14Script
	signpost 11, 1, $0, MapVermilionGymSignpost14Script
	signpost 11, 3, $0, MapVermilionGymSignpost14Script
	signpost 11, 5, $0, MapVermilionGymSignpost14Script
	signpost 11, 7, $0, MapVermilionGymSignpost14Script
	signpost 11, 9, $0, MapVermilionGymSignpost14Script
	signpost 15, 3, $0, MapVermilionGymSignpost16Script
	signpost 15, 6, $0, MapVermilionGymSignpost16Script

	; people-events
	db 5
	person_event $1f, 6, 9, $6, $0, 255, 255, $b0, 0, UnknownScript_0x1920a5, $ffff
	person_event $40, 12, 12, $8, $0, 255, 255, $92, 4, TrainerGentlemanGregory, $ffff
	person_event $2c, 11, 8, $6, $3, 255, 255, $82, 3, TrainerGuitaristVincent, $ffff
	person_event $2b, 14, 4, $9, $0, 255, 255, $92, 4, TrainerJugglerHorton, $ffff
	person_event $48, 19, 11, $6, $0, 255, 255, $90, 1, VermilionGymGuyScript, $ffff
; 0x1926e3

Route6SaffronGate_MapScriptHeader: ; 0x1926e3
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x1926e9, $0000

	; callback count
	db 0
; 0x1926e9

UnknownScript_0x1926e9: ; 0x1926e9
	end
; 0x1926ea

UnknownScript_0x1926ea: ; 0x1926ea
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x1926f8
	2writetext UnknownText_0x1926fe
	closetext
	loadmovesprites
	end
; 0x1926f8

UnknownScript_0x1926f8: ; 0x1926f8
	2writetext UnknownText_0x1927cb
	closetext
	loadmovesprites
	end
; 0x1926fe

UnknownText_0x1926fe: ; 0x1926fe
	db $0, "Welcome to SAFFRON", $4f
	db "CITY, home of the", $55
	db "MAGNET TRAIN!", $51
	db "…That's what I'd", $4f
	db "normally say, but", $51
	db "the MAGNET TRAIN", $4f
	db "isn't running now.", $51
	db "It's not getting", $4f
	db "any electricity", $51
	db "because there's", $4f
	db "something wrong", $51
	db "with the POWER", $4f
	db "PLANT.", $57
; 0x1927cb

UnknownText_0x1927cb: ; 0x1927cb
	db $0, "The MAGNET TRAIN", $4f
	db "is the most famous", $51
	db "thing about SAF-", $4f
	db "FRON.", $57
; 0x192807

Route6SaffronGate_MapEventHeader: ; 0x192807
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 12, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $0, $5, 13, GROUP_SAFFRON_CITY, MAP_SAFFRON_CITY
	warp_def $7, $4, 2, GROUP_ROUTE_6, MAP_ROUTE_6
	warp_def $7, $5, 2, GROUP_ROUTE_6, MAP_ROUTE_6

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 8, 4, $9, $0, 255, 255, $90, 0, UnknownScript_0x1926ea, $ffff
; 0x19282e

Route6UndergroundEntrance_MapScriptHeader: ; 0x19282e
	; trigger count
	db 0

	; callback count
	db 0
; 0x192830

Route6UndergroundEntrance_MapEventHeader: ; 0x192830
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_ROUTE_6, MAP_ROUTE_6
	warp_def $7, $4, 1, GROUP_ROUTE_6, MAP_ROUTE_6
	warp_def $3, $4, 2, GROUP_UNDERGROUND, MAP_UNDERGROUND

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x192845

PokeCenter2F_MapScriptHeader: ; 0x192845
	; trigger count
	db 6

	; triggers
	dw UnknownScript_0x19285f, $0000
	dw UnknownScript_0x192873, $0000
	dw UnknownScript_0x192877, $0000
	dw UnknownScript_0x19287b, $0000
	dw UnknownScript_0x19287f, $0000
	dw UnknownScript_0x192883, $0000

	; callback count
	db 0
; 0x19285f

UnknownScript_0x19285f: ; 0x19285f
	special $0011
	if_equal $0, UnknownScript_0x192872
	clearbit1 $0711
	checkbit1 $0001
	iftrue UnknownScript_0x192872
	priorityjump UnknownScript_0x192887
; 0x192872

UnknownScript_0x192872: ; 0x192872
	end
; 0x192873

UnknownScript_0x192873: ; 0x192873
	priorityjump UnknownScript_0x192ab6
	end
; 0x192877

UnknownScript_0x192877: ; 0x192877
	priorityjump UnknownScript_0x192add
	end
; 0x19287b

UnknownScript_0x19287b: ; 0x19287b
	priorityjump UnknownScript_0x192c4e
	end
; 0x19287f

UnknownScript_0x19287f: ; 0x19287f
	priorityjump UnknownScript_0x192ac3
	end
; 0x192883

UnknownScript_0x192883: ; 0x192883
	priorityjump UnknownScript_0x192aea
	end
; 0x192887

UnknownScript_0x192887: ; 0x192887
	appear $5
	setbit1 $0001
	end
; 0x19288d

UnknownScript_0x19288d: ; 0x19288d
	faceplayer
	loadfont
	2writetext UnknownText_0x19312f
	closetext
	loadmovesprites
	end
; 0x192895

UnknownScript_0x192895: ; 0x192895
	faceplayer
	loadfont
	2writetext UnknownText_0x19315f
	closetext
	loadmovesprites
	end
; 0x19289d

UnknownScript_0x19289d: ; 0x19289d
	checkbit1 $001f
	iffalse UnknownScript_0x19288d
	loadfont
	2writetext UnknownText_0x192e3a
	yesorno
	iffalse UnknownScript_0x19291d
	special $00a0
	iffalse UnknownScript_0x1928be
	2writetext UnknownText_0x192d7e
	special $008c
	iffalse UnknownScript_0x19291d
	if_equal $1, UnknownScript_0x19291f
UnknownScript_0x1928be: ; 0x1928be
	special $0001
	2writetext UnknownText_0x192f67
	special $0002
	iffalse UnknownScript_0x1928f6
	2writetext UnknownText_0x192f34
	yesorno
	iffalse UnknownScript_0x192917
	special $0004
	iffalse UnknownScript_0x192917
	2writetext UnknownText_0x192f67
	special $0003
	iffalse UnknownScript_0x192911
	copybytetovar $cf51
	iffalse UnknownScript_0x1928fe
	special $0005
	iffalse UnknownScript_0x192909
	2writetext UnknownText_0x19306b
	closetext
	loadmovesprites
	2call UnknownScript_0x192b04
	warpcheck
	end
; 0x1928f6

UnknownScript_0x1928f6: ; 0x1928f6
	special $0008
	2writetext UnknownText_0x192f19
	loadmovesprites
	end
; 0x1928fe

UnknownScript_0x1928fe: ; 0x1928fe
	special $0006
	2writetext UnknownText_0x193029
	special $0007
	loadmovesprites
	end
; 0x192909

UnknownScript_0x192909: ; 0x192909
	2writetext UnknownText_0x19304a
	special $0007
	loadmovesprites
	end
; 0x192911

UnknownScript_0x192911: ; 0x192911
	2writetext UnknownText_0x192f75
	2jump UnknownScript_0x19291a
; 0x192917

UnknownScript_0x192917: ; 0x192917
	2writetext UnknownText_0x192fd1
UnknownScript_0x19291a: ; 0x19291a
	special $0008
UnknownScript_0x19291d: ; 0x19291d
	loadmovesprites
	end
; 0x19291f

UnknownScript_0x19291f: ; 0x19291f
	2call UnknownScript_0x19292b
	iftrue UnknownScript_0x19292a
	2call UnknownScript_0x19294a
	warpcheck
	end
; 0x19292a

UnknownScript_0x19292a: ; 0x19292a
	end
; 0x19292b

UnknownScript_0x19292b: ; 0x19292b
	2writetext UnknownText_0x192f34
	yesorno
	iffalse UnknownScript_0x192943
	special $0004
	iffalse UnknownScript_0x192943
	special $007f
	2writetext UnknownText_0x19306b
	closetext
	loadmovesprites
	writebyte $0
	end
; 0x192943

UnknownScript_0x192943: ; 0x192943
	2writetext UnknownText_0x192fd1
	loadmovesprites
	writebyte $1
	end
; 0x19294a

UnknownScript_0x19294a: ; 0x19294a
	applymovement2 MovementData_0x192cce
	applymovement $0, MovementData_0x192ce7
	end
; 0x192952

UnknownScript_0x192952: ; 0x192952
	checkbit1 $001f
	iffalse UnknownScript_0x192895
	loadfont
	2writetext UnknownText_0x192de0
	yesorno
	iffalse UnknownScript_0x1929d2
	special $00a0
	iffalse UnknownScript_0x192973
	2writetext UnknownText_0x192d39
	special $008c
	iffalse UnknownScript_0x1929d2
	if_equal $1, UnknownScript_0x1929d4
UnknownScript_0x192973: ; 0x192973
	special $0009
	2writetext UnknownText_0x192f67
	special $0002
	iffalse UnknownScript_0x1929ab
	2writetext UnknownText_0x192f34
	yesorno
	iffalse UnknownScript_0x1929cc
	special $0004
	iffalse UnknownScript_0x1929cc
	2writetext UnknownText_0x192f67
	special $0003
	iffalse UnknownScript_0x1929c6
	copybytetovar $cf51
	iffalse UnknownScript_0x1929b3
	special $0005
	iffalse UnknownScript_0x1929be
	2writetext UnknownText_0x19306b
	closetext
	loadmovesprites
	2call UnknownScript_0x192b04
	warpcheck
	end
; 0x1929ab

UnknownScript_0x1929ab: ; 0x1929ab
	special $0008
	2writetext UnknownText_0x192f19
	loadmovesprites
	end
; 0x1929b3

UnknownScript_0x1929b3: ; 0x1929b3
	special $0006
	2writetext UnknownText_0x193029
	special $0007
	loadmovesprites
	end
; 0x1929be

UnknownScript_0x1929be: ; 0x1929be
	2writetext UnknownText_0x19304a
	special $0007
	loadmovesprites
	end
; 0x1929c6

UnknownScript_0x1929c6: ; 0x1929c6
	2writetext UnknownText_0x192f75
	2jump UnknownScript_0x1929cf
; 0x1929cc

UnknownScript_0x1929cc: ; 0x1929cc
	2writetext UnknownText_0x192fd1
UnknownScript_0x1929cf: ; 0x1929cf
	special $0008
UnknownScript_0x1929d2: ; 0x1929d2
	loadmovesprites
	end
; 0x1929d4

UnknownScript_0x1929d4: ; 0x1929d4
	2call UnknownScript_0x192a05
	iffalse UnknownScript_0x1929e5
	2call UnknownScript_0x1929e6
	iftrue UnknownScript_0x1929e5
	2call UnknownScript_0x19294a
	warpcheck
	end
; 0x1929e5

UnknownScript_0x1929e5: ; 0x1929e5
	end
; 0x1929e6

UnknownScript_0x1929e6: ; 0x1929e6
	2writetext UnknownText_0x192f34
	yesorno
	iffalse UnknownScript_0x1929fe
	special $00a1
	iffalse UnknownScript_0x1929fe
	special $007f
	2writetext UnknownText_0x19306b
	closetext
	loadmovesprites
	writebyte $0
	end
; 0x1929fe

UnknownScript_0x1929fe: ; 0x1929fe
	2writetext UnknownText_0x192fd1
	loadmovesprites
	writebyte $1
	end
; 0x192a05

UnknownScript_0x192a05: ; 0x192a05
	special $009a
	iffalse UnknownScript_0x192a1e
	if_equal $1, UnknownScript_0x192a22
	if_equal $2, UnknownScript_0x192a22
	if_equal $3, UnknownScript_0x192a1a
	2jump UnknownScript_0x192a1e
; 0x192a1a

UnknownScript_0x192a1a: ; 0x192a1a
	2writetext UnknownText_0x1932bc
	closetext
UnknownScript_0x192a1e: ; 0x192a1e
	loadmovesprites
	writebyte $0
	end
; 0x192a22

UnknownScript_0x192a22: ; 0x192a22
	writebyte $1
	end
; 0x192a25

UnknownScript_0x192a25: ; 0x192a25
	faceplayer
	loadfont
	2writetext UnknownText_0x193100
	closetext
	loadmovesprites
	end
; 0x192a2d

UnknownScript_0x192a2d: ; 0x192a2d
	checkbit1 $0712
	iftrue UnknownScript_0x192a25
	checkbit2 $0053
	iftrue UnknownScript_0x192a25
	special $000a
	faceplayer
	loadfont
	2writetext UnknownText_0x192e9f
	yesorno
	iffalse UnknownScript_0x192aa2
	special $000b
	if_equal $1, UnknownScript_0x192aa7
	if_equal $2, UnknownScript_0x192aac
	if_equal $3, UnknownScript_0x192ab1
	2writetext UnknownText_0x192f67
	special $0002
	iffalse UnknownScript_0x192a91
	2writetext UnknownText_0x192f34
	yesorno
	iffalse UnknownScript_0x192a9f
	special $0004
	iffalse UnknownScript_0x192a9f
	2writetext UnknownText_0x192f67
	special $0003
	iffalse UnknownScript_0x192a99
	copybytetovar $cf51
	iffalse UnknownScript_0x192a84
	special $0005
	2writetext UnknownText_0x19304a
	special $0007
	loadmovesprites
	end
; 0x192a84

UnknownScript_0x192a84: ; 0x192a84
	special $000c
	2writetext UnknownText_0x19306b
	closetext
	loadmovesprites
	2call UnknownScript_0x192bc4
	warpcheck
	end
; 0x192a91

UnknownScript_0x192a91: ; 0x192a91
	special $0008
	2writetext UnknownText_0x192f19
	loadmovesprites
	end
; 0x192a99

UnknownScript_0x192a99: ; 0x192a99
	2writetext UnknownText_0x192f75
	2jump UnknownScript_0x192aa2
; 0x192a9f

UnknownScript_0x192a9f: ; 0x192a9f
	2writetext UnknownText_0x192fd1
UnknownScript_0x192aa2: ; 0x192aa2
	special $0008
	loadmovesprites
	end
; 0x192aa7

UnknownScript_0x192aa7: ; 0x192aa7
	2writetext UnknownText_0x19308b
	loadmovesprites
	end
; 0x192aac

UnknownScript_0x192aac: ; 0x192aac
	2writetext UnknownText_0x1930a8
	loadmovesprites
	end
; 0x192ab1

UnknownScript_0x192ab1: ; 0x192ab1
	2writetext UnknownText_0x1930cf
	loadmovesprites
	end
; 0x192ab6

UnknownScript_0x192ab6: ; 0x192ab6
	special $0008
	2call UnknownScript_0x192b50
	dotrigger $0
	domaptrigger GROUP_TRADE_CENTER, MAP_TRADE_CENTER, $0
	end
; 0x192ac3

UnknownScript_0x192ac3: ; 0x192ac3
	special $0080
	2call UnknownScript_0x192ad0
	dotrigger $0
	domaptrigger GROUP_MOBILE_TRADE_ROOM_MOBILE, MAP_MOBILE_TRADE_ROOM_MOBILE, $0
	end
; 0x192ad0

UnknownScript_0x192ad0: ; 0x192ad0
	applymovement $2, MovementData_0x192d0b
	applymovement $0, MovementData_0x192d0f
	applymovement $2, MovementData_0x192d14
	end
; 0x192add

UnknownScript_0x192add: ; 0x192add
	special $0008
	2call UnknownScript_0x192b8a
	dotrigger $0
	domaptrigger GROUP_COLOSSEUM, MAP_COLOSSEUM, $0
	end
; 0x192aea

UnknownScript_0x192aea: ; 0x192aea
	special $0080
	2call UnknownScript_0x192af7
	dotrigger $0
	domaptrigger GROUP_MOBILE_BATTLE_ROOM, MAP_MOBILE_BATTLE_ROOM, $0
	end
; 0x192af7

UnknownScript_0x192af7: ; 0x192af7
	applymovement $3, MovementData_0x192d0b
	applymovement $0, MovementData_0x192d0f
	applymovement $3, MovementData_0x192d14
	end
; 0x192b04

UnknownScript_0x192b04: ; 0x192b04
	checkbit2 $0063
	iftrue UnknownScript_0x192b12
	applymovement2 MovementData_0x192cca
	applymovement $0, MovementData_0x192cde
	end
; 0x192b12

UnknownScript_0x192b12: ; 0x192b12
	applymovement2 MovementData_0x192cd8
	applymovement $0, MovementData_0x192ce2
	loadfont
	2writetext UnknownText_0x193266
	closetext
	loadmovesprites
	applymovement2 MovementData_0x192cdc
	spriteface $0, $2
	loadfont
	2writetext UnknownText_0x193278
	closetext
	loadmovesprites
	playsound $00ca
	applymovement $0, MovementData_0x192d17
	writebyte $80
	special $0098
	applymovement $0, MovementData_0x192d1c
	setbit2 $009f
	special $0038
	loadfont
	2writetext UnknownText_0x19329a
	closetext
	loadmovesprites
	showemote $0, $0, 15
	applymovement $0, MovementData_0x192ce5
	end
; 0x192b50

UnknownScript_0x192b50: ; 0x192b50
	checkbit2 $009f
	iftrue UnknownScript_0x192b63
	applymovement $2, MovementData_0x192d04
	applymovement $0, MovementData_0x192cf5
	applymovement $2, MovementData_0x192cfe
	end
; 0x192b63

UnknownScript_0x192b63: ; 0x192b63
	applymovement $2, MovementData_0x192d04
	applymovement $0, MovementData_0x192d28
	clearbit2 $009f
	playsound $00ca
	applymovement $0, MovementData_0x192d17
	writebyte $90
	special $0098
	applymovement $0, MovementData_0x192d1c
	special $0038
	applymovement $0, MovementData_0x192d2a
	applymovement $2, MovementData_0x192cfe
	end
; 0x192b8a

UnknownScript_0x192b8a: ; 0x192b8a
	checkbit2 $009f
	iftrue UnknownScript_0x192b9d
	applymovement $3, MovementData_0x192d04
	applymovement $0, MovementData_0x192cf5
	applymovement $3, MovementData_0x192cfe
	end
; 0x192b9d

UnknownScript_0x192b9d: ; 0x192b9d
	applymovement $3, MovementData_0x192d04
	applymovement $0, MovementData_0x192d28
	clearbit2 $009f
	playsound $00ca
	applymovement $0, MovementData_0x192d17
	writebyte $90
	special $0098
	applymovement $0, MovementData_0x192d1c
	special $0038
	applymovement $0, MovementData_0x192d2a
	applymovement $3, MovementData_0x192cfe
	end
; 0x192bc4

UnknownScript_0x192bc4: ; 0x192bc4
	checkbit2 $0063
	iftrue UnknownScript_0x192bec
	checkcode $9
	if_equal $2, UnknownScript_0x192bdc
	if_equal $3, UnknownScript_0x192be4
	applymovement2 MovementData_0x192cd2
	applymovement $0, MovementData_0x192cec
	end
; 0x192bdc

UnknownScript_0x192bdc: ; 0x192bdc
	applymovement2 MovementData_0x192cd2
	applymovement $0, MovementData_0x192cef
	end
; 0x192be4

UnknownScript_0x192be4: ; 0x192be4
	applymovement2 MovementData_0x192cd5
	applymovement $0, MovementData_0x192cf2
	end
; 0x192bec

UnknownScript_0x192bec: ; 0x192bec
	checkcode $9
	if_equal $3, UnknownScript_0x192c00
	if_equal $2, UnknownScript_0x192c0a
	applymovement2 MovementData_0x192d33
	applymovement $0, MovementData_0x192d2d
	2jump UnknownScript_0x192c11
; 0x192c00

UnknownScript_0x192c00: ; 0x192c00
	applymovement2 MovementData_0x192d36
	applymovement $0, MovementData_0x192d2f
	2jump UnknownScript_0x192c11
; 0x192c0a

UnknownScript_0x192c0a: ; 0x192c0a
	applymovement2 MovementData_0x192d33
	applymovement $0, MovementData_0x192d31
UnknownScript_0x192c11: ; 0x192c11
	loadfont
	2writetext UnknownText_0x193266
	closetext
	loadmovesprites
	checkcode $9
	if_not_equal $1, UnknownScript_0x192c20
	spriteface $0, $2
UnknownScript_0x192c20: ; 0x192c20
	loadfont
	2writetext UnknownText_0x193278
	closetext
	loadmovesprites
	playsound $00ca
	applymovement $0, MovementData_0x192d17
	writebyte $80
	special $0098
	applymovement $0, MovementData_0x192d22
	faceperson $0, $4
	setbit2 $009f
	special $0038
	loadfont
	2writetext UnknownText_0x19329a
	closetext
	loadmovesprites
	showemote $0, $0, 15
	applymovement $0, MovementData_0x192d2d
	end
; 0x192c4e

UnknownScript_0x192c4e: ; 0x192c4e
	special $0008
	checkbit2 $009f
	iftrue UnknownScript_0x192c66
	applymovement $4, MovementData_0x192d08
	applymovement $0, MovementData_0x192cf9
	applymovement $4, MovementData_0x192d01
	2jump UnknownScript_0x192c8c
; 0x192c66

UnknownScript_0x192c66: ; 0x192c66
	applymovement $4, MovementData_0x192d08
	applymovement $0, MovementData_0x192cfc
	clearbit2 $009f
	playsound $00ca
	applymovement $0, MovementData_0x192d17
	writebyte $90
	special $0098
	applymovement $0, MovementData_0x192d1c
	special $0038
	applymovement $0, MovementData_0x192cfc
	applymovement $4, MovementData_0x192d01
UnknownScript_0x192c8c: ; 0x192c8c
	dotrigger $0
	domaptrigger GROUP_TIME_CAPSULE, MAP_TIME_CAPSULE, $0
	end
; 0x192c93

MapPokeCenter2FSignpost0Script: ; 0x192c93
	refreshscreen $0
	special $0058
	loadmovesprites
	end
; 0x192c9a

UnknownScript_0x192c9a: ; 0x192c9a
	faceplayer
	loadfont
	checkbit1 $0711
	iftrue UnknownScript_0x192cb8
	2writetext UnknownText_0x193190
	yesorno
	iffalse UnknownScript_0x192cc4
	2writetext UnknownText_0x1931c4
	keeptextopen
	waitbutton
	special $0012
	iffalse UnknownScript_0x192cbe
	itemnotify
	setbit1 $0711
UnknownScript_0x192cb8: ; 0x192cb8
	2writetext UnknownText_0x1931d2
	closetext
	loadmovesprites
	end
; 0x192cbe

UnknownScript_0x192cbe: ; 0x192cbe
	2writetext UnknownText_0x1931ef
	closetext
	loadmovesprites
	end
; 0x192cc4

UnknownScript_0x192cc4: ; 0x192cc4
	2writetext UnknownText_0x19324d
	closetext
	loadmovesprites
	end
; 0x192cca

MovementData_0x192cca: ; 0x192cca
	slow_step_up
	slow_step_left
	turn_head_right
	step_end
; 0x192cce

MovementData_0x192cce: ; 0x192cce
	slow_step_up
	slow_step_left
	turn_head_down
	step_end
; 0x192cd2

MovementData_0x192cd2: ; 0x192cd2
	slow_step_left
	turn_head_down
	step_end
; 0x192cd5

MovementData_0x192cd5: ; 0x192cd5
	slow_step_right
	turn_head_down
	step_end
; 0x192cd8

MovementData_0x192cd8: ; 0x192cd8
	slow_step_up
	slow_step_left
	turn_head_right
	step_end
; 0x192cdc

MovementData_0x192cdc: ; 0x192cdc
	turn_head_right
	step_end
; 0x192cde

MovementData_0x192cde: ; 0x192cde
	step_up
	step_up
	step_up
	step_end
; 0x192ce2

MovementData_0x192ce2: ; 0x192ce2
	step_up
	step_up
	step_end
; 0x192ce5

MovementData_0x192ce5: ; 0x192ce5
	step_up
	step_end
; 0x192ce7

MovementData_0x192ce7: ; 0x192ce7
	step_up
	step_up
	step_right
	step_up
	step_end
; 0x192cec

MovementData_0x192cec: ; 0x192cec
	step_up
	step_up
	step_end
; 0x192cef

MovementData_0x192cef: ; 0x192cef
	step_left
	step_up
	step_end
; 0x192cf2

MovementData_0x192cf2: ; 0x192cf2
	step_right
	step_up
	step_end
; 0x192cf5

MovementData_0x192cf5: ; 0x192cf5
	step_down
	step_down
	step_down
	step_end
; 0x192cf9

MovementData_0x192cf9: ; 0x192cf9
	step_down
	step_down
	step_end
; 0x192cfc

MovementData_0x192cfc: ; 0x192cfc
	step_down
	step_end
; 0x192cfe

MovementData_0x192cfe: ; 0x192cfe
	slow_step_right
	slow_step_down
	step_end
; 0x192d01

MovementData_0x192d01: ; 0x192d01
	slow_step_right
	turn_head_down
	step_end
; 0x192d04

MovementData_0x192d04: ; 0x192d04
	slow_step_up
	slow_step_left
	turn_head_right
	step_end
; 0x192d08

MovementData_0x192d08: ; 0x192d08
	slow_step_left
	turn_head_right
	step_end
; 0x192d0b

MovementData_0x192d0b: ; 0x192d0b
	slow_step_up
	slow_step_left
	turn_head_right
	step_end
; 0x192d0f

MovementData_0x192d0f: ; 0x192d0f
	step_down
	step_left
	step_down
	step_down
	step_end
; 0x192d14

MovementData_0x192d14: ; 0x192d14
	slow_step_right
	slow_step_down
	step_end
; 0x192d17

MovementData_0x192d17: ; 0x192d17
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	step_end
; 0x192d1c

MovementData_0x192d1c: ; 0x192d1c
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_left
	step_end
; 0x192d22

MovementData_0x192d22: ; 0x192d22
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	step_end
; 0x192d28

MovementData_0x192d28: ; 0x192d28
	step_down
	step_end
; 0x192d2a

MovementData_0x192d2a: ; 0x192d2a
	step_down
	step_down
	step_end
; 0x192d2d

MovementData_0x192d2d: ; 0x192d2d
	step_up
	step_end
; 0x192d2f

MovementData_0x192d2f: ; 0x192d2f
	step_right
	step_end
; 0x192d31

MovementData_0x192d31: ; 0x192d31
	step_left
	step_end
; 0x192d33

MovementData_0x192d33: ; 0x192d33
	slow_step_left
	turn_head_right
	step_end
; 0x192d36

MovementData_0x192d36: ; 0x192d36
	slow_step_right
	turn_head_left
	step_end
; 0x192d39

UnknownText_0x192d39: ; 0x192d39
	db $0, "Would you like to", $4f
	db "battle over a GAME", $51
	db "LINK cable or by", $4f
	db "mobile phone?", $57
; 0x192d7e

UnknownText_0x192d7e: ; 0x192d7e
	db $0, "Would you like to", $4f
	db "trade over a GAME", $51
	db "LINK cable or by", $4f
	db "mobile phone?", $57
; 0x192dc2

UnknownText_0x192dc2: ; 0x192dc2
	db $0, "This way to the", $4f
	db "MOBILE ROOM.", $57
; 0x192de0

UnknownText_0x192de0: ; 0x192de0
	db $0, "Welcome to CABLE", $4f
	db "CLUB COLOSSEUM.", $51
	db "You may battle a", $4f
	db "friend here.", $51
	db "Would you like to", $4f
	db "battle?", $57
; 0x192e3a

UnknownText_0x192e3a: ; 0x192e3a
	db $0, "Welcome to CABLE", $4f
	db "TRADE CENTER.", $51
	db "You may trade your", $4f
	db "#MON here with", $55
	db "a friend.", $51
	db "Would you like to", $4f
	db "trade?", $57
; 0x192e9f

UnknownText_0x192e9f: ; 0x192e9f
	db $0, "Welcome to CABLE", $4f
	db "CLUB TIME CAPSULE.", $51
	db "You can travel to", $4f
	db "the past and trade", $55
	db "your #MON.", $51
	db "Would you like to", $4f
	db "trade across time?", $57
; 0x192f19

UnknownText_0x192f19: ; 0x192f19
	db $0, "Your friend is not", $4f
	db "ready.", $58
; 0x192f34

UnknownText_0x192f34: ; 0x192f34
	db $0, "Before opening the", $4f
	db "link, you must", $55
	db "save your game.", $57
; 0x192f67

UnknownText_0x192f67: ; 0x192f67
	db $0, "Please wait.", $57
; 0x192f75

UnknownText_0x192f75: ; 0x192f75
	db $0, "The link has been", $4f
	db "closed because of", $55
	db "inactivity.", $51
	db "Please contact", $4f
	db "your friend and", $55
	db "come again.", $58
; 0x192fd1

UnknownText_0x192fd1: ; 0x192fd1
	db $0, "Please come again.", $58
; 0x192fe5

UnknownText_0x192fe5: ; 0x192fe5
	db $0, "Please come in.", $58
; 0x192ff6

UnknownText_0x192ff6: ; 0x192ff6
	db $0, "We'll put you in", $4f
	db "the link room for", $55
	db "the time being.", $57
; 0x193029

UnknownText_0x193029: ; 0x193029
	db $0, "You can't link to", $4f
	db "the past here.", $58
; 0x19304a

UnknownText_0x19304a: ; 0x19304a
	db $0, "Incompatible rooms", $4f
	db "were chosen.", $58
; 0x19306b

UnknownText_0x19306b: ; 0x19306b
	db $0, "Please come in.", $57
; 0x19307c

UnknownText_0x19307c: ; 0x19307c
	db $0, "Please enter.", $58
; 0x19308b

UnknownText_0x19308b: ; 0x19308b
	db $0, "Sorry--@"
	text_from_ram $d073
	db $0, $4f
	db "can't be taken.", $58
; 0x1930a8

UnknownText_0x1930a8: ; 0x1930a8
	db $0, "You can't take the", $4f
	db "@"
	text_from_ram $d073
	db $0, " with a", $55
	db "@"
	text_from_ram $d086
	db $0, ".", $58
; 0x1930cf

UnknownText_0x1930cf: ; 0x1930cf
	db $0, "You can't take the", $4f
	db "@"
	text_from_ram $d073
	db $0, " that", $55
	db "has MAIL with you.", $58
; 0x193100

UnknownText_0x193100: ; 0x193100
	db $0, "I'm sorry--the", $4f
	db "TIME CAPSULE is", $55
	db "being adjusted.", $57
; 0x19312f

UnknownText_0x19312f: ; 0x19312f
	db $0, "I'm sorry--the", $4f
	db "TRADE MACHINE is", $55
	db "being adjusted.", $57
; 0x19315f

UnknownText_0x19315f: ; 0x19315f
	db $0, "I'm sorry--the", $4f
	db "BATTLE MACHINE is", $55
	db "being adjusted.", $57
; 0x193190

UnknownText_0x193190: ; 0x193190
	db $0, "Hello! You're", $4f
	db $52, ", right?", $51
	db "I have some-", $4f
	db "thing for you.", $57
; 0x1931c4

UnknownText_0x1931c4: ; 0x1931c4
	db $0, "Here you go!", $57
; 0x1931d2

UnknownText_0x1931d2: ; 0x1931d2
	db $0, "We hope to serve", $4f
	db "you again.", $57
; 0x1931ef

UnknownText_0x1931ef: ; 0x1931ef
	db $0, "Oh, you have no", $4f
	db "space for this.", $51
	db "Stop in at any", $4f
	db "#MON CENTER", $51
	db "across the country", $4f
	db "to pick it up.", $57
; 0x19324d

UnknownText_0x19324d: ; 0x19324d
	db $0, "No? That's very", $4f
	db "strange…", $57
; 0x193266

UnknownText_0x193266: ; 0x193266
	db $0, "Oh, please wait.", $57
; 0x193278

UnknownText_0x193278: ; 0x193278
	db $0, "We need to change", $4f
	db "the look here…", $57
; 0x19329a

UnknownText_0x19329a: ; 0x19329a
	db $0, "How does this", $4f
	db "style look to you?", $57
; 0x1932bc

UnknownText_0x1932bc: ; 0x1932bc
	db $0, "Excuse me!", $51
	db "For STADIUM rules,", $4f
	db "please bring six", $51
	db "different #MON,", $4f
	db "excluding EGGS.", $51
	db "The six #MON", $4f
	db "must be different.", $51
	db "Also, they must", $4f
	db "not be holding", $55
	db "identical items.", $51
	db "Please come back", $4f
	db "when you're ready.", $57
; 0x19337f

PokeCenter2F_MapEventHeader: ; 0x19337f
	; filler
	db 0, 0

	; warps
	db 6
	warp_def $7, $0, 255, GROUP_POKECENTER_2F, MAP_POKECENTER_2F
	warp_def $0, $5, 1, GROUP_TRADE_CENTER, MAP_TRADE_CENTER
	warp_def $0, $9, 1, GROUP_COLOSSEUM, MAP_COLOSSEUM
	warp_def $2, $d, 1, GROUP_TIME_CAPSULE, MAP_TIME_CAPSULE
	warp_def $0, $6, 1, GROUP_MOBILE_TRADE_ROOM_MOBILE, MAP_MOBILE_TRADE_ROOM_MOBILE
	warp_def $0, $a, 1, GROUP_MOBILE_BATTLE_ROOM, MAP_MOBILE_BATTLE_ROOM

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 3, 7, $0, MapPokeCenter2FSignpost0Script

	; people-events
	db 4
	person_event $38, 6, 9, $6, $0, 255, 255, $a0, 0, UnknownScript_0x19289d, $ffff
	person_event $38, 6, 13, $6, $0, 255, 255, $a0, 0, UnknownScript_0x192952, $ffff
	person_event $38, 7, 17, $6, $0, 255, 255, $a0, 0, UnknownScript_0x192a2d, $ffff
	person_event $43, 5, 5, $6, $0, 255, 255, $0, 0, UnknownScript_0x192c9a, $0711
; 0x1933dc

TradeCenter_MapScriptHeader: ; 0x1933dc
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1933e9, $0000
	dw UnknownScript_0x1933ed, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x1933ee
; 0x1933e9

UnknownScript_0x1933e9: ; 0x1933e9
	priorityjump UnknownScript_0x1933fe
	end
; 0x1933ed

UnknownScript_0x1933ed: ; 0x1933ed
	end
; 0x1933ee

UnknownScript_0x1933ee: ; 0x1933ee
	special $0010
	iffalse UnknownScript_0x1933f9
	disappear $3
	appear $2
	return
; 0x1933f9

UnknownScript_0x1933f9: ; 0x1933f9
	disappear $2
	appear $3
	return
; 0x1933fe

UnknownScript_0x1933fe: ; 0x1933fe
	dotrigger $1
	domaptrigger GROUP_POKECENTER_2F, MAP_POKECENTER_2F, $1
	end
; 0x193405

MapTradeCenterSignpost1Script: ; 0x193405
	special $000d
	newloadmap $f8
	end
; 0x19340b

UnknownScript_0x19340b: ; 0x19340b
	loadfont
	2writetext UnknownText_0x193412
	closetext
	loadmovesprites
	end
; 0x193412

UnknownText_0x193412: ; 0x193412
	db $0, "Your friend is", $4f
	db "ready.", $57
; 0x193429

TradeCenter_MapEventHeader: ; 0x193429
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $4, 2, GROUP_POKECENTER_2F, MAP_POKECENTER_2F
	warp_def $7, $5, 2, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 4, 4, $3, MapTradeCenterSignpost1Script
	signpost 4, 5, $4, MapTradeCenterSignpost1Script

	; people-events
	db 2
	person_event $1, 8, 7, $9, $0, 255, 255, $0, 0, UnknownScript_0x193499, $0000
	person_event $1, 8, 10, $8, $0, 255, 255, $0, 0, UnknownScript_0x193499, $0001
; 0x19345d

Colosseum_MapScriptHeader: ; 0x19345d
	; trigger count
	db 3

	; triggers
	dw UnknownScript_0x193471, $0000
	dw UnknownScript_0x193475, $0000
	dw UnknownScript_0x193476, $0000

	; callback count
	db 2

	; callbacks

	dbw 2, UnknownScript_0x193477

	dbw 5, UnknownScript_0x193487
; 0x193471

UnknownScript_0x193471: ; 0x193471
	priorityjump UnknownScript_0x19348c
	end
; 0x193475

UnknownScript_0x193475: ; 0x193475
	end
; 0x193476

UnknownScript_0x193476: ; 0x193476
	end
; 0x193477

UnknownScript_0x193477: ; 0x193477
	special $0010
	iffalse UnknownScript_0x193482
	disappear $3
	appear $2
	return
; 0x193482

UnknownScript_0x193482: ; 0x193482
	disappear $2
	appear $3
	return
; 0x193487

UnknownScript_0x193487: ; 0x193487
	domaptrigger GROUP_POKECENTER_2F, MAP_POKECENTER_2F, $2
	return
; 0x19348c

UnknownScript_0x19348c: ; 0x19348c
	dotrigger $1
	domaptrigger GROUP_POKECENTER_2F, MAP_POKECENTER_2F, $2
	end
; 0x193493

MapColosseumSignpost1Script: ; 0x193493
	special $000e
	newloadmap $f8
	end
; 0x193499

UnknownScript_0x193499: ; 0x193499
	loadfont
	2writetext UnknownText_0x1934a0
	closetext
	loadmovesprites
	end
; 0x1934a0

UnknownText_0x1934a0: ; 0x1934a0
	db $0, "Your friend is", $4f
	db "ready.", $57
; 0x1934b7

Colosseum_MapEventHeader: ; 0x1934b7
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $4, 3, GROUP_POKECENTER_2F, MAP_POKECENTER_2F
	warp_def $7, $5, 3, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 4, 4, $3, MapColosseumSignpost1Script
	signpost 4, 5, $4, MapColosseumSignpost1Script

	; people-events
	db 2
	person_event $1, 8, 7, $9, $0, 255, 255, $0, 0, UnknownScript_0x193499, $0000
	person_event $1, 8, 10, $8, $0, 255, 255, $0, 0, UnknownScript_0x193499, $0001
; 0x1934eb

TimeCapsule_MapScriptHeader: ; 0x1934eb
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1934f8, $0000
	dw UnknownScript_0x1934fc, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x1934fd
; 0x1934f8

UnknownScript_0x1934f8: ; 0x1934f8
	priorityjump UnknownScript_0x19350d
	end
; 0x1934fc

UnknownScript_0x1934fc: ; 0x1934fc
	end
; 0x1934fd

UnknownScript_0x1934fd: ; 0x1934fd
	special $0010
	iffalse UnknownScript_0x193508
	disappear $3
	appear $2
	return
; 0x193508

UnknownScript_0x193508: ; 0x193508
	disappear $2
	appear $3
	return
; 0x19350d

UnknownScript_0x19350d: ; 0x19350d
	dotrigger $1
	domaptrigger GROUP_POKECENTER_2F, MAP_POKECENTER_2F, $3
	end
; 0x193514

MapTimeCapsuleSignpost1Script: ; 0x193514
	special $000f
	newloadmap $f8
	end
; 0x19351a

UnknownScript_0x19351a: ; 0x19351a
	loadfont
	2writetext UnknownText_0x193521
	closetext
	loadmovesprites
	end
; 0x193521

UnknownText_0x193521: ; 0x193521
	db $0, "Your friend is", $4f
	db "ready.", $57
; 0x193538

TimeCapsule_MapEventHeader: ; 0x193538
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $4, 4, GROUP_POKECENTER_2F, MAP_POKECENTER_2F
	warp_def $7, $5, 4, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 4, 4, $3, MapTimeCapsuleSignpost1Script
	signpost 4, 5, $4, MapTimeCapsuleSignpost1Script

	; people-events
	db 2
	person_event $1, 8, 7, $9, $0, 255, 255, $0, 0, UnknownScript_0x19351a, $0000
	person_event $1, 8, 10, $8, $0, 255, 255, $0, 0, UnknownScript_0x19351a, $0001
; 0x19356c

MobileTradeRoomMobile_MapScriptHeader: ; 0x19356c
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x193576, $0000
	dw UnknownScript_0x19357a, $0000

	; callback count
	db 0
; 0x193576

UnknownScript_0x193576: ; 0x193576
	priorityjump UnknownScript_0x19357b
	end
; 0x19357a

UnknownScript_0x19357a: ; 0x19357a
	end
; 0x19357b

UnknownScript_0x19357b: ; 0x19357b
	dotrigger $1
	domaptrigger GROUP_POKECENTER_2F, MAP_POKECENTER_2F, $4
	end
; 0x193582

MapMobileTradeRoomMobileSignpost0Script: ; 0x193582
	refreshscreen $0
	special $009f
	2writetext UnknownText_0x193591
	closetext
	reloadmappart
	special $0082
	loadmovesprites
	end
; 0x193591

UnknownText_0x193591: ; 0x193591
	db $0, "Establishing", $4f
	db "communications…", $57
; 0x1935af

MobileTradeRoomMobile_MapEventHeader: ; 0x1935af
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $4, 5, GROUP_POKECENTER_2F, MAP_POKECENTER_2F
	warp_def $7, $5, 5, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 2, 4, $1, MapMobileTradeRoomMobileSignpost0Script

	; people-events
	db 0
; 0x1935c4

MobileBattleRoom_MapScriptHeader: ; 0x1935c4
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1935ce, $0000
	dw UnknownScript_0x1935d2, $0000

	; callback count
	db 0
; 0x1935ce

UnknownScript_0x1935ce: ; 0x1935ce
	priorityjump UnknownScript_0x1935d3
	end
; 0x1935d2

UnknownScript_0x1935d2: ; 0x1935d2
	end
; 0x1935d3

UnknownScript_0x1935d3: ; 0x1935d3
	dotrigger $1
	domaptrigger GROUP_POKECENTER_2F, MAP_POKECENTER_2F, $5
	end
; 0x1935da

MapMobileBattleRoomSignpost0Script: ; 0x1935da
	refreshscreen $0
	special $009f
	if_equal $1, UnknownScript_0x193619
	special $009b
	iffalse UnknownScript_0x193624
	if_equal $1, UnknownScript_0x1935f4
	if_equal $2, UnknownScript_0x19360d
	2jump UnknownScript_0x193624
; 0x1935f4

UnknownScript_0x1935f4: ; 0x1935f4
	2writetext UnknownText_0x193644
	pause 20
	loadmovesprites
	special $002e
	playmusic $000d
	special $00a4
	pause 60
	special $0031
	special $003d
	refreshscreen $0
UnknownScript_0x19360d: ; 0x19360d
	special $009d
	special $001b
	special $009c
	iftrue UnknownScript_0x193624
UnknownScript_0x193619: ; 0x193619
	special $00a2
	2writetext UnknownText_0x193626
	closetext
	reloadmappart
	special $0081
UnknownScript_0x193624: ; 0x193624
	loadmovesprites
	end
; 0x193626

UnknownText_0x193626: ; 0x193626
	db $0, "Establishing", $4f
	db "communications…", $57
; 0x193644

UnknownText_0x193644: ; 0x193644
	db $0, "Your #MON will", $4f
	db "be fully healed", $55
	db "before battle.", $57
; 0x193673

MobileBattleRoom_MapEventHeader: ; 0x193673
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $4, 6, GROUP_POKECENTER_2F, MAP_POKECENTER_2F
	warp_def $7, $5, 6, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 2, 4, $1, MapMobileBattleRoomSignpost0Script

	; people-events
	db 0
; 0x193688

SECTION "bank65",DATA,BANK[$65]

Route36_MapScriptHeader: ; 0x194000
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x19400d, $0000
	dw UnknownScript_0x19400e, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x19400f
; 0x19400d

UnknownScript_0x19400d: ; 0x19400d
	end
; 0x19400e

UnknownScript_0x19400e: ; 0x19400e
	end
; 0x19400f

UnknownScript_0x19400f: ; 0x19400f
	checkcode $b
	if_equal THURSDAY, UnknownScript_0x194018
	disappear $8
	return
; 0x194018

UnknownScript_0x194018: ; 0x194018
	appear $8
	return
; 0x19401b

UnknownScript_0x19401b: ; 0x19401b
	showemote $0, $0, 15
	pause 15
	playsound $0014
	spriteface $0, $1
	applymovement $a, MovementData_0x194262
	disappear $a
	spriteface $0, $0
	pause 10
	dotrigger $0
	clearbit1 $07ae
	domaptrigger GROUP_CIANWOOD_CITY, MAP_CIANWOOD_CITY, $1
	end
; 0x19403c

UnknownScript_0x19403c: ; 0x19403c
	checkitem SQUIRTBOTTLE
	iftrue UnknownScript_0x19404a
	waitbutton
	playsound $006d
	applymovement $4, MovementData_0x194249
	end
; 0x19404a

UnknownScript_0x19404a: ; 0x19404a
	loadfont
	2writetext UnknownText_0x19426b
	yesorno
	iffalse UnknownScript_0x194079
	loadmovesprites
	loadfont
	2writetext UnknownText_0x194290
	closetext
	loadmovesprites
	waitbutton
	playsound $006d
	applymovement $4, MovementData_0x194249
	loadfont
	2writetext UnknownText_0x1942aa
	closetext
	loadmovesprites
	loadpokedata SUDOWOODO, 20
	startbattle
	setbit1 $002a
	if_equal $2, UnknownScript_0x19407b
	disappear $4
	variablesprite $4, $26
	returnafterbattle
	end
; 0x194079

UnknownScript_0x194079: ; 0x194079
	loadmovesprites
	end
; 0x19407b

UnknownScript_0x19407b: ; 0x19407b
	returnafterbattle
	applymovement $4, MovementData_0x19424b
	disappear $4
	variablesprite $4, $26
	special $005e
	special $009e
	end
; 0x19408c

UnknownScript_0x19408c: ; 0x19408c
	faceplayer
	loadfont
	checkbit1 $00ba
	iftrue UnknownScript_0x1940b3
	setbit1 $00b9
	2writetext UnknownText_0x1942f1
	closetext
	loadmovesprites
	clearbit1 $0768
	checkcode $9
	if_equal $1, UnknownScript_0x1940ac
	applymovement $9, MovementData_0x19424e
	disappear $9
	end
; 0x1940ac

UnknownScript_0x1940ac: ; 0x1940ac
	applymovement $9, MovementData_0x194258
	disappear $9
	end
; 0x1940b3

UnknownScript_0x1940b3: ; 0x1940b3
	2writetext UnknownText_0x1943ed
	closetext
	loadmovesprites
	end
; 0x1940b9

UnknownScript_0x1940b9: ; 0x1940b9
	faceplayer
	loadfont
	checkbit1 $004b
	iftrue UnknownScript_0x1940da
	checkbit1 $002a
	iftrue UnknownScript_0x1940cd
	2writetext UnknownText_0x19446f
	closetext
	loadmovesprites
	end
; 0x1940cd

UnknownScript_0x1940cd: ; 0x1940cd
	2writetext UnknownText_0x1944d0
	keeptextopen
	verbosegiveitem TM_08, 1
	iffalse UnknownScript_0x1940de
	setbit1 $004b
UnknownScript_0x1940da: ; 0x1940da
	2writetext UnknownText_0x19452c
	closetext
UnknownScript_0x1940de: ; 0x1940de
	loadmovesprites
	end
; 0x1940e0

UnknownScript_0x1940e0: ; 0x1940e0
	faceplayer
	loadfont
	checkbit1 $002a
	iftrue UnknownScript_0x1940ee
	2writetext UnknownText_0x194626
	closetext
	loadmovesprites
	end
; 0x1940ee

UnknownScript_0x1940ee: ; 0x1940ee
	2writetext UnknownText_0x19469e
	closetext
	loadmovesprites
	end
; 0x1940f4

TrainerSchoolboyAlan1: ; 0x1940f4
	; bit/flag number
	dw $46e

	; trainer group && trainer id
	db SCHOOLBOY, ALAN1

	; text when seen
	dw SchoolboyAlan1SeenText

	; text when trainer beaten
	dw SchoolboyAlan1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyAlan1Script
; 0x194100

SchoolboyAlan1Script: ; 0x194100
	writecode $17, $18
	talkaftercancel
	loadfont
	checkbit2 $0073
	iftrue UnknownScript_0x194140
	checkbit2 $0081
	iftrue UnknownScript_0x1941b4
	checkcellnum $18
	iftrue UnknownScript_0x1941d5
	checkbit1 $0285
	iftrue UnknownScript_0x194129
	2writetext UnknownText_0x1947aa
	keeptextopen
	setbit1 $0285
	2call UnknownScript_0x1941c9
	2jump UnknownScript_0x19412c
; 0x194129

UnknownScript_0x194129: ; 0x194129
	2call UnknownScript_0x1941cd
UnknownScript_0x19412c: ; 0x19412c
	askforphonenumber $18
	if_equal $1, UnknownScript_0x1941dd
	if_equal $2, UnknownScript_0x1941d9
	trainertotext SCHOOLBOY, ALAN1, $0
	2call UnknownScript_0x1941d1
	2jump UnknownScript_0x1941d5
; 0x194140

UnknownScript_0x194140: ; 0x194140
	2call UnknownScript_0x1941e1
	winlosstext SchoolboyAlan1BeatenText, $0000
	copybytetovar $da02
	if_equal $4, UnknownScript_0x19415f
	if_equal $3, UnknownScript_0x194165
	if_equal $2, UnknownScript_0x19416b
	if_equal $1, UnknownScript_0x194171
	if_equal $0, UnknownScript_0x194177
UnknownScript_0x19415f: ; 0x19415f
	checkbit1 $00cd
	iftrue UnknownScript_0x1941ab
UnknownScript_0x194165: ; 0x194165
	checkbit1 $0044
	iftrue UnknownScript_0x19419e
UnknownScript_0x19416b: ; 0x19416b
	checkbit2 $004b
	iftrue UnknownScript_0x194191
UnknownScript_0x194171: ; 0x194171
	checkbit2 $0047
	iftrue UnknownScript_0x194184
UnknownScript_0x194177: ; 0x194177
	loadtrainer SCHOOLBOY, ALAN1
	startbattle
	returnafterbattle
	loadvar $da02, $1
	clearbit2 $0073
	end
; 0x194184

UnknownScript_0x194184: ; 0x194184
	loadtrainer SCHOOLBOY, ALAN2
	startbattle
	returnafterbattle
	loadvar $da02, $2
	clearbit2 $0073
	end
; 0x194191

UnknownScript_0x194191: ; 0x194191
	loadtrainer SCHOOLBOY, ALAN3
	startbattle
	returnafterbattle
	loadvar $da02, $3
	clearbit2 $0073
	end
; 0x19419e

UnknownScript_0x19419e: ; 0x19419e
	loadtrainer SCHOOLBOY, ALAN4
	startbattle
	returnafterbattle
	loadvar $da02, $4
	clearbit2 $0073
	end
; 0x1941ab

UnknownScript_0x1941ab: ; 0x1941ab
	loadtrainer SCHOOLBOY, ALAN5
	startbattle
	returnafterbattle
	clearbit2 $0073
	end
; 0x1941b4

UnknownScript_0x1941b4: ; 0x1941b4
	2call UnknownScript_0x1941e5
	verbosegiveitem FIRE_STONE, 1
	iffalse UnknownScript_0x1941c6
	clearbit2 $0081
	setbit1 $0101
	2jump UnknownScript_0x1941d5
; 0x1941c6

UnknownScript_0x1941c6: ; 0x1941c6
	2jump UnknownScript_0x1941e9
; 0x1941c9

UnknownScript_0x1941c9: ; 0x1941c9
	jumpstd $0019
	end
; 0x1941cd

UnknownScript_0x1941cd: ; 0x1941cd
	jumpstd $001a
	end
; 0x1941d1

UnknownScript_0x1941d1: ; 0x1941d1
	jumpstd $001b
	end
; 0x1941d5

UnknownScript_0x1941d5: ; 0x1941d5
	jumpstd $001c
	end
; 0x1941d9

UnknownScript_0x1941d9: ; 0x1941d9
	jumpstd $001d
	end
; 0x1941dd

UnknownScript_0x1941dd: ; 0x1941dd
	jumpstd $001e
	end
; 0x1941e1

UnknownScript_0x1941e1: ; 0x1941e1
	jumpstd $001f
	end
; 0x1941e5

UnknownScript_0x1941e5: ; 0x1941e5
	jumpstd $0020
	end
; 0x1941e9

UnknownScript_0x1941e9: ; 0x1941e9
	jumpstd $0021
	end
; 0x1941ed

TrainerPsychicMark: ; 0x1941ed
	; bit/flag number
	dw $440

	; trainer group && trainer id
	db PSYCHIC_T, MARK

	; text when seen
	dw PsychicMarkSeenText

	; text when trainer beaten
	dw PsychicMarkBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicMarkScript
; 0x1941f9

PsychicMarkScript: ; 0x1941f9
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19471e
	closetext
	loadmovesprites
	end
; 0x194201

UnknownScript_0x194201: ; 0x194201
	faceplayer
	loadfont
	checkbit1 $0067
	iftrue UnknownScript_0x19422f
	checkcode $b
	if_not_equal THURSDAY, UnknownScript_0x194235
	checkbit1 $0066
	iftrue UnknownScript_0x19421c
	2writetext UnknownText_0x194800
	keeptextopen
	setbit1 $0066
UnknownScript_0x19421c: ; 0x19421c
	2writetext UnknownText_0x19482d
	keeptextopen
	verbosegiveitem HARD_STONE, 1
	iffalse UnknownScript_0x194233
	setbit1 $0067
	2writetext UnknownText_0x194847
	closetext
	loadmovesprites
	end
; 0x19422f

UnknownScript_0x19422f: ; 0x19422f
	2writetext UnknownText_0x1948aa
	closetext
UnknownScript_0x194233: ; 0x194233
	loadmovesprites
	end
; 0x194235

UnknownScript_0x194235: ; 0x194235
	2writetext UnknownText_0x1948f3
	closetext
	loadmovesprites
	end
; 0x19423b

MapRoute36Signpost2Script: ; 0x19423b
	jumptext UnknownText_0x194924
; 0x19423e

MapRoute36Signpost1Script: ; 0x19423e
	jumptext UnknownText_0x19492e
; 0x194241

MapRoute36Signpost3Script: ; 0x194241
	jumptext UnknownText_0x19494c
; 0x194244

MapRoute36Signpost0Script: ; 0x194244
	jumptext UnknownText_0x1949ee
; 0x194247

UnknownScript_0x194247: ; 0x194247
	fruittree $d
; 0x194249

MovementData_0x194249: ; 0x194249
	db $56 ; movement
	step_end
; 0x19424b

MovementData_0x19424b: ; 0x19424b
	fast_jump_step_up
	fast_jump_step_up
	step_end
; 0x19424e

MovementData_0x19424e: ; 0x19424e
	step_down
	step_down
	step_down
	step_left
	step_left
	step_left
	step_left
	step_left
	step_left
	step_end
; 0x194258

MovementData_0x194258: ; 0x194258
	step_left
	step_down
	step_down
	step_down
	step_left
	step_left
	step_left
	step_left
	step_left
	step_end
; 0x194262

MovementData_0x194262: ; 0x194262
	db $39 ; movement
	fast_jump_step_down
	fast_jump_step_down
	fast_jump_step_down
	fast_jump_step_right
	fast_jump_step_right
	fast_jump_step_right
	db $38 ; movement
	step_end
; 0x19426b

UnknownText_0x19426b: ; 0x19426b
	db $0, "It's a weird tree.", $4f
	db "Use SQUIRTBOTTLE?", $57
; 0x194290

UnknownText_0x194290: ; 0x194290
	db $0, $52, " used the", $4f
	db "SQUIRTBOTTLE.", $57
; 0x1942aa

UnknownText_0x1942aa: ; 0x1942aa
	db $0, "The weird tree", $4f
	db "doesn't like the", $55
	db "SQUIRTBOTTLE!", $51
	db "The weird tree", $4f
	db "attacked!", $57
; 0x1942f1

UnknownText_0x1942f1: ; 0x1942f1
	db $0, "I'm the FLOWER", $4f
	db "SHOP's FLORIA!", $51
	db "Listen, listen!", $51
	db "When I sprinkled", $4f
	db "water on that", $51
	db "wiggly tree, it", $4f
	db "jumped right up!", $51
	db "It just has to be", $4f
	db "a #MON.", $51
	db "I bet it would be", $4f
	db "shocked out of its", $51
	db "disguise if you", $4f
	db "soaked it!", $51
	db "I know! I'll tell", $4f
	db "my sis and borrow", $55
	db "her water bottle!", $57
; 0x1943ed

UnknownText_0x1943ed: ; 0x1943ed
	db $0, "When I told my sis", $4f
	db "about the jiggly", $51
	db "tree, she said", $4f
	db "it's dangerous.", $51
	db "If I beat WHITNEY,", $4f
	db "I wonder if she'll", $51
	db "lend me her water", $4f
	db "bottle…", $57
; 0x19446f

UnknownText_0x19446f: ; 0x19446f
	db $0, "Wa-hey!", $51
	db "I was going to", $4f
	db "snap that tree", $51
	db "with my straight-", $4f
	db "arm punch.", $51
	db "But I couldn't!", $4f
	db "I'm a failure!", $57
; 0x1944d0

UnknownText_0x1944d0: ; 0x1944d0
	db $0, "Did you clear that", $4f
	db "wretched tree?", $51
	db "I'm impressed!", $4f
	db "I want you to", $55
	db "have this.", $57
; 0x19451a

UnknownText_0x19451a: ; 0x19451a
	db $0, $52, " received", $4f
	db "TM08.", $57
; 0x19452c

UnknownText_0x19452c: ; 0x19452c
	db $0, "That happens to be", $4f
	db "ROCK SMASH.", $51
	db "You can shatter", $4f
	db "rocks with just a", $51
	db "single well-aimed", $4f
	db "smack.", $51
	db "If any rocks are", $4f
	db "in your way, just", $55
	db "smash 'em up!", $57
; 0x1945b8

UnknownText_0x1945b8: ; 0x1945b8
	db $0, "An odd tree is", $4f
	db "blocking the way", $55
	db "to GOLDENROD CITY.", $51
	db "I wanted to go see", $4f
	db "the huge #MON", $51
	db "CENTER they just", $4f
	db "opened…", $57
; 0x194626

UnknownText_0x194626: ; 0x194626
	db $0, "An odd tree is", $4f
	db "blocking the way", $55
	db "to GOLDENROD CITY.", $51
	db "It's preventing", $4f
	db "me from shopping.", $51
	db "Something should", $4f
	db "be done about it.", $57
; 0x19469e

UnknownText_0x19469e: ; 0x19469e
	db $0, "That odd tree dis-", $4f
	db "appeared without a", $55
	db "trace.", $51
	db "Oh! That tree was", $4f
	db "really a #MON?", $57
; 0x1946ed

PsychicMarkSeenText: ; 0x1946ed
	db $0, "I'm going to read", $4f
	db "your thoughts!", $57
; 0x19470e

PsychicMarkBeatenText: ; 0x19470e
	db $0, "I misread you!", $57
; 0x19471e

UnknownText_0x19471e: ; 0x19471e
	db $0, "I'd be strong if", $4f
	db "only I could tell", $51
	db "what my opponent", $4f
	db "was thinking.", $57
; 0x194760

SchoolboyAlan1SeenText: ; 0x194760
	db $0, "Thanks to my stud-", $4f
	db "ies, I'm ready for", $55
	db "any #MON!", $57
; 0x194790

SchoolboyAlan1BeatenText: ; 0x194790
	db $0, "Oops! Computation", $4f
	db "error?", $57
; 0x1947aa

UnknownText_0x1947aa: ; 0x1947aa
	db $0, "Darn. I study five", $4f
	db "hours a day too.", $51
	db "There's more to", $4f
	db "learning than just", $55
	db "reading books.", $57
; 0x194800

UnknownText_0x194800: ; 0x194800
	db $0, "ARTHUR: Who are", $4f
	db "you?", $51
	db "I'm ARTHUR of", $4f
	db "Thursday.", $57
; 0x19482d

UnknownText_0x19482d: ; 0x19482d
	db $0, "Here. You can have", $4f
	db "this.", $57
; 0x194847

UnknownText_0x194847: ; 0x194847
	db $0, "ARTHUR: A #MON", $4f
	db "that uses rock-", $51
	db "type moves should", $4f
	db "hold on to that.", $51
	db "It pumps up rock-", $4f
	db "type attacks.", $57
; 0x1948aa

UnknownText_0x1948aa: ; 0x1948aa
	db $0, "ARTHUR: I'm ARTHUR", $4f
	db "of Thursday. I'm", $51
	db "the second son out", $4f
	db "of seven children.", $57
; 0x1948f3

UnknownText_0x1948f3: ; 0x1948f3
	db $0, "ARTHUR: Today's", $4f
	db "not Thursday. How", $55
	db "disappointing.", $57
; 0x194924

UnknownText_0x194924: ; 0x194924
	db $0, "ROUTE 36", $57
; 0x19492e

UnknownText_0x19492e: ; 0x19492e
	db $0, "RUINS OF ALPH", $4f
	db "NORTH ENTRANCE", $57
; 0x19494c

UnknownText_0x19494c: ; 0x19494c
	db $0, "TRAINER TIPS", $51
	db "#MON stats", $4f
	db "vary--even within", $55
	db "the same species.", $51
	db "Their stats may be", $4f
	db "similar at first.", $51
	db "However, differ-", $4f
	db "ences will become", $51
	db "pronounced as the", $4f
	db "#MON grow.", $57
; 0x1949ee

UnknownText_0x1949ee: ; 0x1949ee
	db $0, "TRAINER TIPS", $51
	db "Use DIG to return", $4f
	db "to the entrance of", $55
	db "any place.", $51
	db "It is convenient", $4f
	db "for exploring", $51
	db "caves and other", $4f
	db "landmarks.", $57
; 0x194a66

Route36_MapEventHeader: ; 0x194a66
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $8, $12, 3, GROUP_ROUTE_36_NATIONAL_PARK_GATE, MAP_ROUTE_36_NATIONAL_PARK_GATE
	warp_def $9, $12, 4, GROUP_ROUTE_36_NATIONAL_PARK_GATE, MAP_ROUTE_36_NATIONAL_PARK_GATE
	warp_def $d, $2f, 1, GROUP_ROUTE_36_RUINS_OF_ALPH_GATE, MAP_ROUTE_36_RUINS_OF_ALPH_GATE
	warp_def $d, $30, 2, GROUP_ROUTE_36_RUINS_OF_ALPH_GATE, MAP_ROUTE_36_RUINS_OF_ALPH_GATE

	; xy triggers
	db 2
	xy_trigger 1, $7, $14, $0, UnknownScript_0x19401b, $0, $0
	xy_trigger 1, $7, $16, $0, UnknownScript_0x19401b, $0, $0

	; signposts
	db 4
	signpost 1, 29, $0, MapRoute36Signpost0Script
	signpost 11, 45, $0, MapRoute36Signpost1Script
	signpost 7, 55, $0, MapRoute36Signpost2Script
	signpost 7, 21, $0, MapRoute36Signpost3Script

	; people-events
	db 9
	person_event $27, 17, 24, $9, $0, 255, 255, $92, 3, TrainerPsychicMark, $ffff
	person_event $27, 18, 35, $8, $0, 255, 255, $92, 5, TrainerSchoolboyAlan1, $ffff
	person_event $f4, 13, 39, $17, $0, 255, 255, $0, 0, UnknownScript_0x19403c, $06f8
	person_event $28, 12, 55, $5, $2, 255, 255, $0, 0, UnknownScript_0x1940e0, $ffff
	person_event $3a, 13, 48, $8, $0, 255, 255, $0, 0, UnknownScript_0x1940b9, $ffff
	person_event $5d, 8, 25, $1, $0, 255, 255, $0, 0, UnknownScript_0x194247, $ffff
	person_event $27, 10, 50, $2, $11, 255, 255, $0, 0, UnknownScript_0x194201, $075a
	person_event $28, 16, 37, $6, $0, 255, 255, $90, 0, UnknownScript_0x19408c, $0769
	person_event $63, 10, 25, $1, $0, 255, 255, $90, 0, ObjectEvent, $07b0
; 0x194b19

FuchsiaCity_MapScriptHeader: ; 0x194b19
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x194b1e
; 0x194b1e

UnknownScript_0x194b1e: ; 0x194b1e
	setbit2 $003e
	return
; 0x194b22

UnknownScript_0x194b22: ; 0x194b22
	jumptextfaceplayer UnknownText_0x194b45
; 0x194b25

UnknownScript_0x194b25: ; 0x194b25
	jumptextfaceplayer UnknownText_0x194b83
; 0x194b28

UnknownScript_0x194b28: ; 0x194b28
	jumptextfaceplayer UnknownText_0x194bd3
; 0x194b2b

MapFuchsiaCitySignpost0Script: ; 0x194b2b
	jumptext UnknownText_0x194c22
; 0x194b2e

MapFuchsiaCitySignpost1Script: ; 0x194b2e
	jumptext UnknownText_0x194c4a
; 0x194b31

MapFuchsiaCitySignpost2Script: ; 0x194b31
	jumptext UnknownText_0x194c8b
; 0x194b34

MapFuchsiaCitySignpost3Script: ; 0x194b34
	jumptext UnknownText_0x194cd5
; 0x194b37

MapFuchsiaCitySignpost4Script: ; 0x194b37
	jumptext UnknownText_0x194cf0
; 0x194b3a

MapFuchsiaCitySignpost5Script: ; 0x194b3a
	jumptext UnknownText_0x194d37
; 0x194b3d

MapFuchsiaCitySignpost6Script: ; 0x194b3d
	jumpstd $0010
; 0x194b40

MapFuchsiaCitySignpost7Script: ; 0x194b40
	jumpstd $0011
; 0x194b43

UnknownScript_0x194b43: ; 0x194b43
	fruittree $1e
; 0x194b45

UnknownText_0x194b45: ; 0x194b45
	db $0, "One of the ELITE", $4f
	db "FOUR used to be", $51
	db "the LEADER of", $4f
	db "FUCHSIA's GYM.", $57
; 0x194b83

UnknownText_0x194b83: ; 0x194b83
	db $0, "KOGA's daughter", $4f
	db "succeeded him as", $51
	db "the GYM LEADER", $4f
	db "after he joined", $55
	db "the ELITE FOUR.", $57
; 0x194bd3

UnknownText_0x194bd3: ; 0x194bd3
	db $0, "The SAFARI ZONE is", $4f
	db "closed… It's sad,", $51
	db "considering it's", $4f
	db "FUCHSIA's main", $55
	db "attraction.", $57
; 0x194c22

UnknownText_0x194c22: ; 0x194c22
	db $0, "FUCHSIA CITY", $51
	db "Behold! It's", $4f
	db "Passion Pink!", $57
; 0x194c4a

UnknownText_0x194c4a: ; 0x194c4a
	db $0, "FUCHSIA CITY", $4f
	db "#MON GYM", $55
	db "LEADER: JANINE", $51
	db "The Poisonous", $4f
	db "Ninja Master", $57
; 0x194c8b

UnknownText_0x194c8b: ; 0x194c8b
	db $0, "There's a notice", $4f
	db "here…", $51
	db "SAFARI ZONE OFFICE", $4f
	db "is closed until", $55
	db "further notice.", $57
; 0x194cd5

UnknownText_0x194cd5: ; 0x194cd5
	db $0, "SAFARI ZONE", $4f
	db "WARDEN'S HOME", $57
; 0x194cf0

UnknownText_0x194cf0: ; 0x194cf0
	db $0, "The WARDEN is", $4f
	db "traveling abroad.", $51
	db "Therefore, the", $4f
	db "SAFARI ZONE is", $55
	db "closed.", $57
; 0x194d37

UnknownText_0x194d37: ; 0x194d37
	db $0, "No littering.", $51
	db "Please take your", $4f
	db "waste with you.", $57
; 0x194d67

FuchsiaCity_MapEventHeader: ; 0x194d67
	; filler
	db 0, 0

	; warps
	db 11
	warp_def $d, $5, 2, GROUP_FUCHSIA_MART, MAP_FUCHSIA_MART
	warp_def $d, $16, 1, GROUP_SAFARI_ZONE_MAIN_OFFICE, MAP_SAFARI_ZONE_MAIN_OFFICE
	warp_def $1b, $8, 1, GROUP_FUCHSIA_GYM, MAP_FUCHSIA_GYM
	warp_def $1b, $b, 1, GROUP_FUCHSIA_BILL_SPEECH_HOUSE, MAP_FUCHSIA_BILL_SPEECH_HOUSE
	warp_def $1b, $13, 1, GROUP_FUCHSIA_POKECENTER_1F, MAP_FUCHSIA_POKECENTER_1F
	warp_def $1b, $1b, 1, GROUP_SAFARI_ZONE_WARDENS_HOME, MAP_SAFARI_ZONE_WARDENS_HOME
	warp_def $3, $12, 3, GROUP_SAFARI_ZONE_FUCHSIA_GATE_BETA, MAP_SAFARI_ZONE_FUCHSIA_GATE_BETA
	warp_def $16, $25, 1, GROUP_ROUTE_15_FUCHSIA_GATE, MAP_ROUTE_15_FUCHSIA_GATE
	warp_def $17, $25, 2, GROUP_ROUTE_15_FUCHSIA_GATE, MAP_ROUTE_15_FUCHSIA_GATE
	warp_def $23, $7, 1, GROUP_ROUTE_19___FUCHSIA_GATE, MAP_ROUTE_19___FUCHSIA_GATE
	warp_def $23, $8, 2, GROUP_ROUTE_19___FUCHSIA_GATE, MAP_ROUTE_19___FUCHSIA_GATE

	; xy triggers
	db 0

	; signposts
	db 8
	signpost 15, 21, $0, MapFuchsiaCitySignpost0Script
	signpost 29, 5, $0, MapFuchsiaCitySignpost1Script
	signpost 15, 25, $0, MapFuchsiaCitySignpost2Script
	signpost 29, 27, $0, MapFuchsiaCitySignpost3Script
	signpost 5, 17, $0, MapFuchsiaCitySignpost4Script
	signpost 15, 13, $0, MapFuchsiaCitySignpost5Script
	signpost 27, 20, $0, MapFuchsiaCitySignpost6Script
	signpost 13, 6, $0, MapFuchsiaCitySignpost7Script

	; people-events
	db 4
	person_event $27, 22, 27, $2, $11, 255, 255, $a0, 0, UnknownScript_0x194b22, $ffff
	person_event $2d, 12, 17, $2, $11, 255, 255, $b0, 0, UnknownScript_0x194b25, $ffff
	person_event $29, 18, 20, $2, $11, 255, 255, $80, 0, UnknownScript_0x194b28, $ffff
	person_event $5d, 5, 12, $1, $0, 255, 255, $0, 0, UnknownScript_0x194b43, $ffff
; 0x194e00

BlackthornGym1F_MapScriptHeader: ; 0x194e00
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x194e05
; 0x194e05

UnknownScript_0x194e05: ; 0x194e05
	checkbit1 $0706
	iffalse UnknownScript_0x194e0f
	changeblock $8, $2, $3b
UnknownScript_0x194e0f: ; 0x194e0f
	checkbit1 $0707
	iffalse UnknownScript_0x194e19
	changeblock $2, $4, $3a
UnknownScript_0x194e19: ; 0x194e19
	checkbit1 $0708
	iffalse UnknownScript_0x194e23
	changeblock $8, $6, $3b
UnknownScript_0x194e23: ; 0x194e23
	return
; 0x194e24

UnknownScript_0x194e24: ; 0x194e24
	faceplayer
	loadfont
	checkbit2 $0022
	iftrue UnknownScript_0x194e69
	checkbit1 $04c4
	iftrue UnknownScript_0x194e63
	2writetext UnknownText_0x194efa
	closetext
	loadmovesprites
	winlosstext UnknownText_0x194fd6, $0000
	loadtrainer CLAIR, 1
	startbattle
	returnafterbattle
	setbit1 $04c4
	loadfont
	2writetext UnknownText_0x19500e
	closetext
	loadmovesprites
	setbit1 $054a
	setbit1 $054b
	setbit1 $054c
	setbit1 $055d
	setbit1 $055e
	clearbit1 $0736
	setbit1 $074c
	clearbit1 $074d
	end
; 0x194e63

UnknownScript_0x194e63: ; 0x194e63
	2writetext UnknownText_0x195162
	closetext
	loadmovesprites
	end
; 0x194e69

UnknownScript_0x194e69: ; 0x194e69
	checkbit1 $000f
	iftrue UnknownScript_0x194e94
	2writetext UnknownText_0x195196
	keeptextopen
	giveitem TM_24, $1
	iffalse UnknownScript_0x194e8e
	itemtotext TM_24, $0
	2writetext UnknownText_0x1951bf
	playsound $0001
	waitbutton
	itemnotify
	setbit1 $000f
	2writetext UnknownText_0x1951d1
	keeptextopen
	2jump UnknownScript_0x194e94
; 0x194e8e

UnknownScript_0x194e8e: ; 0x194e8e
	2writetext UnknownText_0x19524f
	closetext
	loadmovesprites
	end
; 0x194e94

UnknownScript_0x194e94: ; 0x194e94
	2writetext UnknownText_0x195272
	closetext
	loadmovesprites
	end
; 0x194e9a

TrainerCooltrainermPaul: ; 0x194e9a
	; bit/flag number
	dw $54a

	; trainer group && trainer id
	db COOLTRAINERM, PAUL

	; text when seen
	dw CooltrainermPaulSeenText

	; text when trainer beaten
	dw CooltrainermPaulBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermPaulScript
; 0x194ea6

CooltrainermPaulScript: ; 0x194ea6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1953f1
	closetext
	loadmovesprites
	end
; 0x194eae

TrainerCooltrainermMike: ; 0x194eae
	; bit/flag number
	dw $54c

	; trainer group && trainer id
	db COOLTRAINERM, MIKE

	; text when seen
	dw CooltrainermMikeSeenText

	; text when trainer beaten
	dw CooltrainermMikeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermMikeScript
; 0x194eba

CooltrainermMikeScript: ; 0x194eba
	talkaftercancel
	loadfont
	2writetext UnknownText_0x195467
	closetext
	loadmovesprites
	end
; 0x194ec2

TrainerCooltrainerfLola: ; 0x194ec2
	; bit/flag number
	dw $55e

	; trainer group && trainer id
	db COOLTRAINERF, LOLA

	; text when seen
	dw CooltrainerfLolaSeenText

	; text when trainer beaten
	dw CooltrainerfLolaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfLolaScript
; 0x194ece

CooltrainerfLolaScript: ; 0x194ece
	talkaftercancel
	loadfont
	2writetext UnknownText_0x195516
	closetext
	loadmovesprites
	end
; 0x194ed6

BlackthornGymGuyScript: ; 0x194ed6
	faceplayer
	loadfont
	checkbit1 $04c4
	iftrue .BlackthornGymGuyWinScript
	2writetext BlackthornGymGuyText
	closetext
	loadmovesprites
	end

.BlackthornGymGuyWinScript
	2writetext BlackthornGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x194eea

MapBlackthornGym1FSignpost1Script: ; 0x194eea
	checkbit2 $0022
	iftrue UnknownScript_0x194ef3
	jumpstd $002d
; 0x194ef3

UnknownScript_0x194ef3: ; 0x194ef3
	trainertotext CLAIR, 1, $1
	jumpstd $002e
; 0x194efa

UnknownText_0x194efa: ; 0x194efa
	db $0, "I am CLAIR.", $51
	db "The world's best", $4f
	db "dragon master.", $51
	db "I can hold my own", $4f
	db "against even the", $51
	db "#MON LEAGUE's", $4f
	db "ELITE FOUR.", $51
	db "Do you still want", $4f
	db "to take me on?", $51
	db "…Fine.", $4f
	db "Let's do it!", $51
	db "As a GYM LEADER,", $4f
	db "I will use my full", $51
	db "power against any", $4f
	db "opponent!", $57
; 0x194fd6

UnknownText_0x194fd6: ; 0x194fd6
	db $0, "I lost?", $51
	db "I don't believe", $4f
	db "it. There must be", $55
	db "some mistake…", $57
; 0x19500e

UnknownText_0x19500e: ; 0x19500e
	db $0, "I won't admit", $4f
	db "this.", $51
	db "I may have lost,", $4f
	db "but you're still", $51
	db "not ready for the", $4f
	db "#MON LEAGUE.", $51
	db "I know. You should", $4f
	db "take the dragon", $55
	db "user challenge.", $51
	db "Behind this GYM is", $4f
	db "a place called", $55
	db "DRAGON'S DEN.", $51
	db "There is a small", $4f
	db "shrine at its", $51
	db "center.", $4f
	db "Go there.", $51
	db "If you can prove", $4f
	db "that you've lost", $51
	db "your lazy ideals,", $4f
	db "I will recognize", $51
	db "you as a trainer", $4f
	db "worthy of a GYM", $55
	db "BADGE!", $57
; 0x195162

UnknownText_0x195162: ; 0x195162
	db $0, "What's the matter?", $51
	db "Is it too much to", $4f
	db "expect of you?", $57
; 0x195196

UnknownText_0x195196: ; 0x195196
	db $0, "You've kept me", $4f
	db "waiting!", $51
	db "Here! Take this!", $57
; 0x1951bf

UnknownText_0x1951bf: ; 0x1951bf
	db $0, $52, " received", $4f
	db "TM24.", $57
; 0x1951d1

UnknownText_0x1951d1: ; 0x1951d1
	db $0, "That contains", $4f
	db "DRAGONBREATH.", $51
	db "No, it doesn't", $4f
	db "have anything to", $55
	db "do with my breath.", $51
	db "If you don't want", $4f
	db "it, you don't have", $55
	db "to take it.", $57
; 0x19524f

UnknownText_0x19524f: ; 0x19524f
	db $0, "What is this? You", $4f
	db "don't have room?", $57
; 0x195272

UnknownText_0x195272: ; 0x195272
	db $0, "What's the matter?", $51
	db "Aren't you headed", $4f
	db "to the #MON", $55
	db "LEAGUE?", $51
	db "Don't you know", $4f
	db "where it is?", $51
	db "From here, go to", $4f
	db "NEW BARK TOWN.", $51
	db "Then SURF east.", $4f
	db "The route there is", $55
	db "very tough.", $51
	db "Don't you dare", $4f
	db "lose at the #-", $55
	db "MON LEAGUE!", $51
	db "If you do, I'll", $4f
	db "feel even worse", $51
	db "about having lost", $4f
	db "to you!", $51
	db "Give it every-", $4f
	db "thing you've got.", $57
; 0x195396

CooltrainermPaulSeenText: ; 0x195396
	db $0, "Your first battle", $4f
	db "against dragons?", $51
	db "I'll show you how", $4f
	db "tough they are!", $57
; 0x1953db

CooltrainermPaulBeatenText: ; 0x1953db
	db $0, "My dragon #MON", $4f
	db "lost?", $57
; 0x1953f1

UnknownText_0x1953f1: ; 0x1953f1
	db $0, "LANCE told you", $4f
	db "that he'd like to", $51
	db "see you again?", $4f
	db "Not a chance!", $57
; 0x19542f

CooltrainermMikeSeenText: ; 0x19542f
	db $0, "My chance of", $4f
	db "losing? Not even", $55
	db "one percent!", $57
; 0x19545b

CooltrainermMikeBeatenText: ; 0x19545b
	db $0, "That's odd.", $57
; 0x195467

UnknownText_0x195467: ; 0x195467
	db $0, "I know my short-", $4f
	db "comings now.", $51
	db "Thanks for showing", $4f
	db "me!", $57
; 0x19549d

CooltrainerfLolaSeenText: ; 0x19549d
	db $0, "Dragons are sacred", $4f
	db "#MON.", $51
	db "They are full of", $4f
	db "life energy.", $51
	db "If you're not", $4f
	db "serious, you won't", $51
	db "be able to beat", $4f
	db "them.", $57
; 0x19550a

CooltrainerfLolaBeatenText: ; 0x19550a
	db $0, "Way to go!", $57
; 0x195516

UnknownText_0x195516: ; 0x195516
	db $0, "Dragons are weak", $4f
	db "against dragon-", $55
	db "type moves.", $57
; 0x195544

BlackthornGymGuyText: ; 0x195544
	db $0, "Yo! CHAMP in", $4f
	db "making!", $51
	db "It's been a long", $4f
	db "journey, but we", $51
	db "are almost done!", $4f
	db "Count on me!", $51
	db "CLAIR uses the", $4f
	db "mythical and sac-", $55
	db "red dragon-type", $55
	db "#MON.", $51
	db "You can't damage", $4f
	db "them very easily.", $51
	db "But you know,", $4f
	db "they're supposed", $51
	db "to be weak against", $4f
	db "ice-type moves.", $57
; 0x195632

BlackthornGymGuyWinText: ; 0x195632
	db $0, "You were great to", $4f
	db "beat CLAIR!", $51
	db "All that's left is", $4f
	db "the #MON LEAGUE", $55
	db "challenge.", $51
	db "You're on the way", $4f
	db "to becoming the", $55
	db "#MON CHAMPION!", $57
; 0x1956ae

BlackthornGym1F_MapEventHeader: ; 0x1956ae
	; filler
	db 0, 0

	; warps
	db 7
	warp_def $11, $4, 1, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $11, $5, 1, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $7, $1, 1, GROUP_BLACKTHORN_GYM_2F, MAP_BLACKTHORN_GYM_2F
	warp_def $9, $7, 2, GROUP_BLACKTHORN_GYM_2F, MAP_BLACKTHORN_GYM_2F
	warp_def $6, $2, 3, GROUP_BLACKTHORN_GYM_2F, MAP_BLACKTHORN_GYM_2F
	warp_def $7, $7, 4, GROUP_BLACKTHORN_GYM_2F, MAP_BLACKTHORN_GYM_2F
	warp_def $6, $7, 5, GROUP_BLACKTHORN_GYM_2F, MAP_BLACKTHORN_GYM_2F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 15, 3, $0, MapBlackthornGym1FSignpost1Script
	signpost 15, 6, $0, MapBlackthornGym1FSignpost1Script

	; people-events
	db 5
	person_event $19, 7, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x194e24, $ffff
	person_event $23, 10, 10, $6, $0, 255, 255, $82, 3, TrainerCooltrainermMike, $ffff
	person_event $23, 18, 5, $6, $0, 255, 255, $82, 3, TrainerCooltrainermPaul, $ffff
	person_event $24, 6, 13, $6, $0, 255, 255, $82, 1, TrainerCooltrainerfLola, $ffff
	person_event $48, 19, 11, $6, $0, 255, 255, $80, 0, BlackthornGymGuyScript, $ffff
; 0x195722

BlackthornGym2F_MapScriptHeader: ; 0x195722
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 3, UnknownScript_0x195727
; 0x195727

UnknownScript_0x195727: ; 0x195727
	writecmdqueue $572b
	return
; 0x19572b

INCBIN "baserom.gbc",$19572b,$33

UnknownScript_0x19575e: ; 0x19575e
	jumpstd $000e
; 0x195761

TrainerCooltrainermCody: ; 0x195761
	; bit/flag number
	dw $54b

	; trainer group && trainer id
	db COOLTRAINERM, CODY

	; text when seen
	dw CooltrainermCodySeenText

	; text when trainer beaten
	dw CooltrainermCodyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermCodyScript
; 0x19576d

CooltrainermCodyScript: ; 0x19576d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1957d5
	closetext
	loadmovesprites
	end
; 0x195775

TrainerCooltrainerfFran: ; 0x195775
	; bit/flag number
	dw $55d

	; trainer group && trainer id
	db COOLTRAINERF, FRAN

	; text when seen
	dw CooltrainerfFranSeenText

	; text when trainer beaten
	dw CooltrainerfFranBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfFranScript
; 0x195781

CooltrainerfFranScript: ; 0x195781
	talkaftercancel
	loadfont
	2writetext UnknownText_0x195883
	closetext
	loadmovesprites
	end
; 0x195789

CooltrainermCodySeenText: ; 0x195789
	db $0, "It's not as if we", $4f
	db "all use dragon-", $55
	db "type #MON.", $57
; 0x1957b6

CooltrainermCodyBeatenText: ; 0x1957b6
	db $0, "Rats! If only I", $4f
	db "had a dragon!", $57
; 0x1957d5

UnknownText_0x1957d5: ; 0x1957d5
	db $0, "Members of our", $4f
	db "dragon-user clan", $51
	db "can use dragon", $4f
	db "#MON only after", $51
	db "our MASTER allows", $4f
	db "it.", $57
; 0x19582b

CooltrainerfFranSeenText: ; 0x19582b
	db $0, "I can't allow a", $4f
	db "nameless trainer", $55
	db "past me!", $51
	db "CLAIR would be", $4f
	db "livid if I did!", $57
; 0x195874

CooltrainerfFranBeatenText: ; 0x195874
	db $0, "Awww… I lost…", $57
; 0x195883

UnknownText_0x195883: ; 0x195883
	db $0, "Uh-oh… CLAIR is", $4f
	db "going to be mad…", $57
; 0x1958a5

UnknownText_0x1958a5: ; 0x1958a5
	db $0, "The boulder fell", $4f
	db "through!", $57
; 0x1958c0

BlackthornGym2F_MapEventHeader: ; 0x1958c0
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $7, $1, 3, GROUP_BLACKTHORN_GYM_1F, MAP_BLACKTHORN_GYM_1F
	warp_def $9, $7, 4, GROUP_BLACKTHORN_GYM_1F, MAP_BLACKTHORN_GYM_1F
	warp_def $5, $2, 5, GROUP_BLACKTHORN_GYM_1F, MAP_BLACKTHORN_GYM_1F
	warp_def $7, $8, 6, GROUP_BLACKTHORN_GYM_1F, MAP_BLACKTHORN_GYM_1F
	warp_def $3, $8, 7, GROUP_BLACKTHORN_GYM_1F, MAP_BLACKTHORN_GYM_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 8
	person_event $23, 5, 8, $9, $0, 255, 255, $82, 1, TrainerCooltrainermCody, $ffff
	person_event $24, 15, 8, $8, $0, 255, 255, $82, 1, TrainerCooltrainerfFran, $ffff
	person_event $5a, 6, 12, $19, $0, 255, 255, $0, 0, UnknownScript_0x19575e, $0706
	person_event $5a, 7, 6, $19, $0, 255, 255, $0, 0, UnknownScript_0x19575e, $0707
	person_event $5a, 20, 10, $19, $0, 255, 255, $0, 0, UnknownScript_0x19575e, $0708
	person_event $5a, 7, 7, $19, $0, 255, 255, $0, 0, UnknownScript_0x19575e, $ffff
	person_event $5a, 5, 10, $19, $0, 255, 255, $0, 0, UnknownScript_0x19575e, $ffff
	person_event $5a, 18, 12, $19, $0, 255, 255, $0, 0, UnknownScript_0x19575e, $ffff
; 0x195947

BlackthornDragonSpeechHouse_MapScriptHeader: ; 0x195947
	; trigger count
	db 0

	; callback count
	db 0
; 0x195949

UnknownScript_0x195949: ; 0x195949
	jumptextfaceplayer UnknownText_0x19595c
; 0x19594c

UnknownScript_0x19594c: ; 0x19594c
	loadfont
	2writetext UnknownText_0x1959ee
	cry DRATINI
	closetext
	loadmovesprites
	end
; 0x195956

UnknownText_0x195956: ; 0x195956
	limited_interpret_data 2
	db $0, "ズ", $03, $00

UnknownText_0x19595c: ; 0x19595c
	db $0, "A clan of trainers", $4f
	db "who can freely", $51
	db "command dragons", $4f
	db "live right here in", $55
	db "BLACKTHORN.", $51
	db "As a result, there", $4f
	db "are many legends", $51
	db "about dragons in", $4f
	db "this town.", $57
; 0x1959ee

UnknownText_0x1959ee: ; 0x1959ee
	db $0, "DRATINI: Draa!", $57
; 0x1959fe

BlackthornDragonSpeechHouse_MapEventHeader: ; 0x1959fe
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $7, $3, 2, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $30, 7, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x195949, $ffff
	person_event $96, 9, 9, $16, $0, 255, 255, $90, 0, UnknownScript_0x19594c, $ffff
; 0x195a28

BlackthornDodrioTradeHouse_MapScriptHeader: ; 0x195a28
	; trigger count
	db 0

	; callback count
	db 0
; 0x195a2a

UnknownScript_0x195a2a: ; 0x195a2a
	faceplayer
	loadfont
	trade $3
	closetext
	loadmovesprites
	end
; 0x195a31

MapBlackthornDodrioTradeHouseSignpost1Script: ; 0x195a31
	jumpstd $0003
; 0x195a34

BlackthornDodrioTradeHouse_MapEventHeader: ; 0x195a34
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $7, $3, 3, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapBlackthornDodrioTradeHouseSignpost1Script
	signpost 1, 1, $0, MapBlackthornDodrioTradeHouseSignpost1Script

	; people-events
	db 1
	person_event $28, 7, 6, $3, $0, 255, 255, $a0, 0, UnknownScript_0x195a2a, $ffff
; 0x195a5b

BlackthornMart_MapScriptHeader: ; 0x195a5b
	; trigger count
	db 0

	; callback count
	db 0
; 0x195a5d

UnknownScript_0x195a5d: ; 0x195a5d
	loadfont
	pokemart $0, $0011
	loadmovesprites
	end
; 0x195a64

UnknownScript_0x195a64: ; 0x195a64
	jumptextfaceplayer UnknownText_0x195a6a
; 0x195a67

UnknownScript_0x195a67: ; 0x195a67
	jumptextfaceplayer UnknownText_0x195ae9
; 0x195a6a

UnknownText_0x195a6a: ; 0x195a6a
	db $0, "You can't buy MAX", $4f
	db "REVIVE, but it", $51
	db "fully restores a", $4f
	db "fainted #MON.", $51
	db "Beware--it won't", $4f
	db "restore PP, the", $51
	db "POWER POINTS", $4f
	db "needed for moves.", $57
; 0x195ae9

UnknownText_0x195ae9: ; 0x195ae9
	db $0, "MAX REPEL keeps", $4f
	db "weak #MON away", $55
	db "from you.", $51
	db "It's the longest", $4f
	db "lasting of the", $55
	db "REPEL sprays.", $57
; 0x195b40

BlackthornMart_MapEventHeader: ; 0x195b40
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $7, $3, 4, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x195a5d, $ffff
	person_event $23, 10, 11, $5, $2, 255, 255, $0, 0, UnknownScript_0x195a64, $ffff
	person_event $41, 6, 9, $6, $0, 255, 255, $a0, 0, UnknownScript_0x195a67, $ffff
; 0x195b77

BlackthornPokeCenter1F_MapScriptHeader: ; 0x195b77
	; trigger count
	db 0

	; callback count
	db 0
; 0x195b79

UnknownScript_0x195b79: ; 0x195b79
	jumpstd $0000
; 0x195b7c

UnknownScript_0x195b7c: ; 0x195b7c
	jumptextfaceplayer UnknownText_0x195b85
; 0x195b7f

UnknownScript_0x195b7f: ; 0x195b7f
	jumptextfaceplayer UnknownText_0x195bfd
; 0x195b82

UnknownScript_0x195b82: ; 0x195b82
	jumpstd $0033
; 0x195b85

UnknownText_0x195b85: ; 0x195b85
	db $0, "Deep inside far-", $4f
	db "off INDIGO PLATEAU", $51
	db "is the #MON", $4f
	db "LEAGUE.", $51
	db "I hear the best", $4f
	db "trainers gather", $51
	db "there from around", $4f
	db "the country.", $57
; 0x195bfd

UnknownText_0x195bfd: ; 0x195bfd
	db $0, "There was this", $4f
	db "move I just had", $51
	db "to teach my #-", $4f
	db "MON.", $51
	db "So I got the MOVE", $4f
	db "DELETER to make it", $55
	db "forget an HM move.", $57
; 0x195c69

BlackthornPokeCenter1F_MapEventHeader: ; 0x195c69
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 5, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $7, $4, 5, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x195b79, $ffff
	person_event $40, 7, 9, $6, $0, 255, 255, $0, 0, UnknownScript_0x195b7c, $ffff
	person_event $26, 8, 5, $3, $0, 255, 255, $a0, 0, UnknownScript_0x195b7f, $ffff
	person_event $23, 10, 11, $5, $1, 255, 255, $80, 0, UnknownScript_0x195b82, $ffff
; 0x195cb2

MoveDeletersHouse_MapScriptHeader: ; 0x195cb2
	; trigger count
	db 0

	; callback count
	db 0
; 0x195cb4

UnknownScript_0x195cb4: ; 0x195cb4
	faceplayer
	loadfont
	special $0021
	closetext
	loadmovesprites
	end
; 0x195cbc

MapMoveDeletersHouseSignpost1Script: ; 0x195cbc
	jumpstd $0001
; 0x195cbf

MoveDeletersHouse_MapEventHeader: ; 0x195cbf
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 6, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY
	warp_def $7, $3, 6, GROUP_BLACKTHORN_CITY, MAP_BLACKTHORN_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapMoveDeletersHouseSignpost1Script
	signpost 1, 1, $0, MapMoveDeletersHouseSignpost1Script

	; people-events
	db 1
	person_event $2b, 7, 6, $6, $0, 255, 255, $0, 0, UnknownScript_0x195cb4, $ffff
; 0x195ce6

FuchsiaMart_MapScriptHeader: ; 0x195ce6
	; trigger count
	db 0

	; callback count
	db 0
; 0x195ce8

UnknownScript_0x195ce8: ; 0x195ce8
	loadfont
	pokemart $0, $001d
	loadmovesprites
	end
; 0x195cef

UnknownScript_0x195cef: ; 0x195cef
	jumptextfaceplayer UnknownText_0x195cf5
; 0x195cf2

UnknownScript_0x195cf2: ; 0x195cf2
	jumptextfaceplayer UnknownText_0x195d36
; 0x195cf5

UnknownText_0x195cf5: ; 0x195cf5
	db $0, "I was hoping to", $4f
	db "buy some SAFARI", $51
	db "ZONE souvenirs,", $4f
	db "but it's closed…", $57
; 0x195d36

UnknownText_0x195d36: ; 0x195d36
	db $0, "The SAFARI ZONE", $4f
	db "WARDEN's grand-", $55
	db "daughter lives in", $55
	db "town.", $57
; 0x195d6e

FuchsiaMart_MapEventHeader: ; 0x195d6e
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $7, $3, 1, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x195ce8, $ffff
	person_event $3a, 6, 7, $8, $0, 255, 255, $80, 0, UnknownScript_0x195cef, $ffff
	person_event $24, 10, 11, $5, $2, 255, 255, $a0, 0, UnknownScript_0x195cf2, $ffff
; 0x195da5

SafariZoneMainOffice_MapScriptHeader: ; 0x195da5
	; trigger count
	db 0

	; callback count
	db 0
; 0x195da7

SafariZoneMainOffice_MapEventHeader: ; 0x195da7
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $7, $3, 2, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x195db7

FuchsiaGym_MapScriptHeader: ; 0x195db7
	; trigger count
	db 0

	; callback count
	db 0
; 0x195db9

UnknownScript_0x195db9: ; 0x195db9
	checkbit2 $0027
	iftrue UnknownScript_0x195e00
	applymovement $2, MovementData_0x195f27
	faceplayer
	loadfont
	2writetext UnknownText_0x195f35
	closetext
	loadmovesprites
	winlosstext UnknownText_0x195fa1, $0000
	loadtrainer JANINE, 1
	startbattle
	returnafterbattle
	setbit1 $04c9
	setbit1 $0517
	setbit1 $051a
	setbit1 $0482
	setbit1 $041e
	variablesprite $7, $28
	variablesprite $8, $28
	variablesprite $9, $28
	variablesprite $a, $27
	special $005e
	loadfont
	2writetext UnknownText_0x195feb
	playsound $009c
	waitbutton
	setbit2 $0027
	2jump UnknownScript_0x195e02
; 0x195e00

UnknownScript_0x195e00: ; 0x195e00
	faceplayer
	loadfont
UnknownScript_0x195e02: ; 0x195e02
	checkbit1 $00dd
	iftrue UnknownScript_0x195e15
	2writetext UnknownText_0x196002
	keeptextopen
	verbosegiveitem TM_06, 1
	iffalse UnknownScript_0x195e15
	setbit1 $00dd
UnknownScript_0x195e15: ; 0x195e15
	2writetext UnknownText_0x196074
	closetext
	loadmovesprites
	end
; 0x195e1b

UnknownScript_0x195e1b: ; 0x195e1b
	checkbit1 $0517
	iftrue UnknownScript_0x195e2c
	applymovement $3, MovementData_0x195f27
	faceplayer
	variablesprite $7, $28
	special $005e
UnknownScript_0x195e2c: ; 0x195e2c
	faceplayer
	loadfont
	checkbit1 $0517
	iftrue UnknownScript_0x195e4f
	2writetext UnknownText_0x1960e6
	closetext
	loadmovesprites
	winlosstext UnknownText_0x196126, $0000
	loadtrainer LASS, ALICE
	startbattle
	iftrue UnknownScript_0x195e4a
	returnafterbattle
	setbit1 $0517
	end
; 0x195e4a

UnknownScript_0x195e4a: ; 0x195e4a
	variablesprite $7, $a
	returnafterbattle
	end
; 0x195e4f

UnknownScript_0x195e4f: ; 0x195e4f
	2writetext UnknownText_0x196139
	closetext
	loadmovesprites
	end
; 0x195e55

UnknownScript_0x195e55: ; 0x195e55
	checkbit1 $051a
	iftrue UnknownScript_0x195e66
	applymovement $4, MovementData_0x195f27
	faceplayer
	variablesprite $8, $28
	special $005e
UnknownScript_0x195e66: ; 0x195e66
	faceplayer
	loadfont
	checkbit1 $051a
	iftrue UnknownScript_0x195e89
	2writetext UnknownText_0x196166
	closetext
	loadmovesprites
	winlosstext UnknownText_0x19617b, $0000
	loadtrainer LASS, LINDA
	startbattle
	iftrue UnknownScript_0x195e84
	returnafterbattle
	setbit1 $051a
	end
; 0x195e84

UnknownScript_0x195e84: ; 0x195e84
	variablesprite $8, $a
	returnafterbattle
	end
; 0x195e89

UnknownScript_0x195e89: ; 0x195e89
	2writetext UnknownText_0x196199
	closetext
	loadmovesprites
	end
; 0x195e8f

UnknownScript_0x195e8f: ; 0x195e8f
	checkbit1 $0482
	iftrue UnknownScript_0x195ea0
	applymovement $5, MovementData_0x195f27
	faceplayer
	variablesprite $9, $28
	special $005e
UnknownScript_0x195ea0: ; 0x195ea0
	faceplayer
	loadfont
	checkbit1 $0482
	iftrue UnknownScript_0x195ec3
	2writetext UnknownText_0x1961bb
	closetext
	loadmovesprites
	winlosstext UnknownText_0x1961f1, $0000
	loadtrainer PICNICKER, CINDY
	startbattle
	iftrue UnknownScript_0x195ebe
	returnafterbattle
	setbit1 $0482
	end
; 0x195ebe

UnknownScript_0x195ebe: ; 0x195ebe
	variablesprite $9, $a
	returnafterbattle
	end
; 0x195ec3

UnknownScript_0x195ec3: ; 0x195ec3
	2writetext UnknownText_0x19620c
	closetext
	loadmovesprites
	end
; 0x195ec9

UnknownScript_0x195ec9: ; 0x195ec9
	checkbit1 $041e
	iftrue UnknownScript_0x195eda
	applymovement $6, MovementData_0x195f27
	faceplayer
	variablesprite $a, $27
	special $005e
UnknownScript_0x195eda: ; 0x195eda
	faceplayer
	loadfont
	checkbit1 $041e
	iftrue UnknownScript_0x195efd
	2writetext UnknownText_0x196228
	closetext
	loadmovesprites
	winlosstext UnknownText_0x19624a, $0000
	loadtrainer CAMPER, BARRY
	startbattle
	iftrue UnknownScript_0x195ef8
	returnafterbattle
	setbit1 $041e
	end
; 0x195ef8

UnknownScript_0x195ef8: ; 0x195ef8
	variablesprite $a, $a
	returnafterbattle
	end
; 0x195efd

UnknownScript_0x195efd: ; 0x195efd
	2writetext UnknownText_0x19626b
	closetext
	loadmovesprites
	end
; 0x195f03

FuchsiaGymGuyScript: ; 0x195f03
	faceplayer
	loadfont
	checkbit1 $04c9
	iftrue .FuchsiaGymGuyWinScript
	2writetext FuchsiaGymGuyText
	closetext
	loadmovesprites
	end

.FuchsiaGymGuyWinScript
	2writetext FuchsiaGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x195f17

MapFuchsiaGymSignpost1Script: ; 0x195f17
	checkbit2 $0027
	iftrue UnknownScript_0x195f20
	jumpstd $002d
; 0x195f20

UnknownScript_0x195f20: ; 0x195f20
	trainertotext JANINE, 1, $1
	jumpstd $002e
; 0x195f27

MovementData_0x195f27: ; 0x195f27
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	step_end
; 0x195f35

UnknownText_0x195f35: ; 0x195f35
	db $0, "Fufufufu…", $51
	db "I'm sorry to dis-", $4f
	db "appoint you…", $51
	db "I'm only joking!", $51
	db "I'm the real deal!", $51
	db "JANINE of FUCHSIA", $4f
	db "GYM, that's me!", $57
; 0x195fa1

UnknownText_0x195fa1: ; 0x195fa1
	db $0, "JANINE: You're a", $4f
	db "tough one. You", $55
	db "definitely won…", $51
	db "Here's SOULBADGE.", $4f
	db "Take it.", $57
; 0x195feb

UnknownText_0x195feb: ; 0x195feb
	db $0, $52, " received", $4f
	db "SOULBADGE.", $57
; 0x196002

UnknownText_0x196002: ; 0x196002
	db $0, "JANINE: You're so", $4f
	db "tough! I have a", $55
	db "special gift!", $51
	db "It's TOXIC, a pow-", $4f
	db "erful poison that", $51
	db "steadily saps the", $4f
	db "victim's HP.", $57
; 0x196074

UnknownText_0x196074: ; 0x196074
	db $0, "JANINE: I'm going", $4f
	db "to really apply", $51
	db "myself and improve", $4f
	db "my skills.", $51
	db "I want to become", $4f
	db "better than both", $55
	db "Father and you!", $57
; 0x1960e6

UnknownText_0x1960e6: ; 0x1960e6
	db $0, "Fufufu!", $51
	db "I'm JANINE, the", $4f
	db "GYM LEADER!", $51
	db "No, I'm not!", $4f
	db "Gotcha, sucker!", $57
; 0x196126

UnknownText_0x196126: ; 0x196126
	db $0, "I had you fooled…", $57
; 0x196139

UnknownText_0x196139: ; 0x196139
	db $0, "How will you dis-", $4f
	db "tinguish our real", $55
	db "LEADER?", $57
; 0x196166

UnknownText_0x196166: ; 0x196166
	db $0, "Fooled you!", $4f
	db "Hahaha!", $57
; 0x19617b

UnknownText_0x19617b: ; 0x19617b
	db $0, "Ooh… I lost…", $4f
	db "You're not weak…", $57
; 0x196199

UnknownText_0x196199: ; 0x196199
	db $0, "Well? Wasn't my", $4f
	db "disguise perfect?", $57
; 0x1961bb

UnknownText_0x1961bb: ; 0x1961bb
	db $0, "I'm JANINE!", $51
	db "How did you know I", $4f
	db "was real?", $51
	db "Let's battle!", $57
; 0x1961f1

UnknownText_0x1961f1: ; 0x1961f1
	db $0, "Darn it!", $4f
	db "I wanted to win!", $57
; 0x19620c

UnknownText_0x19620c: ; 0x19620c
	db $0, "You must be", $4f
	db "getting tired.", $57
; 0x196228

UnknownText_0x196228: ; 0x196228
	db $0, "Wahahaha!", $51
	db "You betcha!", $4f
	db "I'm JANINE!", $57
; 0x19624a

UnknownText_0x19624a: ; 0x19624a
	db $0, "My disguise was", $4f
	db "right on! Dang!", $57
; 0x19626b

UnknownText_0x19626b: ; 0x19626b
	db $0, "Hey, you. Was my", $4f
	db "disguise cute or", $55
	db "what, huh?", $57
; 0x196299

FuchsiaGymGuyText: ; 0x196299
	db $0, "Yo, CHAMP in", $4f
	db "making!", $51
	db "Whoops! Take a", $4f
	db "good look around", $51
	db "you. The trainers", $4f
	db "all look like the", $55
	db "LEADER, JANINE.", $51
	db "Which of them is", $4f
	db "the real JANINE?", $57
; 0x196325

FuchsiaGymGuyWinText: ; 0x196325
	db $0, "That was a great", $4f
	db "battle, trainer", $55
	db "from JOHTO!", $57
; 0x196353

FuchsiaGym_MapEventHeader: ; 0x196353
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $11, $4, 3, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $11, $5, 3, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 15, 3, $0, MapFuchsiaGymSignpost1Script
	signpost 15, 6, $0, MapFuchsiaGymSignpost1Script

	; people-events
	db 6
	person_event $a, 14, 5, $3, $0, 255, 255, $90, 0, UnknownScript_0x195db9, $ffff
	person_event $f7, 11, 9, $a, $0, 255, 255, $90, 0, UnknownScript_0x195e1b, $ffff
	person_event $f8, 15, 9, $a, $0, 255, 255, $90, 0, UnknownScript_0x195e55, $ffff
	person_event $f9, 8, 13, $a, $0, 255, 255, $90, 0, UnknownScript_0x195e8f, $ffff
	person_event $fa, 6, 8, $a, $0, 255, 255, $90, 0, UnknownScript_0x195ec9, $ffff
	person_event $48, 19, 11, $6, $0, 255, 255, $90, 0, FuchsiaGymGuyScript, $ffff
; 0x1963bb

FuchsiaBillSpeechHouse_MapScriptHeader: ; 0x1963bb
	; trigger count
	db 0

	; callback count
	db 0
; 0x1963bd

UnknownScript_0x1963bd: ; 0x1963bd
	jumptextfaceplayer UnknownText_0x1963c3
; 0x1963c0

UnknownScript_0x1963c0: ; 0x1963c0
	jumptextfaceplayer UnknownText_0x1963f9
; 0x1963c3

UnknownText_0x1963c3: ; 0x1963c3
	db $0, "My grandpa is at ", $4f
	db "my brother BILL's", $55
	db "on CERULEAN CAPE.", $57
; 0x1963f9

UnknownText_0x1963f9: ; 0x1963f9
	db $0, "I saw these weird,", $4f
	db "slow #MON on", $55
	db "CYCLING ROAD.", $57
; 0x196428

FuchsiaBillSpeechHouse_MapEventHeader: ; 0x196428
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $7, $3, 4, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $2e, 7, 6, $9, $0, 255, 255, $80, 0, UnknownScript_0x1963bd, $ffff
	person_event $27, 8, 10, $4, $10, 255, 255, $0, 0, UnknownScript_0x1963c0, $ffff
; 0x196452

FuchsiaPokeCenter1F_MapScriptHeader: ; 0x196452
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x196458, $0000

	; callback count
	db 0
; 0x196458

UnknownScript_0x196458: ; 0x196458
	end
; 0x196459

UnknownScript_0x196459: ; 0x196459
	jumpstd $0000
; 0x19645c

UnknownScript_0x19645c: ; 0x19645c
	jumptextfaceplayer UnknownText_0x196494
; 0x19645f

UnknownScript_0x19645f: ; 0x19645f
	jumptextfaceplayer UnknownText_0x1964dc
; 0x196462

UnknownScript_0x196462: ; 0x196462
	faceplayer
	loadfont
	2writetext UnknownText_0x19652e
	closetext
	loadmovesprites
	applymovement $5, MovementData_0x196486
	faceplayer
	variablesprite $c, $a
	special $005e
	loadfont
	2writetext UnknownText_0x19654e
	closetext
	loadmovesprites
	applymovement $5, MovementData_0x196486
	faceplayer
	variablesprite $c, $28
	special $005e
	end
; 0x196486

MovementData_0x196486: ; 0x196486
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	step_end
; 0x196494

UnknownText_0x196494: ; 0x196494
	db $0, "Hey! You have a", $4f
	db "brand new kind of", $55
	db "#DEX.", $51
	db "Did PROF.OAK give", $4f
	db "that to you?", $57
; 0x1964dc

UnknownText_0x1964dc: ; 0x1964dc
	db $0, "I got quite a", $4f
	db "shock at the GYM.", $51
	db "There were all", $4f
	db "these girls who", $55
	db "looked identical.", $57
; 0x19652e

UnknownText_0x19652e: ; 0x19652e
	db $0, "I'm JANINE! Hocus-", $4f
	db "pocus… Poof!", $57
; 0x19654e

UnknownText_0x19654e: ; 0x19654e
	db $0, "See? I look just", $4f
	db "like her now!", $57
; 0x19656e

FuchsiaPokeCenter1F_MapEventHeader: ; 0x19656e
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 5, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $7, $4, 5, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $a0, 0, UnknownScript_0x196459, $ffff
	person_event $23, 8, 12, $5, $1, 255, 255, $0, 0, UnknownScript_0x19645c, $ffff
	person_event $24, 8, 5, $5, $1, 255, 255, $0, 0, UnknownScript_0x19645f, $ffff
	person_event $fc, 7, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x196462, $ffff
; 0x1965b7

FuchsiaPokeCenter2FBeta_MapScriptHeader: ; 0x1965b7
	; trigger count
	db 0

	; callback count
	db 0
; 0x1965b9

FuchsiaPokeCenter2FBeta_MapEventHeader: ; 0x1965b9
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 3, GROUP_FUCHSIA_POKECENTER_1F, MAP_FUCHSIA_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x1965c4

SafariZoneWardensHome_MapScriptHeader: ; 0x1965c4
	; trigger count
	db 0

	; callback count
	db 0
; 0x1965c6

UnknownScript_0x1965c6: ; 0x1965c6
	faceplayer
	loadfont
	checkbit1 $00d9
	iftrue UnknownScript_0x1965d7
	2writetext UnknownText_0x1965e6
	closetext
	loadmovesprites
	setbit1 $00d9
	end
; 0x1965d7

UnknownScript_0x1965d7: ; 0x1965d7
	2writetext UnknownText_0x196691
	closetext
	loadmovesprites
	end
; 0x1965dd

MapSafariZoneWardensHomeSignpost2Script: ; 0x1965dd
	jumptext UnknownText_0x1966ea
; 0x1965e0

MapSafariZoneWardensHomeSignpost3Script: ; 0x1965e0
	jumptext UnknownText_0x196726
; 0x1965e3

MapSafariZoneWardensHomeSignpost1Script: ; 0x1965e3
	jumpstd $0002
; 0x1965e6

UnknownText_0x1965e6: ; 0x1965e6
	db $0, "My grandpa is the", $4f
	db "SAFARI ZONE WAR-", $55
	db "DEN.", $51
	db "At least he was…", $51
	db "He decided to go", $4f
	db "on a vacation and", $51
	db "took off overseas", $4f
	db "all by himself.", $51
	db "He quit running", $4f
	db "SAFARI ZONE just", $55
	db "like that.", $57
; 0x196691

UnknownText_0x196691: ; 0x196691
	db $0, "Many people were", $4f
	db "disappointed that", $51
	db "SAFARI ZONE closed", $4f
	db "down, but Grandpa", $55
	db "is so stubborn…", $57
; 0x1966ea

UnknownText_0x1966ea: ; 0x1966ea
	db $0, "It's a photo of a", $4f
	db "grinning old man", $51
	db "who's surrounded", $4f
	db "by #MON.", $57
; 0x196726

UnknownText_0x196726: ; 0x196726
	db $0, "It's a photo of a", $4f
	db "huge grassy plain", $51
	db "with rare #MON", $4f
	db "frolicking in it.", $57
; 0x19676b

SafariZoneWardensHome_MapEventHeader: ; 0x19676b
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 6, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $7, $3, 6, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 1, 0, $0, MapSafariZoneWardensHomeSignpost1Script
	signpost 1, 1, $0, MapSafariZoneWardensHomeSignpost1Script
	signpost 0, 7, $0, MapSafariZoneWardensHomeSignpost2Script
	signpost 0, 9, $0, MapSafariZoneWardensHomeSignpost3Script

	; people-events
	db 1
	person_event $28, 8, 6, $9, $0, 255, 255, $a0, 0, UnknownScript_0x1965c6, $ffff
; 0x19679c

Route15FuchsiaGate_MapScriptHeader: ; 0x19679c
	; trigger count
	db 0

	; callback count
	db 0
; 0x19679e

UnknownScript_0x19679e: ; 0x19679e
	jumptextfaceplayer UnknownText_0x1967a1
; 0x1967a1

UnknownText_0x1967a1: ; 0x1967a1
	db $0, "You're working on", $4f
	db "a #DEX? That's", $51
	db "really something.", $4f
	db "Don't give up!", $57
; 0x1967e1

Route15FuchsiaGate_MapEventHeader: ; 0x1967e1
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 8, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $5, $0, 9, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $4, $9, 1, GROUP_ROUTE_15, MAP_ROUTE_15
	warp_def $5, $9, 2, GROUP_ROUTE_15, MAP_ROUTE_15

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 6, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x19679e, $ffff
; 0x196808

CherrygroveMart_MapScriptHeader: ; 0x196808
	; trigger count
	db 0

	; callback count
	db 0
; 0x19680a

UnknownScript_0x19680a: ; 0x19680a
	loadfont
	checkbit1 $001f
	iftrue UnknownScript_0x196817
	pokemart $0, $0000
	loadmovesprites
	end
; 0x196817

UnknownScript_0x196817: ; 0x196817
	pokemart $0, $0001
	loadmovesprites
	end
; 0x19681d

UnknownScript_0x19681d: ; 0x19681d
	faceplayer
	loadfont
	checkbit1 $001f
	iftrue UnknownScript_0x19682b
	2writetext UnknownText_0x196834
	closetext
	loadmovesprites
	end
; 0x19682b

UnknownScript_0x19682b: ; 0x19682b
	2writetext UnknownText_0x196873
	closetext
	loadmovesprites
	end
; 0x196831

UnknownScript_0x196831: ; 0x196831
	jumptextfaceplayer UnknownText_0x1968a0
; 0x196834

UnknownText_0x196834: ; 0x196834
	db $0, "They're fresh out", $4f
	db "of # BALLS!", $51
	db "When will they get", $4f
	db "more of them?", $57
; 0x196873

UnknownText_0x196873: ; 0x196873
	db $0, "# BALLS are in", $4f
	db "stock! Now I can", $55
	db "catch #MON!", $57
; 0x1968a0

UnknownText_0x1968a0: ; 0x1968a0
	db $0, "When I was walking", $4f
	db "in the grass, a", $51
	db "bug #MON poi-", $4f
	db "soned my #MON!", $51
	db "I just kept going,", $4f
	db "but then my", $55
	db "#MON fainted.", $51
	db "You should keep an", $4f
	db "ANTIDOTE with you.", $57
; 0x196934

CherrygroveMart_MapEventHeader: ; 0x196934
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY
	warp_def $7, $3, 1, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x19680a, $ffff
	person_event $23, 10, 11, $5, $2, 255, 255, $0, 0, UnknownScript_0x19681d, $ffff
	person_event $27, 9, 6, $6, $0, 255, 255, $80, 0, UnknownScript_0x196831, $ffff
; 0x19696b

CherrygrovePokeCenter1F_MapScriptHeader: ; 0x19696b
	; trigger count
	db 0

	; callback count
	db 0
; 0x19696d

UnknownScript_0x19696d: ; 0x19696d
	jumpstd $0000
; 0x196970

UnknownScript_0x196970: ; 0x196970
	jumptextfaceplayer UnknownText_0x19698a
; 0x196973

UnknownScript_0x196973: ; 0x196973
	jumptextfaceplayer UnknownText_0x1969c8
; 0x196976

UnknownScript_0x196976: ; 0x196976
	faceplayer
	loadfont
	checkbit1 $001f
	iftrue UnknownScript_0x196984
	2writetext UnknownText_0x1969f1
	closetext
	loadmovesprites
	end
; 0x196984

UnknownScript_0x196984: ; 0x196984
	2writetext UnknownText_0x196a46
	closetext
	loadmovesprites
	end
; 0x19698a

UnknownText_0x19698a: ; 0x19698a
	db $0, "It's great. I can", $4f
	db "store any number", $51
	db "of #MON, and", $4f
	db "it's all free.", $57
; 0x1969c8

UnknownText_0x1969c8: ; 0x1969c8
	db $0, "That PC is free", $4f
	db "for any trainer", $55
	db "to use.", $57
; 0x1969f1

UnknownText_0x1969f1: ; 0x1969f1
	db $0, "The COMMUNICATION", $4f
	db "CENTER upstairs", $55
	db "was just built.", $51
	db "But they're still", $4f
	db "finishing it up.", $57
; 0x196a46

UnknownText_0x196a46: ; 0x196a46
	db $0, "The COMMUNICATION", $4f
	db "CENTER upstairs", $55
	db "was just built.", $51
	db "I traded #MON", $4f
	db "there already!", $57
; 0x196a96

CherrygrovePokeCenter1F_MapEventHeader: ; 0x196a96
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 2, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY
	warp_def $7, $4, 2, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x19696d, $ffff
	person_event $3a, 7, 6, $7, $0, 255, 255, $80, 0, UnknownScript_0x196970, $ffff
	person_event $40, 10, 12, $7, $0, 255, 255, $0, 0, UnknownScript_0x196973, $ffff
	person_event $29, 10, 5, $9, $0, 255, 255, $a0, 0, UnknownScript_0x196976, $ffff
; 0x196adf

CherrygroveGymSpeechHouse_MapScriptHeader: ; 0x196adf
	; trigger count
	db 0

	; callback count
	db 0
; 0x196ae1

UnknownScript_0x196ae1: ; 0x196ae1
	jumptextfaceplayer UnknownText_0x196aea
; 0x196ae4

UnknownScript_0x196ae4: ; 0x196ae4
	jumptextfaceplayer UnknownText_0x196b65
; 0x196ae7

MapCherrygroveGymSpeechHouseSignpost1Script: ; 0x196ae7
	jumpstd $0002
; 0x196aea

UnknownText_0x196aea: ; 0x196aea
	db $0, "You're trying to", $4f
	db "see how good you", $51
	db "are as a #MON", $4f
	db "trainer?", $51
	db "You better visit", $4f
	db "the #MON GYMS", $51
	db "all over JOHTO and", $4f
	db "collect BADGES.", $57
; 0x196b65

UnknownText_0x196b65: ; 0x196b65
	db $0, "When I get older,", $4f
	db "I'm going to be a", $55
	db "GYM LEADER!", $51
	db "I make my #MON", $4f
	db "battle with my", $51
	db "friend's to make", $4f
	db "them tougher!", $57
; 0x196bd1

CherrygroveGymSpeechHouse_MapEventHeader: ; 0x196bd1
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY
	warp_def $7, $3, 3, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapCherrygroveGymSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapCherrygroveGymSpeechHouseSignpost1Script

	; people-events
	db 2
	person_event $2d, 7, 6, $6, $0, 255, 255, $0, 0, UnknownScript_0x196ae1, $ffff
	person_event $25, 9, 9, $5, $1, 255, 255, $80, 0, UnknownScript_0x196ae4, $ffff
; 0x196c05

GuideGentsHouse_MapScriptHeader: ; 0x196c05
	; trigger count
	db 0

	; callback count
	db 0
; 0x196c07

UnknownScript_0x196c07: ; 0x196c07
	jumptextfaceplayer UnknownText_0x196c0d
; 0x196c0a

MapGuideGentsHouseSignpost1Script: ; 0x196c0a
	jumpstd $0003
; 0x196c0d

UnknownText_0x196c0d: ; 0x196c0d
	db $0, "When I was a wee", $4f
	db "lad, I was a hot-", $55
	db "shot trainer!", $51
	db "Here's a word of", $4f
	db "advice: Catch lots", $55
	db "of #MON!", $51
	db "Treat them all", $4f
	db "with kindness!", $57
; 0x196c89

GuideGentsHouse_MapEventHeader: ; 0x196c89
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 4, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY
	warp_def $7, $3, 4, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapGuideGentsHouseSignpost1Script
	signpost 1, 1, $0, MapGuideGentsHouseSignpost1Script

	; people-events
	db 1
	person_event $2f, 7, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x196c07, $06ff
; 0x196cb0

CherrygroveEvolutionSpeechHouse_MapScriptHeader: ; 0x196cb0
	; trigger count
	db 0

	; callback count
	db 0
; 0x196cb2

UnknownScript_0x196cb2: ; 0x196cb2
	loadfont
	2writetext UnknownText_0x196cc3
	closetext
	loadmovesprites
	end
; 0x196cb9

UnknownScript_0x196cb9: ; 0x196cb9
	loadfont
	2writetext UnknownText_0x196cfc
	closetext
	loadmovesprites
	end
; 0x196cc0

MapCherrygroveEvolutionSpeechHouseSignpost1Script: ; 0x196cc0
	jumpstd $0003
; 0x196cc3

UnknownText_0x196cc3: ; 0x196cc3
	db $0, "#MON gain expe-", $4f
	db "rience in battle", $51
	db "and change their", $4f
	db "form.", $57
; 0x196cfc

UnknownText_0x196cfc: ; 0x196cfc
	db $0, "#MON change?", $51
	db "I would be shocked", $4f
	db "if one did that!", $57
; 0x196d2e

CherrygroveEvolutionSpeechHouse_MapEventHeader: ; 0x196d2e
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 5, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY
	warp_def $7, $3, 5, GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapCherrygroveEvolutionSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapCherrygroveEvolutionSpeechHouseSignpost1Script

	; people-events
	db 2
	person_event $28, 9, 7, $8, $0, 255, 255, $a0, 0, UnknownScript_0x196cb9, $ffff
	person_event $27, 9, 6, $9, $0, 255, 255, $80, 0, UnknownScript_0x196cb2, $ffff
; 0x196d62

Route30BerrySpeechHouse_MapScriptHeader: ; 0x196d62
	; trigger count
	db 0

	; callback count
	db 0
; 0x196d64

UnknownScript_0x196d64: ; 0x196d64
	faceplayer
	loadfont
	checkbit1 $0027
	iftrue UnknownScript_0x196d79
	2writetext UnknownText_0x196d82
	keeptextopen
	verbosegiveitem BERRY, 1
	iffalse UnknownScript_0x196d7d
	setbit1 $0027
UnknownScript_0x196d79: ; 0x196d79
	2writetext UnknownText_0x196dec
	closetext
UnknownScript_0x196d7d: ; 0x196d7d
	loadmovesprites
	end
; 0x196d7f

MapRoute30BerrySpeechHouseSignpost1Script: ; 0x196d7f
	jumpstd $0003
; 0x196d82

UnknownText_0x196d82: ; 0x196d82
	db $0, "You know, #MON", $4f
	db "eat BERRIES.", $51
	db "Well, my #MON", $4f
	db "got healthier by", $55
	db "eating a BERRY.", $51
	db "Here. I'll share", $4f
	db "one with you!", $57
; 0x196dec

UnknownText_0x196dec: ; 0x196dec
	db $0, "Check trees for", $4f
	db "BERRIES. They just", $55
	db "drop right off.", $57
; 0x196e20

Route30BerrySpeechHouse_MapEventHeader: ; 0x196e20
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_ROUTE_30, MAP_ROUTE_30
	warp_def $7, $3, 1, GROUP_ROUTE_30, MAP_ROUTE_30

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapRoute30BerrySpeechHouseSignpost1Script
	signpost 1, 1, $0, MapRoute30BerrySpeechHouseSignpost1Script

	; people-events
	db 1
	person_event $2d, 7, 6, $6, $0, 255, 255, $b0, 0, UnknownScript_0x196d64, $ffff
; 0x196e47

MrPokemonsHouse_MapScriptHeader: ; 0x196e47
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x196e51, $0000
	dw UnknownScript_0x196e55, $0000

	; callback count
	db 0
; 0x196e51

UnknownScript_0x196e51: ; 0x196e51
	priorityjump UnknownScript_0x196e56
	end
; 0x196e55

UnknownScript_0x196e55: ; 0x196e55
	end
; 0x196e56

UnknownScript_0x196e56: ; 0x196e56
	showemote $0, $2, 15
	spriteface $2, $0
	loadfont
	2writetext UnknownText_0x196f66
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x196f5a
	loadfont
	2writetext UnknownText_0x196fa8
	keeptextopen
	waitbutton
	giveitem MYSTERY_EGG, $1
	2writetext UnknownText_0x196fd2
	playsound $0091
	waitbutton
	itemnotify
	setbit1 $001e
	blackoutmod GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY
	2writetext UnknownText_0x196feb
	keeptextopen
	spriteface $2, $3
	2writetext UnknownText_0x197092
	keeptextopen
	spriteface $2, $0
	spriteface $3, $2
	2writetext UnknownText_0x1970b7
	closetext
	loadmovesprites
	2jump UnknownScript_0x196ec9
; 0x196e97

UnknownScript_0x196e97: ; 0x196e97
	faceplayer
	loadfont
	checkitem RED_SCALE
	iftrue UnknownScript_0x196eb0
	checkbit1 $001f
	iftrue UnknownScript_0x196eaa
	2writetext UnknownText_0x197134
	closetext
	loadmovesprites
	end
; 0x196eaa

UnknownScript_0x196eaa: ; 0x196eaa
	2writetext UnknownText_0x19714a
	closetext
	loadmovesprites
	end
; 0x196eb0

UnknownScript_0x196eb0: ; 0x196eb0
	2writetext UnknownText_0x197476
	yesorno
	iffalse UnknownScript_0x196ec3
	verbosegiveitem EXP_SHARE, 1
	iffalse UnknownScript_0x196ec7
	takeitem RED_SCALE, 1
	2jump UnknownScript_0x196eaa
; 0x196ec3

UnknownScript_0x196ec3: ; 0x196ec3
	2writetext UnknownText_0x19750d
	closetext
UnknownScript_0x196ec7: ; 0x196ec7
	loadmovesprites
	end
; 0x196ec9

UnknownScript_0x196ec9: ; 0x196ec9
	playmusic $001e
	applymovement $3, MovementData_0x196f5d
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x197185
	keeptextopen
	waitbutton
	2writetext UnknownText_0x1973cc
	playsound $0001
	waitbutton
	setbit2 $000b
	2writetext UnknownText_0x1973de
	closetext
	loadmovesprites
	spriteface $0, $0
	applymovement $3, MovementData_0x196f61
	playsound $0023
	disappear $3
	waitbutton
	special $003d
	pause 15
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x1970ed
	closetext
	loadmovesprites
	special $0030
	special $0033
	playmusic $000d
	special $009d
	special $001b
	pause 60
	special $0032
	special $003d
	loadfont
	2writetext UnknownText_0x197134
	closetext
	loadmovesprites
	setbit1 $06bd
	setbit1 $0792
	clearbit1 $0793
	dotrigger $1
	domaptrigger GROUP_CHERRYGROVE_CITY, MAP_CHERRYGROVE_CITY, $1
	domaptrigger GROUP_ELMS_LAB, MAP_ELMS_LAB, $3
	specialphonecall $2
	clearbit1 $0702
	checkbit1 $001c
	iftrue UnknownScript_0x196f49
	checkbit1 $001d
	iftrue UnknownScript_0x196f4d
	setbit1 $0641
	end
; 0x196f49

UnknownScript_0x196f49: ; 0x196f49
	setbit1 $0642
	end
; 0x196f4d

UnknownScript_0x196f4d: ; 0x196f4d
	setbit1 $0640
	end
; 0x196f51

MapMrPokemonsHouseSignpost1Script: ; 0x196f51
	jumptext UnknownText_0x197543
; 0x196f54

MapMrPokemonsHouseSignpost3Script: ; 0x196f54
	jumptext UnknownText_0x197584
; 0x196f57

MapMrPokemonsHouseSignpost4Script: ; 0x196f57
	jumptext UnknownText_0x1975ac
; 0x196f5a

MovementData_0x196f5a: ; 0x196f5a
	step_right
	step_up
	step_end
; 0x196f5d

MovementData_0x196f5d: ; 0x196f5d
	step_down
	step_left
	step_left
	step_end
; 0x196f61

MovementData_0x196f61: ; 0x196f61
	step_down
	step_left
	turn_head_down
	db $3f ; movement
	step_end
; 0x196f66

UnknownText_0x196f66: ; 0x196f66
	db $0, "Hello, hello! You", $4f
	db "must be ", $14, ".", $51
	db "PROF.ELM said that", $4f
	db "you would visit.", $57
; 0x196fa8

UnknownText_0x196fa8: ; 0x196fa8
	db $0, "This is what I", $4f
	db "want PROF.ELM to", $55
	db "examine.", $57
; 0x196fd2

UnknownText_0x196fd2: ; 0x196fd2
	db $0, $52, " received", $4f
	db "MYSTERY EGG.", $57
; 0x196feb

UnknownText_0x196feb: ; 0x196feb
	db $0, "I know a couple", $4f
	db "who run a #MON", $55
	db "DAY-CARE service.", $51
	db "They gave me that", $4f
	db "EGG.", $51
	db "I was intrigued,", $4f
	db "so I sent mail to", $55
	db "PROF.ELM.", $51
	db "For #MON evolu-", $4f
	db "tion, PROF.ELM is", $55
	db "the authority.", $57
; 0x197092

UnknownText_0x197092: ; 0x197092
	db $0, "Even PROF.OAK here", $4f
	db "recognizes that.", $57
; 0x1970b7

UnknownText_0x1970b7: ; 0x1970b7
	db $0, "If my assumption", $4f
	db "is correct, PROF.", $55
	db "ELM will know it.", $57
; 0x1970ed

UnknownText_0x1970ed: ; 0x1970ed
	db $0, "You are returning", $4f
	db "to PROF.ELM?", $51
	db "Here. Your #MON", $4f
	db "should have some", $55
	db "rest.", $57
; 0x197134

UnknownText_0x197134: ; 0x197134
	db $0, "I'm depending on", $4f
	db "you!", $57
; 0x19714a

UnknownText_0x19714a: ; 0x19714a
	db $0, "Life is delight-", $4f
	db "ful! Always, new", $51
	db "discoveries to be", $4f
	db "made!", $57
; 0x197185

UnknownText_0x197185: ; 0x197185
	db $0, "OAK: Aha! So", $4f
	db "you're ", $14, "!", $51
	db "I'm OAK! A #MON", $4f
	db "researcher.", $51
	db "I was just visit-", $4f
	db "ing my old friend", $55
	db "MR.#MON.", $51
	db "I heard you were", $4f
	db "running an errand", $51
	db "for PROF.ELM, so I", $4f
	db "waited here.", $51
	db "Oh! What's this?", $4f
	db "A rare #MON!", $51
	db "Let's see…", $51
	db "Hm, I see!", $51
	db "I understand why", $4f
	db "PROF.ELM gave you", $51
	db "a #MON for this", $4f
	db "errand.", $51
	db "To researchers", $4f
	db "like PROF.ELM and", $51
	db "I, #MON are our", $4f
	db "friends.", $51
	db "He saw that you", $4f
	db "would treat your", $51
	db "#MON with love", $4f
	db "and care.", $51
	db "…Ah!", $51
	db "You seem to be", $4f
	db "dependable.", $51
	db "How would you like", $4f
	db "to help me out?", $51
	db "See? This is the", $4f
	db "latest version of", $55
	db "#DEX.", $51
	db "It automatically", $4f
	db "records data on", $51
	db "#MON you've", $4f
	db "seen or caught.", $51
	db "It's a hi-tech", $4f
	db "encyclopedia!", $57
; 0x1973cc

UnknownText_0x1973cc: ; 0x1973cc
	db $0, $52, " received", $4f
	db "#DEX!", $57
; 0x1973de

UnknownText_0x1973de: ; 0x1973de
	db $0, "Go meet many kinds", $4f
	db "of #MON and", $51
	db "complete that", $4f
	db "#DEX!", $51
	db "But I've stayed", $4f
	db "too long.", $51
	db "I have to get to", $4f
	db "GOLDENROD for my", $55
	db "usual radio show.", $51
	db $14, ", I'm", $4f
	db "counting on you!", $57
; 0x197476

UnknownText_0x197476: ; 0x197476
	db $0, "Hm? That SCALE!", $4f
	db "What's that?", $55
	db "A red GYARADOS?", $51
	db "That's rare! ", $4f
	db "I, I want it…", $51
	db $14, ", would you", $4f
	db "care to trade it?", $51
	db "I can offer this", $4f
	db "EXP.SHARE I got", $55
	db "from PROF.OAK.", $57
; 0x19750d

UnknownText_0x19750d: ; 0x19750d
	db $0, "That's disappoint-", $4f
	db "ing. That happens", $55
	db "to be very rare.", $57
; 0x197543

UnknownText_0x197543: ; 0x197543
	db $0, "It's packed with", $4f
	db "foreign magazines.", $51
	db "Can't even read", $4f
	db "their titles…", $57
; 0x197584

UnknownText_0x197584: ; 0x197584
	db $0, "It's a big com-", $4f
	db "puter. Hmm. It's", $55
	db "broken.", $57
; 0x1975ac

UnknownText_0x1975ac: ; 0x1975ac
	db $0, "A whole pile of", $4f
	db "strange coins!", $51
	db "Maybe they're from", $4f
	db "another country…", $57
; 0x1975ef

MrPokemonsHouse_MapEventHeader: ; 0x1975ef
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_ROUTE_30, MAP_ROUTE_30
	warp_def $7, $3, 2, GROUP_ROUTE_30, MAP_ROUTE_30

	; xy triggers
	db 0

	; signposts
	db 5
	signpost 1, 0, $0, MapMrPokemonsHouseSignpost1Script
	signpost 1, 1, $0, MapMrPokemonsHouseSignpost1Script
	signpost 1, 6, $0, MapMrPokemonsHouseSignpost3Script
	signpost 1, 7, $0, MapMrPokemonsHouseSignpost3Script
	signpost 4, 6, $0, MapMrPokemonsHouseSignpost4Script

	; people-events
	db 2
	person_event $40, 9, 7, $9, $0, 255, 255, $0, 0, UnknownScript_0x196e97, $ffff
	person_event $5, 9, 10, $7, $0, 255, 255, $0, 0, ObjectEvent, $06c9
; 0x197632

Route31VioletGate_MapScriptHeader: ; 0x197632
	; trigger count
	db 0

	; callback count
	db 0
; 0x197634

UnknownScript_0x197634: ; 0x197634
	jumptextfaceplayer UnknownText_0x19763a
; 0x197637

UnknownScript_0x197637: ; 0x197637
	jumptextfaceplayer UnknownText_0x197661
; 0x19763a

UnknownText_0x19763a: ; 0x19763a
	db $0, "Hi there!", $4f
	db "Did you visit", $55
	db "SPROUT TOWER?", $57
; 0x197661

UnknownText_0x197661: ; 0x197661
	db $0, "I came too far", $4f
	db "out. I'd better", $55
	db "phone home!", $57
; 0x19768c

Route31VioletGate_MapEventHeader: ; 0x19768c
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 8, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $5, $0, 9, GROUP_VIOLET_CITY, MAP_VIOLET_CITY
	warp_def $4, $9, 1, GROUP_ROUTE_31, MAP_ROUTE_31
	warp_def $5, $9, 2, GROUP_ROUTE_31, MAP_ROUTE_31

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $43, 6, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x197634, $ffff
	person_event $24, 6, 5, $3, $0, 255, 255, $90, 0, UnknownScript_0x197637, $ffff
; 0x1976c0

SECTION "bank66",DATA,BANK[$66]

AzaleaTown_MapScriptHeader: ; 0x198000
	; trigger count
	db 3

	; triggers
	dw UnknownScript_0x198011, $0000
	dw UnknownScript_0x198012, $0000
	dw UnknownScript_0x198013, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x198014
; 0x198011

UnknownScript_0x198011: ; 0x198011
	end
; 0x198012

UnknownScript_0x198012: ; 0x198012
	end
; 0x198013

UnknownScript_0x198013: ; 0x198013
	end
; 0x198014

UnknownScript_0x198014: ; 0x198014
	setbit2 $0044
	return
; 0x198018

UnknownScript_0x198018: ; 0x198018
	moveperson $b, $b, $b
	spriteface $0, $3
	showemote $0, $0, 15
	special $006a
	pause 15
	appear $b
	applymovement $b, MovementData_0x198134
	spriteface $0, $0
	2jump UnknownScript_0x198049
; 0x198034

UnknownScript_0x198034: ; 0x198034
	spriteface $0, $3
	showemote $0, $0, 15
	special $006a
	pause 15
	appear $b
	applymovement $b, MovementData_0x19813c
	spriteface $0, $1
UnknownScript_0x198049: ; 0x198049
	playmusic $001f
	loadfont
	2writetext UnknownText_0x19814d
	closetext
	loadmovesprites
	setbit1 $06bf
	checkbit1 $001c
	iftrue UnknownScript_0x198071
	checkbit1 $001d
	iftrue UnknownScript_0x198081
	winlosstext UnknownText_0x1981e6, UnknownText_0x19835b
	setlasttalked $b
	loadtrainer RIVAL1, RIVAL1_6
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x198091
; 0x198071

UnknownScript_0x198071: ; 0x198071
	winlosstext UnknownText_0x1981e6, UnknownText_0x19835b
	setlasttalked $b
	loadtrainer RIVAL1, RIVAL1_4
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x198091
; 0x198081

UnknownScript_0x198081: ; 0x198081
	winlosstext UnknownText_0x1981e6, UnknownText_0x19835b
	setlasttalked $b
	loadtrainer RIVAL1, RIVAL1_5
	startbattle
	reloadmapmusic
	returnafterbattle
	2jump UnknownScript_0x198091
; 0x198091

UnknownScript_0x198091: ; 0x198091
	playmusic $0020
	loadfont
	2writetext UnknownText_0x198233
	closetext
	loadmovesprites
	spriteface $0, $2
	applymovement $b, MovementData_0x198144
	playsound $0023
	disappear $b
	dotrigger $0
	waitbutton
	playmapmusic
	end
; 0x1980ab

UnknownScript_0x1980ab: ; 0x1980ab
	jumptextfaceplayer UnknownText_0x19837b
; 0x1980ae

UnknownScript_0x1980ae: ; 0x1980ae
	jumptextfaceplayer UnknownText_0x1983c7
; 0x1980b1

UnknownScript_0x1980b1: ; 0x1980b1
	faceplayer
	loadfont
	checkbit1 $002b
	iftrue UnknownScript_0x1980bf
	2writetext UnknownText_0x19841b
	closetext
	loadmovesprites
	end
; 0x1980bf

UnknownScript_0x1980bf: ; 0x1980bf
	2writetext UnknownText_0x198473
	closetext
	loadmovesprites
	end
; 0x1980c5

UnknownScript_0x1980c5: ; 0x1980c5
	jumptextfaceplayer UnknownText_0x1984ce
; 0x1980c8

UnknownScript_0x1980c8: ; 0x1980c8
	jumptextfaceplayer UnknownText_0x19851a
; 0x1980cb

UnknownScript_0x1980cb: ; 0x1980cb
	loadfont
	2writetext UnknownText_0x1985b0
	pause 60
	2writetext UnknownText_0x1985c3
	cry SLOWPOKE
	closetext
	loadmovesprites
	end
; 0x1980da

UnknownScript_0x1980da: ; 0x1980da
	faceplayer
	loadfont
	2writetext UnknownText_0x1985cd
	cry $00c3
	closetext
	loadmovesprites
	end
; 0x1980e5

UnknownScript_0x1980e5: ; 0x1980e5
	applymovement $0, MovementData_0x198148
	loadfont
	2writetext UnknownText_0x1985df
	keeptextopen
	spriteface $d, $3
	2writetext UnknownText_0x19860b
	keeptextopen
	2writetext UnknownText_0x198628
	closetext
	verbosegiveitem GS_BALL, 1
	spriteface $d, $2
	setbit2 $0064
	clearbit1 $06ed
	setbit1 $06eb
	dotrigger $0
	loadmovesprites
	end
; 0x19810c

UnknownScript_0x19810c: ; 0x19810c
	faceplayer
	loadfont
	2writetext UnknownText_0x198628
	closetext
	spriteface $d, $2
	loadmovesprites
	end
; 0x198117

MapAzaleaTownSignpost0Script: ; 0x198117
	jumptext UnknownText_0x19865a
; 0x19811a

MapAzaleaTownSignpost1Script: ; 0x19811a
	jumptext UnknownText_0x198693
; 0x19811d

MapAzaleaTownSignpost2Script: ; 0x19811d
	jumptext UnknownText_0x1986a1
; 0x198120

MapAzaleaTownSignpost3Script: ; 0x198120
	jumptext UnknownText_0x1986e7
; 0x198123

MapAzaleaTownSignpost4Script: ; 0x198123
	jumptext UnknownText_0x19878d
; 0x198126

MapAzaleaTownSignpost7Script: ; 0x198126
	jumptext UnknownText_0x19879c
; 0x198129

MapAzaleaTownSignpost5Script: ; 0x198129
	jumpstd $0010
; 0x19812c

MapAzaleaTownSignpost6Script: ; 0x19812c
	jumpstd $0011
; 0x19812f

UnknownScript_0x19812f: ; 0x19812f
	fruittree $14
; 0x198131

MapAzaleaTownSignpostItem8: ; 0x198131
	dw $00b1
	db FULL_HEAL
	
; 0x198134

MovementData_0x198134: ; 0x198134
	step_left
	step_left
	step_left
	step_left
	step_left
	step_left
	turn_head_up
	step_end
; 0x19813c

MovementData_0x19813c: ; 0x19813c
	step_left
	step_left
	step_left
	step_left
	step_left
	step_left
	turn_head_down
	step_end
; 0x198144

MovementData_0x198144: ; 0x198144
	step_left
	step_left
	step_left
	step_end
; 0x198148

MovementData_0x198148: ; 0x198148
	step_left
	step_left
	step_up
	turn_head_left
	step_end
; 0x19814d

UnknownText_0x19814d: ; 0x19814d
	db $0, "…Tell me some-", $4f
	db "thing.", $51
	db "Is it true that", $4f
	db "TEAM ROCKET has", $55
	db "returned?", $51
	db "What? You beat", $4f
	db "them? Hah! Quit", $55
	db "lying.", $51
	db "You're not joking?", $4f
	db "Then let's see how", $55
	db "good you are.", $57
; 0x1981e6

UnknownText_0x1981e6: ; 0x1981e6
	db $0, "… Humph! Useless", $4f
	db "#MON!", $51
	db "Listen, you. You", $4f
	db "only won because", $51
	db "my #MON were", $4f
	db "weak.", $57
; 0x198233

UnknownText_0x198233: ; 0x198233
	db $0, "I hate the weak.", $51
	db "#MON, trainers.", $4f
	db "It doesn't matter", $55
	db "who or what.", $51
	db "I'm going to be", $4f
	db "strong and wipe", $55
	db "out the weak.", $51
	db "That goes for TEAM", $4f
	db "ROCKET too.", $51
	db "They act big and", $4f
	db "tough in a group.", $51
	db "But get them", $4f
	db "alone, and they're", $55
	db "weak.", $51
	db "I hate them all.", $51
	db "You stay out of my", $4f
	db "way. A weakling", $51
	db "like you is only a", $4f
	db "distraction.", $57
; 0x19835b

UnknownText_0x19835b: ; 0x19835b
	db $0, "…Humph! I knew", $4f
	db "you were lying.", $57
; 0x19837b

UnknownText_0x19837b: ; 0x19837b
	db $0, "It's unsafe to go", $4f
	db "in there, so I'm", $55
	db "standing guard.", $51
	db "Aren't I a good", $4f
	db "Samaritan?", $57
; 0x1983c7

UnknownText_0x1983c7: ; 0x1983c7
	db $0, "Do you know about", $4f
	db "SLOWPOKETAIL? I", $55
	db "heard it's tasty!", $51
	db "Aren't you glad I", $4f
	db "told you that?", $57
; 0x19841b

UnknownText_0x19841b: ; 0x19841b
	db $0, "The SLOWPOKE have", $4f
	db "disappeared from", $55
	db "town…", $51
	db "I heard their", $4f
	db "TAILS are being", $55
	db "sold somewhere.", $57
; 0x198473

UnknownText_0x198473: ; 0x198473
	db $0, "The SLOWPOKE have", $4f
	db "returned.", $51
	db "Knowing them, they", $4f
	db "could've just been", $51
	db "goofing off some-", $4f
	db "where.", $57
; 0x1984ce

UnknownText_0x1984ce: ; 0x1984ce
	db $0, "Did you come to", $4f
	db "get KURT to make", $55
	db "some BALLS?", $51
	db "A lot of people do", $4f
	db "just that.", $57
; 0x19851a

UnknownText_0x19851a: ; 0x19851a
	db $0, "Cut through AZALEA", $4f
	db "and you'll be in", $55
	db "ILEX FOREST.", $51
	db "But these skinny", $4f
	db "trees make it", $51
	db "impossible to get", $4f
	db "through.", $51
	db "The CHARCOAL MAN's", $4f
	db "#MON can CUT", $55
	db "down trees.", $57
; 0x1985b0

UnknownText_0x1985b0: ; 0x1985b0
	db $0, "SLOWPOKE: …", $51
	db $56, " ", $56, " ", $56, $57
; 0x1985c3

UnknownText_0x1985c3: ; 0x1985c3
	db $0, $56, " ", $56, "Yawn?", $57
; 0x1985cd

UnknownText_0x1985cd: ; 0x1985cd
	db $0, "WOOSTER: Gugyoo…", $57
; 0x1985df

UnknownText_0x1985df: ; 0x1985df
	db $0, "ILEX FOREST is", $4f
	db "restless!", $51
	db "What is going on?", $57
; 0x19860b

UnknownText_0x19860b: ; 0x19860b
	db $0, $52, ", here's", $4f
	db "your GS BALL back!", $57
; 0x198628

UnknownText_0x198628: ; 0x198628
	db $0, "Could you go see", $4f
	db "why ILEX FOREST is", $55
	db "so restless?", $57
; 0x19865a

UnknownText_0x19865a: ; 0x19865a
	db $0, "AZALEA TOWN", $4f
	db "Where People and", $51
	db "#MON Live in", $4f
	db "Happy Harmony", $57
; 0x198693

UnknownText_0x198693: ; 0x198693
	db $0, "KURT'S HOUSE", $57
; 0x1986a1

UnknownText_0x1986a1: ; 0x1986a1
	db $0, "AZALEA TOWN", $4f
	db "#MON GYM", $55
	db "LEADER: BUGSY", $51
	db "The Walking", $4f
	db "Bug #MON", $55
	db "Encyclopedia", $57
; 0x1986e7

UnknownText_0x1986e7: ; 0x1986e7
	db $0, "SLOWPOKE WELL", $51
	db "Also known as the", $4f
	db "RAINMAKER WELL.", $51
	db "Locals believe", $4f
	db "that a SLOWPOKE's", $55
	db "yawn summons rain.", $51
	db "Records show that", $4f
	db "a SLOWPOKE's yawn", $51
	db "ended a drought", $4f
	db "400 years ago.", $57
; 0x19878d

UnknownText_0x19878d: ; 0x19878d
	db $0, "CHARCOAL KILN", $57
; 0x19879c

UnknownText_0x19879c: ; 0x19879c
	db $0, "ILEX FOREST", $51
	db "Enter through the", $4f
	db "gate.", $57
; 0x1987c1

AzaleaTown_MapEventHeader: ; 0x1987c1
	; filler
	db 0, 0

	; warps
	db 8
	warp_def $9, $f, 1, GROUP_AZALEA_POKECENTER_1F, MAP_AZALEA_POKECENTER_1F
	warp_def $d, $15, 1, GROUP_CHARCOAL_KILN, MAP_CHARCOAL_KILN
	warp_def $5, $15, 2, GROUP_AZALEA_MART, MAP_AZALEA_MART
	warp_def $5, $9, 1, GROUP_KURTS_HOUSE, MAP_KURTS_HOUSE
	warp_def $f, $a, 1, GROUP_AZALEA_GYM, MAP_AZALEA_GYM
	warp_def $7, $1f, 1, GROUP_SLOWPOKE_WELL_B1F, MAP_SLOWPOKE_WELL_B1F
	warp_def $a, $2, 3, GROUP_ILEX_FOREST_AZALEA_GATE, MAP_ILEX_FOREST_AZALEA_GATE
	warp_def $b, $2, 4, GROUP_ILEX_FOREST_AZALEA_GATE, MAP_ILEX_FOREST_AZALEA_GATE

	; xy triggers
	db 3
	xy_trigger 1, $a, $5, $0, UnknownScript_0x198018, $0, $0
	xy_trigger 1, $b, $5, $0, UnknownScript_0x198034, $0, $0
	xy_trigger 2, $6, $9, $0, UnknownScript_0x1980e5, $0, $0

	; signposts
	db 9
	signpost 9, 19, $0, MapAzaleaTownSignpost0Script
	signpost 9, 10, $0, MapAzaleaTownSignpost1Script
	signpost 15, 14, $0, MapAzaleaTownSignpost2Script
	signpost 7, 29, $0, MapAzaleaTownSignpost3Script
	signpost 13, 19, $0, MapAzaleaTownSignpost4Script
	signpost 9, 16, $0, MapAzaleaTownSignpost5Script
	signpost 5, 22, $0, MapAzaleaTownSignpost6Script
	signpost 9, 3, $0, MapAzaleaTownSignpost7Script
	signpost 6, 31, $7, MapAzaleaTownSignpostItem8

	; people-events
	db 12
	person_event $f6, 13, 35, $6, $0, 255, 255, $0, 0, UnknownScript_0x1980ab, $06fa
	person_event $2f, 13, 25, $2, $21, 255, 255, $0, 0, UnknownScript_0x1980b1, $ffff
	person_event $29, 17, 19, $4, $20, 255, 255, $90, 0, UnknownScript_0x1980c5, $ffff
	person_event $27, 13, 11, $5, $1, 255, 255, $a0, 0, UnknownScript_0x1980c8, $ffff
	person_event $45, 21, 12, $1, $0, 255, 255, $0, 0, UnknownScript_0x1980cb, $06f9
	person_event $45, 13, 22, $1, $0, 255, 255, $0, 0, UnknownScript_0x1980cb, $06f9
	person_event $45, 13, 33, $1, $0, 255, 255, $0, 0, UnknownScript_0x1980cb, $06f9
	person_event $45, 19, 19, $1, $0, 255, 255, $0, 0, UnknownScript_0x1980cb, $06f9
	person_event $5d, 6, 12, $1, $0, 255, 255, $0, 0, UnknownScript_0x19812f, $ffff
	person_event $f6, 14, 15, $8, $0, 255, 255, $0, 0, ObjectEvent, $06bf
	person_event $f6, 20, 14, $6, $0, 255, 255, $0, 0, UnknownScript_0x1980ae, $06fc
	person_event $62, 9, 10, $8, $0, 255, 255, $0, 0, UnknownScript_0x19810c, $07a4
; 0x1988d0

GoldenrodCity_MapScriptHeader: ; 0x1988d0
	; trigger count
	db 0

	; callback count
	db 2

	; callbacks

	dbw 5, UnknownScript_0x1988d8

	dbw 2, UnknownScript_0x1988e8
; 0x1988d8

UnknownScript_0x1988d8: ; 0x1988d8
	setbit2 $0046
	setbit2 $0016
	checkbit1 $00b9
	iftrue UnknownScript_0x1988e7
	clearbit1 $0769
UnknownScript_0x1988e7: ; 0x1988e7
	return
; 0x1988e8

UnknownScript_0x1988e8: ; 0x1988e8
	checkbit1 $0044
	iffalse UnknownScript_0x198908
	checkitem COIN_CASE
	iffalse UnknownScript_0x1988fd
	checkcode $b
	if_equal WEDNESDAY, UnknownScript_0x198900
	if_equal SATURDAY, UnknownScript_0x198900
UnknownScript_0x1988fd: ; 0x1988fd
	disappear $10
	return
; 0x198900

UnknownScript_0x198900: ; 0x198900
	checkbit2 $005e
	iftrue UnknownScript_0x198908
	appear $10
UnknownScript_0x198908: ; 0x198908
	return
; 0x198909

UnknownScript_0x198909: ; 0x198909
	faceplayer
	loadfont
	2writetext UnknownText_0x199042
	yesorno
	iffalse UnknownScript_0x19899a
	special $004f
	2writetext UnknownText_0x199090
	yesorno
	iffalse UnknownScript_0x1989a0
	checkcoins 4000
	if_equal $2, UnknownScript_0x1989dd
	2writetext UnknownText_0x1990ce
	loadmenudata $4967
	interpretmenu2
	writebackup
	if_equal $1, UnknownScript_0x19893a
	if_equal $2, UnknownScript_0x198949
	if_equal $3, UnknownScript_0x198958
	2jump UnknownScript_0x1989d7
; 0x19893a

UnknownScript_0x19893a: ; 0x19893a
	writebyte $1
	2writetext UnknownText_0x1991cf
	special $0083
	if_equal $0, UnknownScript_0x1989a6
	2jump UnknownScript_0x1989d7
; 0x198949

UnknownScript_0x198949: ; 0x198949
	writebyte $2
	2writetext UnknownText_0x1991cf
	special $0083
	if_equal $0, UnknownScript_0x1989a6
	2jump UnknownScript_0x1989d7
; 0x198958

UnknownScript_0x198958: ; 0x198958
	writebyte $3
	2writetext UnknownText_0x1991cf
	special $0083
	if_equal $0, UnknownScript_0x1989a6
	2jump UnknownScript_0x1989d7
; 0x198967

INCBIN "baserom.gbc",$198967,$33

UnknownScript_0x19899a: ; 0x19899a
	2writetext UnknownText_0x1990b4
	closetext
	loadmovesprites
	end
; 0x1989a0

UnknownScript_0x1989a0: ; 0x1989a0
	2writetext UnknownText_0x199107
	closetext
	loadmovesprites
	end
; 0x1989a6

UnknownScript_0x1989a6: ; 0x1989a6
	2writetext UnknownText_0x19913a
	keeptextopen
	takecoins 4000
	waitbutton
	playsound $0022
	special $004f
	2writetext UnknownText_0x19918b
	closetext
	loadmovesprites
	checkcode $9
	if_equal $2, UnknownScript_0x1989c6
	applymovement $10, MovementData_0x198a5f
	2jump UnknownScript_0x1989ca
; 0x1989c6

UnknownScript_0x1989c6: ; 0x1989c6
	applymovement $10, MovementData_0x198a63
UnknownScript_0x1989ca: ; 0x1989ca
	playsound $001f
	disappear $10
	clearbit1 $076b
	setbit2 $005e
	waitbutton
	end
; 0x1989d7

UnknownScript_0x1989d7: ; 0x1989d7
	2writetext UnknownText_0x1991a4
	closetext
	loadmovesprites
	end
; 0x1989dd

UnknownScript_0x1989dd: ; 0x1989dd
	2writetext UnknownText_0x1991ac
	closetext
	loadmovesprites
	end
; 0x1989e3

UnknownScript_0x1989e3: ; 0x1989e3
	jumptextfaceplayer UnknownText_0x198a69
; 0x1989e6

UnknownScript_0x1989e6: ; 0x1989e6
	jumptextfaceplayer UnknownText_0x198aa9
; 0x1989e9

UnknownScript_0x1989e9: ; 0x1989e9
	faceplayer
	loadfont
	checkbit1 $0021
	iftrue UnknownScript_0x1989f7
	2writetext UnknownText_0x198ae6
	closetext
	loadmovesprites
	end
; 0x1989f7

UnknownScript_0x1989f7: ; 0x1989f7
	2writetext UnknownText_0x198b2d
	closetext
	loadmovesprites
	end
; 0x1989fd

UnknownScript_0x1989fd: ; 0x1989fd
	faceplayer
	loadfont
	checkbit2 $0000
	iftrue UnknownScript_0x198a0b
	2writetext UnknownText_0x198b73
	closetext
	loadmovesprites
	end
; 0x198a0b

UnknownScript_0x198a0b: ; 0x198a0b
	2writetext UnknownText_0x198c14
	closetext
	loadmovesprites
	end
; 0x198a11

UnknownScript_0x198a11: ; 0x198a11
	jumptextfaceplayer UnknownText_0x198c36
; 0x198a14

UnknownScript_0x198a14: ; 0x198a14
	jumptextfaceplayer UnknownText_0x198c83
; 0x198a17

UnknownScript_0x198a17: ; 0x198a17
	jumptextfaceplayer UnknownText_0x198ccf
; 0x198a1a

UnknownScript_0x198a1a: ; 0x198a1a
	loadfont
	2writetext UnknownText_0x198d0d
	keeptextopen
	faceplayer
	2writetext UnknownText_0x198d2a
	closetext
	loadmovesprites
	spriteface $9, $1
	end
; 0x198a29

UnknownScript_0x198a29: ; 0x198a29
	jumptextfaceplayer UnknownText_0x198d4e
; 0x198a2c

UnknownScript_0x198a2c: ; 0x198a2c
	jumptextfaceplayer UnknownText_0x198d6d
; 0x198a2f

UnknownScript_0x198a2f: ; 0x198a2f
	jumptextfaceplayer UnknownText_0x198daa
; 0x198a32

UnknownScript_0x198a32: ; 0x198a32
	jumptextfaceplayer UnknownText_0x198de2
; 0x198a35

UnknownScript_0x198a35: ; 0x198a35
	jumptextfaceplayer UnknownText_0x198e1f
; 0x198a38

UnknownScript_0x198a38: ; 0x198a38
	jumptextfaceplayer UnknownText_0x198e4b
; 0x198a3b

MapGoldenrodCitySignpost0Script: ; 0x198a3b
	jumptext UnknownText_0x198e77
; 0x198a3e

MapGoldenrodCitySignpost1Script: ; 0x198a3e
	jumptext UnknownText_0x198e8f
; 0x198a41

MapGoldenrodCitySignpost2Script: ; 0x198a41
	jumptext UnknownText_0x198eab
; 0x198a44

MapGoldenrodCitySignpost3Script: ; 0x198a44
	jumptext UnknownText_0x198ee4
; 0x198a47

MapGoldenrodCitySignpost4Script: ; 0x198a47
	jumptext UnknownText_0x198f29
; 0x198a4a

MapGoldenrodCitySignpost5Script: ; 0x198a4a
	jumptext UnknownText_0x198f5b
; 0x198a4d

MapGoldenrodCitySignpost6Script: ; 0x198a4d
	jumptext UnknownText_0x198f81
; 0x198a50

MapGoldenrodCitySignpost7Script: ; 0x198a50
	jumptext UnknownText_0x198fae
; 0x198a53

MapGoldenrodCitySignpost8Script: ; 0x198a53
	jumptext UnknownText_0x198fd8
; 0x198a56

MapGoldenrodCitySignpost9Script: ; 0x198a56
	jumptext UnknownText_0x198fee
; 0x198a59

MapGoldenrodCitySignpost10Script: ; 0x198a59
	jumpstd $0010
; 0x198a5c

MapGoldenrodCitySignpost11Script: ; 0x198a5c
	jumptext UnknownText_0x199022
; 0x198a5f

MovementData_0x198a5f: ; 0x198a5f
	step_right
	step_right
	step_up
	step_end
; 0x198a63

MovementData_0x198a63: ; 0x198a63
	step_down
	step_right
	step_right
	step_up
	step_up
	step_end
; 0x198a69

UnknownText_0x198a69: ; 0x198a69
	db $0, "They built the new", $4f
	db "RADIO TOWER to", $51
	db "replace the old,", $4f
	db "creaky one.", $57
; 0x198aa9

UnknownText_0x198aa9: ; 0x198aa9
	db $0, "I know there's a", $4f
	db "new BIKE SHOP, but", $51
	db "I can't find it", $4f
	db "anywhere.", $57
; 0x198ae6

UnknownText_0x198ae6: ; 0x198ae6
	db $0, "Is that man in", $4f
	db "black dressed up", $51
	db "like a TEAM ROCKET", $4f
	db "member? How silly!", $57
; 0x198b2d

UnknownText_0x198b2d: ; 0x198b2d
	db $0, "Was that man in", $4f
	db "black really part", $51
	db "of TEAM ROCKET? I", $4f
	db "can't believe it!", $57
; 0x198b73

UnknownText_0x198b73: ; 0x198b73
	db $0, "The RADIO TOWER in", $4f
	db "GOLDENROD CITY is", $55
	db "a landmark.", $51
	db "They're running a", $4f
	db "promotional cam- ", $55
	db "paign right now.", $51
	db "They'll modify", $4f
	db "your #GEAR,", $51
	db "so it can also", $4f
	db "serve as a radio.", $57
; 0x198c14

UnknownText_0x198c14: ; 0x198c14
	db $0, "Oh, your #GEAR", $4f
	db "works as a radio!", $57
; 0x198c36

UnknownText_0x198c36: ; 0x198c36
	db $0, "E-he-he-he…", $51
	db "I got in trouble", $4f
	db "for playing in the", $51
	db "basement of the", $4f
	db "DEPT.STORE.", $57
; 0x198c83

UnknownText_0x198c83: ; 0x198c83
	db $0, "The man at that", $4f
	db "house rates your", $55
	db "#MON names.", $51
	db "He can even rename", $4f
	db "your #MON.", $57
; 0x198ccf

UnknownText_0x198ccf: ; 0x198ccf
	db $0, "Whew! This is one", $4f
	db "big town. I don't", $51
	db "know where any-", $4f
	db "thing is.", $57
; 0x198d0d

UnknownText_0x198d0d: ; 0x198d0d
	db $0, "So this is the", $4f
	db "RADIO TOWER…", $57
; 0x198d2a

UnknownText_0x198d2a: ; 0x198d2a
	db $0, "What do you want,", $4f
	db "you pest? Scram!", $57
; 0x198d4e

UnknownText_0x198d4e: ; 0x198d4e
	db $0, "Stay out of the", $4f
	db "way! Beat it!", $57
; 0x198d6d

UnknownText_0x198d6d: ; 0x198d6d
	db $0, "Take over the", $4f
	db "RADIO TOWER…", $51
	db "What? It's none of", $4f
	db "your business!", $57
; 0x198daa

UnknownText_0x198daa: ; 0x198daa
	db $0, "#MON? They're", $4f
	db "nothing more than", $51
	db "tools for making", $4f
	db "money!", $57
; 0x198de2

UnknownText_0x198de2: ; 0x198de2
	db $0, "Our dream will", $4f
	db "soon come true…", $51
	db "It was such a long", $4f
	db "struggle…", $57
; 0x198e1f

UnknownText_0x198e1f: ; 0x198e1f
	db $0, "Hey, brat! You", $4f
	db "don't belong here!", $55
	db "Get lost!", $57
; 0x198e4b

UnknownText_0x198e4b: ; 0x198e4b
	db $0, "Come taste the", $4f
	db "true terror of", $55
	db "TEAM ROCKET!", $57
; 0x198e77

UnknownText_0x198e77: ; 0x198e77
	db $0, "GOLDENROD CITY", $4f
	db "STATION", $57
; 0x198e8f

UnknownText_0x198e8f: ; 0x198e8f
	db $0, "GOLDENROD CITY", $4f
	db "RADIO TOWER", $57
; 0x198eab

UnknownText_0x198eab: ; 0x198eab
	db $0, "Full Selection of", $4f
	db "#MON Goods!", $51
	db "GOLDENROD CITY", $4f
	db "DEPT.STORE", $57
; 0x198ee4

UnknownText_0x198ee4: ; 0x198ee4
	db $0, "GOLDENROD CITY", $4f
	db "#MON GYM", $55
	db "LEADER: WHITNEY", $51
	db "The Incredibly", $4f
	db "Pretty Girl!", $57
; 0x198f29

UnknownText_0x198f29: ; 0x198f29
	db $0, "GOLDENROD CITY", $51
	db "The Festive City", $4f
	db "of Opulent Charm", $57
; 0x198f5b

UnknownText_0x198f5b: ; 0x198f5b
	db $0, "The World is a", $4f
	db "Cycle Path!", $55
	db "BIKE SHOP", $57
; 0x198f81

UnknownText_0x198f81: ; 0x198f81
	db $0, "Your Playground!", $51
	db "GOLDENROD CITY", $4f
	db "GAME CORNER", $57
; 0x198fae

UnknownText_0x198fae: ; 0x198fae
	db $0, "NAME RATER", $51
	db "Get Your #MON", $4f
	db "Nicknames Rated", $57
; 0x198fd8

UnknownText_0x198fd8: ; 0x198fd8
	db $0, "UNDERGROUND", $4f
	db "ENTRANCE", $57
; 0x198fee

UnknownText_0x198fee: ; 0x198fee
	db $0, "UNDERGROUND", $4f
	db "ENTRANCE", $57
; 0x199004

UnknownText_0x199004: ; 0x199004
	db $0, "For Mobile Tips!", $4f
	db "#COM CENTER", $57
; 0x199022

UnknownText_0x199022: ; 0x199022
	db $0, "Blooming Beautiful", $4f
	db "FLOWER SHOP", $57
; 0x199042

UnknownText_0x199042: ; 0x199042
	db $0, "I can teach your", $4f
	db "#MON amazing", $51
	db "moves if you'd", $4f
	db "like.", $51
	db "Should I teach a", $4f
	db "new move?", $57
; 0x199090

UnknownText_0x199090: ; 0x199090
	db $0, "It will cost you", $4f
	db "4000 coins. Okay?", $57
; 0x1990b4

UnknownText_0x1990b4: ; 0x1990b4
	db $0, "Aww… But they're", $4f
	db "amazing…", $57
; 0x1990ce

UnknownText_0x1990ce: ; 0x1990ce
	db $0, "Wahahah! You won't", $4f
	db "regret it!", $51
	db "Which move should", $4f
	db "I teach?", $57
; 0x199107

UnknownText_0x199107: ; 0x199107
	db $0, "Hm, too bad. I'll", $4f
	db "have to get some", $55
	db "cash from home…", $57
; 0x19913a

UnknownText_0x19913a: ; 0x19913a
	db $0, "If you understand", $4f
	db "what's so amazing", $51
	db "about this move,", $4f
	db "you've made it as", $55
	db "a trainer.", $57
; 0x19918b

UnknownText_0x19918b: ; 0x19918b
	db $0, "Wahahah!", $4f
	db "Farewell, kid!", $57
; 0x1991a4

UnknownText_0x1991a4: ; 0x1991a4
	db $0, "B-but…", $57
; 0x1991ac

UnknownText_0x1991ac: ; 0x1991ac
	db $0, "…You don't have", $4f
	db "enough coins here…", $57
; 0x1991cf

UnknownText_0x1991cf: ; 0x1991cf
	db $0, $57
; 0x1991d1

GoldenrodCity_MapEventHeader: ; 0x1991d1
	; filler
	db 0, 0

	; warps
	db 15
	warp_def $7, $18, 1, GROUP_GOLDENROD_GYM, MAP_GOLDENROD_GYM
	warp_def $1d, $1d, 1, GROUP_GOLDENROD_BIKE_SHOP, MAP_GOLDENROD_BIKE_SHOP
	warp_def $15, $1f, 1, GROUP_GOLDENROD_HAPPINESS_RATER, MAP_GOLDENROD_HAPPINESS_RATER
	warp_def $19, $5, 1, GROUP_GOLDENROD_BILLS_HOUSE, MAP_GOLDENROD_BILLS_HOUSE
	warp_def $d, $9, 2, GROUP_GOLDENROD_MAGNET_TRAIN_STATION, MAP_GOLDENROD_MAGNET_TRAIN_STATION
	warp_def $5, $1d, 1, GROUP_GOLDENROD_FLOWER_SHOP, MAP_GOLDENROD_FLOWER_SHOP
	warp_def $9, $21, 1, GROUP_GOLDENROD_PP_SPEECH_HOUSE, MAP_GOLDENROD_PP_SPEECH_HOUSE
	warp_def $7, $f, 1, GROUP_GOLDENROD_NAME_RATERS_HOUSE, MAP_GOLDENROD_NAME_RATERS_HOUSE
	warp_def $1b, $18, 1, GROUP_GOLDENROD_DEPT_STORE_1F, MAP_GOLDENROD_DEPT_STORE_1F
	warp_def $15, $e, 1, GROUP_GOLDENROD_GAME_CORNER, MAP_GOLDENROD_GAME_CORNER
	warp_def $f, $5, 1, GROUP_RADIO_TOWER_1F, MAP_RADIO_TOWER_1F
	warp_def $1, $13, 3, GROUP_ROUTE_35_GOLDENROD_GATE, MAP_ROUTE_35_GOLDENROD_GATE
	warp_def $5, $9, 8, GROUP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES, MAP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES
	warp_def $1d, $b, 5, GROUP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES, MAP_UNDERGROUND_PATH_SWITCH_ROOM_ENTRANCES
	warp_def $1b, $f, 1, GROUP_GOLDENROD_POKECENTER_1F, MAP_GOLDENROD_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 12
	signpost 14, 10, $0, MapGoldenrodCitySignpost0Script
	signpost 17, 4, $0, MapGoldenrodCitySignpost1Script
	signpost 27, 26, $0, MapGoldenrodCitySignpost2Script
	signpost 9, 26, $0, MapGoldenrodCitySignpost3Script
	signpost 18, 22, $0, MapGoldenrodCitySignpost4Script
	signpost 30, 28, $0, MapGoldenrodCitySignpost5Script
	signpost 22, 16, $0, MapGoldenrodCitySignpost6Script
	signpost 7, 12, $0, MapGoldenrodCitySignpost7Script
	signpost 6, 8, $0, MapGoldenrodCitySignpost8Script
	signpost 30, 12, $0, MapGoldenrodCitySignpost9Script
	signpost 27, 16, $1, MapGoldenrodCitySignpost10Script
	signpost 6, 30, $0, MapGoldenrodCitySignpost11Script

	; people-events
	db 15
	person_event $2d, 22, 11, $7, $0, 255, 255, $0, 0, UnknownScript_0x1989e3, $06cf
	person_event $27, 21, 34, $2, $11, 255, 255, $0, 0, UnknownScript_0x1989e6, $06cf
	person_event $24, 20, 16, $8, $0, 255, 255, $a0, 0, UnknownScript_0x1989e9, $06cf
	person_event $24, 30, 24, $2, $21, 255, 255, $0, 0, UnknownScript_0x1989fd, $06cf
	person_event $27, 21, 23, $2, $11, 255, 255, $80, 0, UnknownScript_0x198a11, $06cf
	person_event $28, 14, 21, $5, $2, 255, 255, $a0, 0, UnknownScript_0x198a14, $06cf
	person_event $2f, 31, 15, $5, $1, 255, 255, $0, 0, UnknownScript_0x198a17, $06cf
	person_event $35, 20, 8, $7, $0, 255, 255, $0, 0, UnknownScript_0x198a1a, $06cc
	person_event $35, 24, 32, $7, $0, 255, 255, $0, 0, UnknownScript_0x198a29, $06cd
	person_event $35, 19, 12, $6, $0, 255, 255, $0, 0, UnknownScript_0x198a2c, $06cd
	person_event $35, 27, 20, $9, $0, 255, 255, $0, 0, UnknownScript_0x198a2f, $06ce
	person_event $35, 24, 33, $7, $0, 255, 255, $0, 0, UnknownScript_0x198a32, $06ce
	person_event $35, 11, 33, $6, $0, 255, 255, $0, 0, UnknownScript_0x198a35, $06ce
	person_event $35, 14, 35, $8, $0, 255, 255, $0, 0, UnknownScript_0x198a38, $06ce
	person_event $2d, 26, 16, $3, $0, 255, 255, $80, 0, UnknownScript_0x198909, $076a
; 0x199321

SaffronCity_MapScriptHeader: ; 0x199321
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x199326
; 0x199326

UnknownScript_0x199326: ; 0x199326
	setbit2 $003c
	return
; 0x19932a

UnknownScript_0x19932a: ; 0x19932a
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x199338
	2writetext UnknownText_0x19938d
	closetext
	loadmovesprites
	end
; 0x199338

UnknownScript_0x199338: ; 0x199338
	2writetext UnknownText_0x19940d
	closetext
	loadmovesprites
	end
; 0x19933e

UnknownScript_0x19933e: ; 0x19933e
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x19934c
	2writetext UnknownText_0x199460
	closetext
	loadmovesprites
	end
; 0x19934c

UnknownScript_0x19934c: ; 0x19934c
	2writetext UnknownText_0x1994ae
	closetext
	loadmovesprites
	end
; 0x199352

UnknownScript_0x199352: ; 0x199352
	jumptextfaceplayer UnknownText_0x1994fe
; 0x199355

UnknownScript_0x199355: ; 0x199355
	jumptextfaceplayer UnknownText_0x19958e
; 0x199358

UnknownScript_0x199358: ; 0x199358
	faceplayer
	loadfont
	checkbit1 $00c9
	iftrue UnknownScript_0x199366
	2writetext UnknownText_0x1995fc
	closetext
	loadmovesprites
	end
; 0x199366

UnknownScript_0x199366: ; 0x199366
	2writetext UnknownText_0x19964b
	closetext
	loadmovesprites
	end
; 0x19936c

UnknownScript_0x19936c: ; 0x19936c
	jumptextfaceplayer UnknownText_0x1996a5
; 0x19936f

UnknownScript_0x19936f: ; 0x19936f
	jumptextfaceplayer UnknownText_0x1996e5
; 0x199372

UnknownScript_0x199372: ; 0x199372
	jumptextfaceplayer UnknownText_0x199745
; 0x199375

MapSaffronCitySignpost0Script: ; 0x199375
	jumptext UnknownText_0x1997b7
; 0x199378

MapSaffronCitySignpost1Script: ; 0x199378
	jumptext UnknownText_0x1997e6
; 0x19937b

MapSaffronCitySignpost2Script: ; 0x19937b
	jumptext UnknownText_0x199829
; 0x19937e

MapSaffronCitySignpost3Script: ; 0x19937e
	jumptext UnknownText_0x19984a
; 0x199381

MapSaffronCitySignpost4Script: ; 0x199381
	jumptext UnknownText_0x199865
; 0x199384

MapSaffronCitySignpost5Script: ; 0x199384
	jumptext UnknownText_0x199879
; 0x199387

MapSaffronCitySignpost6Script: ; 0x199387
	jumpstd $0010
; 0x19938a

MapSaffronCitySignpost7Script: ; 0x19938a
	jumpstd $0011
; 0x19938d

UnknownText_0x19938d: ; 0x19938d
	db $0, "A little girl who", $4f
	db "is an expert at", $51
	db "mimicking people", $4f
	db "lives here.", $51
	db "She even mimics", $4f
	db "the people she's", $51
	db "conversing with.", $4f
	db "It's confusing.", $57
; 0x19940d

UnknownText_0x19940d: ; 0x19940d
	db $0, "The COPYCAT girl", $4f
	db "looked unhappy.", $51
	db "She said she lost", $4f
	db "her favorite #", $55
	db "DOLL--CLEFAIRY.", $57
; 0x199460

UnknownText_0x199460: ; 0x199460
	db $0, "You came out from", $4f
	db "JOHTO?", $51
	db "You can zip back", $4f
	db "home if the MAGNET", $55
	db "TRAIN's running.", $57
; 0x1994ae

UnknownText_0x1994ae: ; 0x1994ae
	db $0, "You came out from", $4f
	db "JOHTO?", $51
	db "You can zip back", $4f
	db "home by hopping on", $55
	db "the MAGNET TRAIN.", $57
; 0x1994fe

UnknownText_0x1994fe: ; 0x1994fe
	db $0, "I went to the GYM,", $4f
	db "raring for battles", $55
	db "against trainers…", $51
	db "It turns out, I", $4f
	db "stumbled into the", $51
	db "unused GYM next", $4f
	db "door.", $51
	db "Boy, I was pretty", $4f
	db "embarrassed.", $57
; 0x19958e

UnknownText_0x19958e: ; 0x19958e
	db $0, "This is SILPH CO.,", $4f
	db "famous for #MON", $55
	db "merchandise.", $51
	db "In the past, TEAM", $4f
	db "ROCKET wanted the", $51
	db "company because of", $4f
	db "that.", $57
; 0x1995fc

UnknownText_0x1995fc: ; 0x1995fc
	db $0, "Chew… Chew…", $51
	db "I hear there's big", $4f
	db "trouble brewing at", $55
	db "the POWER PLANT.", $51
	db "Chew… Chew…", $57
; 0x19964b

UnknownText_0x19964b: ; 0x19964b
	db $0, "Chew… Chew…", $51
	db "I hear there was", $4f
	db "big trouble at the", $55
	db "POWER PLANT.", $51
	db "Chew… Chew…", $4f
	db "Haaah, I'm full!", $57
; 0x1996a5

UnknownText_0x1996a5: ; 0x1996a5
	db $0, "Going into an", $4f
	db "alley for the", $51
	db "first time makes", $4f
	db "me sorta anxious.", $57
; 0x1996e5

UnknownText_0x1996e5: ; 0x1996e5
	db $0, "There's a place", $4f
	db "called TRAINER", $51
	db "HOUSE in VIRIDIAN", $4f
	db "where trainers", $51
	db "gather from all", $4f
	db "over the place.", $57
; 0x199745

UnknownText_0x199745: ; 0x199745
	db $0, "Our city was", $4f
	db "featured on a", $55
	db "radio program.", $51
	db "It's nice to hear", $4f
	db "praise for your", $51
	db "city, but it's a", $4f
	db "bit embarrassing", $55
	db "too.", $57
; 0x1997b7

UnknownText_0x1997b7: ; 0x1997b7
	db $0, "SAFFRON CITY", $51
	db "Shining, Golden", $4f
	db "Land of Commerce", $57
; 0x1997e6

UnknownText_0x1997e6: ; 0x1997e6
	db $0, "SAFFRON CITY", $4f
	db "#MON GYM", $55
	db "LEADER: SABRINA", $51
	db "The Master of", $4f
	db "Psychic #MON!", $57
; 0x199829

UnknownText_0x199829: ; 0x199829
	db $0, "Everyone Welcome!", $4f
	db "FIGHTING DOJO", $57
; 0x19984a

UnknownText_0x19984a: ; 0x19984a
	db $0, "SILPH CO.", $4f
	db "OFFICE BUILDING", $57
; 0x199865

UnknownText_0x199865: ; 0x199865
	db $0, "MR.PSYCHIC'S", $4f
	db "HOUSE", $57
; 0x199879

UnknownText_0x199879: ; 0x199879
	db $0, "SAFFRON CITY", $4f
	db "MAGNET TRAIN", $55
	db "STATION", $57
; 0x19989c

SaffronCity_MapEventHeader: ; 0x19989c
	; filler
	db 0, 0

	; warps
	db 15
	warp_def $3, $1a, 1, GROUP_FIGHTING_DOJO, MAP_FIGHTING_DOJO
	warp_def $3, $22, 1, GROUP_SAFFRON_GYM, MAP_SAFFRON_GYM
	warp_def $b, $19, 2, GROUP_SAFFRON_MART, MAP_SAFFRON_MART
	warp_def $1d, $9, 1, GROUP_SAFFRON_POKECENTER_1F, MAP_SAFFRON_POKECENTER_1F
	warp_def $1d, $1b, 1, GROUP_MR_PSYCHICS_HOUSE, MAP_MR_PSYCHICS_HOUSE
	warp_def $3, $8, 2, GROUP_SAFFRON_TRAIN_STATION, MAP_SAFFRON_TRAIN_STATION
	warp_def $15, $12, 1, GROUP_SILPH_CO_1F, MAP_SILPH_CO_1F
	warp_def $b, $9, 1, GROUP_COPYCATS_HOUSE_1F, MAP_COPYCATS_HOUSE_1F
	warp_def $3, $12, 3, GROUP_ROUTE_5_SAFFRON_CITY_GATE, MAP_ROUTE_5_SAFFRON_CITY_GATE
	warp_def $18, $0, 3, GROUP_ROUTE_7_SAFFRON_GATE, MAP_ROUTE_7_SAFFRON_GATE
	warp_def $19, $0, 4, GROUP_ROUTE_7_SAFFRON_GATE, MAP_ROUTE_7_SAFFRON_GATE
	warp_def $21, $10, 1, GROUP_ROUTE_6_SAFFRON_GATE, MAP_ROUTE_6_SAFFRON_GATE
	warp_def $21, $11, 2, GROUP_ROUTE_6_SAFFRON_GATE, MAP_ROUTE_6_SAFFRON_GATE
	warp_def $16, $27, 1, GROUP_ROUTE_8_SAFFRON_GATE, MAP_ROUTE_8_SAFFRON_GATE
	warp_def $17, $27, 2, GROUP_ROUTE_8_SAFFRON_GATE, MAP_ROUTE_8_SAFFRON_GATE

	; xy triggers
	db 0

	; signposts
	db 8
	signpost 5, 21, $0, MapSaffronCitySignpost0Script
	signpost 5, 33, $0, MapSaffronCitySignpost1Script
	signpost 5, 25, $0, MapSaffronCitySignpost2Script
	signpost 21, 15, $0, MapSaffronCitySignpost3Script
	signpost 29, 25, $0, MapSaffronCitySignpost4Script
	signpost 5, 11, $0, MapSaffronCitySignpost5Script
	signpost 29, 10, $0, MapSaffronCitySignpost6Script
	signpost 11, 26, $0, MapSaffronCitySignpost7Script

	; people-events
	db 8
	person_event $28, 18, 11, $5, $2, 255, 255, $80, 0, UnknownScript_0x19932a, $ffff
	person_event $2d, 34, 23, $5, $2, 255, 255, $b0, 0, UnknownScript_0x19933e, $ffff
	person_event $23, 11, 36, $5, $1, 255, 255, $a0, 0, UnknownScript_0x199352, $ffff
	person_event $24, 28, 24, $5, $2, 255, 255, $80, 0, UnknownScript_0x199355, $ffff
	person_event $3a, 16, 31, $6, $0, 255, 255, $a0, 0, UnknownScript_0x199358, $ffff
	person_event $27, 23, 19, $4, $10, 255, 255, $90, 0, UnknownScript_0x19936c, $ffff
	person_event $27, 26, 39, $2, $11, 255, 255, $80, 0, UnknownScript_0x19936f, $ffff
	person_event $28, 12, 23, $3, $0, 255, 255, $a0, 0, UnknownScript_0x199372, $ffff
; 0x19997d

MahoganyRedGyaradosSpeechHouse_MapScriptHeader: ; 0x19997d
	; trigger count
	db 0

	; callback count
	db 0
; 0x19997f

UnknownScript_0x19997f: ; 0x19997f
	jumptextfaceplayer UnknownText_0x19999c
; 0x199982

UnknownScript_0x199982: ; 0x199982
	faceplayer
	loadfont
	checkbit2 $0013
	iftrue UnknownScript_0x199990
	2writetext UnknownText_0x199a0e
	closetext
	loadmovesprites
	end
; 0x199990

UnknownScript_0x199990: ; 0x199990
	2writetext UnknownText_0x199a3d
	closetext
	loadmovesprites
	end
; 0x199996

; TODO wtf?
UnknownText_0x199996: ; 0x199996
	limited_interpret_data 2
	db $0, "ズ", $03, $00

UnknownText_0x19999c: ; 0x19999c
	db $0, "I heard that a red", $4f
	db "GYARADOS appeared", $55
	db "at the LAKE.", $51
	db "That's odd, since", $4f
	db "even ordinary", $51
	db "GYARADOS are rare", $4f
	db "in that lake…", $57
; 0x199a0e

UnknownText_0x199a0e: ; 0x199a0e
	db $0, "My favorite radio", $4f
	db "program? I'd say", $55
	db "#MON MUSIC.", $57
; 0x199a3d

UnknownText_0x199a3d: ; 0x199a3d
	db $0, "I've been hearing", $4f
	db "laughter on the", $51
	db "radio…", $4f
	db "It's creepy.", $57
; 0x199a72

MahoganyRedGyaradosSpeechHouse_MapEventHeader: ; 0x199a72
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN
	warp_def $7, $3, 2, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $41, 7, 6, $9, $0, 255, 255, $0, 0, UnknownScript_0x19997f, $ffff
	person_event $29, 9, 10, $4, $10, 255, 255, $90, 0, UnknownScript_0x199982, $ffff
; 0x199a9c

MahoganyGym_MapScriptHeader: ; 0x199a9c
	; trigger count
	db 0

	; callback count
	db 0
; 0x199a9e

UnknownScript_0x199a9e: ; 0x199a9e
	faceplayer
	loadfont
	checkbit1 $04c3
	iftrue UnknownScript_0x199ac8
	2writetext UnknownText_0x199b8d
	closetext
	loadmovesprites
	winlosstext UnknownText_0x199cb3, $0000
	loadtrainer PRYCE, 1
	startbattle
	returnafterbattle
	setbit1 $04c3
	loadfont
	2writetext UnknownText_0x199d3b
	playsound $009c
	waitbutton
	setbit2 $0021
	checkcode $7
	2call UnknownScript_0x199af6
UnknownScript_0x199ac8: ; 0x199ac8
	checkbit1 $000e
	iftrue UnknownScript_0x199af0
	setbit1 $0592
	setbit1 $0593
	setbit1 $040e
	setbit1 $040f
	setbit1 $0410
	2writetext UnknownText_0x199d55
	keeptextopen
	verbosegiveitem TM_16, 1
	iffalse UnknownScript_0x199af4
	setbit1 $000e
	2writetext UnknownText_0x199def
	closetext
	loadmovesprites
	end
; 0x199af0

UnknownScript_0x199af0: ; 0x199af0
	2writetext UnknownText_0x199e59
	closetext
UnknownScript_0x199af4: ; 0x199af4
	loadmovesprites
	end
; 0x199af6

UnknownScript_0x199af6: ; 0x199af6
	if_equal $7, UnknownScript_0x199b02
	if_equal $6, UnknownScript_0x199aff
	end
; 0x199aff

UnknownScript_0x199aff: ; 0x199aff
	jumpstd $0012
; 0x199b02

UnknownScript_0x199b02: ; 0x199b02
	jumpstd $0013
; 0x199b05

TrainerSkierRoxanne: ; 0x199b05
	; bit/flag number
	dw $592

	; trainer group && trainer id
	db SKIER, ROXANNE

	; text when seen
	dw SkierRoxanneSeenText

	; text when trainer beaten
	dw SkierRoxanneBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SkierRoxanneScript
; 0x199b11

SkierRoxanneScript: ; 0x199b11
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19a116
	closetext
	loadmovesprites
	end
; 0x199b19

TrainerSkierClarissa: ; 0x199b19
	; bit/flag number
	dw $593

	; trainer group && trainer id
	db SKIER, CLARISSA

	; text when seen
	dw SkierClarissaSeenText

	; text when trainer beaten
	dw SkierClarissaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SkierClarissaScript
; 0x199b25

SkierClarissaScript: ; 0x199b25
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19a18f
	closetext
	loadmovesprites
	end
; 0x199b2d

TrainerBoarderRonald: ; 0x199b2d
	; bit/flag number
	dw $40e

	; trainer group && trainer id
	db BOARDER, RONALD

	; text when seen
	dw BoarderRonaldSeenText

	; text when trainer beaten
	dw BoarderRonaldBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BoarderRonaldScript
; 0x199b39

BoarderRonaldScript: ; 0x199b39
	talkaftercancel
	loadfont
	2writetext UnknownText_0x199f2d
	closetext
	loadmovesprites
	end
; 0x199b41

TrainerBoarderBrad: ; 0x199b41
	; bit/flag number
	dw $40f

	; trainer group && trainer id
	db BOARDER, BRAD

	; text when seen
	dw BoarderBradSeenText

	; text when trainer beaten
	dw BoarderBradBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BoarderBradScript
; 0x199b4d

BoarderBradScript: ; 0x199b4d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x199fdd
	closetext
	loadmovesprites
	end
; 0x199b55

TrainerBoarderDouglas: ; 0x199b55
	; bit/flag number
	dw $410

	; trainer group && trainer id
	db BOARDER, DOUGLAS

	; text when seen
	dw BoarderDouglasSeenText

	; text when trainer beaten
	dw BoarderDouglasBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BoarderDouglasScript
; 0x199b61

BoarderDouglasScript: ; 0x199b61
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19a047
	closetext
	loadmovesprites
	end
; 0x199b69

MahoganyGymGuyScript: ; 0x199b69
	faceplayer
	loadfont
	checkbit1 $04c3
	iftrue .MahoganyGymGuyWinScript
	2writetext MahoganyGymGuyText
	closetext
	loadmovesprites
	end

.MahoganyGymGuyWinScript
	2writetext MahoganyGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x199b7d

MapMahoganyGymSignpost1Script: ; 0x199b7d
	checkbit2 $0021
	iftrue UnknownScript_0x199b86
	jumpstd $002d
; 0x199b86

UnknownScript_0x199b86: ; 0x199b86
	trainertotext PRYCE, 1, $1
	jumpstd $002e
; 0x199b8d

UnknownText_0x199b8d: ; 0x199b8d
	db $0, "#MON have many", $4f
	db "experiences in", $51
	db "their lives, just ", $4f
	db "like we do. ", $51
	db "I, too, have seen", $4f
	db "and suffered much", $55
	db "in my life.", $51
	db "Since I am your", $4f
	db "elder, let me show", $55
	db "you what I mean.", $51
	db "I have been with", $4f
	db "#MON since", $51
	db "before you were", $4f
	db "born.", $51
	db "I do not lose", $4f
	db "easily.", $51
	db "I, PRYCE--the", $4f
	db "winter trainer--", $51
	db "shall demonstrate", $4f
	db "my power!", $57
; 0x199cb3

UnknownText_0x199cb3: ; 0x199cb3
	db $0, "Ah, I am impressed", $4f
	db "by your prowess.", $51
	db "With your strong", $4f
	db "will, I know you", $51
	db "will overcome all", $4f
	db "life's obstacles.", $51
	db "You are worthy of", $4f
	db "this BADGE!", $57
; 0x199d3b

UnknownText_0x199d3b: ; 0x199d3b
	db $0, $52, " received", $4f
	db "GLACIERBADGE.", $57
; 0x199d55

UnknownText_0x199d55: ; 0x199d55
	db $0, "That BADGE will", $4f
	db "raise the SPECIAL", $55
	db "stats of #MON.", $51
	db "It also lets your", $4f
	db "#MON use WHIRL-", $55
	db "POOL to get across", $55
	db "real whirlpools.", $51
	db "And this… This is", $4f
	db "a gift from me!", $57
; 0x199def

UnknownText_0x199def: ; 0x199def
	db $0, "That TM contains", $4f
	db "ICY WIND.", $51
	db "It inflicts damage", $4f
	db "and lowers speed.", $51
	db "It demonstrates", $4f
	db "the harshness of", $55
	db "winter.", $57
; 0x199e59

UnknownText_0x199e59: ; 0x199e59
	db $0, "When the ice and", $4f
	db "snow melt, spring", $55
	db "arrives.", $51
	db "You and your #-", $4f
	db "MON will be to-", $51
	db "gether for many", $4f
	db "years to come.", $51
	db "Cherish your time", $4f
	db "together!", $57
; 0x199ee1

BoarderRonaldSeenText: ; 0x199ee1
	db $0, "I'll freeze your", $4f
	db "#MON, so you", $55
	db "can't do a thing!", $57
; 0x199f10

BoarderRonaldBeatenText: ; 0x199f10
	db $0, "Darn. I couldn't", $4f
	db "do a thing.", $57
; 0x199f2d

UnknownText_0x199f2d: ; 0x199f2d
	db $0, "I think there's a", $4f
	db "move a #MON", $51
	db "can use while it's", $4f
	db "frozen.", $57
; 0x199f65

BoarderBradSeenText: ; 0x199f65
	db $0, "This GYM has a", $4f
	db "slippery floor.", $51
	db "It's fun, isn't", $4f
	db "it?", $51
	db "But hey--we're", $4f
	db "not playing games", $55
	db "here!", $57
; 0x199fbd

BoarderBradBeatenText: ; 0x199fbd
	db $0, "Do you see how", $4f
	db "serious we are?", $57
; 0x199fdd

UnknownText_0x199fdd: ; 0x199fdd
	db $0, "This GYM is great.", $4f
	db "I love boarding", $55
	db "with my #MON!", $57
; 0x19a00f

BoarderDouglasSeenText: ; 0x19a00f
	db $0, "I know PRYCE's", $4f
	db "secret.", $57
; 0x19a026

BoarderDouglasBeatenText: ; 0x19a026
	db $0, "OK. I'll tell you", $4f
	db "PRYCE's secret.", $57
; 0x19a047

UnknownText_0x19a047: ; 0x19a047
	db $0, "The secret behind", $4f
	db "PRYCE's power…", $51
	db "He meditates under", $4f
	db "a waterfall daily", $51
	db "to strengthen his", $4f
	db "mind and body.", $57
; 0x19a0ae

SkierRoxanneSeenText: ; 0x19a0ae
	db $0, "To get to PRYCE,", $4f
	db "our GYM LEADER,", $51
	db "you need to think", $4f
	db "before you skate.", $57
; 0x19a0f4

SkierRoxanneBeatenText: ; 0x19a0f4
	db $0, "I wouldn't lose to", $4f
	db "you in skiing!", $57
; 0x19a116

UnknownText_0x19a116: ; 0x19a116
	db $0, "If you don't skate", $4f
	db "with precision,", $51
	db "you won't get far", $4f
	db "in this GYM.", $57
; 0x19a157

SkierClarissaSeenText: ; 0x19a157
	db $0, "Check out my", $4f
	db "parallel turn!", $57
; 0x19a174

SkierClarissaBeatenText: ; 0x19a174
	db $0, "No! You made me", $4f
	db "wipe out!", $57
; 0x19a18f

UnknownText_0x19a18f: ; 0x19a18f
	db $0, "I shouldn't have", $4f
	db "been bragging", $55
	db "about my skiing…", $57
; 0x19a1bf

MahoganyGymGuyText: ; 0x19a1bf
	db $0, "PRYCE is a veteran", $4f
	db "who has trained", $51
	db "#MON for some", $4f
	db "50 years.", $51
	db "He's said to be", $4f
	db "good at freezing", $51
	db "opponents with", $4f
	db "ice-type moves.", $51
	db "That means you", $4f
	db "should melt him", $51
	db "with your burning", $4f
	db "ambition!", $57
; 0x19a275

MahoganyGymGuyWinText: ; 0x19a275
	db $0, "PRYCE is some-", $4f
	db "thing, but you're", $55
	db "something else!", $51
	db "That was a hot", $4f
	db "battle that", $51
	db "bridged the gen-", $4f
	db "eration gap!", $57
; 0x19a2df

MahoganyGym_MapEventHeader: ; 0x19a2df
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $11, $4, 3, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN
	warp_def $11, $5, 3, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 15, 3, $0, MapMahoganyGymSignpost1Script
	signpost 15, 6, $0, MapMahoganyGymSignpost1Script

	; people-events
	db 7
	person_event $18, 7, 9, $6, $0, 255, 255, $b0, 0, UnknownScript_0x199a9e, $ffff
	person_event $2a, 10, 8, $6, $0, 255, 255, $82, 1, TrainerSkierRoxanne, $ffff
	person_event $2c, 21, 4, $7, $0, 255, 255, $92, 1, TrainerBoarderRonald, $ffff
	person_event $2a, 21, 13, $7, $0, 255, 255, $82, 1, TrainerSkierClarissa, $ffff
	person_event $2c, 13, 9, $6, $0, 255, 255, $92, 1, TrainerBoarderBrad, $ffff
	person_event $2c, 8, 6, $a, $0, 255, 255, $92, 1, TrainerBoarderDouglas, $ffff
	person_event $48, 19, 11, $6, $0, 255, 255, $80, 0, MahoganyGymGuyScript, $ffff
; 0x19a354

MahoganyPokeCenter1F_MapScriptHeader: ; 0x19a354
	; trigger count
	db 0

	; callback count
	db 0
; 0x19a356

UnknownScript_0x19a356: ; 0x19a356
	jumpstd $0000
; 0x19a359

UnknownScript_0x19a359: ; 0x19a359
	jumptextfaceplayer UnknownText_0x19a362
; 0x19a35c

UnknownScript_0x19a35c: ; 0x19a35c
	jumptextfaceplayer UnknownText_0x19a3b3
; 0x19a35f

UnknownScript_0x19a35f: ; 0x19a35f
	jumptextfaceplayer UnknownText_0x19a418
; 0x19a362

UnknownText_0x19a362: ; 0x19a362
	db $0, "What's this? TEAM", $4f
	db "ROCKET has come", $55
	db "back?", $51
	db "I saw some men in", $4f
	db "black at LAKE OF", $55
	db "RAGE…", $57
; 0x19a3b3

UnknownText_0x19a3b3: ; 0x19a3b3
	db $0, "I stop my #MON", $4f
	db "from evolving too", $55
	db "early.", $51
	db "I make them learn", $4f
	db "certain moves be-", $55
	db "fore I let them", $55
	db "evolve.", $57
; 0x19a418

UnknownText_0x19a418: ; 0x19a418
	db $0, "#MON do become", $4f
	db "stronger when they", $51
	db "evolve, but they", $4f
	db "also learn moves", $55
	db "more slowly.", $57
; 0x19a46a

MahoganyPokeCenter1F_MapEventHeader: ; 0x19a46a
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 4, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN
	warp_def $7, $4, 4, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x19a356, $ffff
	person_event $2d, 6, 11, $2, $11, 255, 255, $80, 0, UnknownScript_0x19a359, $ffff
	person_event $27, 7, 5, $9, $0, 255, 255, $a0, 0, UnknownScript_0x19a35c, $ffff
	person_event $24, 7, 6, $8, $0, 255, 255, $0, 0, UnknownScript_0x19a35f, $ffff
; 0x19a4b3

Route42EcruteakGate_MapScriptHeader: ; 0x19a4b3
	; trigger count
	db 0

	; callback count
	db 0
; 0x19a4b5

UnknownScript_0x19a4b5: ; 0x19a4b5
	jumptextfaceplayer UnknownText_0x19a4b8
; 0x19a4b8

UnknownText_0x19a4b8: ; 0x19a4b8
	db $0, "MT.MORTAR is like", $4f
	db "a maze inside.", $51
	db "Be careful. Don't", $4f
	db "get lost in there.", $57
; 0x19a4fe

Route42EcruteakGate_MapEventHeader: ; 0x19a4fe
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $4, $0, 1, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $5, $0, 2, GROUP_ECRUTEAK_CITY, MAP_ECRUTEAK_CITY
	warp_def $4, $9, 1, GROUP_ROUTE_42, MAP_ROUTE_42
	warp_def $5, $9, 2, GROUP_ROUTE_42, MAP_ROUTE_42

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 6, 9, $6, $0, 255, 255, $80, 0, UnknownScript_0x19a4b5, $ffff
; 0x19a525

LakeofRageHiddenPowerHouse_MapScriptHeader: ; 0x19a525
	; trigger count
	db 0

	; callback count
	db 0
; 0x19a527

UnknownScript_0x19a527: ; 0x19a527
	faceplayer
	loadfont
	checkbit1 $0058
	iftrue UnknownScript_0x19a542
	2writetext UnknownText_0x19a54b
	keeptextopen
	verbosegiveitem TM_10, 1
	iffalse UnknownScript_0x19a546
	setbit1 $0058
	2writetext UnknownText_0x19a5de
	closetext
	loadmovesprites
	end
; 0x19a542

UnknownScript_0x19a542: ; 0x19a542
	2writetext UnknownText_0x19a673
	closetext
UnknownScript_0x19a546: ; 0x19a546
	loadmovesprites
	end
; 0x19a548

MapLakeofRageHiddenPowerHouseSignpost1Script: ; 0x19a548
	jumpstd $0001
; 0x19a54b

UnknownText_0x19a54b: ; 0x19a54b
	db $0, "…You have strayed", $4f
	db "far…", $51
	db "Here I have medi-", $4f
	db "tated. Inside me,", $51
	db "a new power has", $4f
	db "been awakened.", $51
	db "Let me share my", $4f
	db "power with your", $51
	db "#MON.", $4f
	db "Take this, child.", $57
; 0x19a5de

UnknownText_0x19a5de: ; 0x19a5de
	db $0, "Do you see it? It", $4f
	db "is HIDDEN POWER!", $51
	db "It draws out the", $4f
	db "power of #MON", $55
	db "for attacking.", $51
	db "Remember this: its", $4f
	db "type and power de-", $55
	db "pend on the #-", $55
	db "MON using it.", $57
; 0x19a673

UnknownText_0x19a673: ; 0x19a673
	db $0, "I am meditating…", $57
; 0x19a685

LakeofRageHiddenPowerHouse_MapEventHeader: ; 0x19a685
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_LAKE_OF_RAGE, MAP_LAKE_OF_RAGE
	warp_def $7, $3, 1, GROUP_LAKE_OF_RAGE, MAP_LAKE_OF_RAGE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapLakeofRageHiddenPowerHouseSignpost1Script
	signpost 1, 1, $0, MapLakeofRageHiddenPowerHouseSignpost1Script

	; people-events
	db 1
	person_event $3a, 7, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x19a527, $ffff
; 0x19a6ac

LakeofRageMagikarpHouse_MapScriptHeader: ; 0x19a6ac
	; trigger count
	db 0

	; callback count
	db 0
; 0x19a6ae

UnknownScript_0x19a6ae: ; 0x19a6ae
	faceplayer
	loadfont
	checkbit1 $003a
	iftrue UnknownScript_0x19a6fe
	checkbit1 $0039
	iftrue UnknownScript_0x19a6e0
	checkbit1 $0022
	iftrue UnknownScript_0x19a6d7
	checkbit1 $0038
	iftrue UnknownScript_0x19a6d1
	2writetext UnknownText_0x19a72e
	closetext
	loadmovesprites
	setbit1 $0038
	end
; 0x19a6d1

UnknownScript_0x19a6d1: ; 0x19a6d1
	2writetext UnknownText_0x19a84d
	closetext
	loadmovesprites
	end
; 0x19a6d7

UnknownScript_0x19a6d7: ; 0x19a6d7
	2writetext UnknownText_0x19a890
	closetext
	loadmovesprites
	setbit1 $0039
	end
; 0x19a6e0

UnknownScript_0x19a6e0: ; 0x19a6e0
	writebyte MAGIKARP
	special $0042
	iffalse UnknownScript_0x19a6d7
	2writetext UnknownText_0x19a93e
	closetext
	special $0019
	if_equal $0, UnknownScript_0x19a71c
	if_equal $1, UnknownScript_0x19a722
	if_equal $2, UnknownScript_0x19a716
	2jump UnknownScript_0x19a6fe
; 0x19a6fe

UnknownScript_0x19a6fe: ; 0x19a6fe
	2writetext UnknownText_0x19a977
	keeptextopen
	verbosegiveitem ELIXER, 1
	iffalse UnknownScript_0x19a711
	2writetext UnknownText_0x19a9c3
	closetext
	loadmovesprites
	clearbit1 $003a
	end
; 0x19a711

UnknownScript_0x19a711: ; 0x19a711
	loadmovesprites
	setbit1 $003a
	end
; 0x19a716

UnknownScript_0x19a716: ; 0x19a716
	2writetext UnknownText_0x19aa01
	closetext
	loadmovesprites
	end
; 0x19a71c

UnknownScript_0x19a71c: ; 0x19a71c
	2writetext UnknownText_0x19aa5c
	closetext
	loadmovesprites
	end
; 0x19a722

UnknownScript_0x19a722: ; 0x19a722
	2writetext UnknownText_0x19aa79
	closetext
	loadmovesprites
	end
; 0x19a728

UnknownScript_0x19a728: ; 0x19a728
	jumptext UnknownText_0x19aabc
; 0x19a72b

MapLakeofRageMagikarpHouseSignpost1Script: ; 0x19a72b
	jumpstd $0001
; 0x19a72e

UnknownText_0x19a72e: ; 0x19a72e
	db $0, "LAKE OF RAGE is", $4f
	db "actually a crater", $51
	db "made by rampaging", $4f
	db "GYARADOS.", $51
	db "The crater filled", $4f
	db "up with rainwater", $51
	db "and the LAKE was", $4f
	db "formed.", $51
	db "That's the story", $4f
	db "passed on from my", $51
	db "Grandpa's great-", $4f
	db "great-grandpa.", $51
	db "It used to be that", $4f
	db "you could catch", $51
	db "lively MAGIKARP", $4f
	db "there, but…", $51
	db "I don't understand", $4f
	db "what's happening.", $57
; 0x19a84d

UnknownText_0x19a84d: ; 0x19a84d
	db $0, "The LAKE hasn't", $4f
	db "been normal since", $51
	db "those men wearing", $4f
	db "black arrived.", $57
; 0x19a890

UnknownText_0x19a890: ; 0x19a890
	db $0, "LAKE OF RAGE is", $4f
	db "back to normal.", $51
	db "The MAGIKARP have", $4f
	db "returned.", $51
	db "I may yet realize", $4f
	db "my dream of see-", $55
	db "ing the world's", $55
	db "largest MAGIKARP.", $51
	db "Do you have a ROD?", $4f
	db "Please help me if", $55
	db "you do.", $57
; 0x19a93e

UnknownText_0x19a93e: ; 0x19a93e
	db $0, "Ah, you have a", $4f
	db "MAGIKARP! Let's", $51
	db "see how big that", $4f
	db "baby is.", $57
; 0x19a977

UnknownText_0x19a977: ; 0x19a977
	db $0, "Wow! This one is", $4f
	db "outstanding!", $51
	db "I tip my hat to", $4f
	db "you!", $51
	db "Take this as a", $4f
	db "memento!", $57
; 0x19a9c3

UnknownText_0x19a9c3: ; 0x19a9c3
	db $0, "The record is the", $4f
	db "important thing.", $51
	db "Think of that as", $4f
	db "a bonus!", $57
; 0x19aa01

UnknownText_0x19aa01: ; 0x19aa01
	db $0, "Wow! This one is", $4f
	db "outstanding!", $51
	db "…I wish I could", $4f
	db "say that, but I've", $51
	db "seen a bigger one", $4f
	db "before.", $57
; 0x19aa5c

UnknownText_0x19aa5c: ; 0x19aa5c
	db $0, "What? That's not a", $4f
	db "MAGIKARP!", $57
; 0x19aa79

UnknownText_0x19aa79: ; 0x19aa79
	db $0, "Oh… So you didn't", $4f
	db "get one good", $51
	db "enough to show me?", $4f
	db "Maybe next time.", $57
; 0x19aabc

UnknownText_0x19aabc: ; 0x19aabc
	db $0, "CURRENT RECORD", $51
	db "@"
	text_from_ram $d099
	db $0, " caught by", $4f
	db "@"
	text_from_ram $d0ac
	db "@@"
; 0x19aae2

LakeofRageMagikarpHouse_MapEventHeader: ; 0x19aae2
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_LAKE_OF_RAGE, MAP_LAKE_OF_RAGE
	warp_def $7, $3, 2, GROUP_LAKE_OF_RAGE, MAP_LAKE_OF_RAGE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapLakeofRageMagikarpHouseSignpost1Script
	signpost 1, 1, $0, MapLakeofRageMagikarpHouseSignpost1Script

	; people-events
	db 1
	person_event $3b, 7, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x19a6ae, $ffff
; 0x19ab09

Route43MahoganyGate_MapScriptHeader: ; 0x19ab09
	; trigger count
	db 0

	; callback count
	db 0
; 0x19ab0b

UnknownScript_0x19ab0b: ; 0x19ab0b
	faceplayer
	loadfont
	checkbit1 $0022
	iftrue UnknownScript_0x19ab19
	2writetext UnknownText_0x19ab1f
	closetext
	loadmovesprites
	end
; 0x19ab19

UnknownScript_0x19ab19: ; 0x19ab19
	2writetext UnknownText_0x19ab65
	closetext
	loadmovesprites
	end
; 0x19ab1f

UnknownText_0x19ab1f: ; 0x19ab1f
	db $0, "Only people headed", $4f
	db "up to LAKE OF RAGE", $51
	db "have been through", $4f
	db "here lately.", $57
; 0x19ab65

UnknownText_0x19ab65: ; 0x19ab65
	db $0, "Nobody goes up to", $4f
	db "LAKE OF RAGE these", $55
	db "days.", $57
; 0x19ab91

Route43MahoganyGate_MapEventHeader: ; 0x19ab91
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 1, GROUP_ROUTE_43, MAP_ROUTE_43
	warp_def $0, $5, 2, GROUP_ROUTE_43, MAP_ROUTE_43
	warp_def $7, $4, 5, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN
	warp_def $7, $5, 5, GROUP_MAHOGANY_TOWN, MAP_MAHOGANY_TOWN

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 8, 4, $9, $0, 255, 255, $80, 0, UnknownScript_0x19ab0b, $ffff
; 0x19abb8

Route43Gate_MapScriptHeader: ; 0x19abb8
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x19abc5, $0000
	dw UnknownScript_0x19abc9, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x19abca
; 0x19abc5

UnknownScript_0x19abc5: ; 0x19abc5
	priorityjump UnknownScript_0x19abda
	end
; 0x19abc9

UnknownScript_0x19abc9: ; 0x19abc9
	end
; 0x19abca

UnknownScript_0x19abca: ; 0x19abca
	checkbit1 $0022
	iftrue UnknownScript_0x19abd5
	domaptrigger GROUP_ROUTE_43, MAP_ROUTE_43, $0
	return
; 0x19abd5

UnknownScript_0x19abd5: ; 0x19abd5
	domaptrigger GROUP_ROUTE_43, MAP_ROUTE_43, $1
	return
; 0x19abda

UnknownScript_0x19abda: ; 0x19abda
	playmusic $0039
	checkcode $9
	if_equal $0, UnknownScript_0x19abea
	if_equal $1, UnknownScript_0x19ac38
	dotrigger $1
	end
; 0x19abea

UnknownScript_0x19abea: ; 0x19abea
	applymovement $0, MovementData_0x19aca2
	showemote $0, $4, 15
	applymovement $4, MovementData_0x19acbb
	spriteface $3, $1
	showemote $0, $3, 15
	applymovement $3, MovementData_0x19aca4
	loadfont
	2writetext UnknownText_0x19acd2
	keeptextopen
	checkmoney $0, 999
	if_equal $0, UnknownScript_0x19ac12
	2jump UnknownScript_0x19ac1d
; 0x19ac12

UnknownScript_0x19ac12: ; 0x19ac12
	takemoney $0, 1000
	2writetext UnknownText_0x19ad0a
	2jump UnknownScript_0x19ac28
; 0x19ac1d

UnknownScript_0x19ac1d: ; 0x19ac1d
	takemoney $0, 1000
	2writetext UnknownText_0x19ad20
	2jump UnknownScript_0x19ac28
; 0x19ac28

UnknownScript_0x19ac28: ; 0x19ac28
	keeptextopen
	loadmovesprites
	applymovement $3, MovementData_0x19acaa
	applymovement $4, MovementData_0x19acc1
	dotrigger $1
	special $003d
	end
; 0x19ac38

UnknownScript_0x19ac38: ; 0x19ac38
	showemote $0, $3, 15
	applymovement $3, MovementData_0x19acaf
	spriteface $4, $0
	showemote $0, $4, 15
	applymovement $4, MovementData_0x19acc7
	loadfont
	2writetext UnknownText_0x19acd2
	keeptextopen
	checkmoney $0, 999
	if_equal $0, UnknownScript_0x19ac5c
	2jump UnknownScript_0x19ac67
; 0x19ac5c

UnknownScript_0x19ac5c: ; 0x19ac5c
	takemoney $0, 1000
	2writetext UnknownText_0x19ad0a
	2jump UnknownScript_0x19ac72
; 0x19ac67

UnknownScript_0x19ac67: ; 0x19ac67
	takemoney $0, 1000
	2writetext UnknownText_0x19ad20
	2jump UnknownScript_0x19ac72
; 0x19ac72

UnknownScript_0x19ac72: ; 0x19ac72
	keeptextopen
	loadmovesprites
	applymovement $4, MovementData_0x19accd
	applymovement $3, MovementData_0x19acb5
	dotrigger $1
	special $003d
	end
; 0x19ac82

UnknownScript_0x19ac82: ; 0x19ac82
	jumptextfaceplayer UnknownText_0x19ad41
; 0x19ac85

UnknownScript_0x19ac85: ; 0x19ac85
	faceplayer
	loadfont
	checkbit1 $0059
	iftrue UnknownScript_0x19ac9c
	2writetext UnknownText_0x19ad9b
	keeptextopen
	verbosegiveitem TM_36, 1
	iffalse UnknownScript_0x19aca0
	setbit1 $0059
	loadmovesprites
	end
; 0x19ac9c

UnknownScript_0x19ac9c: ; 0x19ac9c
	2writetext UnknownText_0x19ae2d
	closetext
UnknownScript_0x19aca0: ; 0x19aca0
	loadmovesprites
	end
; 0x19aca2

MovementData_0x19aca2: ; 0x19aca2
	step_down
	step_end
; 0x19aca4

MovementData_0x19aca4: ; 0x19aca4
	big_step_up
	big_step_up
	big_step_right
	big_step_right
	turn_head_up
	step_end
; 0x19acaa

MovementData_0x19acaa: ; 0x19acaa
	big_step_left
	big_step_left
	big_step_down
	big_step_down
	step_end
; 0x19acaf

MovementData_0x19acaf: ; 0x19acaf
	big_step_down
	big_step_down
	big_step_right
	big_step_right
	turn_head_down
	step_end
; 0x19acb5

MovementData_0x19acb5: ; 0x19acb5
	big_step_left
	big_step_left
	big_step_up
	big_step_up
	turn_head_down
	step_end
; 0x19acbb

MovementData_0x19acbb: ; 0x19acbb
	big_step_up
	big_step_up
	big_step_left
	big_step_left
	turn_head_up
	step_end
; 0x19acc1

MovementData_0x19acc1: ; 0x19acc1
	big_step_right
	big_step_right
	big_step_down
	big_step_down
	turn_head_up
	step_end
; 0x19acc7

MovementData_0x19acc7: ; 0x19acc7
	big_step_down
	big_step_down
	big_step_left
	big_step_left
	turn_head_down
	step_end
; 0x19accd

MovementData_0x19accd: ; 0x19accd
	big_step_right
	big_step_right
	big_step_up
	big_step_up
	step_end
; 0x19acd2

UnknownText_0x19acd2: ; 0x19acd2
	db $0, "Hold it there,", $4f
	db "kiddo!", $51
	db "The toll is ¥1000", $4f
	db "to go through.", $57
; 0x19ad0a

UnknownText_0x19ad0a: ; 0x19ad0a
	db $0, "Thank you very", $4f
	db "much!", $57
; 0x19ad20

UnknownText_0x19ad20: ; 0x19ad20
	db $0, "Then pay what you", $4f
	db "have, please.", $57
; 0x19ad41

UnknownText_0x19ad41: ; 0x19ad41
	db $0, "He-he-he. We're", $4f
	db "making a bundle.", $51
	db "Everyone wants to", $4f
	db "see what's going", $51
	db "on up at LAKE OF", $4f
	db "RAGE.", $57
; 0x19ad9b

UnknownText_0x19ad9b: ; 0x19ad9b
	db $0, "I got chased from", $4f
	db "my post by these", $55
	db "thugs in black.", $51
	db "They left this", $4f
	db "behind.", $51
	db "It makes me uncom-", $4f
	db "fortable. Could", $55
	db "you take it away?", $57
; 0x19ae1b

UnknownText_0x19ae1b: ; 0x19ae1b
	db $0, $52, " received", $4f
	db "TM30.", $57
; 0x19ae2d

UnknownText_0x19ae2d: ; 0x19ae2d
	db $0, "Use this gate to", $4f
	db "avoid walking in", $55
	db "the grass.", $57
; 0x19ae5b

Route43Gate_MapEventHeader: ; 0x19ae5b
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 4, GROUP_ROUTE_43, MAP_ROUTE_43
	warp_def $0, $5, 5, GROUP_ROUTE_43, MAP_ROUTE_43
	warp_def $7, $4, 3, GROUP_ROUTE_43, MAP_ROUTE_43
	warp_def $7, $5, 3, GROUP_ROUTE_43, MAP_ROUTE_43

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $43, 8, 4, $9, $0, 255, 255, $80, 0, UnknownScript_0x19ac85, $0735
	person_event $35, 8, 6, $6, $0, 255, 255, $0, 0, UnknownScript_0x19ac82, $06dc
	person_event $35, 8, 11, $7, $0, 255, 255, $0, 0, UnknownScript_0x19ac82, $06dc
; 0x19ae9c

RedsHouse1F_MapScriptHeader: ; 0x19ae9c
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x19aea2, $0000

	; callback count
	db 0
; 0x19aea2

UnknownScript_0x19aea2: ; 0x19aea2
	end
; 0x19aea3

UnknownScript_0x19aea3: ; 0x19aea3
	faceplayer
	loadfont
	checkbit1 $00cc
	iftrue UnknownScript_0x19aeb4
	2writetext UnknownText_0x19aec0
	closetext
	loadmovesprites
	setbit1 $00cc
	end
; 0x19aeb4

UnknownScript_0x19aeb4: ; 0x19aeb4
	2writetext UnknownText_0x19af81
	closetext
	loadmovesprites
	end
; 0x19aeba

MapRedsHouse1FSignpost2Script: ; 0x19aeba
	jumptext UnknownText_0x19afe8
; 0x19aebd

MapRedsHouse1FSignpost1Script: ; 0x19aebd
	jumpstd $0002
; 0x19aec0

UnknownText_0x19aec0: ; 0x19aec0
	db $0, "Hi!", $51
	db "RED's been away", $4f
	db "for a long time.", $51
	db "He hasn't called", $4f
	db "either, so I have", $51
	db "no idea where he", $4f
	db "is or what he's", $55
	db "been doing.", $51
	db "They say that no", $4f
	db "word is proof that", $51
	db "he's doing fine,", $4f
	db "but I do worry", $55
	db "about him.", $57
; 0x19af81

UnknownText_0x19af81: ; 0x19af81
	db $0, "I worry about RED", $4f
	db "getting hurt or", $51
	db "sick, but he's a", $4f
	db "boy. I'm proud", $51
	db "that he is doing", $4f
	db "what he wants to", $51
	db "do.", $57
; 0x19afe8

UnknownText_0x19afe8: ; 0x19afe8
	db $0, "They have programs", $4f
	db "that aren't shown", $55
	db "in JOHTO…", $57
; 0x19b017

RedsHouse1F_MapEventHeader: ; 0x19b017
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $2, 1, GROUP_PALLET_TOWN, MAP_PALLET_TOWN
	warp_def $7, $3, 1, GROUP_PALLET_TOWN, MAP_PALLET_TOWN
	warp_def $0, $7, 1, GROUP_REDS_HOUSE_2F, MAP_REDS_HOUSE_2F

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 1, 0, $0, MapRedsHouse1FSignpost1Script
	signpost 1, 1, $0, MapRedsHouse1FSignpost1Script
	signpost 1, 2, $0, MapRedsHouse1FSignpost2Script

	; people-events
	db 1
	person_event $e, 7, 9, $8, $0, 255, 255, $0, 0, UnknownScript_0x19aea3, $ffff
; 0x19b048

RedsHouse2F_MapScriptHeader: ; 0x19b048
	; trigger count
	db 0

	; callback count
	db 0
; 0x19b04a

MapRedsHouse2FSignpost0Script: ; 0x19b04a
	jumptext UnknownText_0x19b050
; 0x19b04d

MapRedsHouse2FSignpost1Script: ; 0x19b04d
	jumptext UnknownText_0x19b087
; 0x19b050

UnknownText_0x19b050: ; 0x19b050
	db $0, $52, " played the", $4f
	db "N64.", $51
	db "Better get going--", $4f
	db "no time to lose!", $57
; 0x19b087

UnknownText_0x19b087: ; 0x19b087
	db $0, "It looks like it", $4f
	db "hasn't been used", $55
	db "in a long time…", $57
; 0x19b0b9

RedsHouse2F_MapEventHeader: ; 0x19b0b9
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $0, $7, 3, GROUP_REDS_HOUSE_1F, MAP_REDS_HOUSE_1F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 5, 3, $0, MapRedsHouse2FSignpost0Script
	signpost 1, 0, $0, MapRedsHouse2FSignpost1Script

	; people-events
	db 0
; 0x19b0ce

BluesHouse_MapScriptHeader: ; 0x19b0ce
	; trigger count
	db 0

	; callback count
	db 0
; 0x19b0d0

UnknownScript_0x19b0d0: ; 0x19b0d0
	faceplayer
	loadfont
	checkcode $a
	if_equal $f, UnknownScript_0x19b0de
	2writetext UnknownText_0x19b130
	closetext
	loadmovesprites
	end
; 0x19b0de

UnknownScript_0x19b0de: ; 0x19b0de
	checkbit2 $005c
	iftrue UnknownScript_0x19b11e
	2writetext UnknownText_0x19b1b6
	yesorno
	iffalse UnknownScript_0x19b124
	2writetext UnknownText_0x19b244
	closetext
	special $0063
	if_equal $0, UnknownScript_0x19b124
	if_equal $1, UnknownScript_0x19b12a
	setbit2 $005c
	2writetext UnknownText_0x19b266
	closetext
	loadmovesprites
	special $002e
	playmusic $000d
	pause 60
	special $0031
	special $003d
	loadfont
	2writetext UnknownText_0x19b296
	special $0064
	keeptextopen
	2writetext UnknownText_0x19b2aa
	closetext
	loadmovesprites
	end
; 0x19b11e

UnknownScript_0x19b11e: ; 0x19b11e
	2writetext UnknownText_0x19b2fa
	closetext
	loadmovesprites
	end
; 0x19b124

UnknownScript_0x19b124: ; 0x19b124
	2writetext UnknownText_0x19b334
	closetext
	loadmovesprites
	end
; 0x19b12a

UnknownScript_0x19b12a: ; 0x19b12a
	2writetext UnknownText_0x19b377
	closetext
	loadmovesprites
	end
; 0x19b130

UnknownText_0x19b130: ; 0x19b130
	db $0, "DAISY: Hi! My kid", $4f
	db "brother is the GYM", $51
	db "LEADER in VIRIDIAN", $4f
	db "CITY.", $51
	db "But he goes out", $4f
	db "of town so often,", $51
	db "it causes problems", $4f
	db "for the trainers.", $57
; 0x19b1b6

UnknownText_0x19b1b6: ; 0x19b1b6
	db $0, "DAISY: Hi! Good", $4f
	db "timing. I'm about", $55
	db "to have some tea.", $51
	db "Would you like to", $4f
	db "join me?", $51
	db "Oh, your #MON", $4f
	db "are a bit dirty.", $51
	db "Would you like me", $4f
	db "to groom one?", $57
; 0x19b244

UnknownText_0x19b244: ; 0x19b244
	db $0, "DAISY: Which one", $4f
	db "should I groom?", $57
; 0x19b266

UnknownText_0x19b266: ; 0x19b266
	db $0, "DAISY: OK, I'll", $4f
	db "get it looking", $55
	db "nice in no time.", $57
; 0x19b296

UnknownText_0x19b296: ; 0x19b296
	text_from_ram $d099
	db $0, " looks", $4f
	db "content.", $57
; 0x19b2aa

UnknownText_0x19b2aa: ; 0x19b2aa
	db $0, "DAISY: There you", $4f
	db "go! All done.", $51
	db "See? Doesn't it", $4f
	db "look nice?", $51
	db "It's such a cute", $4f
	db "#MON.", $57
; 0x19b2fa

UnknownText_0x19b2fa: ; 0x19b2fa
	db $0, "DAISY: I always", $4f
	db "have tea around", $51
	db "this time. Come", $4f
	db "join me.", $57
; 0x19b334

UnknownText_0x19b334: ; 0x19b334
	db $0, "DAISY: You don't", $4f
	db "want to have one", $51
	db "groomed? OK, we'll", $4f
	db "just have tea.", $57
; 0x19b377

UnknownText_0x19b377: ; 0x19b377
	db $0, "DAISY: Oh, sorry.", $4f
	db "I honestly can't", $55
	db "groom an EGG.", $57
; 0x19b3a8

BluesHouse_MapEventHeader: ; 0x19b3a8
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 2, GROUP_PALLET_TOWN, MAP_PALLET_TOWN
	warp_def $7, $3, 2, GROUP_PALLET_TOWN, MAP_PALLET_TOWN

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $f, 7, 6, $3, $0, 255, 255, $0, 0, UnknownScript_0x19b0d0, $ffff
; 0x19b3c5

OaksLab_MapScriptHeader: ; 0x19b3c5
	; trigger count
	db 0

	; callback count
	db 0
; 0x19b3c7

UnknownScript_0x19b3c7: ; 0x19b3c7
	end
; 0x19b3c8

UnknownScript_0x19b3c8: ; 0x19b3c8
	faceplayer
	loadfont
	checkbit1 $074f
	iftrue UnknownScript_0x19b3ea
	checkbit1 $00e1
	iftrue UnknownScript_0x19b3dd
	2writetext UnknownText_0x19b427
	keeptextopen
	setbit1 $00e1
UnknownScript_0x19b3dd: ; 0x19b3dd
	checkcode $7
	if_equal $10, UnknownScript_0x19b3f7
	if_equal $8, UnknownScript_0x19b401
	2jump UnknownScript_0x19b408
; 0x19b3ea

UnknownScript_0x19b3ea: ; 0x19b3ea
	2writetext UnknownText_0x19b4a2
	closetext
	special $0065
	2writetext UnknownText_0x19b4c8
	closetext
	loadmovesprites
	end
; 0x19b3f7

UnknownScript_0x19b3f7: ; 0x19b3f7
	2writetext UnknownText_0x19b4fc
	keeptextopen
	setbit1 $074f
	2jump UnknownScript_0x19b3ea
; 0x19b401

UnknownScript_0x19b401: ; 0x19b401
	2writetext UnknownText_0x19b6a2
	keeptextopen
	2jump UnknownScript_0x19b3ea
; 0x19b408

UnknownScript_0x19b408: ; 0x19b408
	2writetext UnknownText_0x19b73c
	keeptextopen
	2jump UnknownScript_0x19b3ea
; 0x19b40f

UnknownScript_0x19b40f: ; 0x19b40f
	jumptextfaceplayer UnknownText_0x19b7fb
; 0x19b412

UnknownScript_0x19b412: ; 0x19b412
	jumptextfaceplayer UnknownText_0x19b859
; 0x19b415

UnknownScript_0x19b415: ; 0x19b415
	jumptextfaceplayer UnknownText_0x19b8a7
; 0x19b418

MapOaksLabSignpost11Script: ; 0x19b418
	jumpstd $0001
; 0x19b41b

MapOaksLabSignpost12Script: ; 0x19b41b
	jumptext UnknownText_0x19b8ea
; 0x19b41e

MapOaksLabSignpost13Script: ; 0x19b41e
	jumptext UnknownText_0x19b909
; 0x19b421

MapOaksLabSignpost14Script: ; 0x19b421
	jumptext UnknownText_0x19b945
; 0x19b424

MapOaksLabSignpost15Script: ; 0x19b424
	jumptext UnknownText_0x19b95e
; 0x19b427

UnknownText_0x19b427: ; 0x19b427
	db $0, "OAK: Ah, ", $14, "!", $4f
	db "It's good of you", $51
	db "to come all this", $4f
	db "way to KANTO.", $51
	db "What do you think", $4f
	db "of the trainers", $51
	db "out here?", $4f
	db "Pretty tough, huh?", $57
; 0x19b4a2

UnknownText_0x19b4a2: ; 0x19b4a2
	db $0, "How is your #-", $4f
	db "DEX coming?", $51
	db "Let's see…", $57
; 0x19b4c8

UnknownText_0x19b4c8: ; 0x19b4c8
	db $0, "If you're in the", $4f
	db "area, I hope you", $55
	db "come visit again.", $57
; 0x19b4fc

UnknownText_0x19b4fc: ; 0x19b4fc
	db $0, "OAK: Wow! That's", $4f
	db "excellent!", $51
	db "You collected the", $4f
	db "BADGES of GYMS in", $55
	db "KANTO. Well done!", $51
	db "I was right in my", $4f
	db "assessment of you.", $51
	db "Tell you what,", $4f
	db $14, ". I'll make", $51
	db "arrangements so", $4f
	db "that you can go to", $55
	db "MT.SILVER.", $51
	db "MT.SILVER is a big", $4f
	db "mountain that is", $51
	db "home to many wild", $4f
	db "#MON.", $51
	db "It's too dangerous", $4f
	db "for your average", $51
	db "trainer, so it's", $4f
	db "off limits. But", $51
	db "we can make an", $4f
	db "exception in your", $55
	db "case, ", $14, ".", $51
	db "Go up to INDIGO", $4f
	db "PLATEAU. You can", $51
	db "reach MT.SILVER", $4f
	db "from there.", $57
; 0x19b6a2

UnknownText_0x19b6a2: ; 0x19b6a2
	db $0, "OAK: Hmm? You're", $4f
	db "not collecting", $55
	db "KANTO GYM BADGES?", $51
	db "The GYM LEADERS in", $4f
	db "KANTO are as tough", $51
	db "as any you battled", $4f
	db "in JOHTO.", $51
	db "I recommend that", $4f
	db "you challenge", $55
	db "them.", $57
; 0x19b73c

UnknownText_0x19b73c: ; 0x19b73c
	db $0, "OAK: Ah, you're", $4f
	db "collecting KANTO", $55
	db "GYM BADGES.", $51
	db "I imagine that", $4f
	db "it's hard, but the", $51
	db "experience is sure", $4f
	db "to help you.", $51
	db "Come see me when", $4f
	db "you get them all.", $51
	db "I'll have a gift", $4f
	db "for you.", $51
	db "Keep trying hard,", $4f
	db $14, "!", $57
; 0x19b7fb

UnknownText_0x19b7fb: ; 0x19b7fb
	db $0, "The PROF's #MON", $4f
	db "TALK radio program", $51
	db "isn't aired here", $4f
	db "in KANTO.", $51
	db "It's a shame--I'd", $4f
	db "like to hear it.", $57
; 0x19b859

UnknownText_0x19b859: ; 0x19b859
	db $0, "Thanks to your", $4f
	db "work on the #-", $55
	db "DEX, the PROF's", $51
	db "research is coming", $4f
	db "along great.", $57
; 0x19b8a7

UnknownText_0x19b8a7: ; 0x19b8a7
	db $0, "Don't tell anyone,", $4f
	db "but PROF.OAK'S", $51
	db "#MON TALK isn't", $4f
	db "a live broadcast.", $57
; 0x19b8ea

UnknownText_0x19b8ea: ; 0x19b8ea
	db $0, "Press START to", $4f
	db "open the MENU.", $57
; 0x19b909

UnknownText_0x19b909: ; 0x19b909
	db $0, "The SAVE option is", $4f
	db "on the MENU.", $51
	db "Use it in a timely", $4f
	db "manner.", $57
; 0x19b945

UnknownText_0x19b945: ; 0x19b945
	db $0, "There's nothing in", $4f
	db "here…", $57
; 0x19b95e

UnknownText_0x19b95e: ; 0x19b95e
	db $0, "There's an e-mail", $4f
	db "message on the PC.", $51
	db "…", $51
	db "PROF.OAK, how is", $4f
	db "your research", $55
	db "coming along?", $51
	db "I'm still plugging", $4f
	db "away.", $51
	db "I heard rumors", $4f
	db "that ", $14, " is", $51
	db "getting quite a", $4f
	db "reputation.", $51
	db "I'm delighted to", $4f
	db "hear that.", $51
	db "ELM in NEW BARK", $4f
	db "TOWN 8-)", $57
; 0x19ba33

OaksLab_MapEventHeader: ; 0x19ba33
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $b, $4, 3, GROUP_PALLET_TOWN, MAP_PALLET_TOWN
	warp_def $b, $5, 3, GROUP_PALLET_TOWN, MAP_PALLET_TOWN

	; xy triggers
	db 0

	; signposts
	db 16
	signpost 1, 6, $0, MapOaksLabSignpost11Script
	signpost 1, 7, $0, MapOaksLabSignpost11Script
	signpost 1, 8, $0, MapOaksLabSignpost11Script
	signpost 1, 9, $0, MapOaksLabSignpost11Script
	signpost 7, 0, $0, MapOaksLabSignpost11Script
	signpost 7, 1, $0, MapOaksLabSignpost11Script
	signpost 7, 2, $0, MapOaksLabSignpost11Script
	signpost 7, 3, $0, MapOaksLabSignpost11Script
	signpost 7, 6, $0, MapOaksLabSignpost11Script
	signpost 7, 7, $0, MapOaksLabSignpost11Script
	signpost 7, 8, $0, MapOaksLabSignpost11Script
	signpost 7, 9, $0, MapOaksLabSignpost11Script
	signpost 0, 4, $0, MapOaksLabSignpost12Script
	signpost 0, 5, $0, MapOaksLabSignpost13Script
	signpost 3, 9, $0, MapOaksLabSignpost14Script
	signpost 1, 0, $0, MapOaksLabSignpost15Script

	; people-events
	db 4
	person_event $5, 6, 8, $6, $0, 255, 255, $0, 0, UnknownScript_0x19b3c8, $ffff
	person_event $3c, 12, 5, $5, $1, 255, 255, $90, 0, UnknownScript_0x19b40f, $ffff
	person_event $3c, 13, 12, $4, $10, 255, 255, $90, 0, UnknownScript_0x19b412, $ffff
	person_event $3c, 8, 5, $2, $11, 255, 255, $90, 0, UnknownScript_0x19b415, $ffff
; 0x19bac7

SECTION "bank67",DATA,BANK[$67]

CherrygroveCity_MapScriptHeader: ; 0x19c000
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x19c00d, $0000
	dw UnknownScript_0x19c00e, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x19c00f
; 0x19c00d

UnknownScript_0x19c00d: ; 0x19c00d
	end
; 0x19c00e

UnknownScript_0x19c00e: ; 0x19c00e
	end
; 0x19c00f

UnknownScript_0x19c00f: ; 0x19c00f
	setbit2 $0042
	return
; 0x19c013

UnknownScript_0x19c013: ; 0x19c013
	faceplayer
	loadfont
	2writetext UnknownText_0x19c1e3
	yesorno
	iffalse UnknownScript_0x19c0a4
	2jump UnknownScript_0x19c01f
; 0x19c01f

UnknownScript_0x19c01f: ; 0x19c01f
	2writetext UnknownText_0x19c26f
	closetext
	loadmovesprites
	playmusic $0011
	follow $2, $0
	applymovement $2, MovementData_0x19c195
	loadfont
	2writetext UnknownText_0x19c285
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x19c19b
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x19c304
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x19c1a3
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x19c359
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x19c1ac
	spriteface $0, $2
	loadfont
	2writetext UnknownText_0x19c3a7
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x19c1b6
	spriteface $0, $1
	pause 60
	spriteface $2, $2
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x19c3ec
	keeptextopen
	stringtotext $409b, $1
	2call UnknownScript_0x19c097
	setbit2 $0001
	2writetext UnknownText_0x19c438
	keeptextopen
	2writetext UnknownText_0x19c451
	closetext
	loadmovesprites
	stopfollow
	special $003d
	spriteface $0, $1
	applymovement $2, MovementData_0x19c1cb
	playsound $001f
	disappear $2
	clearbit1 $06ff
	waitbutton
	end
; 0x19c097

UnknownScript_0x19c097: ; 0x19c097
	jumpstd $002f
	end
; 0x19c09b

UnknownRawText_0x19c09b: ; 0x19c09b
	db "MAP CARD@"
; 0x19c0a4

UnknownScript_0x19c0a4: ; 0x19c0a4
	2writetext UnknownText_0x19c49f
	closetext
	loadmovesprites
	end
; 0x19c0aa

UnknownScript_0x19c0aa: ; 0x19c0aa
	moveperson $3, $27, $7
; 0x19c0ae

UnknownScript_0x19c0ae: ; 0x19c0ae
	spriteface $0, $3
	showemote $0, $0, 15
	special $006a
	pause 15
	appear $3
	applymovement $3, MovementData_0x19c1ce
	spriteface $0, $3
	playmusic $001f
	loadfont
	2writetext UnknownText_0x19c4e2
	closetext
	loadmovesprites
	checkbit1 $001c
	iftrue UnknownScript_0x19c0ee
	checkbit1 $001d
	iftrue UnknownScript_0x19c104
	winlosstext UnknownText_0x19c57f, UnknownText_0x19c5e6
	setlasttalked $3
	loadtrainer RIVAL1, RIVAL1_3
	writecode $3, $1
	startbattle
	reloadmapmusic
	reloadmap
	iftrue UnknownScript_0x19c11a
	2jump UnknownScript_0x19c126
; 0x19c0ee

UnknownScript_0x19c0ee: ; 0x19c0ee
	winlosstext UnknownText_0x19c57f, UnknownText_0x19c5e6
	setlasttalked $3
	loadtrainer RIVAL1, RIVAL1_1
	writecode $3, $1
	startbattle
	reloadmapmusic
	reloadmap
	iftrue UnknownScript_0x19c11a
	2jump UnknownScript_0x19c126
; 0x19c104

UnknownScript_0x19c104: ; 0x19c104
	winlosstext UnknownText_0x19c57f, UnknownText_0x19c5e6
	setlasttalked $3
	loadtrainer RIVAL1, RIVAL1_2
	writecode $3, $1
	startbattle
	reloadmapmusic
	reloadmap
	iftrue UnknownScript_0x19c11a
	2jump UnknownScript_0x19c126
; 0x19c11a

UnknownScript_0x19c11a: ; 0x19c11a
	playmusic $0020
	loadfont
	2writetext UnknownText_0x19c608
	closetext
	loadmovesprites
	2jump UnknownScript_0x19c12f
; 0x19c126

UnknownScript_0x19c126: ; 0x19c126
	playmusic $0020
	loadfont
	2writetext UnknownText_0x19c59e
	closetext
	loadmovesprites
UnknownScript_0x19c12f: ; 0x19c12f
	playsound $0041
	applymovement $0, MovementData_0x19c1d4
	spriteface $0, $2
	applymovement $3, MovementData_0x19c1da
	disappear $3
	dotrigger $0
	special $001b
	playmapmusic
	end
; 0x19c146

UnknownScript_0x19c146: ; 0x19c146
	faceplayer
	loadfont
	checkbit2 $0001
	iftrue UnknownScript_0x19c154
	2writetext UnknownText_0x19c650
	closetext
	loadmovesprites
	end
; 0x19c154

UnknownScript_0x19c154: ; 0x19c154
	2writetext UnknownText_0x19c6a8
	closetext
	loadmovesprites
	end
; 0x19c15a

UnknownScript_0x19c15a: ; 0x19c15a
	faceplayer
	loadfont
	checkbit2 $000b
	iftrue UnknownScript_0x19c168
	2writetext UnknownText_0x19c6d6
	closetext
	loadmovesprites
	end
; 0x19c168

UnknownScript_0x19c168: ; 0x19c168
	2writetext UnknownText_0x19c701
	closetext
	loadmovesprites
	end
; 0x19c16e

UnknownScript_0x19c16e: ; 0x19c16e
	faceplayer
	loadfont
	checkbit1 $004d
	iftrue UnknownScript_0x19c183
	2writetext UnknownText_0x19c766
	keeptextopen
	verbosegiveitem MYSTIC_WATER, 1
	iffalse UnknownScript_0x19c187
	setbit1 $004d
UnknownScript_0x19c183: ; 0x19c183
	2writetext UnknownText_0x19c7c1
	closetext
UnknownScript_0x19c187: ; 0x19c187
	loadmovesprites
	end
; 0x19c189

MapCherrygroveCitySignpost0Script: ; 0x19c189
	jumptext UnknownText_0x19c7e0
; 0x19c18c

MapCherrygroveCitySignpost1Script: ; 0x19c18c
	jumptext UnknownText_0x19c815
; 0x19c18f

MapCherrygroveCitySignpost3Script: ; 0x19c18f
	jumpstd $0010
; 0x19c192

MapCherrygroveCitySignpost2Script: ; 0x19c192
	jumpstd $0011
; 0x19c195

MovementData_0x19c195: ; 0x19c195
	step_left
	step_left
	step_up
	step_left
	turn_head_up
	step_end
; 0x19c19b

MovementData_0x19c19b: ; 0x19c19b
	step_left
	step_left
	step_left
	step_left
	step_left
	step_left
	turn_head_up
	step_end
; 0x19c1a3

MovementData_0x19c1a3: ; 0x19c1a3
	step_left
	step_left
	step_left
	step_left
	step_left
	step_left
	step_left
	turn_head_up
	step_end
; 0x19c1ac

MovementData_0x19c1ac: ; 0x19c1ac
	step_left
	step_left
	step_left
	step_down
	step_left
	step_left
	step_left
	step_down
	turn_head_left
	step_end
; 0x19c1b6

MovementData_0x19c1b6: ; 0x19c1b6
	step_down
	step_down
	step_right
	step_right
	step_right
	step_right
	step_right
	step_right
	step_right
	step_right
	step_right
	step_right
	step_down
	step_down
	step_right
	step_right
	step_right
	step_right
	step_right
	turn_head_up
	step_end
; 0x19c1cb

MovementData_0x19c1cb: ; 0x19c1cb
	step_up
	step_up
	step_end
; 0x19c1ce

MovementData_0x19c1ce: ; 0x19c1ce
	step_left
	step_left
	step_left
	step_left
	step_left
	step_end
; 0x19c1d4

MovementData_0x19c1d4: ; 0x19c1d4
	big_step_down
	turn_head_up
	step_end
; 0x19c1d7

MovementData_0x19c1d7: ; 0x19c1d7
	step_left
	turn_head_down
	step_end
; 0x19c1da

MovementData_0x19c1da: ; 0x19c1da
	big_step_left
	big_step_left
	big_step_left
	big_step_left
	big_step_up
	big_step_up
	big_step_left
	big_step_left
	step_end
; 0x19c1e3

UnknownText_0x19c1e3: ; 0x19c1e3
	db $0, "You're a rookie", $4f
	db "trainer, aren't", $55
	db "you? I can tell!", $51
	db "That's OK! Every-", $4f
	db "one is a rookie", $55
	db "at some point!", $51
	db "If you'd like, I", $4f
	db "can teach you a", $55
	db "few things.", $57
; 0x19c26f

UnknownText_0x19c26f: ; 0x19c26f
	db $0, "OK, then!", $4f
	db "Follow me!", $57
; 0x19c285

UnknownText_0x19c285: ; 0x19c285
	db $0, "This is a #MON", $4f
	db "CENTER. They heal", $51
	db "your #MON in no", $4f
	db "time at all.", $51
	db "You'll be relying", $4f
	db "on them a lot, so", $51
	db "you better learn", $4f
	db "about them.", $57
; 0x19c304

UnknownText_0x19c304: ; 0x19c304
	db $0, "This is a #MON", $4f
	db "MART.", $51
	db "They sell BALLS", $4f
	db "for catching wild", $51
	db "#MON and other", $4f
	db "useful items.", $57
; 0x19c359

UnknownText_0x19c359: ; 0x19c359
	db $0, "ROUTE 30 is out", $4f
	db "this way.", $51
	db "Trainers will be", $4f
	db "battling their", $51
	db "prized #MON", $4f
	db "there.", $57
; 0x19c3a7

UnknownText_0x19c3a7: ; 0x19c3a7
	db $0, "This is the sea,", $4f
	db "as you can see.", $51
	db "Some #MON are", $4f
	db "found only in", $55
	db "water.", $57
; 0x19c3ec

UnknownText_0x19c3ec: ; 0x19c3ec
	db $0, "Here…", $51
	db "It's my house!", $4f
	db "Thanks for your", $55
	db "company.", $51
	db "Let me give you a", $4f
	db "small gift.", $57
; 0x19c438

UnknownText_0x19c438: ; 0x19c438
	db $0, $52, "'s #GEAR", $4f
	db "now has a MAP!", $57
; 0x19c451

UnknownText_0x19c451: ; 0x19c451
	db $0, "#GEAR becomes", $4f
	db "more useful as you", $55
	db "add CARDS.", $51
	db "I wish you luck on", $4f
	db "your journey!", $57
; 0x19c49f

UnknownText_0x19c49f: ; 0x19c49f
	db $0, "Oh… It's something", $4f
	db "I enjoy doing…", $51
	db "Fine. Come see me", $4f
	db "when you like.", $57
; 0x19c4e2

UnknownText_0x19c4e2: ; 0x19c4e2
	db $0, $56, " ", $56, " ", $56, $51
	db "You got a #MON", $4f
	db "at the LAB.", $51
	db "What a waste.", $4f
	db "A wimp like you.", $51
	db $56, " ", $56, " ", $56, $51
	db "Don't you get what", $4f
	db "I'm saying?", $51
	db "Well, I too, have", $4f
	db "a good #MON.", $51
	db "I'll show you", $4f
	db "what I mean!", $57
; 0x19c57f

UnknownText_0x19c57f: ; 0x19c57f
	db $0, "Humph. Are you", $4f
	db "happy you won?", $57
; 0x19c59e

UnknownText_0x19c59e: ; 0x19c59e
	db $0, $56, " ", $56, " ", $56, $51
	db "My name's ???.", $51
	db "I'm going to be", $4f
	db "the world's great-", $55
	db "est #MON", $55
	db "trainer.", $57
; 0x19c5e6

UnknownText_0x19c5e6: ; 0x19c5e6
	db $0, "Humph. That was a", $4f
	db "waste of time.", $57
; 0x19c608

UnknownText_0x19c608: ; 0x19c608
	db $0, $56, " ", $56, " ", $56, $51
	db "My name's ???.", $51
	db "I'm going to be", $4f
	db "the world's great-", $55
	db "est #MON", $55
	db "trainer.", $57
; 0x19c650

UnknownText_0x19c650: ; 0x19c650
	db $0, "Did you talk to", $4f
	db "the old man by the", $55
	db "#MON CENTER?", $51
	db "He'll put a MAP of", $4f
	db "JOHTO on your", $55
	db "#GEAR.", $57
; 0x19c6a8

UnknownText_0x19c6a8: ; 0x19c6a8
	db $0, "When you're with", $4f
	db "#MON, going", $55
	db "anywhere is fun.", $57
; 0x19c6d6

UnknownText_0x19c6d6: ; 0x19c6d6
	db $0, "MR.#MON's house", $4f
	db "is still farther", $55
	db "up ahead.", $57
; 0x19c701

UnknownText_0x19c701: ; 0x19c701
	db $0, "I battled the", $4f
	db "trainers on the", $55
	db "road.", $51
	db "My #MON lost.", $4f
	db "They're a mess! I", $51
	db "must take them to", $4f
	db "a #MON CENTER.", $57
; 0x19c766

UnknownText_0x19c766: ; 0x19c766
	db $0, "A #MON I caught", $4f
	db "had an item.", $51
	db "I think it's", $4f
	db "MYSTIC WATER.", $51
	db "I don't need it,", $4f
	db "so do you want it?", $57
; 0x19c7c1

UnknownText_0x19c7c1: ; 0x19c7c1
	db $0, "Back to fishing", $4f
	db "for me, then.", $57
; 0x19c7e0

UnknownText_0x19c7e0: ; 0x19c7e0
	db $0, "CHERRYGROVE CITY", $51
	db "The City of Cute,", $4f
	db "Fragrant Flowers", $57
; 0x19c815

UnknownText_0x19c815: ; 0x19c815
	db $0, "GUIDE GENT'S HOUSE", $57
; 0x19c829

CherrygroveCity_MapEventHeader: ; 0x19c829
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $3, $17, 2, GROUP_CHERRYGROVE_MART, MAP_CHERRYGROVE_MART
	warp_def $3, $1d, 1, GROUP_CHERRYGROVE_POKECENTER_1F, MAP_CHERRYGROVE_POKECENTER_1F
	warp_def $7, $11, 1, GROUP_CHERRYGROVE_GYM_SPEECH_HOUSE, MAP_CHERRYGROVE_GYM_SPEECH_HOUSE
	warp_def $9, $19, 1, GROUP_GUIDE_GENTS_HOUSE, MAP_GUIDE_GENTS_HOUSE
	warp_def $b, $1f, 1, GROUP_CHERRYGROVE_EVOLUTION_SPEECH_HOUSE, MAP_CHERRYGROVE_EVOLUTION_SPEECH_HOUSE

	; xy triggers
	db 2
	xy_trigger 1, $6, $21, $0, UnknownScript_0x19c0ae, $0, $0
	xy_trigger 1, $7, $21, $0, UnknownScript_0x19c0aa, $0, $0

	; signposts
	db 4
	signpost 8, 30, $0, MapCherrygroveCitySignpost0Script
	signpost 9, 23, $0, MapCherrygroveCitySignpost1Script
	signpost 3, 24, $0, MapCherrygroveCitySignpost2Script
	signpost 3, 30, $0, MapCherrygroveCitySignpost3Script

	; people-events
	db 5
	person_event $2f, 10, 36, $6, $0, 255, 255, $0, 0, UnknownScript_0x19c013, $06fe
	person_event $4, 10, 43, $3, $0, 255, 255, $0, 0, ObjectEvent, $06be
	person_event $29, 16, 31, $5, $1, 255, 255, $90, 0, UnknownScript_0x19c146, $ffff
	person_event $27, 11, 27, $5, $1, 255, 255, $80, 0, UnknownScript_0x19c15a, $ffff
	person_event $3a, 16, 11, $9, $0, 255, 255, $a0, 0, UnknownScript_0x19c16e, $ffff
; 0x19c8ad

Route35_MapScriptHeader: ; 0x19c8ad
	; trigger count
	db 0

	; callback count
	db 0
; 0x19c8af

TrainerBird_keeperBryan: ; 0x19c8af
	; bit/flag number
	dw $3fd

	; trainer group && trainer id
	db BIRD_KEEPER, BRYAN

	; text when seen
	dw Bird_keeperBryanSeenText

	; text when trainer beaten
	dw Bird_keeperBryanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperBryanScript
; 0x19c8bb

Bird_keeperBryanScript: ; 0x19c8bb
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19cc87
	closetext
	loadmovesprites
	end
; 0x19c8c3

TrainerJugglerIrwin1: ; 0x19c8c3
	; bit/flag number
	dw $495

	; trainer group && trainer id
	db JUGGLER, IRWIN1

	; text when seen
	dw JugglerIrwin1SeenText

	; text when trainer beaten
	dw JugglerIrwin1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw JugglerIrwin1Script
; 0x19c8cf

JugglerIrwin1Script: ; 0x19c8cf
	writecode $17, $16
	talkaftercancel
	loadfont
	checkcellnum $16
	iftrue UnknownScript_0x19c90f
	checkbit1 $0281
	iftrue UnknownScript_0x19c8ec
	2writetext UnknownText_0x19cd5a
	keeptextopen
	setbit1 $0281
	2call UnknownScript_0x19c903
	2jump UnknownScript_0x19c8ef
; 0x19c8ec

UnknownScript_0x19c8ec: ; 0x19c8ec
	2call UnknownScript_0x19c907
UnknownScript_0x19c8ef: ; 0x19c8ef
	askforphonenumber $16
	if_equal $1, UnknownScript_0x19c917
	if_equal $2, UnknownScript_0x19c913
	trainertotext JUGGLER, IRWIN1, $0
	2call UnknownScript_0x19c90b
	2jump UnknownScript_0x19c90f
; 0x19c903

UnknownScript_0x19c903: ; 0x19c903
	jumpstd $0019
	end
; 0x19c907

UnknownScript_0x19c907: ; 0x19c907
	jumpstd $001a
	end
; 0x19c90b

UnknownScript_0x19c90b: ; 0x19c90b
	jumpstd $001b
	end
; 0x19c90f

UnknownScript_0x19c90f: ; 0x19c90f
	jumpstd $001c
	end
; 0x19c913

UnknownScript_0x19c913: ; 0x19c913
	jumpstd $001d
	end
; 0x19c917

UnknownScript_0x19c917: ; 0x19c917
	jumpstd $001e
	end
; 0x19c91b

UnknownScript_0x19c91b: ; 0x19c91b
	jumpstd $001f
	end
; 0x19c91f

TrainerCamperIvan: ; 0x19c91f
	; bit/flag number
	dw $41c

	; trainer group && trainer id
	db CAMPER, IVAN

	; text when seen
	dw CamperIvanSeenText

	; text when trainer beaten
	dw CamperIvanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperIvanScript
; 0x19c92b

CamperIvanScript: ; 0x19c92b
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19cac4
	closetext
	loadmovesprites
	end
; 0x19c933

TrainerCamperElliot: ; 0x19c933
	; bit/flag number
	dw $41d

	; trainer group && trainer id
	db CAMPER, ELLIOT

	; text when seen
	dw CamperElliotSeenText

	; text when trainer beaten
	dw CamperElliotBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperElliotScript
; 0x19c93f

CamperElliotScript: ; 0x19c93f
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19cb47
	closetext
	loadmovesprites
	end
; 0x19c947

TrainerPicnickerBrooke: ; 0x19c947
	; bit/flag number
	dw $480

	; trainer group && trainer id
	db PICNICKER, BROOKE

	; text when seen
	dw PicnickerBrookeSeenText

	; text when trainer beaten
	dw PicnickerBrookeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerBrookeScript
; 0x19c953

PicnickerBrookeScript: ; 0x19c953
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19cbba
	closetext
	loadmovesprites
	end
; 0x19c95b

TrainerPicnickerKim: ; 0x19c95b
	; bit/flag number
	dw $481

	; trainer group && trainer id
	db PICNICKER, KIM

	; text when seen
	dw PicnickerKimSeenText

	; text when trainer beaten
	dw PicnickerKimBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerKimScript
; 0x19c967

PicnickerKimScript: ; 0x19c967
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19cc21
	closetext
	loadmovesprites
	end
; 0x19c96f

TrainerBug_catcherArnie1: ; 0x19c96f
	; bit/flag number
	dw $53f

	; trainer group && trainer id
	db BUG_CATCHER, ARNIE1

	; text when seen
	dw Bug_catcherArnie1SeenText

	; text when trainer beaten
	dw Bug_catcherArnie1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherArnie1Script
; 0x19c97b

Bug_catcherArnie1Script: ; 0x19c97b
	writecode $17, $17
	talkaftercancel
	loadfont
	checkbit2 $0072
	iftrue UnknownScript_0x19c9bb
	checkbit2 $00a1
	iftrue UnknownScript_0x19ca2f
	checkcellnum $17
	iftrue UnknownScript_0x19c90f
	checkbit1 $0283
	iftrue UnknownScript_0x19c9a4
	2writetext UnknownText_0x19cdf6
	keeptextopen
	setbit1 $0283
	2call UnknownScript_0x19c903
	2jump UnknownScript_0x19c9a7
; 0x19c9a4

UnknownScript_0x19c9a4: ; 0x19c9a4
	2call UnknownScript_0x19c907
UnknownScript_0x19c9a7: ; 0x19c9a7
	askforphonenumber $17
	if_equal $1, UnknownScript_0x19c917
	if_equal $2, UnknownScript_0x19c913
	trainertotext BUG_CATCHER, ARNIE1, $0
	2call UnknownScript_0x19c90b
	2jump UnknownScript_0x19c90f
; 0x19c9bb

UnknownScript_0x19c9bb: ; 0x19c9bb
	2call UnknownScript_0x19c91b
	winlosstext Bug_catcherArnie1BeatenText, $0000
	copybytetovar $da01
	if_equal $4, UnknownScript_0x19c9da
	if_equal $3, UnknownScript_0x19c9e0
	if_equal $2, UnknownScript_0x19c9e6
	if_equal $1, UnknownScript_0x19c9ec
	if_equal $0, UnknownScript_0x19c9f2
UnknownScript_0x19c9da: ; 0x19c9da
	checkbit1 $00cd
	iftrue UnknownScript_0x19ca26
UnknownScript_0x19c9e0: ; 0x19c9e0
	checkbit1 $0044
	iftrue UnknownScript_0x19ca19
UnknownScript_0x19c9e6: ; 0x19c9e6
	checkbit2 $004b
	iftrue UnknownScript_0x19ca0c
UnknownScript_0x19c9ec: ; 0x19c9ec
	checkbit2 $004a
	iftrue UnknownScript_0x19c9ff
UnknownScript_0x19c9f2: ; 0x19c9f2
	loadtrainer BUG_CATCHER, ARNIE1
	startbattle
	returnafterbattle
	loadvar $da01, $1
	clearbit2 $0072
	end
; 0x19c9ff

UnknownScript_0x19c9ff: ; 0x19c9ff
	loadtrainer BUG_CATCHER, ARNIE2
	startbattle
	returnafterbattle
	loadvar $da01, $2
	clearbit2 $0072
	end
; 0x19ca0c

UnknownScript_0x19ca0c: ; 0x19ca0c
	loadtrainer BUG_CATCHER, ARNIE3
	startbattle
	returnafterbattle
	loadvar $da01, $3
	clearbit2 $0072
	end
; 0x19ca19

UnknownScript_0x19ca19: ; 0x19ca19
	loadtrainer BUG_CATCHER, ARNIE4
	startbattle
	returnafterbattle
	loadvar $da01, $4
	clearbit2 $0072
	end
; 0x19ca26

UnknownScript_0x19ca26: ; 0x19ca26
	loadtrainer BUG_CATCHER, ARNIE5
	startbattle
	returnafterbattle
	clearbit2 $0072
	end
; 0x19ca2f

UnknownScript_0x19ca2f: ; 0x19ca2f
	2writetext UnknownText_0x19ce38
	closetext
	loadmovesprites
	end
; 0x19ca35

TrainerFirebreatherWalt: ; 0x19ca35
	; bit/flag number
	dw $44b

	; trainer group && trainer id
	db FIREBREATHER, WALT

	; text when seen
	dw FirebreatherWaltSeenText

	; text when trainer beaten
	dw FirebreatherWaltBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FirebreatherWaltScript
; 0x19ca41

FirebreatherWaltScript: ; 0x19ca41
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19cebc
	closetext
	loadmovesprites
	end
; 0x19ca49

UnknownScript_0x19ca49: ; 0x19ca49
	faceplayer
	loadfont
	checktime $4
	iffalse UnknownScript_0x19ca73
	checkbit1 $0547
	iftrue UnknownScript_0x19ca6d
	playmusic $000c
	2writetext UnknownText_0x19ceea
	closetext
	loadmovesprites
	winlosstext UnknownText_0x19cf06, $0000
	loadtrainer OFFICER, DIRK
	startbattle
	returnafterbattle
	setbit1 $0547
	loadmovesprites
	end
; 0x19ca6d

UnknownScript_0x19ca6d: ; 0x19ca6d
	2writetext UnknownText_0x19cf0f
	closetext
	loadmovesprites
	end
; 0x19ca73

UnknownScript_0x19ca73: ; 0x19ca73
	2writetext UnknownText_0x19cf56
	closetext
	loadmovesprites
	end
; 0x19ca79

MapRoute35Signpost1Script: ; 0x19ca79
	jumptext UnknownText_0x19cf94
; 0x19ca7c

ItemFragment_0x19ca7c: ; 0x19ca7c
	db TM_04, 1
; 0x19ca7e

UnknownScript_0x19ca7e: ; 0x19ca7e
	fruittree $b
; 0x19ca80

CamperIvanSeenText: ; 0x19ca80
	db $0, "I've been getting", $4f
	db "#MON data off", $51
	db "my radio. I think", $4f
	db "I'm good.", $57
; 0x19cabb

CamperIvanBeatenText: ; 0x19cabb
	db $0, "I give!", $57
; 0x19cac4

UnknownText_0x19cac4: ; 0x19cac4
	db $0, "Music on the radio", $4f
	db "changes the moods", $55
	db "of wild #MON.", $57
; 0x19caf8

CamperElliotSeenText: ; 0x19caf8
	db $0, "I'm gonna show my", $4f
	db "girlfriend I'm hot", $55
	db "stuff!", $57
; 0x19cb23

CamperElliotBeatenText: ; 0x19cb23
	db $0, "I wish you would", $4f
	db "have lost for me…", $57
; 0x19cb47

UnknownText_0x19cb47: ; 0x19cb47
	db $0, "I was humiliated", $4f
	db "in front of my", $55
	db "girlfriend…", $57
; 0x19cb74

PicnickerBrookeSeenText: ; 0x19cb74
	db $0, "My boyfriend's", $4f
	db "weak, so I can't", $55
	db "rely on him.", $57
; 0x19cba0

PicnickerBrookeBeatenText: ; 0x19cba0
	db $0, "Oh, my! You're so", $4f
	db "strong!", $57
; 0x19cbba

UnknownText_0x19cbba: ; 0x19cbba
	db $0, "I can count on my", $4f
	db "#MON more than", $55
	db "my boyfriend.", $57
; 0x19cbea

PicnickerKimSeenText: ; 0x19cbea
	db $0, "Are you going to", $4f
	db "the GYM? Me too!", $57
; 0x19cc0d

PicnickerKimBeatenText: ; 0x19cc0d
	db $0, "Oh. I couldn't", $4f
	db "win…", $57
; 0x19cc21

UnknownText_0x19cc21: ; 0x19cc21
	db $0, "The GYM BADGES are", $4f
	db "pretty. I collect", $55
	db "them.", $57
; 0x19cc4d

Bird_keeperBryanSeenText: ; 0x19cc4d
	db $0, "What kinds of", $4f
	db "BALLS do you use?", $57
; 0x19cc6e

Bird_keeperBryanBeatenText: ; 0x19cc6e
	db $0, "Yikes! Not fast", $4f
	db "enough!", $57
; 0x19cc87

UnknownText_0x19cc87: ; 0x19cc87
	db $0, "Some #MON flee", $4f
	db "right away.", $51
	db "Try catching them", $4f
	db "with KURT's FAST", $55
	db "BALL.", $51
	db "Whenever I find a", $4f
	db "WHT APRICORN, I", $55
	db "take it to KURT.", $51
	db "He turns it into a", $4f
	db "custom BALL.", $57
; 0x19cd1e

JugglerIrwin1SeenText: ; 0x19cd1e
	db $0, "Behold my graceful", $4f
	db "BALL dexterity!", $57
; 0x19cd42

JugglerIrwin1BeatenText: ; 0x19cd42
	db $0, "Whew! That was a", $4f
	db "jolt!", $57
; 0x19cd5a

UnknownText_0x19cd5a: ; 0x19cd5a
	db $0, "I was going to", $4f
	db "dazzle you with my", $55
	db "prize #MON.", $51
	db "But your prowess", $4f
	db "electrified me!", $57
; 0x19cdaa

Bug_catcherArnie1SeenText: ; 0x19cdaa
	db $0, "I'll go anywhere", $4f
	db "if bug #MON", $55
	db "appear there.", $57
; 0x19cdd5

Bug_catcherArnie1BeatenText: ; 0x19cdd5
	db $0, "Huh? I shouldn't", $4f
	db "have lost that…", $57
; 0x19cdf6

UnknownText_0x19cdf6: ; 0x19cdf6
	db $0, "My VENONAT won me", $4f
	db "the Bug-Catching", $51
	db "Contest at the", $4f
	db "NATIONAL PARK.", $57
; 0x19ce38

UnknownText_0x19ce38: ; 0x19ce38
	db $0, "Wow… Look at all", $4f
	db "those YANMA!", $51
	db "I'm so blown away,", $4f
	db "I can't move.", $57
; 0x19ce76

FirebreatherWaltSeenText: ; 0x19ce76
	db $0, "I'm practicing my", $4f
	db "fire breathing.", $57
; 0x19ce98

FirebreatherWaltBeatenText: ; 0x19ce98
	db $0, "Ow! I scorched the", $4f
	db "tip of my nose!", $57
; 0x19cebc

UnknownText_0x19cebc: ; 0x19cebc
	db $0, "The #MON March", $4f
	db "on the radio lures", $55
	db "wild #MON.", $57
; 0x19ceea

UnknownText_0x19ceea: ; 0x19ceea
	db $0, "Danger lurks in", $4f
	db "the night!", $57
; 0x19cf06

UnknownText_0x19cf06: ; 0x19cf06
	db $0, "Whoops!", $57
; 0x19cf0f

UnknownText_0x19cf0f: ; 0x19cf0f
	db $0, "You know, night-", $4f
	db "time is fun in its", $55
	db "own ways.", $51
	db "But don't overdo", $4f
	db "it, OK?", $57
; 0x19cf56

UnknownText_0x19cf56: ; 0x19cf56
	db $0, "Your #MON look", $4f
	db "pretty tough.", $51
	db "You could go any-", $4f
	db "where safely.", $57
; 0x19cf94

UnknownText_0x19cf94: ; 0x19cf94
	db $0, "ROUTE 35", $57
; 0x19cf9e

Route35_MapEventHeader: ; 0x19cf9e
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $21, $9, 1, GROUP_ROUTE_35_GOLDENROD_GATE, MAP_ROUTE_35_GOLDENROD_GATE
	warp_def $21, $a, 2, GROUP_ROUTE_35_GOLDENROD_GATE, MAP_ROUTE_35_GOLDENROD_GATE
	warp_def $5, $3, 3, GROUP_ROUTE_35_NATIONAL_PARK_GATE, MAP_ROUTE_35_NATIONAL_PARK_GATE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 7, 1, $0, MapRoute35Signpost1Script
	signpost 31, 11, $0, MapRoute35Signpost1Script

	; people-events
	db 11
	person_event $27, 23, 8, $a, $0, 255, 255, $a2, 2, TrainerCamperIvan, $ffff
	person_event $27, 24, 12, $6, $0, 255, 255, $a2, 3, TrainerCamperElliot, $ffff
	person_event $28, 24, 11, $6, $0, 255, 255, $a2, 3, TrainerPicnickerBrooke, $ffff
	person_event $28, 30, 14, $a, $0, 255, 255, $a2, 1, TrainerPicnickerKim, $ffff
	person_event $27, 32, 18, $6, $0, 255, 255, $92, 0, TrainerBird_keeperBryan, $ffff
	person_event $3a, 14, 6, $1e, $0, 255, 255, $82, 2, TrainerFirebreatherWalt, $ffff
	person_event $25, 11, 20, $6, $2, 255, 255, $b2, 3, TrainerBug_catcherArnie1, $ffff
	person_event $2b, 14, 9, $a, $0, 255, 255, $92, 2, TrainerJugglerIrwin1, $ffff
	person_event $43, 10, 9, $6, $0, 255, 255, $90, 0, UnknownScript_0x19ca49, $ffff
	person_event $5d, 29, 6, $1, $0, 255, 255, $0, 0, UnknownScript_0x19ca7e, $ffff
	person_event $54, 20, 17, $1, $0, 255, 255, $1, 0, ItemFragment_0x19ca7c, $06b2
; 0x19d04c

Route43_MapScriptHeader: ; 0x19d04c
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x19d051
; 0x19d051

UnknownScript_0x19d051: ; 0x19d051
	checkbit1 $0022
	iftrue UnknownScript_0x19d05c
	domaptrigger GROUP_ROUTE_43_GATE, MAP_ROUTE_43_GATE, $0
	return
; 0x19d05c

UnknownScript_0x19d05c: ; 0x19d05c
	domaptrigger GROUP_ROUTE_43_GATE, MAP_ROUTE_43_GATE, $1
	return
; 0x19d061

TrainerCamperSpencer: ; 0x19d061
	; bit/flag number
	dw $42c

	; trainer group && trainer id
	db CAMPER, SPENCER

	; text when seen
	dw CamperSpencerSeenText

	; text when trainer beaten
	dw CamperSpencerBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperSpencerScript
; 0x19d06d

CamperSpencerScript: ; 0x19d06d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19d57e
	closetext
	loadmovesprites
	end
; 0x19d075

TrainerPokemaniacBen: ; 0x19d075
	; bit/flag number
	dw $4e8

	; trainer group && trainer id
	db POKEMANIAC, BEN

	; text when seen
	dw PokemaniacBenSeenText

	; text when trainer beaten
	dw PokemaniacBenBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacBenScript
; 0x19d081

PokemaniacBenScript: ; 0x19d081
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19d2d2
	closetext
	loadmovesprites
	end
; 0x19d089

TrainerPokemaniacBrent1: ; 0x19d089
	; bit/flag number
	dw $4e9

	; trainer group && trainer id
	db POKEMANIAC, BRENT1

	; text when seen
	dw PokemaniacBrent1SeenText

	; text when trainer beaten
	dw PokemaniacBrent1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacBrent1Script
; 0x19d095

PokemaniacBrent1Script: ; 0x19d095
	writecode $17, $1e
	talkaftercancel
	loadfont
	checkbit2 $0077
	iftrue UnknownScript_0x19d0cf
	checkcellnum $1e
	iftrue UnknownScript_0x19d138
	checkbit1 $0291
	iftrue UnknownScript_0x19d0b8
	2writetext UnknownText_0x19d359
	keeptextopen
	setbit1 $0291
	2call UnknownScript_0x19d12c
	2jump UnknownScript_0x19d0bb
; 0x19d0b8

UnknownScript_0x19d0b8: ; 0x19d0b8
	2call UnknownScript_0x19d130
UnknownScript_0x19d0bb: ; 0x19d0bb
	askforphonenumber $1e
	if_equal $1, UnknownScript_0x19d140
	if_equal $2, UnknownScript_0x19d13c
	trainertotext POKEMANIAC, BRENT1, $0
	2call UnknownScript_0x19d134
	2jump UnknownScript_0x19d138
; 0x19d0cf

UnknownScript_0x19d0cf: ; 0x19d0cf
	2call UnknownScript_0x19d144
	winlosstext PokemaniacBrent1BeatenText, $0000
	copybytetovar $da07
	if_equal $3, UnknownScript_0x19d0ea
	if_equal $2, UnknownScript_0x19d0f0
	if_equal $1, UnknownScript_0x19d0f6
	if_equal $0, UnknownScript_0x19d0fc
UnknownScript_0x19d0ea: ; 0x19d0ea
	checkbit1 $00cd
	iftrue UnknownScript_0x19d123
UnknownScript_0x19d0f0: ; 0x19d0f0
	checkbit1 $0044
	iftrue UnknownScript_0x19d116
UnknownScript_0x19d0f6: ; 0x19d0f6
	checkbit1 $0022
	iftrue UnknownScript_0x19d109
UnknownScript_0x19d0fc: ; 0x19d0fc
	loadtrainer POKEMANIAC, BRENT1
	startbattle
	returnafterbattle
	loadvar $da07, $1
	clearbit2 $0077
	end
; 0x19d109

UnknownScript_0x19d109: ; 0x19d109
	loadtrainer POKEMANIAC, BRENT2
	startbattle
	returnafterbattle
	loadvar $da07, $2
	clearbit2 $0077
	end
; 0x19d116

UnknownScript_0x19d116: ; 0x19d116
	loadtrainer POKEMANIAC, BRENT3
	startbattle
	returnafterbattle
	loadvar $da07, $3
	clearbit2 $0077
	end
; 0x19d123

UnknownScript_0x19d123: ; 0x19d123
	loadtrainer POKEMANIAC, BRENT4
	startbattle
	returnafterbattle
	clearbit2 $0077
	end
; 0x19d12c

UnknownScript_0x19d12c: ; 0x19d12c
	jumpstd $0019
	end
; 0x19d130

UnknownScript_0x19d130: ; 0x19d130
	jumpstd $001a
	end
; 0x19d134

UnknownScript_0x19d134: ; 0x19d134
	jumpstd $001b
	end
; 0x19d138

UnknownScript_0x19d138: ; 0x19d138
	jumpstd $001c
	end
; 0x19d13c

UnknownScript_0x19d13c: ; 0x19d13c
	jumpstd $001d
	end
; 0x19d140

UnknownScript_0x19d140: ; 0x19d140
	jumpstd $001e
	end
; 0x19d144

UnknownScript_0x19d144: ; 0x19d144
	jumpstd $001f
	end
; 0x19d148

TrainerPokemaniacRon: ; 0x19d148
	; bit/flag number
	dw $4ea

	; trainer group && trainer id
	db POKEMANIAC, RON

	; text when seen
	dw PokemaniacRonSeenText

	; text when trainer beaten
	dw PokemaniacRonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacRonScript
; 0x19d154

PokemaniacRonScript: ; 0x19d154
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19d3f8
	closetext
	loadmovesprites
	end
; 0x19d15c

TrainerFisherMarvin: ; 0x19d15c
	; bit/flag number
	dw $453

	; trainer group && trainer id
	db FISHER, MARVIN

	; text when seen
	dw FisherMarvinSeenText

	; text when trainer beaten
	dw FisherMarvinBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherMarvinScript
; 0x19d168

FisherMarvinScript: ; 0x19d168
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19d4d3
	closetext
	loadmovesprites
	end
; 0x19d170

TrainerPicnickerTiffany3: ; 0x19d170
	; bit/flag number
	dw $491

	; trainer group && trainer id
	db PICNICKER, TIFFANY3

	; text when seen
	dw PicnickerTiffany3SeenText

	; text when trainer beaten
	dw PicnickerTiffany3BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerTiffany3Script
; 0x19d17c

PicnickerTiffany3Script: ; 0x19d17c
	writecode $17, $1f
	talkaftercancel
	loadfont
	checkbit2 $0078
	iftrue UnknownScript_0x19d1c1
	checkbit2 $0085
	iftrue UnknownScript_0x19d21e
	checkcellnum $1f
	iftrue UnknownScript_0x19d245
	checkpoke CLEFAIRY
	iffalse UnknownScript_0x19d233
	checkbit1 $0293
	iftrue UnknownScript_0x19d1aa
	2writetext UnknownText_0x19d618
	keeptextopen
	setbit1 $0293
	2call UnknownScript_0x19d239
	2jump UnknownScript_0x19d1ad
; 0x19d1aa

UnknownScript_0x19d1aa: ; 0x19d1aa
	2call UnknownScript_0x19d23d
UnknownScript_0x19d1ad: ; 0x19d1ad
	askforphonenumber $1f
	if_equal $1, UnknownScript_0x19d24d
	if_equal $2, UnknownScript_0x19d249
	trainertotext PICNICKER, TIFFANY3, $0
	2call UnknownScript_0x19d241
	2jump UnknownScript_0x19d245
; 0x19d1c1

UnknownScript_0x19d1c1: ; 0x19d1c1
	2call UnknownScript_0x19d251
	winlosstext PicnickerTiffany3BeatenText, $0000
	copybytetovar $da08
	if_equal $3, UnknownScript_0x19d1dc
	if_equal $2, UnknownScript_0x19d1e2
	if_equal $1, UnknownScript_0x19d1e8
	if_equal $0, UnknownScript_0x19d1ee
UnknownScript_0x19d1dc: ; 0x19d1dc
	checkbit1 $00cd
	iftrue UnknownScript_0x19d215
UnknownScript_0x19d1e2: ; 0x19d1e2
	checkbit1 $0044
	iftrue UnknownScript_0x19d208
UnknownScript_0x19d1e8: ; 0x19d1e8
	checkbit1 $0021
	iftrue UnknownScript_0x19d1fb
UnknownScript_0x19d1ee: ; 0x19d1ee
	loadtrainer PICNICKER, TIFFANY3
	startbattle
	returnafterbattle
	loadvar $da08, $1
	clearbit2 $0078
	end
; 0x19d1fb

UnknownScript_0x19d1fb: ; 0x19d1fb
	loadtrainer PICNICKER, TIFFANY1
	startbattle
	returnafterbattle
	loadvar $da08, $2
	clearbit2 $0078
	end
; 0x19d208

UnknownScript_0x19d208: ; 0x19d208
	loadtrainer PICNICKER, TIFFANY2
	startbattle
	returnafterbattle
	loadvar $da08, $3
	clearbit2 $0078
	end
; 0x19d215

UnknownScript_0x19d215: ; 0x19d215
	loadtrainer PICNICKER, TIFFANY4
	startbattle
	returnafterbattle
	clearbit2 $0078
	end
; 0x19d21e

UnknownScript_0x19d21e: ; 0x19d21e
	2call UnknownScript_0x19d255
	verbosegiveitem PINK_BOW, 1
	iffalse UnknownScript_0x19d230
	clearbit2 $0085
	setbit1 $0104
	2jump UnknownScript_0x19d245
; 0x19d230

UnknownScript_0x19d230: ; 0x19d230
	2jump UnknownScript_0x19d259
; 0x19d233

UnknownScript_0x19d233: ; 0x19d233
	2writetext UnknownText_0x19d64b
	closetext
	loadmovesprites
	end
; 0x19d239

UnknownScript_0x19d239: ; 0x19d239
	jumpstd $0023
	end
; 0x19d23d

UnknownScript_0x19d23d: ; 0x19d23d
	jumpstd $0024
	end
; 0x19d241

UnknownScript_0x19d241: ; 0x19d241
	jumpstd $0025
	end
; 0x19d245

UnknownScript_0x19d245: ; 0x19d245
	jumpstd $0026
	end
; 0x19d249

UnknownScript_0x19d249: ; 0x19d249
	jumpstd $0027
	end
; 0x19d24d

UnknownScript_0x19d24d: ; 0x19d24d
	jumpstd $0028
	end
; 0x19d251

UnknownScript_0x19d251: ; 0x19d251
	jumpstd $0029
	end
; 0x19d255

UnknownScript_0x19d255: ; 0x19d255
	jumpstd $002a
	end
; 0x19d259

UnknownScript_0x19d259: ; 0x19d259
	jumpstd $002b
	end
; 0x19d25d

MapRoute43Signpost0Script: ; 0x19d25d
	jumptext UnknownText_0x19d67b
; 0x19d260

MapRoute43Signpost1Script: ; 0x19d260
	jumptext UnknownText_0x19d6a2
; 0x19d263

MapRoute43Signpost2Script: ; 0x19d263
	jumptext UnknownText_0x19d6c9
; 0x19d266

UnknownScript_0x19d266: ; 0x19d266
	fruittree $8
; 0x19d268

ItemFragment_0x19d268: ; 0x19d268
	db MAX_ETHER, 1
; 0x19d26a

PokemaniacBenSeenText: ; 0x19d26a
	db $0, "I love #MON!", $51
	db "That's why I", $4f
	db "started--and why", $51
	db "I'll keep on col-", $4f
	db "lecting #MON!", $57
; 0x19d2b4

PokemaniacBenBeatenText: ; 0x19d2b4
	db $0, "How could you do", $4f
	db "this to me?", $57
; 0x19d2d2

UnknownText_0x19d2d2: ; 0x19d2d2
	db $0, "What else do I", $4f
	db "like besides", $55
	db "#MON?", $51
	db "MARY on the radio.", $4f
	db "I bet she's cute!", $57
; 0x19d319

PokemaniacBrent1SeenText: ; 0x19d319
	db $0, "Hey! Do you have", $4f
	db "any rare #MON?", $57
; 0x19d33a

PokemaniacBrent1BeatenText: ; 0x19d33a
	db $0, "Oh, my poor #-", $4f
	db "MON! Darlings!", $57
; 0x19d359

UnknownText_0x19d359: ; 0x19d359
	db $0, "I'd be happy just", $4f
	db "to own a single", $55
	db "rare #MON.", $57
; 0x19d386

PokemaniacRonSeenText: ; 0x19d386
	db $0, "Would you get", $4f
	db "this?", $51
	db "Some ", $53, " guy", $4f
	db "made fun of my", $55
	db "#MON!", $51
	db "Darn it! My #-", $4f
	db "MON's great!", $57
; 0x19d3d6

PokemaniacRonBeatenText: ; 0x19d3d6
	db $0, "My NIDOKING did", $4f
	db "pretty right on!", $57
; 0x19d3f8

UnknownText_0x19d3f8: ; 0x19d3f8
	db $0, "It's okay for", $4f
	db "people to like", $51
	db "different types", $4f
	db "of #MON.", $51
	db "#MON isn't just", $4f
	db "about having the", $55
	db "most powerful one.", $57
; 0x19d461

FisherMarvinSeenText: ; 0x19d461
	db $0, "I'm in a slump.", $51
	db "Maybe it's the", $4f
	db "gear I'm using.", $51
	db "Let's battle for a", $4f
	db "change of pace!", $57
; 0x19d4b0

FisherMarvinBeatenText: ; 0x19d4b0
	db $0, "I lost, but I feel", $4f
	db "better anyway.", $57
; 0x19d4d3

UnknownText_0x19d4d3: ; 0x19d4d3
	db $0, "KURT's LURE BALL", $4f
	db "is the best for", $51
	db "catching hooked", $4f
	db "#MON.", $51
	db "It's much more", $4f
	db "effective than a", $55
	db "ULTRA BALL.", $57
; 0x19d535

CamperSpencerSeenText: ; 0x19d535
	db $0, "I can do so much", $4f
	db "with my #MON--", $55
	db "it's super-fun!", $57
; 0x19d565

CamperSpencerBeatenText: ; 0x19d565
	db $0, "Losing isn't fun", $4f
	db "at all…", $57
; 0x19d57e

UnknownText_0x19d57e: ; 0x19d57e
	db $0, "What is going on", $4f
	db "at LAKE OF RAGE?", $51
	db "We were planning", $4f
	db "to camp there.", $57
; 0x19d5c1

PicnickerTiffany3SeenText: ; 0x19d5c1
	db $0, "Are you going to", $4f
	db "LAKE OF RAGE too?", $51
	db "Let's play for a ", $4f
	db "little while!", $57
; 0x19d604

PicnickerTiffany3BeatenText: ; 0x19d604
	db $0, "I played too much!", $57
; 0x19d618

UnknownText_0x19d618: ; 0x19d618
	db $0, "I'm having a pic-", $4f
	db "nic with #MON.", $51
	db "Won't you join us?", $57
; 0x19d64b

UnknownText_0x19d64b: ; 0x19d64b
	db $0, "Isn't my CLEFAIRY", $4f
	db "just the most", $55
	db "adorable thing?", $57
; 0x19d67b

UnknownText_0x19d67b: ; 0x19d67b
	db $0, "ROUTE 43", $51
	db "LAKE OF RAGE -", $4f
	db "MAHOGANY TOWN", $57
; 0x19d6a2

UnknownText_0x19d6a2: ; 0x19d6a2
	db $0, "ROUTE 43", $51
	db "LAKE OF RAGE -", $4f
	db "MAHOGANY TOWN", $57
; 0x19d6c9

UnknownText_0x19d6c9: ; 0x19d6c9
	db $0, "TRAINER TIPS", $51
	db "All #MON have", $4f
	db "pros and cons", $51
	db "depending on their", $4f
	db "types.", $51
	db "If their types", $4f
	db "differ, a higher-", $51
	db "level #MON may", $4f
	db "lose in battle.", $51
	db "Learn which types", $4f
	db "are strong and", $51
	db "weak against your", $4f
	db "#MON's type.", $57
; 0x19d78c

Route43_MapEventHeader: ; 0x19d78c
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $33, $9, 1, GROUP_ROUTE_43_MAHOGANY_GATE, MAP_ROUTE_43_MAHOGANY_GATE
	warp_def $33, $a, 2, GROUP_ROUTE_43_MAHOGANY_GATE, MAP_ROUTE_43_MAHOGANY_GATE
	warp_def $23, $11, 3, GROUP_ROUTE_43_GATE, MAP_ROUTE_43_GATE
	warp_def $1f, $11, 1, GROUP_ROUTE_43_GATE, MAP_ROUTE_43_GATE
	warp_def $1f, $12, 2, GROUP_ROUTE_43_GATE, MAP_ROUTE_43_GATE

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 3, 13, $0, MapRoute43Signpost0Script
	signpost 49, 11, $0, MapRoute43Signpost1Script
	signpost 38, 16, $0, MapRoute43Signpost2Script

	; people-events
	db 8
	person_event $2b, 9, 17, $8, $0, 255, 255, $92, 2, TrainerPokemaniacBen, $ffff
	person_event $2b, 24, 17, $a, $0, 255, 255, $92, 3, TrainerPokemaniacBrent1, $ffff
	person_event $2b, 11, 18, $6, $0, 255, 255, $92, 2, TrainerPokemaniacRon, $ffff
	person_event $3a, 20, 8, $9, $0, 255, 255, $a2, 4, TrainerFisherMarvin, $ffff
	person_event $28, 29, 13, $6, $0, 255, 255, $a2, 2, TrainerPicnickerTiffany3, $ffff
	person_event $27, 44, 17, $a, $0, 255, 255, $a2, 3, TrainerCamperSpencer, $ffff
	person_event $5d, 30, 5, $1, $0, 255, 255, $0, 0, UnknownScript_0x19d266, $ffff
	person_event $54, 36, 16, $1, $0, 255, 255, $1, 0, ItemFragment_0x19d268, $06b5
; 0x19d822

Route44_MapScriptHeader: ; 0x19d822
	; trigger count
	db 0

	; callback count
	db 0
; 0x19d824

TrainerBird_keeperVance1: ; 0x19d824
	; bit/flag number
	dw $401

	; trainer group && trainer id
	db BIRD_KEEPER, VANCE1

	; text when seen
	dw Bird_keeperVance1SeenText

	; text when trainer beaten
	dw Bird_keeperVance1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperVance1Script
; 0x19d830

Bird_keeperVance1Script: ; 0x19d830
	writecode $17, $20
	talkaftercancel
	loadfont
	checkbit2 $0079
	iftrue UnknownScript_0x19d86a
	checkcellnum $20
	iftrue UnknownScript_0x19d8eb
	checkbit1 $0295
	iftrue UnknownScript_0x19d853
	2writetext UnknownText_0x19dbf3
	keeptextopen
	setbit1 $0295
	2call UnknownScript_0x19d8df
	2jump UnknownScript_0x19d856
; 0x19d853

UnknownScript_0x19d853: ; 0x19d853
	2call UnknownScript_0x19d8e3
UnknownScript_0x19d856: ; 0x19d856
	askforphonenumber $20
	if_equal $1, UnknownScript_0x19d8f3
	if_equal $2, UnknownScript_0x19d8ef
	trainertotext BIRD_KEEPER, VANCE1, $0
	2call UnknownScript_0x19d8e7
	2jump UnknownScript_0x19d8eb
; 0x19d86a

UnknownScript_0x19d86a: ; 0x19d86a
	2call UnknownScript_0x19d8f7
	winlosstext Bird_keeperVance1BeatenText, $0000
	copybytetovar $da09
	if_equal $2, UnknownScript_0x19d881
	if_equal $1, UnknownScript_0x19d887
	if_equal $0, UnknownScript_0x19d88d
UnknownScript_0x19d881: ; 0x19d881
	checkbit1 $00cd
	iftrue UnknownScript_0x19d8a7
UnknownScript_0x19d887: ; 0x19d887
	checkbit1 $0044
	iftrue UnknownScript_0x19d89a
UnknownScript_0x19d88d: ; 0x19d88d
	loadtrainer BIRD_KEEPER, VANCE1
	startbattle
	returnafterbattle
	loadvar $da09, $1
	clearbit2 $0079
	end
; 0x19d89a

UnknownScript_0x19d89a: ; 0x19d89a
	loadtrainer BIRD_KEEPER, VANCE2
	startbattle
	returnafterbattle
	loadvar $da09, $2
	clearbit2 $0079
	end
; 0x19d8a7

UnknownScript_0x19d8a7: ; 0x19d8a7
	loadtrainer BIRD_KEEPER, VANCE3
	startbattle
	returnafterbattle
	clearbit2 $0079
	checkbit1 $0339
	iftrue UnknownScript_0x19d8cb
	checkbit1 $0267
	iftrue UnknownScript_0x19d8ca
	2call UnknownScript_0x19d90a
	verbosegiveitem CARBOS, 1
	iffalse UnknownScript_0x19d903
	setbit1 $0267
	2jump UnknownScript_0x19d8eb
; 0x19d8ca

UnknownScript_0x19d8ca: ; 0x19d8ca
	end
; 0x19d8cb

UnknownScript_0x19d8cb: ; 0x19d8cb
	loadfont
	2writetext UnknownText_0x19dc67
	closetext
	verbosegiveitem CARBOS, 1
	iffalse UnknownScript_0x19d903
	clearbit1 $0339
	setbit1 $0267
	2jump UnknownScript_0x19d8eb
; 0x19d8df

UnknownScript_0x19d8df: ; 0x19d8df
	jumpstd $0019
	end
; 0x19d8e3

UnknownScript_0x19d8e3: ; 0x19d8e3
	jumpstd $001a
	end
; 0x19d8e7

UnknownScript_0x19d8e7: ; 0x19d8e7
	jumpstd $001b
	end
; 0x19d8eb

UnknownScript_0x19d8eb: ; 0x19d8eb
	jumpstd $001c
	end
; 0x19d8ef

UnknownScript_0x19d8ef: ; 0x19d8ef
	jumpstd $001d
	end
; 0x19d8f3

UnknownScript_0x19d8f3: ; 0x19d8f3
	jumpstd $001e
	end
; 0x19d8f7

UnknownScript_0x19d8f7: ; 0x19d8f7
	jumpstd $001f
	end
; 0x19d8fb

UnknownScript_0x19d8fb: ; 0x19d8fb
	jumpstd $0020
	end
; 0x19d8ff

UnknownScript_0x19d8ff: ; 0x19d8ff
	jumpstd $0021
	end
; 0x19d903

UnknownScript_0x19d903: ; 0x19d903
	setbit1 $0339
	jumpstd $0021
	end
; 0x19d90a

UnknownScript_0x19d90a: ; 0x19d90a
	jumpstd $0022
	end
; 0x19d90e

TrainerPsychicPhil: ; 0x19d90e
	; bit/flag number
	dw $441

	; trainer group && trainer id
	db PSYCHIC_T, PHIL

	; text when seen
	dw PsychicPhilSeenText

	; text when trainer beaten
	dw PsychicPhilBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicPhilScript
; 0x19d91a

PsychicPhilScript: ; 0x19d91a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19dcfc
	closetext
	loadmovesprites
	end
; 0x19d922

TrainerFisherWilton1: ; 0x19d922
	; bit/flag number
	dw $457

	; trainer group && trainer id
	db FISHER, WILTON1

	; text when seen
	dw FisherWilton1SeenText

	; text when trainer beaten
	dw FisherWilton1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherWilton1Script
; 0x19d92e

FisherWilton1Script: ; 0x19d92e
	writecode $17, $21
	talkaftercancel
	loadfont
	checkbit2 $007a
	iftrue UnknownScript_0x19d96e
	checkbit2 $0086
	iftrue UnknownScript_0x19d9b4
	checkcellnum $21
	iftrue UnknownScript_0x19d8eb
	checkbit1 $0297
	iftrue UnknownScript_0x19d957
	2writetext UnknownText_0x19daa8
	keeptextopen
	setbit1 $0297
	2call UnknownScript_0x19d8df
	2jump UnknownScript_0x19d95a
; 0x19d957

UnknownScript_0x19d957: ; 0x19d957
	2call UnknownScript_0x19d8e3
UnknownScript_0x19d95a: ; 0x19d95a
	askforphonenumber $21
	if_equal $1, UnknownScript_0x19d8f3
	if_equal $2, UnknownScript_0x19d8ef
	trainertotext FISHER, WILTON1, $0
	2call UnknownScript_0x19d8e7
	2jump UnknownScript_0x19d8eb
; 0x19d96e

UnknownScript_0x19d96e: ; 0x19d96e
	2call UnknownScript_0x19d8f7
	winlosstext FisherWilton1BeatenText, $0000
	copybytetovar $da0a
	if_equal $2, UnknownScript_0x19d985
	if_equal $1, UnknownScript_0x19d98b
	if_equal $0, UnknownScript_0x19d991
UnknownScript_0x19d985: ; 0x19d985
	checkbit1 $00cd
	iftrue UnknownScript_0x19d9ab
UnknownScript_0x19d98b: ; 0x19d98b
	checkbit1 $0044
	iftrue UnknownScript_0x19d99e
UnknownScript_0x19d991: ; 0x19d991
	loadtrainer FISHER, WILTON1
	startbattle
	returnafterbattle
	loadvar $da0a, $1
	clearbit2 $007a
	end
; 0x19d99e

UnknownScript_0x19d99e: ; 0x19d99e
	loadtrainer FISHER, WILTON2
	startbattle
	returnafterbattle
	loadvar $da0a, $2
	clearbit2 $007a
	end
; 0x19d9ab

UnknownScript_0x19d9ab: ; 0x19d9ab
	loadtrainer FISHER, WILTON3
	startbattle
	returnafterbattle
	clearbit2 $007a
	end
; 0x19d9b4

UnknownScript_0x19d9b4: ; 0x19d9b4
	2call UnknownScript_0x19d8fb
	checkbit1 $032f
	iftrue UnknownScript_0x19d9c9
	checkbit1 $0330
	iftrue UnknownScript_0x19d9d2
	checkbit1 $0331
	iftrue UnknownScript_0x19d9db
UnknownScript_0x19d9c9: ; 0x19d9c9
	verbosegiveitem ULTRA_BALL, 1
	iffalse UnknownScript_0x19d9e7
	2jump UnknownScript_0x19d9e1
; 0x19d9d2

UnknownScript_0x19d9d2: ; 0x19d9d2
	verbosegiveitem GREAT_BALL, 1
	iffalse UnknownScript_0x19d9e7
	2jump UnknownScript_0x19d9e1
; 0x19d9db

UnknownScript_0x19d9db: ; 0x19d9db
	verbosegiveitem POKE_BALL, 1
	iffalse UnknownScript_0x19d9e7
UnknownScript_0x19d9e1: ; 0x19d9e1
	clearbit2 $0086
	2jump UnknownScript_0x19d8eb
; 0x19d9e7

UnknownScript_0x19d9e7: ; 0x19d9e7
	2jump UnknownScript_0x19d8ff
; 0x19d9ea

TrainerFisherEdgar: ; 0x19d9ea
	; bit/flag number
	dw $458

	; trainer group && trainer id
	db FISHER, EDGAR

	; text when seen
	dw FisherEdgarSeenText

	; text when trainer beaten
	dw FisherEdgarBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherEdgarScript
; 0x19d9f6

FisherEdgarScript: ; 0x19d9f6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19db6f
	closetext
	loadmovesprites
	end
; 0x19d9fe

TrainerCooltrainerfCybil: ; 0x19d9fe
	; bit/flag number
	dw $56a

	; trainer group && trainer id
	db COOLTRAINERF, CYBIL

	; text when seen
	dw CooltrainerfCybilSeenText

	; text when trainer beaten
	dw CooltrainerfCybilBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfCybilScript
; 0x19da0a

CooltrainerfCybilScript: ; 0x19da0a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19df4d
	closetext
	loadmovesprites
	end
; 0x19da12

TrainerPokemaniacZach: ; 0x19da12
	; bit/flag number
	dw $4f0

	; trainer group && trainer id
	db POKEMANIAC, ZACH

	; text when seen
	dw PokemaniacZachSeenText

	; text when trainer beaten
	dw PokemaniacZachBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacZachScript
; 0x19da1e

PokemaniacZachScript: ; 0x19da1e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19dd7e
	closetext
	loadmovesprites
	end
; 0x19da26

TrainerCooltrainermAllen: ; 0x19da26
	; bit/flag number
	dw $55a

	; trainer group && trainer id
	db COOLTRAINERM, ALLEN

	; text when seen
	dw CooltrainermAllenSeenText

	; text when trainer beaten
	dw CooltrainermAllenBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermAllenScript
; 0x19da32

CooltrainermAllenScript: ; 0x19da32
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19de66
	closetext
	loadmovesprites
	end
; 0x19da3a

MapRoute44Signpost0Script: ; 0x19da3a
	jumptext UnknownText_0x19dfb3
; 0x19da3d

MapRoute44Signpost1Script: ; 0x19da3d
	jumptext UnknownText_0x19dfcc
; 0x19da40

UnknownScript_0x19da40: ; 0x19da40
	fruittree $10
; 0x19da42

ItemFragment_0x19da42: ; 0x19da42
	db MAX_REVIVE, 1
; 0x19da44

ItemFragment_0x19da44: ; 0x19da44
	db ULTRA_BALL, 1
; 0x19da46

ItemFragment_0x19da46: ; 0x19da46
	db MAX_REPEL, 1
; 0x19da48

MapRoute44SignpostItem2: ; 0x19da48
	dw $00ae
	db ELIXER
	
; 0x19da4b

FisherWilton1SeenText: ; 0x19da4b
	db $0, "Aack! You made me", $4f
	db "lose a POLIWAG!", $51
	db "What are you going", $4f
	db "to do about it?", $57
; 0x19da91

FisherWilton1BeatenText: ; 0x19da91
	db $0, "Just forget about", $4f
	db "it.", $57
; 0x19daa8

UnknownText_0x19daa8: ; 0x19daa8
	db $0, "That POLIWAG that", $4f
	db "got away…", $55
	db "It was huge.", $51
	db "I swear it must've", $4f
	db "been 16 feet long!", $57
; 0x19daf7

FisherEdgarSeenText: ; 0x19daf7
	db $0, "I fish until I", $4f
	db "can't anymore.", $51
	db "I also battle", $4f
	db "until I drop.", $51
	db "That's my", $4f
	db "relationship", $55
	db "with my #MON.", $57
; 0x19db55

FisherEdgarBeatenText: ; 0x19db55
	db $0, "Hmmmm… ", $4f
	db "This isn't right.", $57
; 0x19db6f

UnknownText_0x19db6f: ; 0x19db6f
	db $0, "That's 100 wins", $4f
	db "to 101 losses.", $51
	db "I won't battle", $4f
	db "again for a while.", $57
; 0x19dbaf

Bird_keeperVance1SeenText: ; 0x19dbaf
	db $0, "Do you know about", $4f
	db "the legendary bird", $55
	db "#MON?", $57
; 0x19dbdb

Bird_keeperVance1BeatenText: ; 0x19dbdb
	db $0, "Whew! You're hot", $4f
	db "stuff.", $57
; 0x19dbf3

UnknownText_0x19dbf3: ; 0x19dbf3
	db $0, "ARTICUNO, ZAPDOS", $4f
	db "and MOLTRES are", $51
	db "the three legend-", $4f
	db "ary bird #MON.", $51
	db "I heard there are", $4f
	db "other legendary", $55
	db "birds, though.", $57
; 0x19dc67

UnknownText_0x19dc67: ; 0x19dc67
	db $0, "Why can't I ever", $4f
	db "beat you?", $51
	db "Oh yeah, here you", $4f
	db "go. It's that gift", $51
	db "I couldn't give", $4f
	db "you last time.", $57
; 0x19dcc4

PsychicPhilSeenText: ; 0x19dcc4
	db $0, "I'm gonna win,", $4f
	db "for sure!", $57
; 0x19dcdd

PsychicPhilBeatenText: ; 0x19dcdd
	db $0, "Arrgh… That's a", $4f
	db "shocking loss…", $57
; 0x19dcfc

UnknownText_0x19dcfc: ; 0x19dcfc
	db $0, "It's important to", $4f
	db "have conviction", $55
	db "on your side.", $57
; 0x19dd2c

PokemaniacZachSeenText: ; 0x19dd2c
	db $0, "I'll do anything", $4f
	db "to get my hands on", $55
	db "rare #MON!", $57
; 0x19dd5b

PokemaniacZachBeatenText: ; 0x19dd5b
	db $0, "Oooh, your #MON", $4f
	db "are so appealing.", $57
; 0x19dd7e

UnknownText_0x19dd7e: ; 0x19dd7e
	db $0, "If a #MON has", $4f
	db "different colors", $51
	db "from usual, it's", $4f
	db "more valuable.", $51
	db "What? You mean", $4f
	db "that's not true?", $57
; 0x19dddc

CooltrainermAllenSeenText: ; 0x19dddc
	db $0, "I can tell you're", $4f
	db "a good trainer by", $55
	db "looking at you.", $51
	db "I'm good at #-", $4f
	db "MON, and I can see", $55
	db "that you are too.", $57
; 0x19de43

CooltrainermAllenBeatenText: ; 0x19de43
	db $0, "Tch! It's a total", $4f
	db "loss on my part.", $57
; 0x19de66

UnknownText_0x19de66: ; 0x19de66
	db $0, "Wow. You have a", $4f
	db "lot of BADGES.", $51
	db "No wonder you're", $4f
	db "so tough.", $51
	db "I wonder if", $4f
	db "ECRUTEAK GYM's", $51
	db "MORTY is still in", $4f
	db "training?", $51
	db "He really hammered", $4f
	db "me.", $57
; 0x19deed

CooltrainerfCybilSeenText: ; 0x19deed
	db $0, "You look strong.", $51
	db "Good trainers seek", $4f
	db "tough opponents", $55
	db "instinctively.", $57
; 0x19df31

CooltrainerfCybilBeatenText: ; 0x19df31
	db $0, "Nope! This won't", $4f
	db "do at all.", $57
; 0x19df4d

UnknownText_0x19df4d: ; 0x19df4d
	db $0, "We all get better", $4f
	db "by experiencing", $55
	db "many battles.", $51
	db "I battled a lot to", $4f
	db "become what I am", $55
	db "today--an elite.", $57
; 0x19dfb3

UnknownText_0x19dfb3: ; 0x19dfb3
	db $0, "ROUTE 44", $4f
	db "ICE PATH AHEAD", $57
; 0x19dfcc

UnknownText_0x19dfcc: ; 0x19dfcc
	db $0, "ROUTE 44", $51
	db "MAHOGANY TOWN -", $4f
	db "BLACKTHORN CITY", $57
; 0x19dff6

Route44_MapEventHeader: ; 0x19dff6
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $38, 1, GROUP_ICE_PATH_1F, MAP_ICE_PATH_1F

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 7, 53, $0, MapRoute44Signpost0Script
	signpost 10, 6, $0, MapRoute44Signpost1Script
	signpost 9, 32, $7, MapRoute44SignpostItem2

	; people-events
	db 11
	person_event $3a, 7, 39, $6, $0, 255, 255, $a2, 1, TrainerFisherWilton1, $ffff
	person_event $3a, 17, 23, $9, $0, 255, 255, $a2, 1, TrainerFisherEdgar, $ffff
	person_event $27, 13, 14, $1f, $0, 255, 255, $92, 3, TrainerPsychicPhil, $ffff
	person_event $2b, 6, 47, $1f, $0, 255, 255, $a2, 3, TrainerPokemaniacZach, $ffff
	person_event $27, 9, 55, $6, $0, 255, 255, $a2, 2, TrainerBird_keeperVance1, $ffff
	person_event $23, 19, 45, $8, $0, 255, 255, $82, 5, TrainerCooltrainermAllen, $ffff
	person_event $24, 18, 35, $8, $0, 255, 255, $82, 5, TrainerCooltrainerfCybil, $ffff
	person_event $5d, 9, 13, $1, $0, 255, 255, $0, 0, UnknownScript_0x19da40, $ffff
	person_event $54, 12, 34, $1, $0, 255, 255, $1, 0, ItemFragment_0x19da42, $06b6
	person_event $54, 8, 49, $1, $0, 255, 255, $1, 0, ItemFragment_0x19da44, $06b7
	person_event $54, 13, 18, $1, $0, 255, 255, $1, 0, ItemFragment_0x19da46, $07bd
; 0x19e09f

Route45_MapScriptHeader: ; 0x19e09f
	; trigger count
	db 0

	; callback count
	db 0
; 0x19e0a1

TrainerBlackbeltKenji3: ; 0x19e0a1
	; bit/flag number
	dw $4ab

	; trainer group && trainer id
	db BLACKBELT_T, KENJI3

	; text when seen
	dw BlackbeltKenji3SeenText

	; text when trainer beaten
	dw BlackbeltKenji3BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BlackbeltKenji3Script
; 0x19e0ad

BlackbeltKenji3Script: ; 0x19e0ad
	writecode $17, $22
	talkaftercancel
	loadfont
	checkcellnum $22
	iftrue UnknownScript_0x19e0e4
	checkbit1 $0299
	iftrue UnknownScript_0x19e0cd
	special $0095
	2writetext UnknownText_0x19e5e2
	closetext
	setbit1 $0299
	2call UnknownScript_0x19e11b
	2jump UnknownScript_0x19e0d0
; 0x19e0cd

UnknownScript_0x19e0cd: ; 0x19e0cd
	2call UnknownScript_0x19e11f
UnknownScript_0x19e0d0: ; 0x19e0d0
	askforphonenumber $22
	if_equal $1, UnknownScript_0x19e12f
	if_equal $2, UnknownScript_0x19e12b
	trainertotext BLACKBELT_T, KENJI3, $0
	2call UnknownScript_0x19e123
	2jump UnknownScript_0x19e127
; 0x19e0e4

UnknownScript_0x19e0e4: ; 0x19e0e4
	checkcode $1a
	if_not_equal $1, UnknownScript_0x19e127
	checktime $1
	iftrue UnknownScript_0x19e10c
	checktime $4
	iftrue UnknownScript_0x19e112
	checkbit1 $026a
	iffalse UnknownScript_0x19e127
	2call UnknownScript_0x19e137
	verbosegiveitem PP_UP, 1
	iffalse UnknownScript_0x19e118
	clearbit1 $026a
	special $0095
	2jump UnknownScript_0x19e127
; 0x19e10c

UnknownScript_0x19e10c: ; 0x19e10c
	2writetext UnknownText_0x19e634
	closetext
	loadmovesprites
	end
; 0x19e112

UnknownScript_0x19e112: ; 0x19e112
	2writetext UnknownText_0x19e66c
	closetext
	loadmovesprites
	end
; 0x19e118

UnknownScript_0x19e118: ; 0x19e118
	2jump UnknownScript_0x19e13b
; 0x19e11b

UnknownScript_0x19e11b: ; 0x19e11b
	jumpstd $0019
	end
; 0x19e11f

UnknownScript_0x19e11f: ; 0x19e11f
	jumpstd $001a
	end
; 0x19e123

UnknownScript_0x19e123: ; 0x19e123
	jumpstd $001b
	end
; 0x19e127

UnknownScript_0x19e127: ; 0x19e127
	jumpstd $001c
	end
; 0x19e12b

UnknownScript_0x19e12b: ; 0x19e12b
	jumpstd $001d
	end
; 0x19e12f

UnknownScript_0x19e12f: ; 0x19e12f
	jumpstd $001e
	end
; 0x19e133

UnknownScript_0x19e133: ; 0x19e133
	jumpstd $001f
	end
; 0x19e137

UnknownScript_0x19e137: ; 0x19e137
	jumpstd $0020
	end
; 0x19e13b

UnknownScript_0x19e13b: ; 0x19e13b
	jumpstd $0021
	end
; 0x19e13f

UnknownScript_0x19e13f: ; 0x19e13f
	setbit1 $033a
	jumpstd $0021
	end
; 0x19e146

UnknownScript_0x19e146: ; 0x19e146
	jumpstd $0022
	end
; 0x19e14a

TrainerHikerErik: ; 0x19e14a
	; bit/flag number
	dw $52a

	; trainer group && trainer id
	db HIKER, ERIK

	; text when seen
	dw HikerErikSeenText

	; text when trainer beaten
	dw HikerErikBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerErikScript
; 0x19e156

HikerErikScript: ; 0x19e156
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19e301
	closetext
	loadmovesprites
	end
; 0x19e15e

TrainerHikerMichael: ; 0x19e15e
	; bit/flag number
	dw $52b

	; trainer group && trainer id
	db HIKER, MICHAEL

	; text when seen
	dw HikerMichaelSeenText

	; text when trainer beaten
	dw HikerMichaelBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerMichaelScript
; 0x19e16a

HikerMichaelScript: ; 0x19e16a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19e3b1
	closetext
	loadmovesprites
	end
; 0x19e172

TrainerHikerParry3: ; 0x19e172
	; bit/flag number
	dw $52c

	; trainer group && trainer id
	db HIKER, PARRY3

	; text when seen
	dw HikerParry3SeenText

	; text when trainer beaten
	dw HikerParry3BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerParry3Script
; 0x19e17e

HikerParry3Script: ; 0x19e17e
	writecode $17, $23
	talkaftercancel
	loadfont
	checkbit2 $007b
	iftrue UnknownScript_0x19e1b8
	checkcellnum $23
	iftrue UnknownScript_0x19e127
	checkbit1 $029b
	iftrue UnknownScript_0x19e1a1
	2writetext UnknownText_0x19e434
	keeptextopen
	setbit1 $029b
	2call UnknownScript_0x19e11b
	2jump UnknownScript_0x19e1a4
; 0x19e1a1

UnknownScript_0x19e1a1: ; 0x19e1a1
	2call UnknownScript_0x19e11f
UnknownScript_0x19e1a4: ; 0x19e1a4
	askforphonenumber $23
	if_equal $1, UnknownScript_0x19e12f
	if_equal $2, UnknownScript_0x19e12b
	trainertotext HIKER, PARRY1, $0
	2call UnknownScript_0x19e123
	2jump UnknownScript_0x19e127
; 0x19e1b8

UnknownScript_0x19e1b8: ; 0x19e1b8
	2call UnknownScript_0x19e133
	winlosstext HikerParry3BeatenText, $0000
	copybytetovar $da0c
	if_equal $2, UnknownScript_0x19e1cf
	if_equal $1, UnknownScript_0x19e1d5
	if_equal $0, UnknownScript_0x19e1db
UnknownScript_0x19e1cf: ; 0x19e1c
	checkbit1 $00cd
	iftrue UnknownScript_0x19e1f5
UnknownScript_0x19e1d5: ; 0x19e1d5
	checkbit1 $0044
	iftrue UnknownScript_0x19e1e8
UnknownScript_0x19e1db: ; 0x19e1db
	loadtrainer HIKER, PARRY3
	startbattle
	returnafterbattle
	loadvar $da0c, $1
	clearbit2 $007b
	end
; 0x19e1e8

UnknownScript_0x19e1e8: ; 0x19e1e8
	loadtrainer HIKER, PARRY1
	startbattle
	returnafterbattle
	loadvar $da0c, $2
	clearbit2 $007b
	end
; 0x19e1f5

UnknownScript_0x19e1f5: ; 0x19e1f5
	loadtrainer HIKER, PARRY2
	startbattle
	returnafterbattle
	clearbit2 $007b
	checkbit1 $033a
	iftrue UnknownScript_0x19e219
	checkbit1 $0268
	iftrue UnknownScript_0x19e218
	2call UnknownScript_0x19e146
	verbosegiveitem IRON, 1
	iffalse UnknownScript_0x19e13f
	setbit1 $0268
	2jump UnknownScript_0x19e127
; 0x19e218

UnknownScript_0x19e218: ; 0x19e218
	end
; 0x19e219

UnknownScript_0x19e219: ; 0x19e219
	loadfont
	2writetext UnknownText_0x19e52c
	closetext
	verbosegiveitem IRON, 1
	iffalse UnknownScript_0x19e13f
	clearbit1 $033a
	setbit1 $0268
	2jump UnknownScript_0x19e127
; 0x19e22d

TrainerHikerTimothy: ; 0x19e22d
	; bit/flag number
	dw $52d

	; trainer group && trainer id
	db HIKER, TIMOTHY

	; text when seen
	dw HikerTimothySeenText

	; text when trainer beaten
	dw HikerTimothyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerTimothyScript
; 0x19e239

HikerTimothyScript: ; 0x19e239
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19e4f1
	closetext
	loadmovesprites
	end
; 0x19e241

TrainerCooltrainermRyan: ; 0x19e241
	; bit/flag number
	dw $54f

	; trainer group && trainer id
	db COOLTRAINERM, RYAN

	; text when seen
	dw CooltrainermRyanSeenText

	; text when trainer beaten
	dw CooltrainermRyanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermRyanScript
; 0x19e24d

CooltrainermRyanScript: ; 0x19e24d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19e70d
	closetext
	loadmovesprites
	end
; 0x19e255

TrainerCooltrainerfKelly: ; 0x19e255
	; bit/flag number
	dw $561

	; trainer group && trainer id
	db COOLTRAINERF, KELLY

	; text when seen
	dw CooltrainerfKellySeenText

	; text when trainer beaten
	dw CooltrainerfKellyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfKellyScript
; 0x19e261

CooltrainerfKellyScript: ; 0x19e261
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19e7d1
	closetext
	loadmovesprites
	end
; 0x19e269

UnknownScript_0x19e269: ; 0x19e269
	faceplayer
	loadfont
	checkbit1 $05c3
	iftrue UnknownScript_0x19e285
	2writetext UnknownText_0x19e87f
	closetext
	loadmovesprites
	winlosstext UnknownText_0x19e899, $0000
	loadtrainer CAMPER, QUENTIN
	startbattle
	returnafterbattle
	setbit1 $05c3
	loadmovesprites
	end
; 0x19e285

UnknownScript_0x19e285: ; 0x19e285
	2writetext UnknownText_0x19e8bb
	closetext
	loadmovesprites
	end
; 0x19e28b

UnknownScript_0x19e28b: ; 0x19e28b
	2writetext UnknownText_0x19e830
	closetext
	loadmovesprites
	end
; 0x19e291

MapRoute45Signpost0Script: ; 0x19e291
	jumptext UnknownText_0x19e8fe
; 0x19e294

UnknownScript_0x19e294: ; 0x19e294
	fruittree $c
; 0x19e296

ItemFragment_0x19e296: ; 0x19e296
	db NUGGET, 1
; 0x19e298

ItemFragment_0x19e298: ; 0x19e298
	db REVIVE, 1
; 0x19e29a

ItemFragment_0x19e29a: ; 0x19e29a
	db ELIXER, 1
; 0x19e29c

ItemFragment_0x19e29c: ; 0x19e29c
	db MAX_POTION, 1
; 0x19e29e

MapRoute45SignpostItem1: ; 0x19e29e
	dw $00af
	db PP_UP
	
; 0x19e2a1

HikerErikSeenText: ; 0x19e2a1
	db $0, "Be prepared for", $4f
	db "anything!", $51
	db "Let me see if your", $4f
	db "#MON have been", $55
	db "raised properly!", $57
; 0x19e2ef

HikerErikBeatenText: ; 0x19e2ef
	db $0, "Oh, I lost that!", $57
; 0x19e301

UnknownText_0x19e301: ; 0x19e301
	db $0, "I'll head back to", $4f
	db "BLACKTHORN's ICE", $51
	db "PATH and train", $4f
	db "some more.", $57
; 0x19e33d

HikerMichaelSeenText: ; 0x19e33d
	db $0, "Yo! You're spunky!", $4f
	db "But you know what?", $51
	db "When it comes to", $4f
	db "sheer spunkiness,", $55
	db "I'm the man!", $57
; 0x19e392

HikerMichaelBeatenText: ; 0x19e392
	db $0, "My #MON weren't", $4f
	db "spunky enough!", $57
; 0x19e3b1

UnknownText_0x19e3b1: ; 0x19e3b1
	db $0, "Boy, do I love", $4f
	db "HP UP! Mmmm, yum!", $51
	db "I keep drinking my", $4f
	db "#MON's!", $51
	db "I can't help it!", $57
; 0x19e3fd

HikerParry3SeenText: ; 0x19e3fd
	db $0, "My #MON are", $4f
	db "power packed!", $57
; 0x19e418

HikerParry3BeatenText: ; 0x19e418
	db $0, "Wahahah! I'm the", $4f
	db "big loser!", $57
; 0x19e434

UnknownText_0x19e434: ; 0x19e434
	db $0, "I'm not much good", $4f
	db "at thinking, see?", $51
	db "So, I just plow", $4f
	db "ahead with power!", $57
; 0x19e47a

HikerTimothySeenText: ; 0x19e47a
	db $0, "Why do I climb", $4f
	db "mountains?", $51
	db "Because they're", $4f
	db "there.", $51
	db "Why do I train", $4f
	db "#MON?", $51
	db "Because they're", $4f
	db "there!", $57
; 0x19e4d6

HikerTimothyBeatenText: ; 0x19e4d6
	db $0, "Losses…", $4f
	db "They're there too!", $57
; 0x19e4f1

UnknownText_0x19e4f1: ; 0x19e4f1
	db $0, "The best thing to", $4f
	db "ever happen to me", $51
	db "was discovering", $4f
	db "#MON.", $57
; 0x19e52c

UnknownText_0x19e52c: ; 0x19e52c
	db $0, "I just can't find", $4f
	db "a way to win!", $51
	db "Keep it up!", $51
	db "Oh, and take this", $4f
	db "--it's the gift", $51
	db "you couldn't take", $4f
	db "when we last met.", $57
; 0x19e59c

BlackbeltKenji3SeenText: ; 0x19e59c
	db $0, "I was training", $4f
	db "here alone.", $51
	db "Behold the fruits", $4f
	db "of my labor!", $57
; 0x19e5d7

BlackbeltKenji3BeatenText: ; 0x19e5d7
	db $0, "Waaaargh!", $57
; 0x19e5e2

UnknownText_0x19e5e2: ; 0x19e5e2
	db $0, "This calls for", $4f
	db "extreme measures.", $51
	db "I must take to the", $4f
	db "hills and train in", $55
	db "solitude.", $57
; 0x19e634

UnknownText_0x19e634: ; 0x19e634
	db $0, "I'm going to train", $4f
	db "a bit more before", $55
	db "I break for lunch.", $57
; 0x19e66c

UnknownText_0x19e66c: ; 0x19e66c
	db $0, "We had plenty of", $4f
	db "rest at lunch, so", $51
	db "now we're all", $4f
	db "ready to go again!", $51
	db "We're going to", $4f
	db "train again!", $57
; 0x19e6cb

CooltrainermRyanSeenText: ; 0x19e6cb
	db $0, "What are your", $4f
	db "thoughts on rais-", $55
	db "ing #MON?", $57
; 0x19e6f6

CooltrainermRyanBeatenText: ; 0x19e6f6
	db $0, "You've won my", $4f
	db "respect.", $57
; 0x19e70d

UnknownText_0x19e70d: ; 0x19e70d
	db $0, "I see you're rais-", $4f
	db "ing your #MON", $55
	db "with care.", $51
	db "The bond you build", $4f
	db "will save you in", $55
	db "tough situations.", $57
; 0x19e76f

CooltrainerfKellySeenText: ; 0x19e76f
	db $0, "What is your", $4f
	db "battle strategy?", $51
	db "It is foolish to", $4f
	db "use strong moves", $55
	db "indiscriminately.", $57
; 0x19e7c2

CooltrainerfKellyBeatenText: ; 0x19e7c2
	db $0, "Fine. I lost.", $57
; 0x19e7d1

UnknownText_0x19e7d1: ; 0x19e7d1
	db $0, "I'm not in favor", $4f
	db "of overly power-", $55
	db "ful moves.", $51
	db "I want to win, but", $4f
	db "I also don't want", $55
	db "to harm #MON.", $57
; 0x19e830

UnknownText_0x19e830: ; 0x19e830
	db $0, "I'm really, really", $4f
	db "tough!", $51
	db "Is there anywhere", $4f
	db "I can prove how", $55
	db "tough I really am?", $57
; 0x19e87f

UnknownText_0x19e87f: ; 0x19e87f
	db $0, "I'm really, really", $4f
	db "tough!", $57
; 0x19e899

UnknownText_0x19e899: ; 0x19e899
	db $0, "I was tough at the", $4f
	db "BATTLE TOWER…", $57
; 0x19e8bb

UnknownText_0x19e8bb: ; 0x19e8bb
	db $0, "Have you been to", $4f
	db "the BATTLE TOWER?", $51
	db "I never, ever lose", $4f
	db "there, but…", $57
; 0x19e8fe

UnknownText_0x19e8fe: ; 0x19e8fe
	db $0, "ROUTE 45", $4f
	db "MOUNTAIN RD. AHEAD", $57
; 0x19e91b

Route45_MapEventHeader: ; 0x19e91b
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $5, $2, 1, GROUP_DARK_CAVE_BLACKTHORN_ENTRANCE, MAP_DARK_CAVE_BLACKTHORN_ENTRANCE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 4, 10, $0, MapRoute45Signpost0Script
	signpost 80, 13, $7, MapRoute45SignpostItem1

	; people-events
	db 13
	person_event $2d, 20, 14, $9, $0, 255, 255, $b2, 1, TrainerHikerErik, $ffff
	person_event $2d, 69, 19, $9, $0, 255, 255, $b2, 2, TrainerHikerMichael, $ffff
	person_event $2d, 32, 9, $7, $0, 255, 255, $b2, 2, TrainerHikerParry3, $ffff
	person_event $2d, 69, 13, $8, $0, 255, 255, $b2, 1, TrainerHikerTimothy, $ffff
	person_event $41, 54, 15, $a, $0, 255, 255, $b2, 2, TrainerBlackbeltKenji3, $ffff
	person_event $23, 22, 21, $8, $0, 255, 255, $82, 1, TrainerCooltrainermRyan, $ffff
	person_event $24, 40, 9, $a, $0, 255, 255, $82, 3, TrainerCooltrainerfKelly, $ffff
	person_event $5d, 86, 20, $1, $0, 255, 255, $0, 0, UnknownScript_0x19e294, $ffff
	person_event $54, 55, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x19e296, $06b8
	person_event $54, 70, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x19e298, $06b9
	person_event $54, 24, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x19e29a, $06ba
	person_event $54, 37, 11, $1, $0, 255, 255, $1, 0, ItemFragment_0x19e29c, $06bb
	person_event $27, 74, 8, $3, $0, 255, 255, $a0, 0, UnknownScript_0x19e269, $ffff
; 0x19e9d9

Route19_MapScriptHeader: ; 0x19e9d9
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 1, UnknownScript_0x19e9de
; 0x19e9de

UnknownScript_0x19e9de: ; 0x19e9de
	checkbit1 $00d7
	iftrue UnknownScript_0x19e9fc
	changeblock $6, $6, $7a
	changeblock $8, $6, $7a
	changeblock $a, $6, $7a
	changeblock $c, $8, $7a
	changeblock $4, $8, $7a
	changeblock $a, $a, $7a
UnknownScript_0x19e9fc: ; 0x19e9fc
	return
; 0x19e9fd

TrainerSwimmerfDawn: ; 0x19e9fd
	; bit/flag number
	dw $3f3

	; trainer group && trainer id
	db SWIMMERF, DAWN

	; text when seen
	dw SwimmerfDawnSeenText

	; text when trainer beaten
	dw SwimmerfDawnBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfDawnScript
; 0x19ea09

SwimmerfDawnScript: ; 0x19ea09
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19ebad
	closetext
	loadmovesprites
	end
; 0x19ea11

TrainerSwimmermHarold: ; 0x19ea11
	; bit/flag number
	dw $594

	; trainer group && trainer id
	db SWIMMERM, HAROLD

	; text when seen
	dw SwimmermHaroldSeenText

	; text when trainer beaten
	dw SwimmermHaroldBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermHaroldScript
; 0x19ea1d

SwimmermHaroldScript: ; 0x19ea1d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19eab4
	closetext
	loadmovesprites
	end
; 0x19ea25

TrainerSwimmermJerome: ; 0x19ea25
	; bit/flag number
	dw $5a1

	; trainer group && trainer id
	db SWIMMERM, JEROME

	; text when seen
	dw SwimmermJeromeSeenText

	; text when trainer beaten
	dw SwimmermJeromeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermJeromeScript
; 0x19ea31

SwimmermJeromeScript: ; 0x19ea31
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19ec7e
	closetext
	loadmovesprites
	end
; 0x19ea39

TrainerSwimmermTucker: ; 0x19ea39
	; bit/flag number
	dw $5a2

	; trainer group && trainer id
	db SWIMMERM, TUCKER

	; text when seen
	dw SwimmermTuckerSeenText

	; text when trainer beaten
	dw SwimmermTuckerBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermTuckerScript
; 0x19ea45

SwimmermTuckerScript: ; 0x19ea45
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19eb3b
	closetext
	loadmovesprites
	end
; 0x19ea4d

UnknownScript_0x19ea4d: ; 0x19ea4d
	faceplayer
	loadfont
	checkbit1 $00d7
	iftrue UnknownScript_0x19ea5b
	2writetext UnknownText_0x19ecaf
	closetext
	loadmovesprites
	end
; 0x19ea5b

UnknownScript_0x19ea5b: ; 0x19ea5b
	2writetext UnknownText_0x19ed24
	closetext
	loadmovesprites
	end
; 0x19ea61

UnknownScript_0x19ea61: ; 0x19ea61
	faceplayer
	loadfont
	checkbit1 $00d7
	iftrue UnknownScript_0x19ea6f
	2writetext UnknownText_0x19ed45
	closetext
	loadmovesprites
	end
; 0x19ea6f

UnknownScript_0x19ea6f: ; 0x19ea6f
	2writetext UnknownText_0x19ed7d
	closetext
	loadmovesprites
	end
; 0x19ea75

MapRoute19Signpost0Script: ; 0x19ea75
	jumptext UnknownText_0x19edbc
; 0x19ea78

MapRoute19Signpost1Script: ; 0x19ea78
	jumptext UnknownText_0x19ede5
; 0x19ea7b

SwimmermHaroldSeenText: ; 0x19ea7b
	db $0, "Have you ever gone", $4f
	db "swimming in the", $55
	db "sea at night?", $57
; 0x19eaad

SwimmermHaroldBeatenText: ; 0x19eaad
	db $0, "Glub…", $57
; 0x19eab4

UnknownText_0x19eab4: ; 0x19eab4
	db $0, "At night, the sea", $4f
	db "turns black. It", $51
	db "feels like it will", $4f
	db "swallow you up.", $57
; 0x19eafa

SwimmermTuckerSeenText: ; 0x19eafa
	db $0, "Pant, pant…", $4f
	db "Just… a little…", $51
	db "farther… to…", $4f
	db "FUCHSIA…", $57
; 0x19eb2d

SwimmermTuckerBeatenText: ; 0x19eb2d
	db $0, "I'm drowning!", $57
; 0x19eb3b

UnknownText_0x19eb3b: ; 0x19eb3b
	db $0, "I… asked my girl-", $4f
	db "friend to swim to", $55
	db "FUCHSIA… Gasp…", $57
; 0x19eb6f

SwimmerfDawnSeenText: ; 0x19eb6f
	db $0, "I'm disgusted by", $4f
	db "wimpy people!", $57
; 0x19eb8e

SwimmerfDawnBeatenText: ; 0x19eb8e
	db $0, "I could beat you", $4f
	db "at swimming…", $57
; 0x19ebad

UnknownText_0x19ebad: ; 0x19ebad
	db $0, "It's a quick swim", $4f
	db "between FUCHSIA", $51
	db "and SEAFOAM IS-", $4f
	db "LANDS…", $51
	db "Sheesh, some big", $4f
	db "man my boyfriend", $51
	db "is! What a wimp!", $57
; 0x19ec19

SwimmermJeromeSeenText: ; 0x19ec19
	db $0, "Swimming?", $4f
	db "I'm lousy at it.", $51
	db "I'm just splashing", $4f
	db "around in these", $55
	db "shallow waters.", $57
; 0x19ec66

SwimmermJeromeBeatenText: ; 0x19ec66
	db $0, "I thought I could", $4f
	db "win.", $57
; 0x19ec7e

UnknownText_0x19ec7e: ; 0x19ec7e
	db $0, "I might be bad at", $4f
	db "swimming, but I", $55
	db "love the sea.", $57
; 0x19ecaf

UnknownText_0x19ecaf: ; 0x19ecaf
	db $0, "Sorry. This road", $4f
	db "is closed for", $55
	db "construction.", $51
	db "If you want to get", $4f
	db "to CINNABAR, you'd", $51
	db "better go south", $4f
	db "from PALLET TOWN.", $57
; 0x19ed24

UnknownText_0x19ed24: ; 0x19ed24
	db $0, "I'm all sweaty.", $4f
	db "Time for a swim!", $57
; 0x19ed45

UnknownText_0x19ed45: ; 0x19ed45
	db $0, "Who knows how long", $4f
	db "it would take to", $55
	db "move this boulder…", $57
; 0x19ed7d

UnknownText_0x19ed7d: ; 0x19ed7d
	db $0, "The roadwork is", $4f
	db "finally finished.", $51
	db "Now I can go", $4f
	db "fishing again.", $57
; 0x19edbc

UnknownText_0x19edbc: ; 0x19edbc
	db $0, "ROUTE 19", $51
	db "FUCHSIA CITY -", $4f
	db "SEAFOAM ISLANDS", $57
; 0x19ede5

UnknownText_0x19ede5: ; 0x19ede5
	db $0, "Please be careful", $4f
	db "if you are swim-", $55
	db "ming to SEAFOAM", $55
	db "ISLANDS.", $51
	db "FUCHSIA POLICE", $57
; 0x19ee31

Route19_MapEventHeader: ; 0x19ee31
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $3, $7, 3, GROUP_ROUTE_19___FUCHSIA_GATE, MAP_ROUTE_19___FUCHSIA_GATE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 13, 11, $0, MapRoute19Signpost0Script
	signpost 1, 11, $0, MapRoute19Signpost1Script

	; people-events
	db 6
	person_event $32, 27, 13, $8, $0, 255, 255, $a2, 0, TrainerSwimmerfDawn, $ffff
	person_event $31, 32, 17, $a, $0, 255, 255, $82, 3, TrainerSwimmermHarold, $ffff
	person_event $31, 21, 15, $a, $0, 255, 255, $82, 3, TrainerSwimmermJerome, $ffff
	person_event $31, 27, 12, $7, $0, 255, 255, $82, 0, TrainerSwimmermTucker, $ffff
	person_event $3a, 9, 13, $6, $0, 255, 255, $80, 1, UnknownScript_0x19ea4d, $ffff
	person_event $3a, 9, 15, $5, $1, 255, 255, $90, 1, UnknownScript_0x19ea61, $ffff
; 0x19ee94

Route25_MapScriptHeader: ; 0x19ee94
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x19ee9e, $0000
	dw UnknownScript_0x19ee9f, $0000

	; callback count
	db 0
; 0x19ee9e

UnknownScript_0x19ee9e: ; 0x19ee9e
	end
; 0x19ee9f

UnknownScript_0x19ee9f: ; 0x19ee9f
	end
; 0x19eea0

UnknownScript_0x19eea0: ; 0x19eea0
	showemote $4, $2, 15
	pause 30
	showemote $0, $3, 10
	spriteface $2, $0
	applymovement $3, MovementData_0x19efe8
	disappear $3
	pause 15
	playmusic $0038
	spriteface $2, $1
	pause 10
	applymovement $2, MovementData_0x19efed
	loadfont
	2writetext UnknownText_0x19f006
	closetext
	loadmovesprites
	spriteface $0, $0
	applymovement $2, MovementData_0x19effa
	spriteface $0, $2
	applymovement $2, MovementData_0x19f000
	disappear $2
	clearbit1 $076f
	dotrigger $0
	special $003d
	end
; 0x19eee0

UnknownScript_0x19eee0: ; 0x19eee0
	showemote $4, $2, 15
	pause 30
	showemote $0, $3, 10
	spriteface $2, $0
	applymovement $3, MovementData_0x19efea
	disappear $3
	pause 15
	playmusic $0038
	spriteface $2, $1
	pause 10
	applymovement $2, MovementData_0x19eff4
	loadfont
	2writetext UnknownText_0x19f006
	closetext
	loadmovesprites
	spriteface $0, $1
	applymovement $2, MovementData_0x19effd
	spriteface $0, $2
	applymovement $2, MovementData_0x19f000
	disappear $2
	clearbit1 $076f
	dotrigger $0
	special $003d
	end
; 0x19ef20

TrainerSchoolboyDudley: ; 0x19ef20
	; bit/flag number
	dw $472

	; trainer group && trainer id
	db SCHOOLBOY, DUDLEY

	; text when seen
	dw SchoolboyDudleySeenText

	; text when trainer beaten
	dw SchoolboyDudleyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyDudleyScript
; 0x19ef2c

SchoolboyDudleyScript: ; 0x19ef2c
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19f1b5
	closetext
	loadmovesprites
	end
; 0x19ef34

TrainerLassEllen: ; 0x19ef34
	; bit/flag number
	dw $51f

	; trainer group && trainer id
	db LASS, ELLEN

	; text when seen
	dw LassEllenSeenText

	; text when trainer beaten
	dw LassEllenBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw LassEllenScript
; 0x19ef40

LassEllenScript: ; 0x19ef40
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19f208
	closetext
	loadmovesprites
	end
; 0x19ef48

TrainerSchoolboyJoe: ; 0x19ef48
	; bit/flag number
	dw $473

	; trainer group && trainer id
	db SCHOOLBOY, JOE

	; text when seen
	dw SchoolboyJoeSeenText

	; text when trainer beaten
	dw SchoolboyJoeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyJoeScript
; 0x19ef54

SchoolboyJoeScript: ; 0x19ef54
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19f25c
	closetext
	loadmovesprites
	end
; 0x19ef5c

TrainerLassLaura: ; 0x19ef5c
	; bit/flag number
	dw $51b

	; trainer group && trainer id
	db LASS, LAURA

	; text when seen
	dw LassLauraSeenText

	; text when trainer beaten
	dw LassLauraBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw LassLauraScript
; 0x19ef68

LassLauraScript: ; 0x19ef68
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19f2a6
	closetext
	loadmovesprites
	end
; 0x19ef70

TrainerCamperLloyd: ; 0x19ef70
	; bit/flag number
	dw $41f

	; trainer group && trainer id
	db CAMPER, LLOYD

	; text when seen
	dw CamperLloydSeenText

	; text when trainer beaten
	dw CamperLloydBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperLloydScript
; 0x19ef7c

CamperLloydScript: ; 0x19ef7c
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19f2f8
	closetext
	loadmovesprites
	end
; 0x19ef84

TrainerLassShannon: ; 0x19ef84
	; bit/flag number
	dw $51c

	; trainer group && trainer id
	db LASS, SHANNON

	; text when seen
	dw LassShannonSeenText

	; text when trainer beaten
	dw LassShannonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw LassShannonScript
; 0x19ef90

LassShannonScript: ; 0x19ef90
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19f35b
	closetext
	loadmovesprites
	end
; 0x19ef98

TrainerSupernerdPat: ; 0x19ef98
	; bit/flag number
	dw $588

	; trainer group && trainer id
	db SUPER_NERD, PAT

	; text when seen
	dw SupernerdPatSeenText

	; text when trainer beaten
	dw SupernerdPatBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SupernerdPatScript
; 0x19efa4

SupernerdPatScript: ; 0x19efa4
	talkaftercancel
	loadfont
	2writetext UnknownText_0x19f41a
	closetext
	loadmovesprites
	end
; 0x19efac

UnknownScript_0x19efac: ; 0x19efac
	faceplayer
	loadfont
	checkbit1 $0558
	iftrue UnknownScript_0x19efda
	checkbit1 $00d8
	iftrue UnknownScript_0x19efc7
	2writetext UnknownText_0x19f43b
	keeptextopen
	verbosegiveitem NUGGET, 1
	iffalse UnknownScript_0x19efde
	setbit1 $00d8
UnknownScript_0x19efc7: ; 0x19efc7
	2writetext UnknownText_0x19f49d
	closetext
	loadmovesprites
	winlosstext UnknownText_0x19f4fd, $0000
	loadtrainer COOLTRAINERM, KEVIN
	startbattle
	returnafterbattle
	setbit1 $0558
	loadfont
UnknownScript_0x19efda: ; 0x19efda
	2writetext UnknownText_0x19f520
	closetext
UnknownScript_0x19efde: ; 0x19efde
	loadmovesprites
	end
; 0x19efe0

MapRoute25Signpost0Script: ; 0x19efe0
	jumptext UnknownText_0x19f567
; 0x19efe3

ItemFragment_0x19efe3: ; 0x19efe3
	db PROTEIN, 1
; 0x19efe5

MapRoute25SignpostItem1: ; 0x19efe5
	dw $00f8
	db POTION
	
; 0x19efe8

MovementData_0x19efe8: ; 0x19efe8
	big_step_down
	step_end
; 0x19efea

MovementData_0x19efea: ; 0x19efea
	big_step_down
	big_step_down
	step_end
; 0x19efed

MovementData_0x19efed: ; 0x19efed
	step_up
	step_up
	step_up
	step_left
	step_left
	step_left
	step_end
; 0x19eff4

MovementData_0x19eff4: ; 0x19eff4
	step_up
	step_up
	step_left
	step_left
	step_left
	step_end
; 0x19effa

MovementData_0x19effa: ; 0x19effa
	step_down
	step_left
	step_end
; 0x19effd

MovementData_0x19effd: ; 0x19effd
	step_up
	step_left
	step_end
; 0x19f000

MovementData_0x19f000: ; 0x19f000
	step_left
	step_left
	step_left
	step_left
	step_left
	step_end
; 0x19f006

UnknownText_0x19f006: ; 0x19f006
	db $0, "MISTY: Aww! Why", $4f
	db "did you have to", $51
	db "show up and bug us", $4f
	db "now?", $51
	db "Do you know what", $4f
	db "they call people", $55
	db "like you?", $51
	db "Pests! You heard", $4f
	db "me right, pest!", $51
	db "…", $51
	db "…Oh? Those BADGES", $4f
	db "you have… Are they", $55
	db "JOHTO GYM BADGES?", $51
	db "If you have eight,", $4f
	db "you must be good.", $51
	db "OK, then. Come to", $4f
	db "CERULEAN GYM.", $51
	db "I'll be happy to", $4f
	db "take you on.", $51
	db "I'm MISTY, the", $4f
	db "GYM LEADER in", $55
	db "CERULEAN.", $57
; 0x19f14d

SchoolboyDudleySeenText: ; 0x19f14d
	db $0, "Beat the six of us", $4f
	db "trainers to win a", $55
	db "fabulous prize!", $51
	db "Think you've got", $4f
	db "what it takes?", $57
; 0x19f1a2

SchoolboyDudleyBeatenText: ; 0x19f1a2
	db $0, "Whoo! Good stuff.", $57
; 0x19f1b5

UnknownText_0x19f1b5: ; 0x19f1b5
	db $0, "I did my best.", $4f
	db "I have no regrets.", $57
; 0x19f1d8

LassEllenSeenText: ; 0x19f1d8
	db $0, "I'm second.", $4f
	db "Now it's serious!", $57
; 0x19f1f5

LassEllenBeatenText: ; 0x19f1f5
	db $0, "How could I lose?", $57
; 0x19f208

UnknownText_0x19f208: ; 0x19f208
	db $0, "I did my best.", $4f
	db "I have no regrets.", $57
; 0x19f22b

SchoolboyJoeSeenText: ; 0x19f22b
	db $0, "Here's No. 3!", $4f
	db "I won't be easy.", $57
; 0x19f249

SchoolboyJoeBeatenText: ; 0x19f249
	db $0, "Ow! Stomped flat!", $57
; 0x19f25c

UnknownText_0x19f25c: ; 0x19f25c
	db $0, "I did my best.", $4f
	db "I have no regrets.", $57
; 0x19f27f

LassLauraSeenText: ; 0x19f27f
	db $0, "I'm No. 4!", $4f
	db "Getting tired?", $57
; 0x19f299

LassLauraBeatenText: ; 0x19f299
	db $0, "I lost too…", $57
; 0x19f2a6

UnknownText_0x19f2a6: ; 0x19f2a6
	db $0, "I did my best.", $4f
	db "I have no regrets.", $57
; 0x19f2c9

CamperLloydSeenText: ; 0x19f2c9
	db $0, "OK! I'm No. 5.", $4f
	db "I'll stomp you!", $57
; 0x19f2e7

CamperLloydBeatenText: ; 0x19f2e7
	db $0, "Whoa! Too much.", $57
; 0x19f2f8

UnknownText_0x19f2f8: ; 0x19f2f8
	db $0, "I did my best.", $4f
	db "I have no regrets.", $57
; 0x19f31b

LassShannonSeenText: ; 0x19f31b
	db $0, "I'm the last in", $4f
	db "line, but I tell", $55
	db "you, I'm tough!", $57
; 0x19f34b

LassShannonBeatenText: ; 0x19f34b
	db $0, "You're kidding.", $57
; 0x19f35b

UnknownText_0x19f35b: ; 0x19f35b
	db $0, "I did my best.", $4f
	db "I have no regrets.", $57
; 0x19f37e

SupernerdPatSeenText: ; 0x19f37e
	db $0, "Mufufufu…", $51
	db "I have nothing to", $4f
	db "do with the six-", $55
	db "pack trainers.", $51
	db "I waited here to", $4f
	db "beat you when you", $51
	db "were tired out by", $4f
	db "all the battles.", $57
; 0x19f401

SupernerdPatBeatenText: ; 0x19f401
	db $0, "Aren't you tired", $4f
	db "at all?", $57
; 0x19f41a

UnknownText_0x19f41a: ; 0x19f41a
	db $0, "I'm sorry… I won't", $4f
	db "cheat anymore…", $57
; 0x19f43b

UnknownText_0x19f43b: ; 0x19f43b
	db $0, "You took on one", $4f
	db "more battle than", $51
	db "you expected, but", $4f
	db "you won anyway.", $51
	db "As promised, you", $4f
	db "win a prize.", $57
; 0x19f49d

UnknownText_0x19f49d: ; 0x19f49d
	db $0, "But after seeing", $4f
	db "how you battle, I", $51
	db "want to see how", $4f
	db "I'll fare.", $51
	db "How about it? Let", $4f
	db "me take you on.", $57
; 0x19f4fd

UnknownText_0x19f4fd: ; 0x19f4fd
	db $0, "I've never had a", $4f
	db "battle this good!", $57
; 0x19f520

UnknownText_0x19f520: ; 0x19f520
	db $0, "That was a great", $4f
	db "battle!", $51
	db "You and your #-", $4f
	db "MON are truly out-", $55
	db "standing!", $57
; 0x19f567

UnknownText_0x19f567: ; 0x19f567
	db $0, "SEA COTTAGE", $4f
	db "BILL'S HOUSE", $57
; 0x19f581

UnknownText_0x19f581: ; 0x19f581
	db $0, "BILL'S HOUSE", $57
; 0x19f58f

Route25_MapEventHeader: ; 0x19f58f
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $5, $2f, 1, GROUP_BILLS_HOUSE, MAP_BILLS_HOUSE

	; xy triggers
	db 2
	xy_trigger 1, $6, $2a, $0, UnknownScript_0x19eea0, $0, $0
	xy_trigger 1, $7, $2a, $0, UnknownScript_0x19eee0, $0, $0

	; signposts
	db 2
	signpost 5, 45, $0, MapRoute25Signpost0Script
	signpost 5, 4, $7, MapRoute25SignpostItem1

	; people-events
	db 11
	person_event $1d, 13, 50, $8, $0, 255, 255, $80, 0, ObjectEvent, $076e
	person_event $23, 14, 50, $8, $0, 255, 255, $a0, 0, ObjectEvent, $076e
	person_event $27, 12, 16, $6, $0, 255, 255, $92, 3, TrainerSchoolboyDudley, $ffff
	person_event $28, 15, 20, $7, $0, 255, 255, $92, 3, TrainerLassEllen, $ffff
	person_event $27, 12, 25, $6, $0, 255, 255, $92, 1, TrainerSchoolboyJoe, $ffff
	person_event $28, 10, 26, $9, $0, 255, 255, $92, 3, TrainerLassLaura, $ffff
	person_event $27, 8, 29, $6, $0, 255, 255, $a2, 2, TrainerCamperLloyd, $ffff
	person_event $28, 15, 32, $7, $0, 255, 255, $92, 1, TrainerLassShannon, $ffff
	person_event $2b, 11, 35, $6, $0, 255, 255, $b2, 1, TrainerSupernerdPat, $ffff
	person_event $23, 12, 41, $8, $0, 255, 255, $80, 0, UnknownScript_0x19efac, $ffff
	person_event $54, 8, 36, $1, $0, 255, 255, $1, 0, ItemFragment_0x19efe3, $078b
; 0x19f643

SECTION "bank68",DATA,BANK[$68]

CianwoodCity_MapScriptHeader: ; 0x1a0000
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1a000d, $0000
	dw UnknownScript_0x1a000e, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1a000f
; 0x1a000d

UnknownScript_0x1a000d: ; 0x1a000d
	end
; 0x1a000e

UnknownScript_0x1a000e: ; 0x1a000e
	end
; 0x1a000f

UnknownScript_0x1a000f: ; 0x1a000f
	setbit2 $0045
	setbit1 $07aa
	checkbit1 $0333
	iffalse UnknownScript_0x1a001d
	disappear $c
UnknownScript_0x1a001d: ; 0x1a001d
	return
; 0x1a001e

UnknownScript_0x1a001e: ; 0x1a001e
	spriteface $0, $1
	showemote $0, $0, 15
	pause 15
	playsound $0014
	applymovement $d, MovementData_0x1a00da
	spriteface $0, $0
	pause 15
	playsound $0014
	applymovement $d, MovementData_0x1a00e0
	disappear $d
	pause 10
	dotrigger $0
	clearbit1 $07af
	domaptrigger GROUP_ROUTE_42, MAP_ROUTE_42, $1
	checkbit1 $0333
	iftrue UnknownScript_0x1a0083
	setbit1 $0333
	playmusic $0061
	appear $c
	applymovement $c, MovementData_0x1a00e7
	loadfont
	2writetext UnknownText_0x1a0433
	closetext
	loadmovesprites
	winlosstext UnknownText_0x1a05a1, $0000
	setlasttalked $c
	loadtrainer MYSTICALMAN, EUSINE
	startbattle
	reloadmapmusic
	returnafterbattle
	playmusic $0061
	loadfont
	2writetext UnknownText_0x1a05c3
	closetext
	loadmovesprites
	applymovement $c, MovementData_0x1a00ec
	disappear $c
	pause 20
	special $006a
	playmapmusic
	pause 10
UnknownScript_0x1a0083: ; 0x1a0083
	end
; 0x1a0084

UnknownScript_0x1a0084: ; 0x1a0084
	faceplayer
	loadfont
	checkbit1 $0011
	iftrue UnknownScript_0x1a00ad
	2writetext UnknownText_0x1a00f1
	keeptextopen
	checkbit1 $04c2
	iftrue UnknownScript_0x1a009c
	2writetext UnknownText_0x1a0163
	closetext
	loadmovesprites
	end
; 0x1a009c

UnknownScript_0x1a009c: ; 0x1a009c
	2writetext UnknownText_0x1a01e3
	keeptextopen
	verbosegiveitem HM_02, 1
	iffalse UnknownScript_0x1a00b1
	setbit1 $0011
	2writetext UnknownText_0x1a021d
	keeptextopen
UnknownScript_0x1a00ad: ; 0x1a00ad
	2writetext UnknownText_0x1a0277
	closetext
UnknownScript_0x1a00b1: ; 0x1a00b1
	loadmovesprites
	end
; 0x1a00b3

UnknownScript_0x1a00b3: ; 0x1a00b3
	jumptextfaceplayer UnknownText_0x1a02df
; 0x1a00b6

UnknownScript_0x1a00b6: ; 0x1a00b6
	jumptextfaceplayer UnknownText_0x1a0319
; 0x1a00b9

UnknownScript_0x1a00b9: ; 0x1a00b9
	jumptextfaceplayer UnknownText_0x1a0394
; 0x1a00bc

UnknownScript_0x1a00bc: ; 0x1a00bc
	jumptextfaceplayer UnknownText_0x1a03cc
; 0x1a00bf

MapCianwoodCitySignpost0Script: ; 0x1a00bf
	jumptext UnknownText_0x1a0660
; 0x1a00c2

MapCianwoodCitySignpost1Script: ; 0x1a00c2
	jumptext UnknownText_0x1a068f
; 0x1a00c5

MapCianwoodCitySignpost3Script: ; 0x1a00c5
	jumptext UnknownText_0x1a06d6
; 0x1a00c8

MapCianwoodCitySignpost4Script: ; 0x1a00c8
	jumptext UnknownText_0x1a0725
; 0x1a00cb

MapCianwoodCitySignpost5Script: ; 0x1a00cb
	jumptext UnknownText_0x1a0760
; 0x1a00ce

MapCianwoodCitySignpost2Script: ; 0x1a00ce
	jumpstd $0010
; 0x1a00d1

UnknownScript_0x1a00d1: ; 0x1a00d1
	jumpstd $000f
; 0x1a00d4

MapCianwoodCitySignpostItem6: ; 0x1a00d4
	dw $00b2
	db REVIVE
	
; 0x1a00d7

MapCianwoodCitySignpostItem7: ; 0x1a00d7
	dw $00b3
	db MAX_ETHER
	
; 0x1a00da

MovementData_0x1a00da: ; 0x1a00da
	db $39 ; movement
	fast_jump_step_down
	fast_jump_step_down
	fast_jump_step_right
	db $38 ; movement
	step_end
; 0x1a00e0

MovementData_0x1a00e0: ; 0x1a00e0
	db $39 ; movement
	fast_jump_step_right
	fast_jump_step_up
	fast_jump_step_right
	fast_jump_step_right
	db $38 ; movement
	step_end
; 0x1a00e7

MovementData_0x1a00e7: ; 0x1a00e7
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x1a00ec

MovementData_0x1a00ec: ; 0x1a00ec
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x1a00f1

UnknownText_0x1a00f1: ; 0x1a00f1
	db $0, "You crossed the", $4f
	db "sea to get here?", $51
	db "That must have", $4f
	db "been hard.", $51
	db "It would be much", $4f
	db "easier if your", $51
	db "#MON knew how", $4f
	db "to FLY…", $57
; 0x1a0163

UnknownText_0x1a0163: ; 0x1a0163
	db $0, "But you can't use", $4f
	db "FLY without this", $55
	db "city's GYM BADGE.", $51
	db "If you beat the", $4f
	db "GYM LEADER here,", $55
	db "come see me.", $51
	db "I'll have a nice", $4f
	db "gift for you.", $57
; 0x1a01e3

UnknownText_0x1a01e3: ; 0x1a01e3
	db $0, "That's CIANWOOD's", $4f
	db "GYM BADGE!", $51
	db "Then you should", $4f
	db "take this HM.", $57
; 0x1a021d

UnknownText_0x1a021d: ; 0x1a021d
	db $0, "Teach FLY to your", $4f
	db "#MON.", $51
	db "You will be able", $4f
	db "to FLY instantly", $51
	db "to anywhere you ", $4f
	db "have visited.", $57
; 0x1a0277

UnknownText_0x1a0277: ; 0x1a0277
	db $0, "My husband lost to", $4f
	db "you, so he needs", $55
	db "to train harder.", $51
	db "That's good, since", $4f
	db "he was getting a", $55
	db "little chubby.", $57
; 0x1a02df

UnknownText_0x1a02df: ; 0x1a02df
	db $0, "If you use FLY,", $4f
	db "you can get back", $51
	db "to OLIVINE in-", $4f
	db "stantly.", $57
; 0x1a0319

UnknownText_0x1a0319: ; 0x1a0319
	db $0, "Boulders to the", $4f
	db "north of town can", $55
	db "be crushed.", $51
	db "They may be hiding", $4f
	db "something.", $51
	db "Your #MON could", $4f
	db "use ROCK SMASH to", $55
	db "break them.", $57
; 0x1a0394

UnknownText_0x1a0394: ; 0x1a0394
	db $0, "CHUCK, the GYM", $4f
	db "LEADER, spars with", $51
	db "his fighting #-", $4f
	db "MON.", $57
; 0x1a03cc

; possibly unused
UnknownText_0x1a03cc: ; 0x1a03cc
	db $0, "There are several", $4f
	db "islands between", $55
	db "here and OLIVINE.", $51
	db "A mythical sea", $4f
	db "creature supposed-", $55
	db "ly lives there.", $57
; 0x1a0433

UnknownText_0x1a0433: ; 0x1a0433
	db $0, "EUSINE: Yo,", $4f
	db $52, ".", $51
	db "Wasn't that", $4f
	db "SUICUNE just now?", $51
	db "I only caught a", $4f
	db "quick glimpse, but", $51
	db "I thought I saw", $4f
	db "SUICUNE running on", $55
	db "the waves.", $51
	db "SUICUNE is beau-", $4f
	db "tiful and grand.", $51
	db "And it races", $4f
	db "through towns and", $51
	db "roads at simply", $4f
	db "awesome speeds.", $51
	db "It's wonderful…", $51
	db "I want to see", $4f
	db "SUICUNE up close…", $51
	db "I've decided.", $51
	db "I'll battle you as", $4f
	db "a trainer to earn", $55
	db "SUICUNE's respect!", $51
	db "Come on, ", $52, ".", $4f
	db "Let's battle now!", $57
; 0x1a05a1

UnknownText_0x1a05a1: ; 0x1a05a1
	db $0, "I hate to admit", $4f
	db "it, but you win.", $57
; 0x1a05c3

UnknownText_0x1a05c3: ; 0x1a05c3
	db $0, "You're amazing,", $4f
	db $52, "!", $51
	db "No wonder #MON", $4f
	db "gravitate to you.", $51
	db "I get it now.", $51
	db "I'm going to keep", $4f
	db "searching for", $55
	db "SUICUNE.", $51
	db "I'm sure we'll see", $4f
	db "each other again.", $51
	db "See you around!", $57
; 0x1a0660

UnknownText_0x1a0660: ; 0x1a0660
	db $0, "CIANWOOD CITY", $51
	db "A Port Surrounded", $4f
	db "by Rough Seas", $57
; 0x1a068f

UnknownText_0x1a068f: ; 0x1a068f
	db $0, "CIANWOOD CITY", $4f
	db "#MON GYM", $51
	db "LEADER: CHUCK", $51
	db "His Roaring Fists", $4f
	db "Do the Talking", $57
; 0x1a06d6

UnknownText_0x1a06d6: ; 0x1a06d6
	db $0, "500 Years of", $4f
	db "Tradition", $51
	db "CIANWOOD CITY", $4f
	db "PHARMACY", $51
	db "We Await Your", $4f
	db "Medicinal Queries", $57
; 0x1a0725

UnknownText_0x1a0725: ; 0x1a0725
	db $0, "CIANWOOD CITY", $4f
	db "PHOTO STUDIO", $51
	db "Take a Snapshot as", $4f
	db "a Keepsake!", $57
; 0x1a0760

UnknownText_0x1a0760: ; 0x1a0760
	db $0, "THE # SEER", $4f
	db "AHEAD", $57
; 0x1a0772

CianwoodCity_MapEventHeader: ; 0x1a0772
	; filler
	db 0, 0

	; warps
	db 7
	warp_def $29, $11, 1, GROUP_MANIAS_HOUSE, MAP_MANIAS_HOUSE
	warp_def $2b, $8, 1, GROUP_CIANWOOD_GYM, MAP_CIANWOOD_GYM
	warp_def $2b, $17, 1, GROUP_CIANWOOD_POKECENTER_1F, MAP_CIANWOOD_POKECENTER_1F
	warp_def $2f, $f, 1, GROUP_CIANWOOD_PHARMACY, MAP_CIANWOOD_PHARMACY
	warp_def $1f, $9, 1, GROUP_CIANWOOD_CITY_PHOTO_STUDIO, MAP_CIANWOOD_CITY_PHOTO_STUDIO
	warp_def $25, $f, 1, GROUP_CIANWOOD_LUGIA_SPEECH_HOUSE, MAP_CIANWOOD_LUGIA_SPEECH_HOUSE
	warp_def $11, $5, 1, GROUP_POKE_SEERS_HOUSE, MAP_POKE_SEERS_HOUSE

	; xy triggers
	db 1
	xy_trigger 1, $10, $b, $0, UnknownScript_0x1a001e, $0, $0

	; signposts
	db 8
	signpost 34, 20, $0, MapCianwoodCitySignpost0Script
	signpost 45, 7, $0, MapCianwoodCitySignpost1Script
	signpost 43, 24, $0, MapCianwoodCitySignpost2Script
	signpost 47, 19, $0, MapCianwoodCitySignpost3Script
	signpost 32, 8, $0, MapCianwoodCitySignpost4Script
	signpost 24, 8, $0, MapCianwoodCitySignpost5Script
	signpost 19, 4, $7, MapCianwoodCitySignpostItem6
	signpost 29, 5, $7, MapCianwoodCitySignpostItem7

	; people-events
	db 12
	person_event $66, 41, 25, $3, $0, 255, 255, $a0, 0, UnknownScript_0x1a00b3, $ffff
	person_event $2d, 37, 21, $5, $1, 255, 255, $0, 0, UnknownScript_0x1a00b6, $ffff
	person_event $28, 46, 18, $4, $20, 255, 255, $0, 0, UnknownScript_0x1a00b9, $ffff
	person_event $59, 20, 12, $18, $0, 255, 255, $0, 0, UnknownScript_0x1a00d1, $ffff
	person_event $59, 21, 13, $18, $0, 255, 255, $0, 0, UnknownScript_0x1a00d1, $ffff
	person_event $59, 29, 8, $18, $0, 255, 255, $0, 0, UnknownScript_0x1a00d1, $ffff
	person_event $59, 33, 9, $18, $0, 255, 255, $0, 0, UnknownScript_0x1a00d1, $ffff
	person_event $59, 31, 14, $18, $0, 255, 255, $0, 0, UnknownScript_0x1a00d1, $ffff
	person_event $59, 23, 8, $18, $0, 255, 255, $0, 0, UnknownScript_0x1a00d1, $ffff
	person_event $2e, 50, 14, $5, $1, 255, 255, $0, 0, UnknownScript_0x1a0084, $ffff
	person_event $2b, 25, 15, $7, $0, 255, 255, $90, 0, ObjectEvent, $07ad
	person_event $63, 18, 14, $1, $0, 255, 255, $90, 0, ObjectEvent, $07ae
; 0x1a0867

Route27_MapScriptHeader: ; 0x1a0867
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1a0871, $0000
	dw UnknownScript_0x1a0872, $0000

	; callback count
	db 0
; 0x1a0871

UnknownScript_0x1a0871: ; 0x1a0871
	end
; 0x1a0872

UnknownScript_0x1a0872: ; 0x1a0872
	end
; 0x1a0873

UnknownScript_0x1a0873: ; 0x1a0873
	spriteface $a, $2
	showemote $0, $a, 15
	applymovement $a, MovementData_0x1a0a66
	2jump UnknownScript_0x1a088c
; 0x1a0881

UnknownScript_0x1a0881: ; 0x1a0881
	spriteface $a, $2
	showemote $0, $a, 15
	applymovement $a, MovementData_0x1a0a69
UnknownScript_0x1a088c: ; 0x1a088c
	spriteface $0, $3
	loadfont
	2writetext UnknownText_0x1a0a6b
	keeptextopen
	2writetext UnknownText_0x1a0a71
	closetext
	loadmovesprites
	dotrigger $1
	end
; 0x1a089c

UnknownScript_0x1a089c: ; 0x1a089c
	jumptextfaceplayer UnknownText_0x1a0a71
; 0x1a089f

TrainerPsychicGilbert: ; 0x1a089f
	; bit/flag number
	dw $443

	; trainer group && trainer id
	db PSYCHIC_T, GILBERT

	; text when seen
	dw PsychicGilbertSeenText

	; text when trainer beaten
	dw PsychicGilbertBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicGilbertScript
; 0x1a08ab

PsychicGilbertScript: ; 0x1a08ab
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a0dd2
	closetext
	loadmovesprites
	end
; 0x1a08b3

TrainerBird_keeperJose2: ; 0x1a08b3
	; bit/flag number
	dw $408

	; trainer group && trainer id
	db BIRD_KEEPER, JOSE2

	; text when seen
	dw Bird_keeperJose2SeenText

	; text when trainer beaten
	dw Bird_keeperJose2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperJose2Script
; 0x1a08bf

Bird_keeperJose2Script: ; 0x1a08bf
	writecode $17, $d
	talkaftercancel
	loadfont
	checkbit2 $0069
	iftrue UnknownScript_0x1a08ff
	checkbit2 $007e
	iftrue UnknownScript_0x1a0945
	checkcellnum $d
	iftrue UnknownScript_0x1a0963
	checkbit1 $026f
	iftrue UnknownScript_0x1a08e8
	2writetext UnknownText_0x1a0e42
	keeptextopen
	setbit1 $026f
	2call UnknownScript_0x1a0957
	2jump UnknownScript_0x1a08eb
; 0x1a08e8

UnknownScript_0x1a08e8: ; 0x1a08e8
	2call UnknownScript_0x1a095b
UnknownScript_0x1a08eb: ; 0x1a08eb
	askforphonenumber $d
	if_equal $1, UnknownScript_0x1a096b
	if_equal $2, UnknownScript_0x1a0967
	trainertotext BIRD_KEEPER, JOSE2, $0
	2call UnknownScript_0x1a095f
	2jump UnknownScript_0x1a0963
; 0x1a08ff

UnknownScript_0x1a08ff: ; 0x1a08ff
	2call UnknownScript_0x1a096f
	winlosstext Bird_keeperJose2BeatenText, $0000
	copybytetovar $d9f7
	if_equal $2, UnknownScript_0x1a0916
	if_equal $1, UnknownScript_0x1a091c
	if_equal $0, UnknownScript_0x1a0922
UnknownScript_0x1a0916: ; 0x1a0916
	checkbit1 $00cd
	iftrue UnknownScript_0x1a093c
UnknownScript_0x1a091c: ; 0x1a091c
	checkbit1 $0044
	iftrue UnknownScript_0x1a092f
UnknownScript_0x1a0922: ; 0x1a0922
	loadtrainer BIRD_KEEPER, JOSE2
	startbattle
	returnafterbattle
	loadvar $d9f7, $1
	clearbit2 $0069
	end
; 0x1a092f

UnknownScript_0x1a092f: ; 0x1a092f
	loadtrainer BIRD_KEEPER, JOSE1
	startbattle
	returnafterbattle
	loadvar $d9f7, $2
	clearbit2 $0069
	end
; 0x1a093c

UnknownScript_0x1a093c: ; 0x1a093c
	loadtrainer BIRD_KEEPER, JOSE3
	startbattle
	returnafterbattle
	clearbit2 $0069
	end
; 0x1a0945

UnknownScript_0x1a0945: ; 0x1a0945
	2call UnknownScript_0x1a0973
	verbosegiveitem STAR_PIECE, 1
	iffalse UnknownScript_0x1a0954
	clearbit2 $007e
	2jump UnknownScript_0x1a0963
; 0x1a0954

UnknownScript_0x1a0954: ; 0x1a0954
	2jump UnknownScript_0x1a0977
; 0x1a0957

UnknownScript_0x1a0957: ; 0x1a0957
	jumpstd $0019
	end
; 0x1a095b

UnknownScript_0x1a095b: ; 0x1a095b
	jumpstd $001a
	end
; 0x1a095f

UnknownScript_0x1a095f: ; 0x1a095f
	jumpstd $001b
	end
; 0x1a0963

UnknownScript_0x1a0963: ; 0x1a0963
	jumpstd $001c
	end
; 0x1a0967

UnknownScript_0x1a0967: ; 0x1a0967
	jumpstd $001d
	end
; 0x1a096b

UnknownScript_0x1a096b: ; 0x1a096b
	jumpstd $001e
	end
; 0x1a096f

UnknownScript_0x1a096f: ; 0x1a096f
	jumpstd $001f
	end
; 0x1a0973

UnknownScript_0x1a0973: ; 0x1a0973
	jumpstd $0020
	end
; 0x1a0977

UnknownScript_0x1a0977: ; 0x1a0977
	jumpstd $0021
	end
; 0x1a097b

TrainerCooltrainermBlake: ; 0x1a097b
	; bit/flag number
	dw $552

	; trainer group && trainer id
	db COOLTRAINERM, BLAKE

	; text when seen
	dw CooltrainermBlakeSeenText

	; text when trainer beaten
	dw CooltrainermBlakeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermBlakeScript
; 0x1a0987

CooltrainermBlakeScript: ; 0x1a0987
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a0b0b
	closetext
	loadmovesprites
	end
; 0x1a098f

TrainerCooltrainermBrian: ; 0x1a098f
	; bit/flag number
	dw $553

	; trainer group && trainer id
	db COOLTRAINERM, BRIAN

	; text when seen
	dw CooltrainermBrianSeenText

	; text when trainer beaten
	dw CooltrainermBrianBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermBrianScript
; 0x1a099b

CooltrainermBrianScript: ; 0x1a099b
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a0bac
	closetext
	loadmovesprites
	end
; 0x1a09a3

TrainerCooltrainerfReena1: ; 0x1a09a3
	; bit/flag number
	dw $564

	; trainer group && trainer id
	db COOLTRAINERF, REENA1

	; text when seen
	dw CooltrainerfReena1SeenText

	; text when trainer beaten
	dw CooltrainerfReena1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfReena1Script
; 0x1a09af

CooltrainerfReena1Script: ; 0x1a09af
	writecode $17, $e
	talkaftercancel
	loadfont
	checkbit2 $006a
	iftrue UnknownScript_0x1a09e9
	checkcellnum $e
	iftrue UnknownScript_0x1a0a3b
	checkbit1 $0271
	iftrue UnknownScript_0x1a09d2
	2writetext UnknownText_0x1a0c35
	keeptextopen
	setbit1 $0271
	2call UnknownScript_0x1a0a2f
	2jump UnknownScript_0x1a09d5
; 0x1a09d2

UnknownScript_0x1a09d2: ; 0x1a09d2
	2call UnknownScript_0x1a0a33
UnknownScript_0x1a09d5: ; 0x1a09d5
	askforphonenumber $e
	if_equal $1, UnknownScript_0x1a0a43
	if_equal $2, UnknownScript_0x1a0a3f
	trainertotext COOLTRAINERF, REENA1, $0
	2call UnknownScript_0x1a0a37
	2jump UnknownScript_0x1a0a3b
; 0x1a09e9

UnknownScript_0x1a09e9: ; 0x1a09e9
	2call UnknownScript_0x1a0a47
	winlosstext CooltrainerfReena1BeatenText, $0000
	copybytetovar $d9f8
	if_equal $2, UnknownScript_0x1a0a00
	if_equal $1, UnknownScript_0x1a0a06
	if_equal $0, UnknownScript_0x1a0a0c
UnknownScript_0x1a0a00: ; 0x1a0a00
	checkbit1 $00cd
	iftrue UnknownScript_0x1a0a26
UnknownScript_0x1a0a06: ; 0x1a0a06
	checkbit1 $0044
	iftrue UnknownScript_0x1a0a19
UnknownScript_0x1a0a0c: ; 0x1a0a0c
	loadtrainer COOLTRAINERF, REENA1
	startbattle
	returnafterbattle
	loadvar $d9f8, $1
	clearbit2 $006a
	end
; 0x1a0a19

UnknownScript_0x1a0a19: ; 0x1a0a19
	loadtrainer COOLTRAINERF, REENA2
	startbattle
	returnafterbattle
	loadvar $d9f8, $2
	clearbit2 $006a
	end
; 0x1a0a26

UnknownScript_0x1a0a26: ; 0x1a0a26
	loadtrainer COOLTRAINERF, REENA3
	startbattle
	returnafterbattle
	clearbit2 $006a
	end
; 0x1a0a2f

UnknownScript_0x1a0a2f: ; 0x1a0a2f
	jumpstd $0023
	end
; 0x1a0a33

UnknownScript_0x1a0a33: ; 0x1a0a33
	jumpstd $0024
	end
; 0x1a0a37

UnknownScript_0x1a0a37: ; 0x1a0a37
	jumpstd $0025
	end
; 0x1a0a3b

UnknownScript_0x1a0a3b: ; 0x1a0a3b
	jumpstd $0026
	end
; 0x1a0a3f

UnknownScript_0x1a0a3f: ; 0x1a0a3f
	jumpstd $0027
	end
; 0x1a0a43

UnknownScript_0x1a0a43: ; 0x1a0a43
	jumpstd $0028
	end
; 0x1a0a47

UnknownScript_0x1a0a47: ; 0x1a0a47
	jumpstd $0029
	end
; 0x1a0a4b

TrainerCooltrainerfMegan: ; 0x1a0a4b
	; bit/flag number
	dw $565

	; trainer group && trainer id
	db COOLTRAINERF, MEGAN

	; text when seen
	dw CooltrainerfMeganSeenText

	; text when trainer beaten
	dw CooltrainerfMeganBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfMeganScript
; 0x1a0a57

CooltrainerfMeganScript: ; 0x1a0a57
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a0cce
	closetext
	loadmovesprites
	end
; 0x1a0a5f

MapRoute27Signpost0Script: ; 0x1a0a5f
	jumptext UnknownText_0x1a0e7f
; 0x1a0a62

ItemFragment_0x1a0a62: ; 0x1a0a62
	db TM_22, 1
; 0x1a0a64

ItemFragment_0x1a0a64: ; 0x1a0a64
	db RARE_CANDY, 1
; 0x1a0a66

MovementData_0x1a0a66: ; 0x1a0a66
	step_left
	step_left
	step_end
; 0x1a0a69

MovementData_0x1a0a69: ; 0x1a0a69
	step_left
	step_end
; 0x1a0a6b

UnknownText_0x1a0a6b: ; 0x1a0a6b
	db $0, "Hey!", $57
; 0x1a0a71

UnknownText_0x1a0a71: ; 0x1a0a71
	db $0, "Do you know what", $4f
	db "you just did?", $51
	db "You've taken your", $4f
	db "first step into", $55
	db "KANTO.", $51
	db "Check your #-", $4f
	db "GEAR MAP and see.", $57
; 0x1a0ad9

CooltrainermBlakeSeenText: ; 0x1a0ad9
	db $0, "You look pretty", $4f
	db "strong.", $55
	db "Let me battle you!", $57
; 0x1a0b05

CooltrainermBlakeBeatenText: ; 0x1a0b05
	db $0, "Yow!", $57
; 0x1a0b0b

UnknownText_0x1a0b0b: ; 0x1a0b0b
	db $0, "If you prevail on", $4f
	db "this harsh trek,", $51
	db "the truth will be", $4f
	db "revealed!", $51
	db "Heh, sorry, I just", $4f
	db "wanted to say", $55
	db "something cool.", $57
; 0x1a0b7c

CooltrainermBrianSeenText: ; 0x1a0b7c
	db $0, "Hm? You're good,", $4f
	db "aren't you?", $57
; 0x1a0b98

CooltrainermBrianBeatenText: ; 0x1a0b98
	db $0, "Just as I thought!", $57
; 0x1a0bac

UnknownText_0x1a0bac: ; 0x1a0bac
	db $0, "A good trainer can", $4f
	db "recognize other", $55
	db "good trainers.", $57
; 0x1a0bdf

CooltrainerfReena1SeenText: ; 0x1a0bdf
	db $0, "You shouldn't", $4f
	db "underestimate the", $51
	db "wild #MON in", $4f
	db "these parts.", $57
; 0x1a0c19

CooltrainerfReena1BeatenText: ; 0x1a0c19
	db $0, "Oh! You're much", $4f
	db "too strong!", $57
; 0x1a0c35

UnknownText_0x1a0c35: ; 0x1a0c35
	db $0, "You're just a kid,", $4f
	db "but you're not to", $51
	db "be underestimated", $4f
	db "either.", $57
; 0x1a0c73

CooltrainerfMeganSeenText: ; 0x1a0c73
	db $0, "It's rare to see", $4f
	db "anyone come here.", $51
	db "Are you training", $4f
	db "on your own?", $57
; 0x1a0cb4

CooltrainerfMeganBeatenText: ; 0x1a0cb4
	db $0, "Oh! You're really", $4f
	db "strong!", $57
; 0x1a0cce

UnknownText_0x1a0cce: ; 0x1a0cce
	db $0, "I'm checking out", $4f
	db "pre- and post-", $55
	db "evolution #MON.", $51
	db "Evolution really", $4f
	db "does make #MON", $55
	db "stronger.", $51
	db "But evolved forms", $4f
	db "also learn moves", $55
	db "later on.", $57
; 0x1a0d55

PsychicGilbertSeenText: ; 0x1a0d55
	db $0, "Don't say a thing!", $51
	db "Let me guess what", $4f
	db "you're thinking.", $51
	db "Mmmmmmm…", $51
	db "I got it! You're", $4f
	db "on the #MON", $55
	db "LEAGUE challenge!", $57
; 0x1a0dc1

PsychicGilbertBeatenText: ; 0x1a0dc1
	db $0, "You're too much!", $57
; 0x1a0dd2

UnknownText_0x1a0dd2: ; 0x1a0dd2
	db $0, "With your skills,", $4f
	db "you'll do well at", $55
	db "the LEAGUE.", $51
	db "That's what my", $4f
	db "premonition says.", $57
; 0x1a0e22

Bird_keeperJose2SeenText: ; 0x1a0e22
	db $0, "Tweet! Tweet!", $4f
	db "Tetweet!", $57
; 0x1a0e3a

Bird_keeperJose2BeatenText: ; 0x1a0e3a
	db $0, "Tweet!", $57
; 0x1a0e42

UnknownText_0x1a0e42: ; 0x1a0e42
	db $0, "BIRD KEEPERS like", $4f
	db "me mimic bird", $51
	db "whistles to com-", $4f
	db "mand #MON.", $57
; 0x1a0e7f

UnknownText_0x1a0e7f: ; 0x1a0e7f
	db $0, "TOHJO FALLS", $51
	db "THE LINK BETWEEN", $4f
	db "KANTO AND JOHTO", $57
; 0x1a0ead

Route27_MapEventHeader: ; 0x1a0ead
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $21, 1, GROUP_ROUTE_27_SANDSTORM_HOUSE, MAP_ROUTE_27_SANDSTORM_HOUSE
	warp_def $5, $1a, 1, GROUP_TOHJO_FALLS, MAP_TOHJO_FALLS
	warp_def $5, $24, 2, GROUP_TOHJO_FALLS, MAP_TOHJO_FALLS

	; xy triggers
	db 2
	xy_trigger 0, $a, $12, $0, UnknownScript_0x1a0873, $0, $0
	xy_trigger 0, $a, $13, $0, UnknownScript_0x1a0881, $0, $0

	; signposts
	db 1
	signpost 7, 25, $0, MapRoute27Signpost0Script

	; people-events
	db 9
	person_event $23, 11, 52, $7, $0, 255, 255, $82, 3, TrainerCooltrainermBlake, $ffff
	person_event $23, 10, 62, $9, $0, 255, 255, $82, 4, TrainerCooltrainermBrian, $ffff
	person_event $24, 14, 76, $7, $0, 255, 255, $82, 4, TrainerCooltrainerfReena1, $ffff
	person_event $24, 10, 41, $1f, $0, 255, 255, $82, 2, TrainerCooltrainerfMegan, $ffff
	person_event $27, 11, 69, $8, $0, 255, 255, $92, 3, TrainerPsychicGilbert, $ffff
	person_event $27, 17, 62, $9, $0, 255, 255, $92, 3, TrainerBird_keeperJose2, $ffff
	person_event $54, 16, 64, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a0a62, $06ab
	person_event $54, 16, 57, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a0a64, $06ac
	person_event $3a, 14, 25, $3, $0, 255, 255, $0, 3, UnknownScript_0x1a089c, $ffff
; 0x1a0f4c

Route29_MapScriptHeader: ; 0x1a0f4c
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1a0f59, $0000
	dw UnknownScript_0x1a0f5a, $0000

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x1a0f5b
; 0x1a0f59

UnknownScript_0x1a0f59: ; 0x1a0f59
	end
; 0x1a0f5a

UnknownScript_0x1a0f5a: ; 0x1a0f5a
	end
; 0x1a0f5b

UnknownScript_0x1a0f5b: ; 0x1a0f5b
	checkbit2 $001b
	iftrue UnknownScript_0x1a0f64
UnknownScript_0x1a0f61: ; 0x1a0f61
	disappear $8
	return
; 0x1a0f64

UnknownScript_0x1a0f64: ; 0x1a0f64
	checkcode $b
	if_not_equal TUESDAY, UnknownScript_0x1a0f61
	appear $8
	return
; 0x1a0f6d

UnknownScript_0x1a0f6d: ; 0x1a0f6d
	spriteface $2, $1
	showemote $0, $2, 15
	applymovement $2, MovementData_0x1a108d
	spriteface $0, $2
	setbit1 $0041
	loadfont
	2writetext UnknownText_0x1a10df
	yesorno
	iffalse UnknownScript_0x1a0fd9
	loadmovesprites
	follow $2, $0
	applymovement $2, MovementData_0x1a109a
	stopfollow
	loadpokedata RATTATA, 5
	catchtutorial $3
	spriteface $2, $1
	loadfont
	2writetext UnknownText_0x1a114d
	closetext
	loadmovesprites
	dotrigger $0
	setbit1 $0042
	end
; 0x1a0fa3

UnknownScript_0x1a0fa3: ; 0x1a0fa3
	spriteface $2, $1
	showemote $0, $2, 15
	applymovement $2, MovementData_0x1a1094
	spriteface $0, $2
	setbit1 $0041
	loadfont
	2writetext UnknownText_0x1a10df
	yesorno
	iffalse UnknownScript_0x1a0fe5
	loadmovesprites
	follow $2, $0
	applymovement $2, MovementData_0x1a10a1
	stopfollow
	loadpokedata RATTATA, 5
	catchtutorial $3
	spriteface $2, $1
	loadfont
	2writetext UnknownText_0x1a114d
	closetext
	loadmovesprites
	dotrigger $0
	setbit1 $0042
	end
; 0x1a0fd9

UnknownScript_0x1a0fd9: ; 0x1a0fd9
	2writetext UnknownText_0x1a1197
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x1a109a
	dotrigger $0
	end
; 0x1a0fe5

UnknownScript_0x1a0fe5: ; 0x1a0fe5
	2writetext UnknownText_0x1a1197
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x1a10a1
	dotrigger $0
	end
; 0x1a0ff1

UnknownScript_0x1a0ff1: ; 0x1a0ff1
	faceplayer
	loadfont
	checkcode $10
	if_equal $0, UnknownScript_0x1a101c
	checkbit1 $0042
	iftrue UnknownScript_0x1a101c
	checkbit1 $001f
	iffalse UnknownScript_0x1a101c
	2writetext UnknownText_0x1a11e3
	yesorno
	iffalse UnknownScript_0x1a1022
	loadmovesprites
	loadpokedata RATTATA, 5
	catchtutorial $3
	loadfont
	2writetext UnknownText_0x1a114d
	closetext
	loadmovesprites
	setbit1 $0042
	end
; 0x1a101c

UnknownScript_0x1a101c: ; 0x1a101c
	2writetext UnknownText_0x1a10a7
	closetext
	loadmovesprites
	end
; 0x1a1022

UnknownScript_0x1a1022: ; 0x1a1022
	2writetext UnknownText_0x1a1197
	closetext
	loadmovesprites
	end
; 0x1a1028

UnknownScript_0x1a1028: ; 0x1a1028
	jumptextfaceplayer UnknownText_0x1a1214
; 0x1a102b

UnknownScript_0x1a102b: ; 0x1a102b
	jumptextfaceplayer UnknownText_0x1a126c
; 0x1a102e

UnknownScript_0x1a102e: ; 0x1a102e
	jumptextfaceplayer UnknownText_0x1a12d9
; 0x1a1031

UnknownScript_0x1a1031: ; 0x1a1031
	faceplayer
	loadfont
	checktime $2
	iftrue UnknownScript_0x1a103d
	checktime $4
	iftrue UnknownScript_0x1a1043
UnknownScript_0x1a103d: ; 0x1a103d
	2writetext UnknownText_0x1a134c
	closetext
	loadmovesprites
	end
; 0x1a1043

UnknownScript_0x1a1043: ; 0x1a1043
	2writetext UnknownText_0x1a137c
	closetext
	loadmovesprites
	end
; 0x1a1049

UnknownScript_0x1a1049: ; 0x1a1049
	faceplayer
	loadfont
	checkbit1 $0065
	iftrue UnknownScript_0x1a1077
	checkcode $b
	if_not_equal TUESDAY, UnknownScript_0x1a107d
	checkbit1 $0064
	iftrue UnknownScript_0x1a1064
	2writetext UnknownText_0x1a13b2
	keeptextopen
	setbit1 $0064
UnknownScript_0x1a1064: ; 0x1a1064
	2writetext UnknownText_0x1a142f
	keeptextopen
	verbosegiveitem PINK_BOW, 1
	iffalse UnknownScript_0x1a107b
	setbit1 $0065
	2writetext UnknownText_0x1a146f
	closetext
	loadmovesprites
	end
; 0x1a1077

UnknownScript_0x1a1077: ; 0x1a1077
	2writetext UnknownText_0x1a14e7
	closetext
UnknownScript_0x1a107b: ; 0x1a107b
	loadmovesprites
	end
; 0x1a107d

UnknownScript_0x1a107d: ; 0x1a107d
	2writetext UnknownText_0x1a1559
	closetext
	loadmovesprites
	end
; 0x1a1083

MapRoute29Signpost0Script: ; 0x1a1083
	jumptext UnknownText_0x1a158e
; 0x1a1086

MapRoute29Signpost1Script: ; 0x1a1086
	jumptext UnknownText_0x1a15b9
; 0x1a1089

UnknownScript_0x1a1089: ; 0x1a1089
	fruittree $1
; 0x1a108b

ItemFragment_0x1a108b: ; 0x1a108b
	db POTION, 1
; 0x1a108d

MovementData_0x1a108d: ; 0x1a108d
	step_up
	step_up
	step_up
	step_up
	step_right
	step_right
	step_end
; 0x1a1094

MovementData_0x1a1094: ; 0x1a1094
	step_up
	step_up
	step_up
	step_right
	step_right
	step_end
; 0x1a109a

MovementData_0x1a109a: ; 0x1a109a
	step_left
	step_left
	step_down
	step_down
	step_down
	step_down
	step_end
; 0x1a10a1

MovementData_0x1a10a1: ; 0x1a10a1
	step_left
	step_left
	step_down
	step_down
	step_down
	step_end
; 0x1a10a7

UnknownText_0x1a10a7: ; 0x1a10a7
	db $0, "#MON hide in", $4f
	db "the grass. Who", $51
	db "knows when they'll", $4f
	db "pop out…", $57
; 0x1a10df

UnknownText_0x1a10df: ; 0x1a10df
	db $0, "I've seen you a", $4f
	db "couple times. How", $51
	db "many #MON have", $4f
	db "you caught?", $51
	db "Would you like me", $4f
	db "to show you how to", $55
	db "catch #MON?", $57
; 0x1a114d

UnknownText_0x1a114d: ; 0x1a114d
	db $0, "That's how you do", $4f
	db "it.", $51
	db "If you weaken them", $4f
	db "first, #MON are", $55
	db "easier to catch.", $57
; 0x1a1197

UnknownText_0x1a1197: ; 0x1a1197
	db $0, "Oh. Fine, then.", $51
	db "Anyway, if you", $4f
	db "want to catch", $51
	db "#MON, you have", $4f
	db "to walk a lot.", $57
; 0x1a11e3

UnknownText_0x1a11e3: ; 0x1a11e3
	db $0, "Huh? You want me", $4f
	db "to show you how to", $55
	db "catch #MON?", $57
; 0x1a1214

UnknownText_0x1a1214: ; 0x1a1214
	db $0, "Yo. How are your", $4f
	db "#MON?", $51
	db "If they're weak", $4f
	db "and not ready for", $51
	db "battle, keep out", $4f
	db "of the grass.", $57
; 0x1a126c

UnknownText_0x1a126c: ; 0x1a126c
	db $0, "See those ledges?", $4f
	db "It's scary to jump", $55
	db "off them.", $51
	db "But you can go to", $4f
	db "NEW BARK without", $51
	db "walking through", $4f
	db "the grass.", $57
; 0x1a12d9

UnknownText_0x1a12d9: ; 0x1a12d9
	db $0, "I wanted to take a", $4f
	db "break, so I saved", $51
	db "to record my", $4f
	db "progress.", $57
; 0x1a1316

; possibly unused
UnknownText_0x1a1316: ; 0x1a1316
	db $0, "I'm waiting for", $4f
	db "#MON that", $51
	db "appear only in the", $4f
	db "daytime.", $57
; 0x1a134c

UnknownText_0x1a134c: ; 0x1a134c
	db $0, "I'm waiting for", $4f
	db "#MON that", $51
	db "appear only at", $4f
	db "night.", $57
; 0x1a137c

UnknownText_0x1a137c: ; 0x1a137c
	db $0, "I'm waiting for", $4f
	db "#MON that", $51
	db "appear only in the", $4f
	db "morning.", $57
; 0x1a13b2

UnknownText_0x1a13b2: ; 0x1a13b2
	db $0, "TUSCANY: I do be-", $4f
	db "lieve that this is", $51
	db "the first time", $4f
	db "we've met?", $51
	db "Please allow me to", $4f
	db "introduce myself.", $51
	db "I am TUSCANY of", $4f
	db "Tuesday.", $57
; 0x1a142f

UnknownText_0x1a142f: ; 0x1a142f
	db $0, "By way of intro-", $4f
	db "duction, please", $51
	db "accept this gift,", $4f
	db "a PINK BOW.", $57
; 0x1a146f

UnknownText_0x1a146f: ; 0x1a146f
	db $0, "TUSCANY: Wouldn't", $4f
	db "you agree that it", $55
	db "is most adorable?", $51
	db "It strengthens", $4f
	db "normal-type moves.", $51
	db "I am certain it", $4f
	db "will be of use.", $57
; 0x1a14e7

UnknownText_0x1a14e7: ; 0x1a14e7
	db $0, "TUSCANY: Have you", $4f
	db "met MONICA, my", $55
	db "older sister?", $51
	db "Or my younger", $4f
	db "brother, WESLEY?", $51
	db "I am the second of", $4f
	db "seven children.", $57
; 0x1a1559

UnknownText_0x1a1559: ; 0x1a1559
	db $0, "TUSCANY: Today is", $4f
	db "not Tuesday. That", $55
	db "is unfortunate…", $57
; 0x1a158e

UnknownText_0x1a158e: ; 0x1a158e
	db $0, "ROUTE 29", $51
	db "CHERRYGROVE CITY -", $4f
	db "NEW BARK TOWN", $57
; 0x1a15b9

UnknownText_0x1a15b9: ; 0x1a15b9
	db $0, "ROUTE 29", $51
	db "CHERRYGROVE CITY -", $4f
	db "NEW BARK TOWN", $57
; 0x1a15e4

Route29_MapEventHeader: ; 0x1a15e4
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $1, $1b, 3, GROUP_ROUTE_29_46_GATE, MAP_ROUTE_29_46_GATE

	; xy triggers
	db 2
	xy_trigger 1, $8, $35, $0, UnknownScript_0x1a0f6d, $0, $0
	xy_trigger 1, $9, $35, $0, UnknownScript_0x1a0fa3, $0, $0

	; signposts
	db 2
	signpost 7, 51, $0, MapRoute29Signpost0Script
	signpost 5, 3, $0, MapRoute29Signpost1Script

	; people-events
	db 8
	person_event $23, 16, 54, $3, $0, 255, 255, $80, 0, UnknownScript_0x1a0ff1, $ffff
	person_event $27, 20, 31, $4, $10, 255, 255, $a0, 0, UnknownScript_0x1a1028, $ffff
	person_event $29, 15, 19, $5, $1, 255, 255, $a0, 0, UnknownScript_0x1a102b, $ffff
	person_event $5d, 6, 16, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a1089, $ffff
	person_event $3a, 7, 29, $7, $0, 255, 255, $90, 0, UnknownScript_0x1a102e, $ffff
	person_event $23, 8, 17, $6, $0, 255, 255, $80, 0, UnknownScript_0x1a1031, $ffff
	person_event $29, 16, 33, $3, $0, 255, 255, $0, 0, UnknownScript_0x1a1049, $0759
	person_event $54, 6, 52, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a108b, $06ad
; 0x1a1671

Route30_MapScriptHeader: ; 0x1a1671
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a1673

UnknownScript_0x1a1673: ; 0x1a1673
	waitbutton
	playmusic $002a
	loadfont
	2writetext UnknownText_0x1a1806
	pause 30
	loadmovesprites
	playsound $0041
	applymovement $8, MovementData_0x1a17fe
	loadfont
	faceplayer
	2writetext UnknownText_0x1a181c
	closetext
	spriteface $2, $1
	loadmovesprites
	playsound $0041
	applymovement $7, MovementData_0x1a1802
	special $003d
	end
; 0x1a169a

TrainerYoungsterJoey1: ; 0x1a169a
	; bit/flag number
	dw $5a9

	; trainer group && trainer id
	db YOUNGSTER, JOEY1

	; text when seen
	dw YoungsterJoey1SeenText

	; text when trainer beaten
	dw YoungsterJoey1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterJoey1Script
; 0x1a16a6

YoungsterJoey1Script: ; 0x1a16a6
	writecode $17, $f
	talkaftercancel
	loadfont
	checkbit2 $006b
	iftrue UnknownScript_0x1a16e0
	checkcellnum $f
	iftrue UnknownScript_0x1a178f
	checkbit1 $0273
	iftrue UnknownScript_0x1a16c9
	2writetext UnknownText_0x1a18c2
	keeptextopen
	setbit1 $0273
	2call UnknownScript_0x1a1783
	2jump UnknownScript_0x1a16cc
; 0x1a16c9

UnknownScript_0x1a16c9: ; 0x1a16c9
	2call UnknownScript_0x1a1787
UnknownScript_0x1a16cc: ; 0x1a16cc
	askforphonenumber $f
	if_equal $1, UnknownScript_0x1a1797
	if_equal $2, UnknownScript_0x1a1793
	trainertotext YOUNGSTER, JOEY1, $0
	2call UnknownScript_0x1a178b
	2jump UnknownScript_0x1a178f
; 0x1a16e0

UnknownScript_0x1a16e0: ; 0x1a16e0
	2call UnknownScript_0x1a179b
	winlosstext YoungsterJoey1BeatenText, $0000
	copybytetovar $d9f9
	if_equal $4, UnknownScript_0x1a16ff
	if_equal $3, UnknownScript_0x1a1705
	if_equal $2, UnknownScript_0x1a170b
	if_equal $1, UnknownScript_0x1a1711
	if_equal $0, UnknownScript_0x1a1717
UnknownScript_0x1a16ff: ; 0x1a16ff
	checkbit1 $0044
	iftrue UnknownScript_0x1a174b
UnknownScript_0x1a1705: ; 0x1a1705
	checkbit1 $0021
	iftrue UnknownScript_0x1a173e
UnknownScript_0x1a170b: ; 0x1a170b
	checkbit2 $0047
	iftrue UnknownScript_0x1a1731
UnknownScript_0x1a1711: ; 0x1a1711
	checkbit2 $0046
	iftrue UnknownScript_0x1a1724
UnknownScript_0x1a1717: ; 0x1a717
	loadtrainer YOUNGSTER, JOEY1
	startbattle
	returnafterbattle
	loadvar $d9f9, $1
	clearbit2 $006b
	end
; 0x1a1724

UnknownScript_0x1a1724: ; 0x1a1724
	loadtrainer YOUNGSTER, JOEY2
	startbattle
	returnafterbattle
	loadvar $d9f9, $2
	clearbit2 $006b
	end
; 0x1a1731

UnknownScript_0x1a1731: ; 0x1a1731
	loadtrainer YOUNGSTER, JOEY3
	startbattle
	returnafterbattle
	loadvar $d9f9, $3
	clearbit2 $006b
	end
; 0x1a173e

UnknownScript_0x1a173e: ; 0x1a173e
	loadtrainer YOUNGSTER, JOEY4
	startbattle
	returnafterbattle
	loadvar $d9f9, $4
	clearbit2 $006b
	end
; 0x1a174b

UnknownScript_0x1a174b: ; 0x1a174b
	loadtrainer YOUNGSTER, JOEY5
	startbattle
	returnafterbattle
	clearbit2 $006b
	checkbit1 $0338
	iftrue UnknownScript_0x1a176f
	checkbit1 $0266
	iftrue UnknownScript_0x1a176e
	2call UnknownScript_0x1a17a6
	verbosegiveitem HP_UP, 1
	iffalse UnknownScript_0x1a179f
	setbit1 $0266
	2jump UnknownScript_0x1a178f
; 0x1a176e

UnknownScript_0x1a176e: ; 0x1a176e
	end
; 0x1a176f

UnknownScript_0x1a176f: ; 0x1a176f
	loadfont
	2writetext UnknownText_0x1a1bc0
	closetext
	verbosegiveitem HP_UP, 1
	iffalse UnknownScript_0x1a179f
	clearbit1 $0338
	setbit1 $0266
	2jump UnknownScript_0x1a178f
; 0x1a1783

UnknownScript_0x1a1783: ; 0x1a1783
	jumpstd $0019
	end
; 0x1a1787

UnknownScript_0x1a1787: ; 0x1a1787
	jumpstd $001a
	end
; 0x1a178b

UnknownScript_0x1a178b: ; 0x1a178b
	jumpstd $001b
	end
; 0x1a178f

UnknownScript_0x1a178f: ; 0x1a178f
	jumpstd $001c
	end
; 0x1a1793

UnknownScript_0x1a1793: ; 0x1a1793
	jumpstd $001d
	end
; 0x1a1797

UnknownScript_0x1a1797: ; 0x1a1797
	jumpstd $001e
	end
; 0x1a179b

UnknownScript_0x1a179b: ; 0x1a179b
	jumpstd $001f
	end
; 0x1a179f

UnknownScript_0x1a179f: ; 0x1a179f
	setbit1 $0338
	jumpstd $0021
	end
; 0x1a17a6

UnknownScript_0x1a17a6: ; 0x1a17a6
	jumpstd $0022
	end
; 0x1a17aa

TrainerYoungsterMikey: ; 0x1a17aa
	; bit/flag number
	dw $5aa

	; trainer group && trainer id
	db YOUNGSTER, MIKEY

	; text when seen
	dw YoungsterMikeySeenText

	; text when trainer beaten
	dw YoungsterMikeyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterMikeyScript
; 0x1a17b6

YoungsterMikeyScript: ; 0x1a17b6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a197d
	closetext
	loadmovesprites
	end
; 0x1a17be

TrainerBug_catcherDon: ; 0x1a17be
	; bit/flag number
	dw $538

	; trainer group && trainer id
	db BUG_CATCHER, DON

	; text when seen
	dw Bug_catcherDonSeenText

	; text when trainer beaten
	dw Bug_catcherDonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherDonScript
; 0x1a17ca

Bug_catcherDonScript: ; 0x1a17ca
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a1a1c
	closetext
	loadmovesprites
	end
; 0x1a17d2

UnknownScript_0x1a17d2: ; 0x1a17d2
	faceplayer
	loadfont
	checkbit1 $001f
	iftrue UnknownScript_0x1a17e0
	2writetext UnknownText_0x1a1a6a
	closetext
	loadmovesprites
	end
; 0x1a17e0

UnknownScript_0x1a17e0: ; 0x1a17e0
	2writetext UnknownText_0x1a1a94
	closetext
	loadmovesprites
	end
; 0x1a17e6

UnknownScript_0x1a17e6: ; 0x1a17e6
	jumptextfaceplayer UnknownText_0x1a1ac4
; 0x1a17e9

MapRoute30Signpost0Script: ; 0x1a17e9
	jumptext UnknownText_0x1a1b0b
; 0x1a17ec

MapRoute30Signpost1Script: ; 0x1a17ec
	jumptext UnknownText_0x1a1b34
; 0x1a17ef

MapRoute30Signpost2Script: ; 0x1a17ef
	jumptext UnknownText_0x1a1b55
; 0x1a17f2

MapRoute30Signpost3Script: ; 0x1a17f2
	jumptext UnknownText_0x1a1b66
; 0x1a17f5

ItemFragment_0x1a17f5: ; 0x1a17f5
	db ANTIDOTE, 1
; 0x1a17f7

UnknownScript_0x1a17f7: ; 0x1a17f7
	fruittree $2
; 0x1a17f9

UnknownScript_0x1a17f9: ; 0x1a17f9
	fruittree $5
; 0x1a17fb

MapRoute30SignpostItem4: ; 0x1a17fb
	dw $00a4
	db POTION
	
; 0x1a17fe

MovementData_0x1a17fe: ; 0x1a17fe
	fix_facing
	big_step_up
	big_step_down
	step_end
; 0x1a1802

MovementData_0x1a1802: ; 0x1a1802
	fix_facing
	big_step_down
	big_step_up
	step_end
; 0x1a1806

UnknownText_0x1a1806: ; 0x1a1806
	db $0, "Go, RATTATA!", $51
	db "TACKLE!", $57
; 0x1a181c

UnknownText_0x1a181c: ; 0x1a181c
	db $0, "What? This is a", $4f
	db "big battle!", $55
	db "Leave me alone!", $57
; 0x1a1849

YoungsterJoey1SeenText: ; 0x1a1849
	db $0, "I just lost, so", $4f
	db "I'm trying to find", $55
	db "more #MON.", $51
	db "Wait! You look", $4f
	db "weak! Come on,", $55
	db "let's battle!", $57
; 0x1a18a2

YoungsterJoey1BeatenText: ; 0x1a18a2
	db $0, "Ack! I lost again!", $4f
	db "Doggone it!", $57
; 0x1a18c2

UnknownText_0x1a18c2: ; 0x1a18c2
	db $0, "Do I have to have", $4f
	db "more #MON in", $51
	db "order to battle", $4f
	db "better?", $51
	db "No! I'm sticking", $4f
	db "with this one no", $55
	db "matter what!", $57
; 0x1a1928

YoungsterMikeySeenText: ; 0x1a1928
	db $0, "You're a #MON", $4f
	db "trainer, right?", $51
	db "Then you have to", $4f
	db "battle!", $57
; 0x1a195f

YoungsterMikeyBeatenText: ; 0x1a195f
	db $0, "That's strange.", $4f
	db "I won before.", $57
; 0x1a197d

UnknownText_0x1a197d: ; 0x1a197d
	db $0, "Becoming a good", $4f
	db "trainer is really", $55
	db "tough.", $51
	db "I'm going to bat-", $4f
	db "tle other people", $55
	db "to get better.", $57
; 0x1a19d8

Bug_catcherDonSeenText: ; 0x1a19d8
	db $0, "Instead of a bug", $4f
	db "#MON, I found", $55
	db "a trainer!", $57
; 0x1a1a03

Bug_catcherDonBeatenText: ; 0x1a1a03
	db $0, "Argh! You're too", $4f
	db "strong!", $57
; 0x1a1a1c

UnknownText_0x1a1a1c: ; 0x1a1a1c
	db $0, "I ran out of #", $4f
	db "BALLS while I was", $55
	db "catching #MON.", $51
	db "I should've bought", $4f
	db "some more…", $57
; 0x1a1a6a

UnknownText_0x1a1a6a: ; 0x1a1a6a
	db $0, "MR.#MON's", $4f
	db "house? It's a bit", $55
	db "farther ahead.", $57
; 0x1a1a94

UnknownText_0x1a1a94: ; 0x1a1a94
	db $0, "Everyone's having", $4f
	db "fun battling!", $55
	db "You should too!", $57
; 0x1a1ac4

UnknownText_0x1a1ac4: ; 0x1a1ac4
	db $0, "I'm not a trainer.", $51
	db "But if you look", $4f
	db "one in the eyes,", $55
	db "prepare to battle.", $57
; 0x1a1b0b

UnknownText_0x1a1b0b: ; 0x1a1b0b
	db $0, "ROUTE 30", $51
	db "VIOLET CITY -", $4f
	db "CHERRYGROVE CITY", $57
; 0x1a1b34

UnknownText_0x1a1b34: ; 0x1a1b34
	db $0, "MR.#MON'S HOUSE", $4f
	db "STRAIGHT AHEAD!", $57
; 0x1a1b55

UnknownText_0x1a1b55: ; 0x1a1b55
	db $0, "MR.#MON'S HOUSE", $57
; 0x1a1b66

UnknownText_0x1a1b66: ; 0x1a1b66
	db $0, "TRAINER TIPS", $51
	db "No stealing other", $4f
	db "people's #MON!", $51
	db "# BALLS are to", $4f
	db "be thrown only at", $55
	db "wild #MON!", $57
; 0x1a1bc0

UnknownText_0x1a1bc0: ; 0x1a1bc0
	db $0, "I lost again…", $4f
	db "Gee, you're tough!", $51
	db "Oh yeah, I almost", $4f
	db "forgot that I had", $55
	db "to give you this.", $51
	db "Use it to get even", $4f
	db "tougher, OK?", $51
	db "I'm going to get", $4f
	db "tougher too.", $57
; 0x1a1c54

Route30_MapEventHeader: ; 0x1a1c54
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $27, $7, 1, GROUP_ROUTE_30_BERRY_SPEECH_HOUSE, MAP_ROUTE_30_BERRY_SPEECH_HOUSE
	warp_def $5, $11, 1, GROUP_MR_POKEMONS_HOUSE, MAP_MR_POKEMONS_HOUSE

	; xy triggers
	db 0

	; signposts
	db 5
	signpost 43, 9, $0, MapRoute30Signpost0Script
	signpost 29, 13, $0, MapRoute30Signpost1Script
	signpost 5, 15, $0, MapRoute30Signpost2Script
	signpost 21, 3, $0, MapRoute30Signpost3Script
	signpost 9, 14, $7, MapRoute30SignpostItem4

	; people-events
	db 11
	person_event $27, 30, 9, $7, $0, 255, 255, $90, 0, UnknownScript_0x1a1673, $0714
	person_event $27, 32, 6, $9, $0, 255, 255, $92, 3, TrainerYoungsterJoey1, $0715
	person_event $27, 27, 9, $6, $0, 255, 255, $92, 1, TrainerYoungsterMikey, $ffff
	person_event $25, 11, 5, $6, $0, 255, 255, $b2, 3, TrainerBug_catcherDon, $ffff
	person_event $27, 34, 11, $5, $1, 255, 255, $80, 0, UnknownScript_0x1a17d2, $ffff
	person_event $4c, 28, 9, $6, $0, 255, 255, $80, 0, ObjectEvent, $0714
	person_event $4c, 29, 9, $7, $0, 255, 255, $90, 0, ObjectEvent, $0714
	person_event $5d, 43, 9, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a17f7, $ffff
	person_event $5d, 9, 15, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a17f9, $ffff
	person_event $24, 17, 6, $6, $0, 255, 255, $0, 0, UnknownScript_0x1a17e6, $ffff
	person_event $54, 39, 12, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a17f5, $07b8
; 0x1a1d0c

Route38_MapScriptHeader: ; 0x1a1d0c
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a1d0e

TrainerBird_keeperToby: ; 0x1a1d0e
	; bit/flag number
	dw $3ff

	; trainer group && trainer id
	db BIRD_KEEPER, TOBY

	; text when seen
	dw Bird_keeperTobySeenText

	; text when trainer beaten
	dw Bird_keeperTobyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperTobyScript
; 0x1a1d1a

Bird_keeperTobyScript: ; 0x1a1d1a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a1f86
	closetext
	loadmovesprites
	end
; 0x1a1d22

TrainerSailorHarry: ; 0x1a1d22
	; bit/flag number
	dw $57e

	; trainer group && trainer id
	db SAILOR, HARRY

	; text when seen
	dw SailorHarrySeenText

	; text when trainer beaten
	dw SailorHarryBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SailorHarryScript
; 0x1a1d2e

SailorHarryScript: ; 0x1a1d2e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a220c
	closetext
	loadmovesprites
	end
; 0x1a1d36

TrainerLassDana1: ; 0x1a1d36
	; bit/flag number
	dw $51e

	; trainer group && trainer id
	db LASS, DANA1

	; text when seen
	dw LassDana1SeenText

	; text when trainer beaten
	dw LassDana1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw LassDana1Script
; 0x1a1d42

LassDana1Script: ; 0x1a1d42
	writecode $17, $1a
	talkaftercancel
	loadfont
	checkbit2 $0074
	iftrue UnknownScript_0x1a1d82
	checkbit2 $0082
	iftrue UnknownScript_0x1a1df6
	checkcellnum $1a
	iftrue UnknownScript_0x1a1e17
	checkbit1 $0289
	iftrue UnknownScript_0x1a1d6b
	2writetext UnknownText_0x1a20ec
	keeptextopen
	setbit1 $0289
	2call UnknownScript_0x1a1e0b
	2jump UnknownScript_0x1a1d6e
; 0x1a1d6b

UnknownScript_0x1a1d6b: ; 0x1a1d6b
	2call UnknownScript_0x1a1e0f
UnknownScript_0x1a1d6e: ; 0x1a1d6e
	askforphonenumber $1a
	if_equal $1, UnknownScript_0x1a1e1f
	if_equal $2, UnknownScript_0x1a1e1b
	trainertotext LASS, DANA1, $0
	2call UnknownScript_0x1a1e13
	2jump UnknownScript_0x1a1e17
; 0x1a1d82

UnknownScript_0x1a1d82: ; 0x1a1d82
	2call UnknownScript_0x1a1e23
	winlosstext LassDana1BeatenText, $0000
	copybytetovar $da03
	if_equal $4, UnknownScript_0x1a1da1
	if_equal $3, UnknownScript_0x1a1da7
	if_equal $2, UnknownScript_0x1a1dad
	if_equal $1, UnknownScript_0x1a1db3
	if_equal $0, UnknownScript_0x1a1db9
UnknownScript_0x1a1da1: ; 0x1a1da1
	checkbit1 $00cd
	iftrue UnknownScript_0x1a1ded
UnknownScript_0x1a1da7: ; 0x1a1da7
	checkbit1 $0044
	iftrue UnknownScript_0x1a1de0
UnknownScript_0x1a1dad: ; 0x1a1dad
	checkbit1 $0021
	iftrue UnknownScript_0x1a1dd3
UnknownScript_0x1a1db3: ; 0x1a1db3
	checkbit2 $0045
	iftrue UnknownScript_0x1a1dc6
UnknownScript_0x1a1db9: ; 0x1a1db9
	loadtrainer LASS, DANA1
	startbattle
	returnafterbattle
	loadvar $da03, $1
	clearbit2 $0074
	end
; 0x1a1dc6

UnknownScript_0x1a1dc6: ; 0x1a1dc6
	loadtrainer LASS, DANA2
	startbattle
	returnafterbattle
	loadvar $da03, $2
	clearbit2 $0074
	end
; 0x1a1dd3

UnknownScript_0x1a1dd3: ; 0x1a1dd3
	loadtrainer LASS, DANA3
	startbattle
	returnafterbattle
	loadvar $da03, $3
	clearbit2 $0074
	end
; 0x1a1de0

UnknownScript_0x1a1de0: ; 0x1a1de0
	loadtrainer LASS, DANA4
	startbattle
	returnafterbattle
	loadvar $da03, $4
	clearbit2 $0074
	end
; 0x1a1ded

UnknownScript_0x1a1ded: ; 0x1a1ded
	loadtrainer LASS, DANA5
	startbattle
	returnafterbattle
	clearbit2 $0074
	end
; 0x1a1df6

UnknownScript_0x1a1df6: ; 0x1a1df6
	2call UnknownScript_0x1a1e27
	verbosegiveitem THUNDERSTONE, 1
	iffalse UnknownScript_0x1a1e08
	clearbit2 $0082
	setbit1 $0102
	2jump UnknownScript_0x1a1e17
; 0x1a1e08

UnknownScript_0x1a1e08: ; 0x1a1e08
	2jump UnknownScript_0x1a1e2b
; 0x1a1e0b

UnknownScript_0x1a1e0b: ; 0x1a1e0b
	jumpstd $0023
	end
; 0x1a1e0f

UnknownScript_0x1a1e0f: ; 0x1a1e0f
	jumpstd $0024
	end
; 0x1a1e13

UnknownScript_0x1a1e13: ; 0x1a1e13
	jumpstd $0025
	end
; 0x1a1e17

UnknownScript_0x1a1e17: ; 0x1a1e17
	jumpstd $0026
	end
; 0x1a1e1b

UnknownScript_0x1a1e1b: ; 0x1a1e1b
	jumpstd $0027
	end
; 0x1a1e1f

UnknownScript_0x1a1e1f: ; 0x1a1e1f
	jumpstd $0028
	end
; 0x1a1e23

UnknownScript_0x1a1e23: ; 0x1a1e23
	jumpstd $0029
	end
; 0x1a1e27

UnknownScript_0x1a1e27: ; 0x1a1e27
	jumpstd $002a
	end
; 0x1a1e2b

UnknownScript_0x1a1e2b: ; 0x1a1e2b
	jumpstd $002b
	end
; 0x1a1e2f

TrainerSchoolboyChad1: ; 0x1a1e2f
	; bit/flag number
	dw $475

	; trainer group && trainer id
	db SCHOOLBOY, CHAD1

	; text when seen
	dw SchoolboyChad1SeenText

	; text when trainer beaten
	dw SchoolboyChad1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyChad1Script
; 0x1a1e3b

SchoolboyChad1Script: ; 0x1a1e3b
	writecode $17, $1b
	talkaftercancel
	loadfont
	checkbit2 $0075
	iftrue UnknownScript_0x1a1e75
	checkcellnum $1b
	iftrue UnknownScript_0x1a1ef5
	checkbit1 $028b
	iftrue UnknownScript_0x1a1e5e
	2writetext UnknownText_0x1a200e
	keeptextopen
	setbit1 $028b
	2call UnknownScript_0x1a1ee9
	2jump UnknownScript_0x1a1e61
; 0x1a1e5e

UnknownScript_0x1a1e5e: ; 0x1a1e5e
	2call UnknownScript_0x1a1eed
UnknownScript_0x1a1e61: ; 0x1a1e61
	askforphonenumber $1b
	if_equal $1, UnknownScript_0x1a1efd
	if_equal $2, UnknownScript_0x1a1ef9
	trainertotext SCHOOLBOY, CHAD1, $0
	2call UnknownScript_0x1a1ef1
	2jump UnknownScript_0x1a1ef5
; 0x1a1e75

UnknownScript_0x1a1e75: ; 0x1a1e75
	2call UnknownScript_0x1a1f01
	winlosstext SchoolboyChad1BeatenText, $0000
	copybytetovar $da04
	if_equal $4, UnknownScript_0x1a1e94
	if_equal $3, UnknownScript_0x1a1e9a
	if_equal $2, UnknownScript_0x1a1ea0
	if_equal $1, UnknownScript_0x1a1ea6
	if_equal $0, UnknownScript_0x1a1eac
UnknownScript_0x1a1e94: ; 0x1a1e94
	checkbit1 $00cd
	iftrue UnknownScript_0x1a1ee0
UnknownScript_0x1a1e9a: ; 0x1a1e9a
	checkbit1 $0044
	iftrue UnknownScript_0x1a1ed3
UnknownScript_0x1a1ea0: ; 0x1a1ea0
	checkbit1 $0021
	iftrue UnknownScript_0x1a1ec6
UnknownScript_0x1a1ea6: ; 0x1a1ea6
	checkbit2 $0049
	iftrue UnknownScript_0x1a1eb9
UnknownScript_0x1a1eac: ; 0x1a1eac
	loadtrainer SCHOOLBOY, CHAD1
	startbattle
	returnafterbattle
	loadvar $da04, $1
	clearbit2 $0075
	end
; 0x1a1eb9

UnknownScript_0x1a1eb9: ; 0x1a1eb9
	loadtrainer SCHOOLBOY, CHAD2
	startbattle
	returnafterbattle
	loadvar $da04, $2
	clearbit2 $0075
	end
; 0x1a1ec6

UnknownScript_0x1a1ec6: ; 0x1a1ec6
	loadtrainer SCHOOLBOY, CHAD3
	startbattle
	returnafterbattle
	loadvar $da04, $3
	clearbit2 $0075
	end
; 0x1a1ed3

UnknownScript_0x1a1ed3: ; 0x1a1ed3
	loadtrainer SCHOOLBOY, CHAD4
	startbattle
	returnafterbattle
	loadvar $da04, $4
	clearbit2 $0075
	end
; 0x1a1ee0

UnknownScript_0x1a1ee0: ; 0x1a1ee0
	loadtrainer SCHOOLBOY, CHAD5
	startbattle
	returnafterbattle
	clearbit2 $0075
	end
; 0x1a1ee9

UnknownScript_0x1a1ee9: ; 0x1a1ee9
	jumpstd $0019
	end
; 0x1a1eed

UnknownScript_0x1a1eed: ; 0x1a1eed
	jumpstd $001a
	end
; 0x1a1ef1

UnknownScript_0x1a1ef1: ; 0x1a1ef1
	jumpstd $001b
	end
; 0x1a1ef5

UnknownScript_0x1a1ef5: ; 0x1a1ef5
	jumpstd $001c
	end
; 0x1a1ef9

UnknownScript_0x1a1ef9: ; 0x1a1ef9
	jumpstd $001d
	end
; 0x1a1efd

UnknownScript_0x1a1efd: ; 0x1a1efd
	jumpstd $001e
	end
; 0x1a1f01

UnknownScript_0x1a1f01: ; 0x1a1f01
	jumpstd $001f
	end
; 0x1a1f05

TrainerBeautyValerie: ; 0x1a1f05
	; bit/flag number
	dw $4bc

	; trainer group && trainer id
	db BEAUTY, VALERIE

	; text when seen
	dw BeautyValerieSeenText

	; text when trainer beaten
	dw BeautyValerieBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BeautyValerieScript
; 0x1a1f11

BeautyValerieScript: ; 0x1a1f11
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a2185
	closetext
	loadmovesprites
	end
; 0x1a1f19

TrainerBeautyOlivia: ; 0x1a1f19
	; bit/flag number
	dw $5c1

	; trainer group && trainer id
	db BEAUTY, OLIVIA

	; text when seen
	dw BeautyOliviaSeenText

	; text when trainer beaten
	dw BeautyOliviaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BeautyOliviaScript
; 0x1a1f25

BeautyOliviaScript: ; 0x1a1f25
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a229a
	closetext
	loadmovesprites
	end
; 0x1a1f2d

MapRoute38Signpost0Script: ; 0x1a1f2d
	jumptext UnknownText_0x1a22fd
; 0x1a1f30

MapRoute38Signpost1Script: ; 0x1a1f30
	jumptext UnknownText_0x1a2324
; 0x1a1f33

UnknownScript_0x1a1f33: ; 0x1a1f33
	fruittree $3
; 0x1a1f35

Bird_keeperTobySeenText: ; 0x1a1f35
	db $0, "Fly high into the", $4f
	db "sky, my beloved", $55
	db "bird #MON!", $57
; 0x1a1f63

Bird_keeperTobyBeatenText: ; 0x1a1f63
	db $0, "I feel like just", $4f
	db "flying away now.", $57
; 0x1a1f86

UnknownText_0x1a1f86: ; 0x1a1f86
	db $0, "I plan to train in", $4f
	db "CIANWOOD CITY to", $51
	db "teach my #MON", $4f
	db "how to FLY.", $57
; 0x1a1fc5

SchoolboyChad1SeenText: ; 0x1a1fc5
	db $0, "Let me try some-", $4f
	db "thing I learned", $55
	db "today.", $57
; 0x1a1fee

SchoolboyChad1BeatenText: ; 0x1a1fee
	db $0, "I didn't study", $4f
	db "enough, I guess.", $57
; 0x1a200e

UnknownText_0x1a200e: ; 0x1a200e
	db $0, "I have to take so", $4f
	db "many tests, I", $51
	db "don't have much", $4f
	db "time for #MON.", $51
	db "So when I do get", $4f
	db "to play, I really", $55
	db "concentrate.", $57
; 0x1a207d

LassDana1SeenText: ; 0x1a207d
	db $0, "You seem to be", $4f
	db "good at #MON.", $51
	db "If you are, how", $4f
	db "about giving me", $55
	db "some advice?", $57
; 0x1a20c8

LassDana1BeatenText: ; 0x1a20c8
	db $0, "I see. So you can", $4f
	db "battle that way.", $57
; 0x1a20ec

UnknownText_0x1a20ec: ; 0x1a20ec
	db $0, "I know something", $4f
	db "good!", $51
	db "MOOMOO FARM's milk", $4f
	db "is famous for its", $55
	db "flavor.", $57
; 0x1a2130

BeautyValerieSeenText: ; 0x1a2130
	db $0, "Hi! Aren't you a", $4f
	db "cute trainer!", $51
	db "May I see your", $4f
	db "#MON?", $57
; 0x1a2164

BeautyValerieBeatenText: ; 0x1a2164
	db $0, "I'm glad I got to", $4f
	db "see your #MON!", $57
; 0x1a2185

UnknownText_0x1a2185: ; 0x1a2185
	db $0, "When I see #-", $4f
	db "MON, it seems to", $55
	db "soothe my nerves.", $57
; 0x1a21b7

SailorHarrySeenText: ; 0x1a21b7
	db $0, "I've been over-", $4f
	db "seas, so I know", $51
	db "about all sorts of", $4f
	db "#MON!", $57
; 0x1a21f0

SailorHarryBeatenText: ; 0x1a21f0
	db $0, "Your skill is", $4f
	db "world class!", $57
; 0x1a220c

UnknownText_0x1a220c: ; 0x1a220c
	db $0, "All kinds of peo-", $4f
	db "ple around the", $51
	db "world live happily", $4f
	db "with #MON.", $57
; 0x1a224c

BeautyOliviaSeenText: ; 0x1a224c
	db $0, "Don't you think my", $4f
	db "#MON and I are", $55
	db "beautiful?", $57
; 0x1a2279

BeautyOliviaBeatenText: ; 0x1a2279
	db $0, "We drink MOOMOO", $4f
	db "MILK every day.", $57
; 0x1a229a

UnknownText_0x1a229a: ; 0x1a229a
	db $0, "MOOMOO MILK is", $4f
	db "good for beauty", $51
	db "and health, but", $4f
	db "inconveniently,", $51
	db "they only sell a", $4f
	db "bottle at a time.", $57
; 0x1a22fd

UnknownText_0x1a22fd: ; 0x1a22fd
	db $0, "ROUTE 38", $51
	db "OLIVINE CITY -", $4f
	db "ECRUTEAK CITY", $57
; 0x1a2324

UnknownText_0x1a2324: ; 0x1a2324
	db $0, "TRAINER TIPS", $51
	db "If a #MON is", $4f
	db "trying to evolve,", $55
	db "you can stop it.", $51
	db "Press the B But-", $4f
	db "ton during evolu-", $55
	db "tion.", $51
	db "That startles the", $4f
	db "#MON and stops", $55
	db "its evolution.", $57
; 0x1a23bb

Route38_MapEventHeader: ; 0x1a23bb
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $8, $23, 1, GROUP_ROUTE_38_ECRUTEAK_GATE, MAP_ROUTE_38_ECRUTEAK_GATE
	warp_def $9, $23, 2, GROUP_ROUTE_38_ECRUTEAK_GATE, MAP_ROUTE_38_ECRUTEAK_GATE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 7, 33, $0, MapRoute38Signpost0Script
	signpost 13, 5, $0, MapRoute38Signpost1Script

	; people-events
	db 7
	person_event $66, 5, 8, $9, $0, 255, 255, $92, 1, TrainerSchoolboyChad1, $ffff
	person_event $28, 7, 19, $a, $0, 255, 255, $92, 2, TrainerLassDana1, $ffff
	person_event $66, 19, 16, $a, $0, 255, 255, $92, 1, TrainerBird_keeperToby, $ffff
	person_event $2a, 13, 23, $6, $0, 255, 255, $92, 1, TrainerBeautyValerie, $ffff
	person_event $49, 9, 28, $1e, $0, 255, 255, $92, 2, TrainerSailorHarry, $ffff
	person_event $5d, 14, 16, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a1f33, $ffff
	person_event $2a, 12, 9, $a, $0, 255, 255, $92, 1, TrainerBeautyOlivia, $ffff
; 0x1a2430

Route13_MapScriptHeader: ; 0x1a2430
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a2432

TrainerPokefanmAlex: ; 0x1a2432
	; bit/flag number
	dw $4d8

	; trainer group && trainer id
	db POKEFANM, ALEX

	; text when seen
	dw PokefanmAlexSeenText

	; text when trainer beaten
	dw PokefanmAlexBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmAlexScript
; 0x1a243e

PokefanmAlexScript: ; 0x1a243e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a24e3
	closetext
	loadmovesprites
	end
; 0x1a2446

TrainerPokefanmJoshua: ; 0x1a2446
	; bit/flag number
	dw $4d0

	; trainer group && trainer id
	db POKEFANM, JOSHUA

	; text when seen
	dw PokefanmJoshuaSeenText

	; text when trainer beaten
	dw PokefanmJoshuaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmJoshuaScript
; 0x1a2452

PokefanmJoshuaScript: ; 0x1a2452
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a254f
	closetext
	loadmovesprites
	end
; 0x1a245a

TrainerBird_keeperPerry: ; 0x1a245a
	; bit/flag number
	dw $409

	; trainer group && trainer id
	db BIRD_KEEPER, PERRY

	; text when seen
	dw Bird_keeperPerrySeenText

	; text when trainer beaten
	dw Bird_keeperPerryBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperPerryScript
; 0x1a2466

Bird_keeperPerryScript: ; 0x1a2466
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a25db
	closetext
	loadmovesprites
	end
; 0x1a246e

TrainerBird_keeperBret: ; 0x1a246e
	; bit/flag number
	dw $40a

	; trainer group && trainer id
	db BIRD_KEEPER, BRET

	; text when seen
	dw Bird_keeperBretSeenText

	; text when trainer beaten
	dw Bird_keeperBretBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperBretScript
; 0x1a247a

Bird_keeperBretScript: ; 0x1a247a
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a2662
	closetext
	loadmovesprites
	end
; 0x1a2482

TrainerHikerKenny: ; 0x1a2482
	; bit/flag number
	dw $533

	; trainer group && trainer id
	db HIKER, KENNY

	; text when seen
	dw HikerKennySeenText

	; text when trainer beaten
	dw HikerKennyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerKennyScript
; 0x1a248e

HikerKennyScript: ; 0x1a248e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a26c2
	closetext
	loadmovesprites
	end
; 0x1a2496

MapRoute13Signpost0Script: ; 0x1a2496
	jumptext UnknownText_0x1a271c
; 0x1a2499

MapRoute13Signpost1Script: ; 0x1a2499
	jumptext UnknownText_0x1a275b
; 0x1a249c

MapRoute13Signpost2Script: ; 0x1a249c
	jumptext UnknownText_0x1a277d
; 0x1a249f

MapRoute13SignpostItem3: ; 0x1a249f
	dw $00f4
	db CALCIUM
	
; 0x1a24a2

PokefanmAlexSeenText: ; 0x1a24a2
	db $0, "Bow down before my", $4f
	db "regal #MON!", $57
; 0x1a24c2

PokefanmAlexBeatenText: ; 0x1a24c2
	db $0, "How… How dare you", $4f
	db "mock royalty!", $57
; 0x1a24e3

UnknownText_0x1a24e3: ; 0x1a24e3
	db $0, "Doesn't everyone", $4f
	db "wish to someday be", $55
	db "a king?", $57
; 0x1a250f

PokefanmJoshuaSeenText: ; 0x1a250f
	db $0, "Nihihi! Would you", $4f
	db "like to battle my", $55
	db "PIKACHU gang?", $57
; 0x1a2542

PokefanmJoshuaBeatenText: ; 0x1a2542
	db $0, "PI-PIKACHU!", $57
; 0x1a254f

UnknownText_0x1a254f: ; 0x1a254f
	db $0, "You look like you", $4f
	db "have many #MON,", $51
	db "but PIKACHU is", $4f
	db "still the best.", $57
; 0x1a2591

Bird_keeperPerrySeenText: ; 0x1a2591
	db $0, "Agility is the key", $4f
	db "attribute of bird", $55
	db "#MON.", $57
; 0x1a25bd

Bird_keeperPerryBeatenText: ; 0x1a25bd
	db $0, "You beat me with", $4f
	db "your speed…", $57
; 0x1a25db

UnknownText_0x1a25db: ; 0x1a25db
	db $0, "Your #MON are", $4f
	db "remarkably well-", $55
	db "trained.", $57
; 0x1a2604

Bird_keeperBretSeenText: ; 0x1a2604
	db $0, "Check out my #-", $4f
	db "MON. Just look at", $51
	db "their coloring and", $4f
	db "their plumage.", $57
; 0x1a2649

Bird_keeperBretBeatenText: ; 0x1a2649
	db $0, "Shoot!", $4f
	db "Not good enough!", $57
; 0x1a2662

UnknownText_0x1a2662: ; 0x1a2662
	db $0, "If you groom them,", $4f
	db "#MON get happy.", $57
; 0x1a2686

HikerKennySeenText: ; 0x1a2686
	db $0, "I should go to", $4f
	db "ROCK TUNNEL to get", $55
	db "myself an ONIX.", $57
; 0x1a26b9

HikerKennyBeatenText: ; 0x1a26b9
	db $0, "I lost…", $57
; 0x1a26c2

UnknownText_0x1a26c2: ; 0x1a26c2
	db $0, "Geological fea-", $4f
	db "tures don't appear", $55
	db "to change.", $51
	db "But they actually", $4f
	db "change, little by", $55
	db "little.", $57
; 0x1a271c

UnknownText_0x1a271c: ; 0x1a271c
	db $0, "TRAINER TIPS", $51
	db "Look! Right there,", $4f
	db "at the left side", $55
	db "of the post.", $57
; 0x1a275b

UnknownText_0x1a275b: ; 0x1a275b
	db $0, "ROUTE 13", $51
	db "NORTH TO SILENCE", $4f
	db "BRIDGE", $57
; 0x1a277d

UnknownText_0x1a277d: ; 0x1a277d
	db $0, "NORTH TO LAVENDER", $4f
	db "TOWN", $51
	db "WEST TO FUCHSIA", $4f
	db "CITY", $57
; 0x1a27aa

Route13_MapEventHeader: ; 0x1a27aa
	; filler
	db 0, 0

	; warps
	db 0

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 13, 29, $0, MapRoute13Signpost0Script
	signpost 11, 41, $0, MapRoute13Signpost1Script
	signpost 13, 17, $0, MapRoute13Signpost2Script
	signpost 13, 30, $7, MapRoute13SignpostItem3

	; people-events
	db 5
	person_event $27, 10, 46, $6, $0, 255, 255, $92, 2, TrainerBird_keeperPerry, $ffff
	person_event $27, 10, 47, $6, $0, 255, 255, $92, 2, TrainerBird_keeperBret, $ffff
	person_event $2d, 12, 36, $8, $0, 255, 255, $82, 3, TrainerPokefanmJoshua, $ffff
	person_event $2d, 14, 18, $8, $0, 255, 255, $82, 4, TrainerHikerKenny, $ffff
	person_event $2d, 10, 29, $9, $0, 255, 255, $82, 4, TrainerPokefanmAlex, $ffff
; 0x1a2805

PewterNidoranSpeechHouse_MapScriptHeader: ; 0x1a2805
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a2807

UnknownScript_0x1a2807: ; 0x1a2807
	jumptextfaceplayer UnknownText_0x1a2814
; 0x1a280a

UnknownScript_0x1a280a: ; 0x1a280a
	loadfont
	2writetext UnknownText_0x1a2825
	cry NIDORAN_M
	closetext
	loadmovesprites
	end
; 0x1a2814

UnknownText_0x1a2814: ; 0x1a2814
	db $0, "NIDORAN, shake!", $57
; 0x1a2825

UnknownText_0x1a2825: ; 0x1a2825
	db $0, "NIDORAN: Gau gau!", $57
; 0x1a2838

PewterNidoranSpeechHouse_MapEventHeader: ; 0x1a2838
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_PEWTER_CITY, MAP_PEWTER_CITY
	warp_def $7, $3, 1, GROUP_PEWTER_CITY, MAP_PEWTER_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $2b, 9, 7, $9, $0, 255, 255, $a0, 0, UnknownScript_0x1a2807, $ffff
	person_event $82, 9, 8, $16, $0, 255, 255, $90, 0, UnknownScript_0x1a280a, $ffff
; 0x1a2862

PewterGym_MapScriptHeader: ; 0x1a2862
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a2864

UnknownScript_0x1a2864: ; 0x1a2864
	faceplayer
	loadfont
	checkbit2 $0023
	iftrue UnknownScript_0x1a2892
	2writetext UnknownText_0x1a28d0
	closetext
	loadmovesprites
	winlosstext UnknownText_0x1a29bb, $0000
	loadtrainer BROCK, 1
	startbattle
	returnafterbattle
	setbit1 $04c5
	setbit1 $042b
	loadfont
	2writetext UnknownText_0x1a2a3d
	playsound $009c
	waitbutton
	setbit2 $0023
	2writetext UnknownText_0x1a2a57
	closetext
	loadmovesprites
	end
; 0x1a2892

UnknownScript_0x1a2892: ; 0x1a2892
	2writetext UnknownText_0x1a2ada
	closetext
	loadmovesprites
	end
; 0x1a2898

TrainerCamperJerry: ; 0x1a2898
	; bit/flag number
	dw $42b

	; trainer group && trainer id
	db CAMPER, JERRY

	; text when seen
	dw CamperJerrySeenText

	; text when trainer beaten
	dw CamperJerryBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperJerryScript
; 0x1a28a4

CamperJerryScript: ; 0x1a28a4
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a2c0f
	closetext
	loadmovesprites
	end
; 0x1a28ac

PewterGymGuyScript: ; 0x1a28ac
	faceplayer
	loadfont
	checkbit1 $04c5
	iftrue .PewterGymGuyWinScript
	2writetext PewterGymGuyText
	closetext
	loadmovesprites
	end

.PewterGymGuyWinScript
	2writetext PewterGymGuyWinText
	closetext
	loadmovesprites
	end
; 0x1a28c0

MapPewterGymSignpost1Script: ; 0x1a28c0
	checkbit2 $0023
	iftrue UnknownScript_0x1a28c9
	jumpstd $002d
; 0x1a28c9

UnknownScript_0x1a28c9: ; 0x1a28c9
	trainertotext BROCK, 1, $1
	jumpstd $002e
; 0x1a28d0

UnknownText_0x1a28d0: ; 0x1a28d0
	db $0, "BROCK: Wow, it's", $4f
	db "not often that we", $51
	db "get a challenger", $4f
	db "from JOHTO.", $51
	db "I'm BROCK, the", $4f
	db "PEWTER GYM LEADER.", $51
	db "I'm an expert on", $4f
	db "rock-type #MON.", $51
	db "My #MON are im-", $4f
	db "pervious to most", $51
	db "physical attacks.", $4f
	db "You'll have a hard", $51
	db "time inflicting", $4f
	db "any damage.", $51
	db "Come on!", $57
; 0x1a29bb

UnknownText_0x1a29bb: ; 0x1a29bb
	db $0, "BROCK: Your #-", $4f
	db "MON's powerful at-", $55
	db "tacks overcame my", $55
	db "rock-hard defense…", $51
	db "You're stronger", $4f
	db "than I expected…", $51
	db "Go ahead--take", $4f
	db "this BADGE.", $57
; 0x1a2a3d

UnknownText_0x1a2a3d: ; 0x1a2a3d
	db $0, $52, " received", $4f
	db "BOULDERBADGE.", $57
; 0x1a2a57

UnknownText_0x1a2a57: ; 0x1a2a57
	db $0, "BROCK: ", $14, ",", $4f
	db "thanks. I enjoyed", $51
	db "battling you, even", $4f
	db "though I am a bit", $55
	db "upset.", $51
	db "That BOULDERBADGE", $4f
	db "will make your", $51
	db "#MON even more", $4f
	db "powerful.", $57
; 0x1a2ada

UnknownText_0x1a2ada: ; 0x1a2ada
	db $0, "BROCK: The world", $4f
	db "is huge. There are", $51
	db "still many strong", $4f
	db "trainers like you.", $51
	db "Just wait and see.", $4f
	db "I'm going to be-", $55
	db "come a lot strong-", $55
	db "er too.", $57
; 0x1a2b62

CamperJerrySeenText: ; 0x1a2b62
	db $0, "The trainers of", $4f
	db "this GYM use rock-", $55
	db "type #MON.", $51
	db "The rock-type has", $4f
	db "high DEFENSE.", $51
	db "Battles could end", $4f
	db "up going a long", $51
	db "time. Are you", $4f
	db "ready for this?", $57
; 0x1a2bf1

CamperJerryBeatenText: ; 0x1a2bf1
	db $0, "I have to win", $4f
	db "these battles…", $57
; 0x1a2c0f

UnknownText_0x1a2c0f: ; 0x1a2c0f
	db $0, "Hey, you! Trainer", $4f
	db "from JOHTO! BROCK", $51
	db "is tough. He'll", $4f
	db "punish you if you", $51
	db "don't take him", $4f
	db "seriously.", $57
; 0x1a2c6e

PewterGymGuyText: ; 0x1a2c6e
	db $0, "Yo! CHAMP in", $4f
	db "making! You're", $51
	db "really rocking.", $4f
	db "Are you battling", $51
	db "the GYM LEADERS of", $4f
	db "KANTO?", $51
	db "They're strong and", $4f
	db "dedicated people,", $51
	db "just like JOHTO's", $4f
	db "GYM LEADERS.", $57
; 0x1a2d07

PewterGymGuyWinText: ; 0x1a2d07
	db $0, "Yo! CHAMP in", $4f
	db "making! That GYM", $51
	db "didn't give you", $4f
	db "much trouble.", $51
	db "The way you took", $4f
	db "charge was really", $51
	db "inspiring. I mean", $4f
	db "that seriously.", $57
; 0x1a2d88

PewterGym_MapEventHeader: ; 0x1a2d88
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $d, $4, 2, GROUP_PEWTER_CITY, MAP_PEWTER_CITY
	warp_def $d, $5, 2, GROUP_PEWTER_CITY, MAP_PEWTER_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 11, 2, $0, MapPewterGymSignpost1Script
	signpost 11, 7, $0, MapPewterGymSignpost1Script

	; people-events
	db 3
	person_event $1a, 5, 9, $6, $0, 255, 255, $b0, 0, UnknownScript_0x1a2864, $ffff
	person_event $27, 9, 6, $9, $0, 255, 255, $a2, 3, TrainerCamperJerry, $ffff
	person_event $48, 15, 10, $6, $0, 255, 255, $90, 1, PewterGymGuyScript, $ffff
; 0x1a2dc9

PewterMart_MapScriptHeader: ; 0x1a2dc9
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a2dcb

UnknownScript_0x1a2dcb: ; 0x1a2dcb
	loadfont
	pokemart $0, $0013
	loadmovesprites
	end
; 0x1a2dd2

UnknownScript_0x1a2dd2: ; 0x1a2dd2
	jumptextfaceplayer UnknownText_0x1a2dd8
; 0x1a2dd5

UnknownScript_0x1a2dd5: ; 0x1a2dd5
	jumptextfaceplayer UnknownText_0x1a2e3a
; 0x1a2dd8

UnknownText_0x1a2dd8: ; 0x1a2dd8
	db $0, "Hi! Check out my", $4f
	db "GYARADOS!", $51
	db "I raised it from a", $4f
	db "MAGIKARP. I can't", $51
	db "believe how strong", $4f
	db "it has become.", $57
; 0x1a2e3a

UnknownText_0x1a2e3a: ; 0x1a2e3a
	db $0, "There once was a", $4f
	db "weird old man who", $55
	db "sold MAGIKARP.", $51
	db "He was saying the", $4f
	db "MAGIKARP from the", $51
	db "LAKE OF RAGE were", $4f
	db "excellent.", $57
; 0x1a2eae

PewterMart_MapEventHeader: ; 0x1a2eae
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 3, GROUP_PEWTER_CITY, MAP_PEWTER_CITY
	warp_def $7, $3, 3, GROUP_PEWTER_CITY, MAP_PEWTER_CITY

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $39, 7, 5, $9, $0, 255, 255, $0, 0, UnknownScript_0x1a2dcb, $ffff
	person_event $27, 6, 13, $5, $2, 255, 255, $0, 0, UnknownScript_0x1a2dd2, $ffff
	person_event $2b, 10, 10, $3, $0, 255, 255, $80, 0, UnknownScript_0x1a2dd5, $ffff
; 0x1a2ee5

PewterPokeCenter1F_MapScriptHeader: ; 0x1a2ee5
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a2ee7

UnknownScript_0x1a2ee7: ; 0x1a2ee7
	jumpstd $0000
; 0x1a2eea

UnknownScript_0x1a2eea: ; 0x1a2eea
	jumptextfaceplayer UnknownText_0x1a2f01
; 0x1a2eed

UnknownScript_0x1a2eed: ; 0x1a2eed
	loadfont
	2writetext UnknownText_0x1a2f5d
	cry JIGGLYPUFF
	closetext
	loadmovesprites
	end
; 0x1a2ef7

UnknownScript_0x1a2ef7: ; 0x1a2ef7
	jumptextfaceplayer UnknownText_0x1a2f75
; 0x1a2efa

UnknownScript_0x1a2efa: ; 0x1a2efa
	faceplayer
	loadfont
	trade $4
	closetext
	loadmovesprites
	end
; 0x1a2f01

UnknownText_0x1a2f01: ; 0x1a2f01
	db $0, "…Yeah, and the", $4f
	db "GYM in CINNABAR's", $51
	db "gone. I was really", $4f
	db "amazed.", $51
	db "…Yes? I'm on the", $4f
	db "phone. Go away!", $57
; 0x1a2f5d

UnknownText_0x1a2f5d: ; 0x1a2f5d
	db $0, "JIGGLYPUFF: Puu", $4f
	db "pupuu.", $57
; 0x1a2f75

UnknownText_0x1a2f75: ; 0x1a2f75
	db $0, "Most #MON get", $4f
	db "drowsy if they", $51
	db "hear a JIGGLYPUFF", $4f
	db "singing.", $51
	db "There are several", $4f
	db "moves that can be", $51
	db "used only while a", $4f
	db "#MON is asleep.", $57
; 0x1a2ff4

PewterPokeCenter1F_MapEventHeader: ; 0x1a2ff4
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 4, GROUP_PEWTER_CITY, MAP_PEWTER_CITY
	warp_def $7, $4, 4, GROUP_PEWTER_CITY, MAP_PEWTER_CITY
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 5
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x1a2ee7, $ffff
	person_event $29, 10, 12, $6, $0, 255, 255, $a0, 0, UnknownScript_0x1a2eea, $ffff
	person_event $94, 7, 5, $16, $0, 255, 255, $0, 0, UnknownScript_0x1a2eed, $ffff
	person_event $25, 7, 6, $6, $0, 255, 255, $90, 0, UnknownScript_0x1a2ef7, $ffff
	person_event $2d, 6, 11, $6, $0, 255, 255, $80, 0, UnknownScript_0x1a2efa, $ffff
; 0x1a304a

PewterPokeCEnter2FBeta_MapScriptHeader: ; 0x1a304a
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a304c

PewterPokeCEnter2FBeta_MapEventHeader: ; 0x1a304c
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 3, GROUP_PEWTER_POKECENTER_1F, MAP_PEWTER_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x1a3057

PewterSnoozeSpeechHouse_MapScriptHeader: ; 0x1a3057
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a3059

UnknownScript_0x1a3059: ; 0x1a3059
	jumptextfaceplayer UnknownText_0x1a305f
; 0x1a305c

MapPewterSnoozeSpeechHouseSignpost1Script: ; 0x1a305c
	jumpstd $0002
; 0x1a305f

UnknownText_0x1a305f: ; 0x1a305f
	db $0, "I like snoozing", $4f
	db "with the radio on…", $55
	db "…Zzzz…", $57
; 0x1a308a

PewterSnoozeSpeechHouse_MapEventHeader: ; 0x1a308a
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 5, GROUP_PEWTER_CITY, MAP_PEWTER_CITY
	warp_def $7, $3, 5, GROUP_PEWTER_CITY, MAP_PEWTER_CITY

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapPewterSnoozeSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapPewterSnoozeSpeechHouseSignpost1Script

	; people-events
	db 1
	person_event $2f, 7, 9, $8, $0, 255, 255, $90, 0, UnknownScript_0x1a3059, $ffff
; 0x1a30b1

SECTION "bank69",DATA,BANK[$69]

EcruteakCity_MapScriptHeader: ; 0x1a4000
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1a4005
; 0x1a4005

UnknownScript_0x1a4005: ; 0x1a4005
	setbit2 $0048
	return
; 0x1a4009

UnknownScript_0x1a4009: ; 0x1a4009
	jumptextfaceplayer UnknownText_0x1a4105
; 0x1a400c

UnknownScript_0x1a400c: ; 0x1a400c
	jumptextfaceplayer UnknownText_0x1a4147
; 0x1a400f

UnknownScript_0x1a400f: ; 0x1a400f
	jumptextfaceplayer UnknownText_0x1a43cb
; 0x1a4012

UnknownScript_0x1a4012: ; 0x1a4012
	jumptextfaceplayer UnknownText_0x1a41db
; 0x1a4015

UnknownScript_0x1a4015: ; 0x1a4015
	faceplayer
	loadfont
	checkbit1 $007b
	iftrue UnknownScript_0x1a4023
	2writetext UnknownText_0x1a421a
	closetext
	loadmovesprites
	end
; 0x1a4023

UnknownScript_0x1a4023: ; 0x1a4023
	2writetext UnknownText_0x1a4269
	closetext
	loadmovesprites
	end
; 0x1a4029

UnknownScript_0x1a4029: ; 0x1a4029
	faceplayer
	loadfont
	checkbit1 $0020
	iftrue UnknownScript_0x1a4037
	2writetext UnknownText_0x1a42ac
	closetext
	loadmovesprites
	end
; 0x1a4037

UnknownScript_0x1a4037: ; 0x1a4037
	2writetext UnknownText_0x1a4325
	closetext
	loadmovesprites
	end
; 0x1a403d

UnknownScript_0x1a403d: ; 0x1a403d
	jumptextfaceplayer UnknownText_0x1a4386
; 0x1a4040

MapEcruteakCitySignpost0Script: ; 0x1a4040
	jumptext UnknownText_0x1a44d1
; 0x1a4043

MapEcruteakCitySignpost1Script: ; 0x1a4043
	jumptext UnknownText_0x1a4513
; 0x1a4046

MapEcruteakCitySignpost2Script: ; 0x1a4046
	jumptext UnknownText_0x1a4548
; 0x1a4049

MapEcruteakCitySignpost3Script: ; 0x1a4049
	jumptext UnknownText_0x1a458c
; 0x1a404c

MapEcruteakCitySignpost4Script: ; 0x1a404c
	jumptext UnknownText_0x1a45a4
; 0x1a404f

MapEcruteakCitySignpost5Script: ; 0x1a404f
	jumpstd $0010
; 0x1a4052

MapEcruteakCitySignpost6Script: ; 0x1a4052
	jumpstd $0011
; 0x1a4055

MapEcruteakCitySignpostItem7: ; 0x1a4055
	dw $00b4
	db HYPER_POTION
	
; 0x1a4058

UnusedMissingDaughterText: ; 0x1a4058
; This text is neither used nor referenced in the final game.
	db $0, "Oh, no. Oh, no…",$51
	db "My daughter is", $4f
	db "missing.", $51
	db "No… She couldn't", $4f
	db "have gone to the", $55
	db "BURNED TOWER.", $51
	db "I told her not to", $4f
	db "go near it…", $51
	db "People seem to", $4f
	db "disappear there…", $51
	db "Oh, what should I", $4f
	db "do…?", $57

UnknownText_0x1a4105: ; 0x1a4105
	db $0, "ECRUTEAK used to", $4f
	db "have two towers:", $51
	db "one each in the", $4f
	db "east and west.", $57
; 0x1a4147

UnknownText_0x1a4147: ; 0x1a4147
	db $0, "Ah, child.", $4f
	db "Have you learned", $51
	db "to dance like the", $4f
	db "KIMONO GIRLS?", $51
	db "If you go to their", $4f
	db "DANCE THEATER, an", $51
	db "odd old man will", $4f
	db "give you something", $55
	db "nice, I hear.", $57
; 0x1a41db

UnknownText_0x1a41db: ; 0x1a41db
	db $0, "I'm going to prac-", $4f
	db "tice at the DANCE", $51
	db "THEATER. Care to", $4f
	db "join me?", $57
; 0x1a421a

UnknownText_0x1a421a: ; 0x1a421a
	db $0, "The tower that", $4f
	db "used to be here…", $51
	db "My grandma told me", $4f
	db "it used to be much", $55
	db "taller.", $57
; 0x1a4269

UnknownText_0x1a4269: ; 0x1a4269
	db $0, "Three big #MON", $4f
	db "ran off in differ-", $55
	db "ent directions.", $55
	db "What were they?", $57
; 0x1a42ac

UnknownText_0x1a42ac: ; 0x1a42ac
	db $0, "I heard a rumor", $4f
	db "about OLIVINE", $55
	db "LIGHTHOUSE.", $51
	db "The #MON that", $4f
	db "serves as the", $51
	db "beacon fell ill.", $4f
	db "Sounds like they", $55
	db "are in trouble.", $57
; 0x1a4325

UnknownText_0x1a4325: ; 0x1a4325
	db $0, "The #MON at", $4f
	db "OLIVINE LIGHTHOUSE", $55
	db "has been cured.", $51
	db "Boats can safely", $4f
	db "sail out to sea at", $55
	db "night again.", $57
; 0x1a4386

UnknownText_0x1a4386: ; 0x1a4386
	db $0, "I hear #MON are", $4f
	db "rampaging at the", $51
	db "LAKE OF RAGE. I'd", $4f
	db "like to see that.", $57
; 0x1a43cb

UnknownText_0x1a43cb: ; 0x1a43cb
	db $0, "In the distant", $4f
	db "past…", $51
	db "This tower burned", $4f
	db "in a fire. Three", $51
	db "nameless #MON", $4f
	db "perished in it.", $51
	db "A rainbow-colored", $4f
	db "#MON descended", $51
	db "from the sky and", $4f
	db "resurrected them…", $51
	db "It's a legend that", $4f
	db "has been passed", $51
	db "down by ECRUTEAK", $4f
	db "GYM LEADERS.", $51
	db "Me?", $51
	db "I was a trainer", $4f
	db "way back when.", $55
	db "Hohoho!", $57
; 0x1a44d1

UnknownText_0x1a44d1: ; 0x1a44d1
	db $0, "ECRUTEAK CITY", $4f
	db "A Historical City", $51
	db "Where the Past", $4f
	db "Meets the Present", $57
; 0x1a4513

UnknownText_0x1a4513: ; 0x1a4513
	db $0, "TIN TOWER", $51
	db "A legendary #-", $4f
	db "MON is said to", $55
	db "roost here.", $57
; 0x1a4548

UnknownText_0x1a4548: ; 0x1a4548
	db $0, "ECRUTEAK CITY", $4f
	db "#MON GYM", $55
	db "LEADER: MORTY", $51
	db "The Mystic Seer of", $4f
	db "the Future", $57
; 0x1a458c

UnknownText_0x1a458c: ; 0x1a458c
	db $0, "ECRUTEAK DANCE", $4f
	db "THEATER", $57
; 0x1a45a4

UnknownText_0x1a45a4: ; 0x1a45a4
	db $0, "BURNED TOWER", $51
	db "It was destroyed", $4f
	db "by a mysterious", $55
	db "fire.", $51
	db "Please stay away,", $4f
	db "as it is unsafe.", $57
; 0x1a45fc

EcruteakCity_MapEventHeader: ; 0x1a45fc
	; filler
	db 0, 0

	; warps
	db 15
	warp_def $1a, $23, 1, GROUP_ROUTE_42_ECRUTEAK_GATE, MAP_ROUTE_42_ECRUTEAK_GATE
	warp_def $1b, $23, 2, GROUP_ROUTE_42_ECRUTEAK_GATE, MAP_ROUTE_42_ECRUTEAK_GATE
	warp_def $b, $12, 1, GROUP_ECRUTEAK_HOUSE, MAP_ECRUTEAK_HOUSE
	warp_def $2, $14, 1, GROUP_WISE_TRIOS_ROOM, MAP_WISE_TRIOS_ROOM
	warp_def $3, $14, 2, GROUP_WISE_TRIOS_ROOM, MAP_WISE_TRIOS_ROOM
	warp_def $1b, $17, 1, GROUP_ECRUTEAK_POKECENTER_1F, MAP_ECRUTEAK_POKECENTER_1F
	warp_def $15, $5, 1, GROUP_ECRUTEAK_LUGIA_SPEECH_HOUSE, MAP_ECRUTEAK_LUGIA_SPEECH_HOUSE
	warp_def $15, $17, 1, GROUP_DANCE_THEATRE, MAP_DANCE_THEATRE
	warp_def $15, $1d, 2, GROUP_ECRUTEAK_MART, MAP_ECRUTEAK_MART
	warp_def $1b, $6, 1, GROUP_ECRUTEAK_GYM, MAP_ECRUTEAK_GYM
	warp_def $1b, $d, 1, GROUP_ECRUTEAK_ITEMFINDER_HOUSE, MAP_ECRUTEAK_ITEMFINDER_HOUSE
	warp_def $7, $25, 1, GROUP_TIN_TOWER_1F, MAP_TIN_TOWER_1F
	warp_def $5, $5, 1, GROUP_BURNED_TOWER_1F, MAP_BURNED_TOWER_1F
	warp_def $12, $0, 3, GROUP_ROUTE_38_ECRUTEAK_GATE, MAP_ROUTE_38_ECRUTEAK_GATE
	warp_def $13, $0, 4, GROUP_ROUTE_38_ECRUTEAK_GATE, MAP_ROUTE_38_ECRUTEAK_GATE

	; xy triggers
	db 0

	; signposts
	db 8
	signpost 21, 15, $0, MapEcruteakCitySignpost0Script
	signpost 10, 38, $0, MapEcruteakCitySignpost1Script
	signpost 28, 8, $0, MapEcruteakCitySignpost2Script
	signpost 21, 21, $0, MapEcruteakCitySignpost3Script
	signpost 10, 2, $0, MapEcruteakCitySignpost4Script
	signpost 27, 24, $0, MapEcruteakCitySignpost5Script
	signpost 21, 30, $0, MapEcruteakCitySignpost6Script
	signpost 14, 23, $7, MapEcruteakCitySignpostItem7

	; people-events
	db 7
	person_event $2f, 19, 22, $2, $11, 255, 255, $0, 0, UnknownScript_0x1a4009, $ffff
	person_event $2f, 25, 24, $3, $0, 255, 255, $0, 0, UnknownScript_0x1a400c, $ffff
	person_event $28, 33, 25, $5, $2, 255, 255, $90, 0, UnknownScript_0x1a4012, $ffff
	person_event $28, 13, 7, $7, $0, 255, 255, $0, 0, UnknownScript_0x1a4015, $ffff
	person_event $3a, 26, 13, $5, $1, 255, 255, $a0, 0, UnknownScript_0x1a4029, $ffff
	person_event $27, 18, 14, $2, $11, 255, 255, $80, 0, UnknownScript_0x1a403d, $ffff
	person_event $2f, 11, 7, $2, $11, 255, 255, $a0, 0, UnknownScript_0x1a400f, $07a9
; 0x1a46d0

BlackthornCity_MapScriptHeader: ; 0x1a46d0
	; trigger count
	db 0

	; callback count
	db 2

	; callbacks

	dbw 5, UnknownScript_0x1a46d8

	dbw 2, UnknownScript_0x1a46dc
; 0x1a46d8

UnknownScript_0x1a46d8: ; 0x1a46d8
	setbit2 $004b
	return
; 0x1a46dc

UnknownScript_0x1a46dc: ; 0x1a46dc
	checkcode $b
	if_equal SATURDAY, UnknownScript_0x1a46e5
	disappear $9
	return
; 0x1a46e5

UnknownScript_0x1a46e5: ; 0x1a46e5
	appear $9
	return
; 0x1a46e8

UnknownScript_0x1a46e8: ; 0x1a46e8
	faceplayer
	loadfont
	checkbit1 $04c4
	iftrue UnknownScript_0x1a4702
	checkbit1 $0021
	iftrue UnknownScript_0x1a46fc
	2writetext UnknownText_0x1a477a
	closetext
	loadmovesprites
	end
; 0x1a46fc

UnknownScript_0x1a46fc: ; 0x1a46fc
	2writetext UnknownText_0x1a47f3
	closetext
	loadmovesprites
	end
; 0x1a4702

UnknownScript_0x1a4702: ; 0x1a4702
	2writetext UnknownText_0x1a4865
	closetext
	loadmovesprites
	end
; 0x1a4708

UnknownScript_0x1a4708: ; 0x1a4708
	jumptextfaceplayer UnknownText_0x1a48c3
; 0x1a470b

UnknownScript_0x1a470b: ; 0x1a470b
	jumptextfaceplayer UnknownText_0x1a48fb
; 0x1a470e

UnknownScript_0x1a470e: ; 0x1a470e
	faceplayer
	loadfont
	checkbit1 $0021
	iftrue UnknownScript_0x1a471c
	2writetext UnknownText_0x1a494a
	closetext
	loadmovesprites
	end
; 0x1a471c

UnknownScript_0x1a471c: ; 0x1a471c
	2writetext UnknownText_0x1a4983
	closetext
	loadmovesprites
	end
; 0x1a4722

UnknownScript_0x1a4722: ; 0x1a4722
	jumptextfaceplayer UnknownText_0x1a49bd
; 0x1a4725

UnknownScript_0x1a4725: ; 0x1a4725
	jumptextfaceplayer UnknownText_0x1a49f1
; 0x1a4728

UnknownScript_0x1a4728: ; 0x1a4728
	jumptextfaceplayer UnknownText_0x1a4b1e
; 0x1a472b

UnknownScript_0x1a472b: ; 0x1a472b
	faceplayer
	loadfont
	checkbit1 $006d
	iftrue UnknownScript_0x1a4759
	checkcode $b
	if_not_equal SATURDAY, UnknownScript_0x1a475f
	checkbit1 $006c
	iftrue UnknownScript_0x1a4746
	2writetext UnknownText_0x1a4a27
	keeptextopen
	setbit1 $006c
UnknownScript_0x1a4746: ; 0x1a4746
	2writetext UnknownText_0x1a4a57
	keeptextopen
	verbosegiveitem SPELL_TAG, 1
	iffalse UnknownScript_0x1a475d
	setbit1 $006d
	2writetext UnknownText_0x1a4a6b
	closetext
	loadmovesprites
	end
; 0x1a4759

UnknownScript_0x1a4759: ; 0x1a4759
	2writetext UnknownText_0x1a4ab6
	closetext
UnknownScript_0x1a475d: ; 0x1a475d
	loadmovesprites
	end
; 0x1a475f

UnknownScript_0x1a475f: ; 0x1a475f
	2writetext UnknownText_0x1a4b00
	closetext
	loadmovesprites
	end
; 0x1a4765

MapBlackthornCitySignpost0Script: ; 0x1a4765
	jumptext UnknownText_0x1a4b67
; 0x1a4768

MapBlackthornCitySignpost1Script: ; 0x1a4768
	jumptext UnknownText_0x1a4b91
; 0x1a476b

MapBlackthornCitySignpost2Script: ; 0x1a476b
	jumptext UnknownText_0x1a4bd9
; 0x1a476e

MapBlackthornCitySignpost3Script: ; 0x1a476e
	jumptext UnknownText_0x1a4bef
; 0x1a4771

MapBlackthornCitySignpost4Script: ; 0x1a4771
	jumptext UnknownText_0x1a4c03
; 0x1a4774

MapBlackthornCitySignpost6Script: ; 0x1a4774
	jumpstd $0010
; 0x1a4777

MapBlackthornCitySignpost5Script: ; 0x1a4777
	jumpstd $0011
; 0x1a477a

UnknownText_0x1a477a: ; 0x1a477a
	db $0, "I am sorry.", $51
	db "CLAIR, our GYM", $4f
	db "LEADER, entered", $51
	db "the DRAGON'S DEN", $4f
	db "behind the GYM.", $51
	db "I have no idea", $4f
	db "when our LEADER", $55
	db "will return.", $57
; 0x1a47f3

UnknownText_0x1a47f3: ; 0x1a47f3
	db $0, "CLAIR, our GYM", $4f
	db "LEADER, is waiting", $55
	db "for you.", $51
	db "However, it would", $4f
	db "be impossible for", $51
	db "a run-of-the-mill", $4f
	db "trainer to win.", $57
; 0x1a4865

UnknownText_0x1a4865: ; 0x1a4865
	db $0, "You defeated", $4f
	db "CLAIR?", $51
	db "That's amazing!", $51
	db "I've never heard", $4f
	db "of her losing to", $51
	db "anyone other than", $4f
	db "LANCE.", $57
; 0x1a48c3

UnknownText_0x1a48c3: ; 0x1a48c3
	db $0, "No. Only chosen", $4f
	db "trainers may train", $51
	db "here.", $4f
	db "Please leave.", $57
; 0x1a48fb

UnknownText_0x1a48fb: ; 0x1a48fb
	db $0, "If CLAIR allows", $4f
	db "it, her grand-", $55
	db "father--our MASTER", $55
	db "--will also.", $51
	db "You may enter.", $57
; 0x1a494a

UnknownText_0x1a494a: ; 0x1a494a
	db $0, "My radio's busted?", $4f
	db "Lately, I only get", $55
	db "this weird signal.", $57
; 0x1a4983

UnknownText_0x1a4983: ; 0x1a4983
	db $0, "Arooo! Voices in", $4f
	db "my head!", $51
	db "Huh? I'm listening", $4f
	db "to my radio!", $57
; 0x1a49bd

UnknownText_0x1a49bd: ; 0x1a49bd
	db $0, "Are you going to", $4f
	db "make your #MON", $55
	db "forget some moves?", $57
; 0x1a49f1

UnknownText_0x1a49f1: ; 0x1a49f1
	db $0, "Dragon masters all", $4f
	db "come from the city", $55
	db "of BLACKTHORN.", $57
; 0x1a4a27

UnknownText_0x1a4a27: ; 0x1a4a27
	db $0, "SANTOS: …", $51
	db "It's Saturday…", $51
	db "I'm SANTOS of", $4f
	db "Saturday…", $57
; 0x1a4a57

UnknownText_0x1a4a57: ; 0x1a4a57
	db $0, "You can have this…", $57
; 0x1a4a6b

UnknownText_0x1a4a6b: ; 0x1a4a6b
	db $0, "SANTOS: …", $51
	db "SPELL TAG…", $51
	db "Ghost-type moves", $4f
	db "get stronger…", $51
	db "It will frighten", $4f
	db "you…", $57
; 0x1a4ab6

UnknownText_0x1a4ab6: ; 0x1a4ab6
	db $0, "SANTOS: …", $51
	db "See you again on", $4f
	db "another Saturday…", $51
	db "I won't have any", $4f
	db "more gifts…", $57
; 0x1a4b00

UnknownText_0x1a4b00: ; 0x1a4b00
	db $0, "SANTOS: Today's", $4f
	db "not Saturday…", $57
; 0x1a4b1e

UnknownText_0x1a4b1e: ; 0x1a4b1e
	db $0, "Wow, you came", $4f
	db "through the ICE", $55
	db "PATH?", $51
	db "You must be a real", $4f
	db "hotshot trainer!", $57
; 0x1a4b67

UnknownText_0x1a4b67: ; 0x1a4b67
	db $0, "BLACKTHORN CITY", $51
	db "A Quiet Mountain", $4f
	db "Retreat", $57
; 0x1a4b91

UnknownText_0x1a4b91: ; 0x1a4b91
	db $0, "BLACKTHORN CITY", $4f
	db "#MON GYM", $55
	db "LEADER: CLAIR", $51
	db "The Blessed User", $4f
	db "of Dragon #MON", $57
; 0x1a4bd9

UnknownText_0x1a4bd9: ; 0x1a4bd9
	db $0, "MOVE DELETER'S", $4f
	db "HOUSE", $57
; 0x1a4bef

UnknownText_0x1a4bef: ; 0x1a4bef
	db $0, "DRAGON'S DEN", $4f
	db "AHEAD", $57
; 0x1a4c03

UnknownText_0x1a4c03: ; 0x1a4c03
	db $0, "TRAINER TIPS", $51
	db "A #MON holding", $4f
	db "a MIRACLEBERRY", $51
	db "will cure itself", $4f
	db "of any status", $55
	db "problem.", $57
; 0x1a4c57

BlackthornCity_MapEventHeader: ; 0x1a4c57
	; filler
	db 0, 0

	; warps
	db 8
	warp_def $b, $12, 1, GROUP_BLACKTHORN_GYM_1F, MAP_BLACKTHORN_GYM_1F
	warp_def $15, $d, 1, GROUP_BLACKTHORN_DRAGON_SPEECH_HOUSE, MAP_BLACKTHORN_DRAGON_SPEECH_HOUSE
	warp_def $17, $1d, 1, GROUP_BLACKTHORN_DODRIO_TRADE_HOUSE, MAP_BLACKTHORN_DODRIO_TRADE_HOUSE
	warp_def $1d, $f, 2, GROUP_BLACKTHORN_MART, MAP_BLACKTHORN_MART
	warp_def $1d, $15, 1, GROUP_BLACKTHORN_POKECENTER_1F, MAP_BLACKTHORN_POKECENTER_1F
	warp_def $1f, $9, 1, GROUP_MOVE_DELETERS_HOUSE, MAP_MOVE_DELETERS_HOUSE
	warp_def $9, $24, 2, GROUP_ICE_PATH_1F, MAP_ICE_PATH_1F
	warp_def $1, $14, 1, GROUP_DRAGONS_DEN_1F, MAP_DRAGONS_DEN_1F

	; xy triggers
	db 0

	; signposts
	db 7
	signpost 24, 34, $0, MapBlackthornCitySignpost0Script
	signpost 13, 17, $0, MapBlackthornCitySignpost1Script
	signpost 31, 7, $0, MapBlackthornCitySignpost2Script
	signpost 3, 21, $0, MapBlackthornCitySignpost3Script
	signpost 25, 5, $0, MapBlackthornCitySignpost4Script
	signpost 29, 16, $0, MapBlackthornCitySignpost5Script
	signpost 29, 22, $0, MapBlackthornCitySignpost6Script

	; people-events
	db 9
	person_event $2b, 16, 22, $6, $0, 255, 255, $80, 0, UnknownScript_0x1a46e8, $06e3
	person_event $2b, 16, 23, $6, $0, 255, 255, $80, 0, UnknownScript_0x1a46e8, $06e4
	person_event $2f, 6, 24, $6, $0, 255, 255, $0, 0, UnknownScript_0x1a4708, $074c
	person_event $2f, 6, 25, $8, $0, 255, 255, $0, 0, UnknownScript_0x1a470b, $074d
	person_event $41, 35, 28, $5, $1, 255, 255, $90, 0, UnknownScript_0x1a470e, $ffff
	person_event $24, 29, 13, $5, $2, 255, 255, $80, 0, UnknownScript_0x1a4722, $ffff
	person_event $27, 19, 17, $5, $1, 255, 255, $0, 0, UnknownScript_0x1a4725, $ffff
	person_event $27, 24, 26, $6, $0, 255, 255, $0, 0, UnknownScript_0x1a472b, $075d
	person_event $24, 23, 39, $7, $0, 255, 255, $a0, 0, UnknownScript_0x1a4728, $ffff
; 0x1a4d1d

Route26_MapScriptHeader: ; 0x1a4d1d
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a4d1f

TrainerCooltrainermJake: ; 0x1a4d1f
	; bit/flag number
	dw $550

	; trainer group && trainer id
	db COOLTRAINERM, JAKE

	; text when seen
	dw CooltrainermJakeSeenText

	; text when trainer beaten
	dw CooltrainermJakeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermJakeScript
; 0x1a4d2b

CooltrainermJakeScript: ; 0x1a4d2b
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a4f08
	closetext
	loadmovesprites
	end
; 0x1a4d33

TrainerCooltrainermGaven3: ; 0x1a4d33
	; bit/flag number
	dw $551

	; trainer group && trainer id
	db COOLTRAINERM, GAVEN3

	; text when seen
	dw CooltrainermGaven3SeenText

	; text when trainer beaten
	dw CooltrainermGaven3BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainermGaven3Script
; 0x1a4d3f

CooltrainermGaven3Script: ; 0x1a4d3f
	writecode $17, $b
	talkaftercancel
	loadfont
	checkbit2 $0067
	iftrue UnknownScript_0x1a4d79
	checkcellnum $b
	iftrue UnknownScript_0x1a4dcb
	checkbit1 $026b
	iftrue UnknownScript_0x1a4d62
	2writetext UnknownText_0x1a4fe4
	keeptextopen
	setbit1 $026b
	2call UnknownScript_0x1a4dbf
	2jump UnknownScript_0x1a4d65
; 0x1a4d62

UnknownScript_0x1a4d62: ; 0x1a4d62
	2call UnknownScript_0x1a4dc3
UnknownScript_0x1a4d65: ; 0x1a4d65
	askforphonenumber $b
	if_equal $1, UnknownScript_0x1a4dd3
	if_equal $2, UnknownScript_0x1a4dcf
	trainertotext COOLTRAINERM, GAVEN3, $0
	2call UnknownScript_0x1a4dc7
	2jump UnknownScript_0x1a4dcb
; 0x1a4d79

UnknownScript_0x1a4d79: ; 0x1a4d79
	2call UnknownScript_0x1a4dd7
	winlosstext CooltrainermGaven3BeatenText, $0000
	copybytetovar $d9f5
	if_equal $2, UnknownScript_0x1a4d90
	if_equal $1, UnknownScript_0x1a4d96
	if_equal $0, UnknownScript_0x1a4d9c
UnknownScript_0x1a4d90: ; 0x1a4d90
	checkbit1 $00cd
	iftrue UnknownScript_0x1a4db6
UnknownScript_0x1a4d96: ; 0x1a4d96
	checkbit1 $0044
	iftrue UnknownScript_0x1a4da9
UnknownScript_0x1a4d9c: ; 0x1a4d9c
	loadtrainer COOLTRAINERM, GAVEN3
	startbattle
	returnafterbattle
	loadvar $d9f5, $1
	clearbit2 $0067
	end
; 0x1a4da9

UnknownScript_0x1a4da9: ; 0x1a4da9
	loadtrainer COOLTRAINERM, GAVEN1
	startbattle
	returnafterbattle
	loadvar $d9f5, $2
	clearbit2 $0067
	end
; 0x1a4db6

UnknownScript_0x1a4db6: ; 0x1a4db6
	loadtrainer COOLTRAINERM, GAVEN2
	startbattle
	returnafterbattle
	clearbit2 $0067
	end
; 0x1a4dbf

UnknownScript_0x1a4dbf: ; 0x1a4dbf
	jumpstd $0019
	end
; 0x1a4dc3

UnknownScript_0x1a4dc3: ; 0x1a4dc3
	jumpstd $001a
	end
; 0x1a4dc7

UnknownScript_0x1a4dc7: ; 0x1a4dc7
	jumpstd $001b
	end
; 0x1a4dcb

UnknownScript_0x1a4dcb: ; 0x1a4dcb
	jumpstd $001c
	end
; 0x1a4dcf

UnknownScript_0x1a4dcf: ; 0x1a4dcf
	jumpstd $001d
	end
; 0x1a4dd3

UnknownScript_0x1a4dd3: ; 0x1a4dd3
	jumpstd $001e
	end
; 0x1a4dd7

UnknownScript_0x1a4dd7: ; 0x1a4dd7
	jumpstd $001f
	end
; 0x1a4ddb

TrainerCooltrainerfJoyce: ; 0x1a4ddb
	; bit/flag number
	dw $562

	; trainer group && trainer id
	db COOLTRAINERF, JOYCE

	; text when seen
	dw CooltrainerfJoyceSeenText

	; text when trainer beaten
	dw CooltrainerfJoyceBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfJoyceScript
; 0x1a4de7

CooltrainerfJoyceScript: ; 0x1a4de7
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a50d7
	closetext
	loadmovesprites
	end
; 0x1a4def

TrainerCooltrainerfBeth1: ; 0x1a4def
	; bit/flag number
	dw $563

	; trainer group && trainer id
	db COOLTRAINERF, BETH1

	; text when seen
	dw CooltrainerfBeth1SeenText

	; text when trainer beaten
	dw CooltrainerfBeth1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfBeth1Script
; 0x1a4dfb

CooltrainerfBeth1Script: ; 0x1a4dfb
	writecode $17, $c
	talkaftercancel
	loadfont
	checkbit2 $0068
	iftrue UnknownScript_0x1a4e35
	checkcellnum $c
	iftrue UnknownScript_0x1a4e87
	checkbit1 $026d
	iftrue UnknownScript_0x1a4e1e
	2writetext UnknownText_0x1a51d9
	keeptextopen
	setbit1 $026d
	2call UnknownScript_0x1a4e7b
	2jump UnknownScript_0x1a4e21
; 0x1a4e1e

UnknownScript_0x1a4e1e: ; 0x1a4e1e
	2call UnknownScript_0x1a4e7f
UnknownScript_0x1a4e21: ; 0x1a4e21
	askforphonenumber $c
	if_equal $1, UnknownScript_0x1a4e8f
	if_equal $2, UnknownScript_0x1a4e8b
	trainertotext COOLTRAINERF, BETH1, $0
	2call UnknownScript_0x1a4e83
	2jump UnknownScript_0x1a4e87
; 0x1a4e35

UnknownScript_0x1a4e35: ; 0x1a4e35
	2call UnknownScript_0x1a4e93
	winlosstext CooltrainerfBeth1BeatenText, $0000
	copybytetovar $d9f6
	if_equal $2, UnknownScript_0x1a4e4c
	if_equal $1, UnknownScript_0x1a4e52
	if_equal $0, UnknownScript_0x1a4e58
UnknownScript_0x1a4e4c: ; 0x1a4e4c
	checkbit1 $00cd
	iftrue UnknownScript_0x1a4e72
UnknownScript_0x1a4e52: ; 0x1a4e52
	checkbit1 $0044
	iftrue UnknownScript_0x1a4e65
UnknownScript_0x1a4e58: ; 0x1a4e58
	loadtrainer COOLTRAINERF, BETH1
	startbattle
	returnafterbattle
	loadvar $d9f6, $1
	clearbit2 $0068
	end
; 0x1a4e65

UnknownScript_0x1a4e65: ; 0x1a4e65
	loadtrainer COOLTRAINERF, BETH2
	startbattle
	returnafterbattle
	loadvar $d9f6, $2
	clearbit2 $0068
	end
; 0x1a4e72

UnknownScript_0x1a4e72: ; 0x1a4e72
	loadtrainer COOLTRAINERF, BETH3
	startbattle
	returnafterbattle
	clearbit2 $0068
	end
; 0x1a4e7b

UnknownScript_0x1a4e7b: ; 0x1a4e7b
	jumpstd $0023
	end
; 0x1a4e7f

UnknownScript_0x1a4e7f: ; 0x1a4e7f
	jumpstd $0024
	end
; 0x1a4e83

UnknownScript_0x1a4e83: ; 0x1a4e83
	jumpstd $0025
	end
; 0x1a4e87

UnknownScript_0x1a4e87: ; 0x1a4e87
	jumpstd $0026
	end
; 0x1a4e8b

UnknownScript_0x1a4e8b: ; 0x1a4e8b
	jumpstd $0027
	end
; 0x1a4e8f

UnknownScript_0x1a4e8f: ; 0x1a4e8f
	jumpstd $0028
	end
; 0x1a4e93

UnknownScript_0x1a4e93: ; 0x1a4e93
	jumpstd $0029
	end
; 0x1a4e97

TrainerPsychicRichard: ; 0x1a4e97
	; bit/flag number
	dw $442

	; trainer group && trainer id
	db PSYCHIC_T, RICHARD

	; text when seen
	dw PsychicRichardSeenText

	; text when trainer beaten
	dw PsychicRichardBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicRichardScript
; 0x1a4ea3

PsychicRichardScript: ; 0x1a4ea3
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a5278
	closetext
	loadmovesprites
	end
; 0x1a4eab

TrainerFisherScott: ; 0x1a4eab
	; bit/flag number
	dw $462

	; trainer group && trainer id
	db FISHER, SCOTT

	; text when seen
	dw FisherScottSeenText

	; text when trainer beaten
	dw FisherScottBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherScottScript
; 0x1a4eb7

FisherScottScript: ; 0x1a4eb7
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a5326
	closetext
	loadmovesprites
	end
; 0x1a4ebf

MapRoute26Signpost0Script: ; 0x1a4ebf
	jumptext UnknownText_0x1a5364
; 0x1a4ec2

UnknownScript_0x1a4ec2: ; 0x1a4ec2
	fruittree $e
; 0x1a4ec4

ItemFragment_0x1a4ec4: ; 0x1a4ec4
	db MAX_ELIXER, 1
; 0x1a4ec6

CooltrainermJakeSeenText: ; 0x1a4ec6
	db $0, "I'm making my", $4f
	db "final preparations", $51
	db "for the #MON", $4f
	db "LEAGUE.", $57
; 0x1a4efc

CooltrainermJakeBeatenText: ; 0x1a4efc
	db $0, "I blew it!", $57
; 0x1a4f08

UnknownText_0x1a4f08: ; 0x1a4f08
	db $0, "It's going to be", $4f
	db "tough to win at", $55
	db "the LEAGUE.", $51
	db "I need to do some", $4f
	db "more training.", $51
	db "I hear that the", $4f
	db "LEAGUE's ELITE", $51
	db "FOUR are tougher", $4f
	db "than GYM LEADERS.", $57
; 0x1a4f97

CooltrainermGaven3SeenText: ; 0x1a4f97
	db $0, "By experiencing", $4f
	db "tough battles, you", $55
	db "gain power.", $57
; 0x1a4fc7

CooltrainermGaven3BeatenText: ; 0x1a4fc7
	db $0, "Gaah! Life is even", $4f
	db "tougher!", $57
; 0x1a4fe4

UnknownText_0x1a4fe4: ; 0x1a4fe4
	db $0, "To get to #MON", $4f
	db "LEAGUE, you have", $51
	db "to get through", $4f
	db "VICTORY ROAD.", $51
	db "But VICTORY ROAD", $4f
	db "is tough.", $51
	db "Practically nobody", $4f
	db "goes there!", $57
; 0x1a505c

CooltrainerfJoyceSeenText: ; 0x1a505c
	db $0, "Since you've come", $4f
	db "this far, you must", $55
	db "be good.", $51
	db "I'm going to give", $4f
	db "this battle every-", $55
	db "thing I've got!", $57
; 0x1a50bd

CooltrainerfJoyceBeatenText: ; 0x1a50bd
	db $0, "No! I don't", $4f
	db "believe this!", $57
; 0x1a50d7

UnknownText_0x1a50d7: ; 0x1a50d7
	db $0, "I've defeated", $4f
	db "eight GYM LEADERS,", $51
	db "so I was feeling", $4f
	db "confident.", $51
	db "I'll have to try", $4f
	db "harder next time.", $57
; 0x1a5136

CooltrainerfBeth1SeenText: ; 0x1a5136
	db $0, "I lost to a train-", $4f
	db "er named ", $53, ".", $51
	db "He was really", $4f
	db "strong, but…", $51
	db "It was as if he", $4f
	db "absolutely had to", $55
	db "win at any cost.", $51
	db "I felt sorry for", $4f
	db "his #MON.", $57
; 0x1a51bf

CooltrainerfBeth1BeatenText: ; 0x1a51bf
	db $0, "#MON aren't", $4f
	db "tools of war.", $57
; 0x1a51d9

UnknownText_0x1a51d9: ; 0x1a51d9
	db $0, "#MON are in-", $4f
	db "valuable, lifelong", $55
	db "partners.", $57
; 0x1a5204

PsychicRichardSeenText: ; 0x1a5204
	db $0, "Wow, look at all", $4f
	db "those BADGES!", $55
	db "I'm impressed.", $51
	db "But you're not", $4f
	db "satisfied by just", $51
	db "collecting them,", $4f
	db "right?", $57
; 0x1a526a

PsychicRichardBeatenText: ; 0x1a526a
	db $0, "Good battle!", $57
; 0x1a5278

UnknownText_0x1a5278: ; 0x1a5278
	db $0, "People and #MON", $4f
	db "grow from their", $55
	db "experiences.", $51
	db "Don't get lazy and", $4f
	db "complacent.", $57
; 0x1a52c4

FisherScottSeenText: ; 0x1a52c4
	db $0, "I'm feeling great", $4f
	db "today!", $51
	db "I feel like I", $4f
	db "could boot even", $55
	db "the LEAGUE CHAMP!", $57
; 0x1a530d

FisherScottBeatenText: ; 0x1a530d
	db $0, "No! Not in this", $4f
	db "battle!", $57
; 0x1a5326

UnknownText_0x1a5326: ; 0x1a5326
	db $0, "Just like in fish-", $4f
	db "ing, it's all over", $51
	db "in #MON if you", $4f
	db "give up.", $57
; 0x1a5364

UnknownText_0x1a5364: ; 0x1a5364
	db $0, "ROUTE 26", $51
	db "#MON LEAGUE", $4f
	db "RECEPTION GATE", $57
; 0x1a5389

Route26_MapEventHeader: ; 0x1a5389
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $5, $7, 3, GROUP_VICTORY_ROAD_GATE, MAP_VICTORY_ROAD_GATE
	warp_def $39, $f, 1, GROUP_ROUTE_26_HEAL_SPEECH_HOUSE, MAP_ROUTE_26_HEAL_SPEECH_HOUSE
	warp_def $47, $5, 1, GROUP_ROUTE_26_DAY_OF_WEEK_SIBLINGS_HOUSE, MAP_ROUTE_26_DAY_OF_WEEK_SIBLINGS_HOUSE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 6, 8, $0, MapRoute26Signpost0Script

	; people-events
	db 8
	person_event $23, 28, 18, $8, $0, 255, 255, $82, 2, TrainerCooltrainermJake, $ffff
	person_event $23, 42, 13, $8, $0, 255, 255, $82, 3, TrainerCooltrainermGaven3, $ffff
	person_event $24, 60, 14, $a, $0, 255, 255, $82, 3, TrainerCooltrainerfJoyce, $ffff
	person_event $24, 12, 9, $9, $0, 255, 255, $82, 4, TrainerCooltrainerfBeth1, $ffff
	person_event $27, 83, 17, $9, $0, 255, 255, $92, 2, TrainerPsychicRichard, $ffff
	person_event $3a, 96, 14, $6, $0, 255, 255, $a2, 3, TrainerFisherScott, $ffff
	person_event $5d, 58, 18, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a4ec2, $ffff
	person_event $54, 19, 13, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a4ec4, $06aa
; 0x1a540b

Route28_MapScriptHeader: ; 0x1a540b
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a540d

MapRoute28Signpost0Script: ; 0x1a540d
	jumptext UnknownText_0x1a5413
; 0x1a5410

MapRoute28SignpostItem1: ; 0x1a5410
	dw $00a3
	db RARE_CANDY
	
; 0x1a5413

UnknownText_0x1a5413: ; 0x1a5413
	db $0, "ROUTE 28", $57
; 0x1a541d

Route28_MapEventHeader: ; 0x1a541d
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $7, 1, GROUP_ROUTE_28_FAMOUS_SPEECH_HOUSE, MAP_ROUTE_28_FAMOUS_SPEECH_HOUSE
	warp_def $5, $21, 7, GROUP_VICTORY_ROAD_GATE, MAP_VICTORY_ROAD_GATE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 5, 31, $0, MapRoute28Signpost0Script
	signpost 2, 25, $7, MapRoute28SignpostItem1

	; people-events
	db 0
; 0x1a5437

Route31_MapScriptHeader: ; 0x1a5437
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1a543c
; 0x1a543c

UnknownScript_0x1a543c: ; 0x1a543c
	checkbit1 $0040
	iffalse UnknownScript_0x1a5443
	return
; 0x1a5443

UnknownScript_0x1a5443: ; 0x1a5443
	specialphonecall $7
	return
; 0x1a5447

TrainerBug_catcherWade1: ; 0x1a5447
	; bit/flag number
	dw $53b

	; trainer group && trainer id
	db BUG_CATCHER, WADE1

	; text when seen
	dw Bug_catcherWade1SeenText

	; text when trainer beaten
	dw Bug_catcherWade1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherWade1Script
; 0x1a5453

Bug_catcherWade1Script: ; 0x1a5453
	writecode $17, $10
	talkaftercancel
	loadfont
	checkbit2 $006c
	iftrue UnknownScript_0x1a5493
	checkbit2 $007f
	iftrue UnknownScript_0x1a5507
	checkcellnum $10
	iftrue UnknownScript_0x1a5558
	checkbit1 $0275
	iftrue UnknownScript_0x1a547c
	2writetext UnknownText_0x1a5671
	closetext
	setbit1 $0275
	2call UnknownScript_0x1a554c
	2jump UnknownScript_0x1a547f
; 0x1a547c

UnknownScript_0x1a547c: ; 0x1a547c
	2call UnknownScript_0x1a5550
UnknownScript_0x1a547f: ; 0x1a547f
	askforphonenumber $10
	if_equal $1, UnknownScript_0x1a5560
	if_equal $2, UnknownScript_0x1a555c
	trainertotext BUG_CATCHER, WADE1, $0
	2call UnknownScript_0x1a5554
	2jump UnknownScript_0x1a5558
; 0x1a5493

UnknownScript_0x1a5493: ; 0x1a5493
	2call UnknownScript_0x1a5564
	winlosstext Bug_catcherWade1BeatenText, $0000
	copybytetovar $d9fa
	if_equal $4, UnknownScript_0x1a54b2
	if_equal $3, UnknownScript_0x1a54b8
	if_equal $2, UnknownScript_0x1a54be
	if_equal $1, UnknownScript_0x1a54c4
	if_equal $0, UnknownScript_0x1a54ca
UnknownScript_0x1a54b2: ; 0x1a54b2
	checkbit1 $0044
	iftrue UnknownScript_0x1a54fe
UnknownScript_0x1a54b8: ; 0x1a54b8
	checkbit1 $0021
	iftrue UnknownScript_0x1a54f1
UnknownScript_0x1a54be: ; 0x1a54be
	checkbit2 $0049
	iftrue UnknownScript_0x1a54e4
UnknownScript_0x1a54c4: ; 0x1a54c4
	checkbit2 $0046
	iftrue UnknownScript_0x1a54d7
UnknownScript_0x1a54ca: ; 0x1a54ca
	loadtrainer BUG_CATCHER, WADE1
	startbattle
	returnafterbattle
	loadvar $d9fa, $1
	clearbit2 $006c
	end
; 0x1a54d7

UnknownScript_0x1a54d7: ; 0x1a54d7
	loadtrainer BUG_CATCHER, WADE2
	startbattle
	returnafterbattle
	loadvar $d9fa, $2
	clearbit2 $006c
	end
; 0x1a54e4

UnknownScript_0x1a54e4: ; 0x1a54e4
	loadtrainer BUG_CATCHER, WADE3
	startbattle
	returnafterbattle
	loadvar $d9fa, $3
	clearbit2 $006c
	end
; 0x1a54f1

UnknownScript_0x1a54f1: ; 0x1a54f1
	loadtrainer BUG_CATCHER, WADE4
	startbattle
	returnafterbattle
	loadvar $d9fa, $4
	clearbit2 $006c
	end
; 0x1a54fe

UnknownScript_0x1a54fe: ; 0x1a54fe
	loadtrainer BUG_CATCHER, WADE5
	startbattle
	returnafterbattle
	clearbit2 $006c
	end
; 0x1a5507

UnknownScript_0x1a5507: ; 0x1a5507
	2call UnknownScript_0x1a5568
	checkbit1 $032b
	iftrue UnknownScript_0x1a5522
	checkbit1 $032c
	iftrue UnknownScript_0x1a552b
	checkbit1 $032d
	iftrue UnknownScript_0x1a5534
	checkbit1 $032e
	iftrue UnknownScript_0x1a553d
UnknownScript_0x1a5522: ; 0x1a5522
	verbosegiveitem BERRY, 1
	iffalse UnknownScript_0x1a5549
	2jump UnknownScript_0x1a5543
; 0x1a552b

UnknownScript_0x1a552b: ; 0x1a552b
	verbosegiveitem PSNCUREBERRY, 1
	iffalse UnknownScript_0x1a5549
	2jump UnknownScript_0x1a5543
; 0x1a5534

UnknownScript_0x1a5534: ; 0x1a5534
	verbosegiveitem PRZCUREBERRY, 1
	iffalse UnknownScript_0x1a5549
	2jump UnknownScript_0x1a5543
; 0x1a553d

UnknownScript_0x1a553d: ; 0x1a553d
	verbosegiveitem BITTER_BERRY, 1
	iffalse UnknownScript_0x1a5549
UnknownScript_0x1a5543: ; 0x1a5543
	clearbit2 $007f
	2jump UnknownScript_0x1a5558
; 0x1a5549

UnknownScript_0x1a5549: ; 0x1a5549
	2jump UnknownScript_0x1a556c
; 0x1a554c

UnknownScript_0x1a554c: ; 0x1a554c
	jumpstd $0019
	end
; 0x1a5550

UnknownScript_0x1a5550: ; 0x1a5550
	jumpstd $001a
	end
; 0x1a5554

UnknownScript_0x1a5554: ; 0x1a5554
	jumpstd $001b
	end
; 0x1a5558

UnknownScript_0x1a5558: ; 0x1a5558
	jumpstd $001c
	end
; 0x1a555c

UnknownScript_0x1a555c: ; 0x1a555c
	jumpstd $001d
	end
; 0x1a5560

UnknownScript_0x1a5560: ; 0x1a5560
	jumpstd $001e
	end
; 0x1a5564

UnknownScript_0x1a5564: ; 0x1a5564
	jumpstd $001f
	end
; 0x1a5568

UnknownScript_0x1a5568: ; 0x1a5568
	jumpstd $0020
	end
; 0x1a556c

UnknownScript_0x1a556c: ; 0x1a556c
	jumpstd $0021
	end
; 0x1a5570

UnknownScript_0x1a5570: ; 0x1a5570
	faceplayer
	loadfont
	checkbit1 $0053
	iftrue UnknownScript_0x1a55af
	checkbit1 $0050
	iftrue UnknownScript_0x1a5584
	2writetext UnknownText_0x1a56d9
	closetext
	loadmovesprites
	end
; 0x1a5584

UnknownScript_0x1a5584: ; 0x1a5584
	2writetext UnknownText_0x1a5761
	keeptextopen
	checkpokeitem ReceivedSpearowMailText
	if_equal $0, UnknownScript_0x1a55b5
	if_equal $2, UnknownScript_0x1a55c1
	if_equal $3, UnknownScript_0x1a55bb
	if_equal $4, UnknownScript_0x1a55c7
	2writetext UnknownText_0x1a5790
	keeptextopen
	2writetext UnknownText_0x1a57ba
	keeptextopen
	setbit1 $0051
	verbosegiveitem TM_50, 1
	iffalse UnknownScript_0x1a55b3
	setbit1 $0053
UnknownScript_0x1a55af: ; 0x1a55af
	2writetext UnknownText_0x1a5896
	closetext
UnknownScript_0x1a55b3: ; 0x1a55b3
	loadmovesprites
	end
; 0x1a55b5

UnknownScript_0x1a55b5: ; 0x1a55b5
	2writetext UnknownText_0x1a5921
	closetext
	loadmovesprites
	end
; 0x1a55bb

UnknownScript_0x1a55bb: ; 0x1a55bb
	2writetext UnknownText_0x1a5939
	closetext
	loadmovesprites
	end
; 0x1a55c1

UnknownScript_0x1a55c1: ; 0x1a55c1
	2writetext UnknownText_0x1a5972
	closetext
	loadmovesprites
	end
; 0x1a55c7

UnknownScript_0x1a55c7: ; 0x1a55c7
	2writetext UnknownText_0x1a5991
	closetext
	loadmovesprites
	end

ReceivedSpearowMailText: ; 0x1a55cd
	db "DARK CAVE leads",$4E
	db "to another road@"

UnknownScript_0x1a55ed: ; 0x1a55ed
	jumptextfaceplayer UnknownText_0x1a59d5
; 0x1a55f0

MapRoute31Signpost0Script: ; 0x1a55f0
	jumptext UnknownText_0x1a5a45
; 0x1a55f3

MapRoute31Signpost1Script: ; 0x1a55f3
	jumptext UnknownText_0x1a5a6e
; 0x1a55f6

UnknownScript_0x1a55f6: ; 0x1a55f6
	jumptextfaceplayer UnknownText_0x1a55ff
; 0x1a55f9

UnknownScript_0x1a55f9: ; 0x1a55f9
	fruittree $7
; 0x1a55fb

ItemFragment_0x1a55fb: ; 0x1a55fb
	db POTION, 1
; 0x1a55fd

ItemFragment_0x1a55fd: ; 0x1a55fd
	db POKE_BALL, 1
; 0x1a55ff

UnknownText_0x1a55ff: ; 0x1a55ff
	db $0, "DARK CAVE…", $51
	db "If #MON could", $4f
	db "light it up, I'd", $55
	db "explore it.", $57
; 0x1a5635

Bug_catcherWade1SeenText: ; 0x1a5635
	db $0, "I caught a bunch", $4f
	db "of #MON. Let me", $55
	db "battle with you!", $57
; 0x1a5668

Bug_catcherWade1BeatenText: ; 0x1a5668
	db $0, "Awwwww…", $57
; 0x1a5671

UnknownText_0x1a5671: ; 0x1a5671
	db $0, "You can catch", $4f
	db "#MON even if", $51
	db "you have six with", $4f
	db "you.", $51
	db "If you catch one,", $4f
	db "it'll go to your", $55
	db "BOX automatically.", $57
; 0x1a56d9

UnknownText_0x1a56d9: ; 0x1a56d9
	db $0, "… Hnuurg… Huh?", $51
	db "I walked too far", $4f
	db "today looking for", $55
	db "#MON.", $51
	db "My feet hurt and", $4f
	db "I'm sleepy…", $51
	db "If I were a wild", $4f
	db "#MON, I'd be", $55
	db "easy to catch…", $51
	db "…Zzzz…", $57
; 0x1a5761

UnknownText_0x1a5761: ; 0x1a5761
	db $0, "…Zzzz… Huh?", $51
	db "What's that? You", $4f
	db "have MAIL for me?", $57
; 0x1a5790

UnknownText_0x1a5790: ; 0x1a5790
	db $0, $52, " handed", $4f
	db "over the #MON", $55
	db "holding the MAIL.", $57
; 0x1a57ba

UnknownText_0x1a57ba: ; 0x1a57ba
	db $0, "Let's see…", $51
	db "…DARK CAVE leads", $4f
	db "to another road…", $51
	db "That's good to", $4f
	db "know.", $51
	db "Thanks for bring-", $4f
	db "ing this to me.", $51
	db "My friend's a good", $4f
	db "guy, and you're", $55
	db "swell too!", $51
	db "I'd like to do", $4f
	db "something good in", $55
	db "return too!", $51
	db "I know! I want you", $4f
	db "to have this!", $57
; 0x1a5896

UnknownText_0x1a5896: ; 0x1a5896
	db $0, "TM50 is NIGHTMARE.", $51
	db "It's a wicked move", $4f
	db "that steadily cuts", $51
	db "the HP of a sleep-", $4f
	db "ing enemy.", $51
	db "Ooooh…", $4f
	db "That's scary…", $51
	db "I don't want to", $4f
	db "have bad dreams.", $57
; 0x1a5921

UnknownText_0x1a5921: ; 0x1a5921
	db $0, "This MAIL isn't", $4f
	db "for me.", $57
; 0x1a5939

UnknownText_0x1a5939: ; 0x1a5939
	db $0, "Why is this #-", $4f
	db "MON so special?", $51
	db "It doesn't have", $4f
	db "any MAIL.", $57
; 0x1a5972

UnknownText_0x1a5972: ; 0x1a5972
	db $0, "What? You don't", $4f
	db "want anything?", $57
; 0x1a5991

UnknownText_0x1a5991: ; 0x1a5991
	db $0, "If I take that", $4f
	db "#MON from you,", $51
	db "what are you going", $4f
	db "to use in battle?", $57
; 0x1a59d5

UnknownText_0x1a59d5: ; 0x1a59d5
	db $0, "I found a good", $4f
	db "#MON in DARK", $55
	db "CAVE.", $51
	db "I'm going to raise", $4f
	db "it to take on", $55
	db "FALKNER.", $51
	db "He's the leader of", $4f
	db "VIOLET CITY's GYM.", $57
; 0x1a5a45

UnknownText_0x1a5a45: ; 0x1a5a45
	db $0, "ROUTE 31", $51
	db "VIOLET CITY -", $4f
	db "CHERRYGROVE CITY", $57
; 0x1a5a6e

UnknownText_0x1a5a6e: ; 0x1a5a6e
	db $0, "DARK CAVE", $57
; 0x1a5a79

Route31_MapEventHeader: ; 0x1a5a79
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $6, $4, 3, GROUP_ROUTE_31_VIOLET_GATE, MAP_ROUTE_31_VIOLET_GATE
	warp_def $7, $4, 4, GROUP_ROUTE_31_VIOLET_GATE, MAP_ROUTE_31_VIOLET_GATE
	warp_def $5, $22, 1, GROUP_DARK_CAVE_VIOLET_ENTRANCE, MAP_DARK_CAVE_VIOLET_ENTRANCE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 5, 7, $0, MapRoute31Signpost0Script
	signpost 5, 31, $0, MapRoute31Signpost1Script

	; people-events
	db 7
	person_event $3a, 11, 21, $6, $0, 255, 255, $0, 0, UnknownScript_0x1a5570, $ffff
	person_event $27, 9, 13, $2, $11, 255, 255, $0, 0, UnknownScript_0x1a55ed, $ffff
	person_event $25, 17, 25, $8, $0, 255, 255, $b2, 5, TrainerBug_catcherWade1, $ffff
	person_event $23, 12, 37, $2, $11, 255, 255, $0, 0, UnknownScript_0x1a55f6, $ffff
	person_event $5d, 11, 20, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a55f9, $ffff
	person_event $54, 9, 33, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a55fb, $06ae
	person_event $54, 19, 23, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a55fd, $06af
; 0x1a5af3

Route39_MapScriptHeader: ; 0x1a5af3
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a5af5

UnknownScript_0x1a5af5: ; 0x1a5af5
	loadfont
	2writetext UnknownText_0x1a5bf9
	cry MILTANK
	closetext
	loadmovesprites
	end
; 0x1a5aff

TrainerPokefanmDerek1: ; 0x1a5aff
	; bit/flag number
	dw $4ce

	; trainer group && trainer id
	db POKEFANM, DEREK1

	; text when seen
	dw PokefanmDerek1SeenText

	; text when trainer beaten
	dw PokefanmDerek1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmDerek1Script
; 0x1a5b0b

PokefanmDerek1Script: ; 0x1a5b0b
	writecode $17, $1c
	talkaftercancel
	loadfont
	checkbit2 $0083
	iftrue UnknownScript_0x1a5b4a
	checkcellnum $1c
	iftrue UnknownScript_0x1a5b6e
	checkpoke PIKACHU
	iffalse UnknownScript_0x1a5b5c
	checkbit1 $028d
	iftrue UnknownScript_0x1a5b33
	2writetext UnknownText_0x1a5cf8
	keeptextopen
	setbit1 $028d
	2call UnknownScript_0x1a5b62
	2jump UnknownScript_0x1a5b36
; 0x1a5b33

UnknownScript_0x1a5b33: ; 0x1a5b33
	2call UnknownScript_0x1a5b66
UnknownScript_0x1a5b36: ; 0x1a5b36
	askforphonenumber $1c
	if_equal $1, UnknownScript_0x1a5b76
	if_equal $2, UnknownScript_0x1a5b72
	trainertotext POKEFANM, DEREK1, $0
	2call UnknownScript_0x1a5b6a
	2jump UnknownScript_0x1a5b6e
; 0x1a5b4a

UnknownScript_0x1a5b4a: ; 0x1a5b4a
	2call UnknownScript_0x1a5b7a
	verbosegiveitem NUGGET, 1
	iffalse UnknownScript_0x1a5b59
	clearbit2 $0083
	2jump UnknownScript_0x1a5b6e
; 0x1a5b59

UnknownScript_0x1a5b59: ; 0x1a5b59
	2jump UnknownScript_0x1a5b7e
; 0x1a5b5c

UnknownScript_0x1a5b5c: ; 0x1a5b5c
	2writetext UnknownText_0x1a5dec
	closetext
	loadmovesprites
	end
; 0x1a5b62

UnknownScript_0x1a5b62: ; 0x1a5b62
	jumpstd $0019
	end
; 0x1a5b66

UnknownScript_0x1a5b66: ; 0x1a5b66
	jumpstd $001a
	end
; 0x1a5b6a

UnknownScript_0x1a5b6a: ; 0x1a5b6a
	jumpstd $001b
	end
; 0x1a5b6e

UnknownScript_0x1a5b6e: ; 0x1a5b6e
	jumpstd $001c
	end
; 0x1a5b72

UnknownScript_0x1a5b72: ; 0x1a5b72
	jumpstd $001d
	end
; 0x1a5b76

UnknownScript_0x1a5b76: ; 0x1a5b76
	jumpstd $001e
	end
; 0x1a5b7a

UnknownScript_0x1a5b7a: ; 0x1a5b7a
	jumpstd $0020
	end
; 0x1a5b7e

UnknownScript_0x1a5b7e: ; 0x1a5b7e
	jumpstd $0021
	end
; 0x1a5b82

TrainerPokefanfRuth: ; 0x1a5b82
	; bit/flag number
	dw $4da

	; trainer group && trainer id
	db POKEFANF, RUTH

	; text when seen
	dw PokefanfRuthSeenText

	; text when trainer beaten
	dw PokefanfRuthBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanfRuthScript
; 0x1a5b8e

PokefanfRuthScript: ; 0x1a5b8e
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a5db2
	closetext
	loadmovesprites
	end
; 0x1a5b96

TrainerSailorEugene: ; 0x1a5b96
	; bit/flag number
	dw $575

	; trainer group && trainer id
	db SAILOR, EUGENE

	; text when seen
	dw SailorEugeneSeenText

	; text when trainer beaten
	dw SailorEugeneBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SailorEugeneScript
; 0x1a5ba2

SailorEugeneScript: ; 0x1a5ba2
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a5c4d
	closetext
	loadmovesprites
	end
; 0x1a5baa

TrainerPsychicNorman: ; 0x1a5baa
	; bit/flag number
	dw $43f

	; trainer group && trainer id
	db PSYCHIC_T, NORMAN

	; text when seen
	dw PsychicNormanSeenText

	; text when trainer beaten
	dw PsychicNormanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicNormanScript
; 0x1a5bb6

PsychicNormanScript: ; 0x1a5bb6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a5e57
	closetext
	loadmovesprites
	end
; 0x1a5bbe

UnknownScript_0x1a5bbe: ; 0x1a5bbe
	faceplayer
	loadfont
	checktime $4
	iffalse UnknownScript_0x1a5be5
	checkbit1 $05c2
	iftrue UnknownScript_0x1a5bdf
	2writetext UnknownText_0x1a5ee8
	closetext
	loadmovesprites
	winlosstext UnknownText_0x1a5f17, $0000
	loadtrainer POKEFANF, JAIME
	startbattle
	returnafterbattle
	setbit1 $05c2
	loadmovesprites
	end
; 0x1a5bdf

UnknownScript_0x1a5bdf: ; 0x1a5bdf
	2writetext UnknownText_0x1a5f31
	closetext
	loadmovesprites
	end
; 0x1a5be5

UnknownScript_0x1a5be5: ; 0x1a5be5
	2writetext UnknownText_0x1a5ec4
	closetext
	loadmovesprites
	end
; 0x1a5beb

MapRoute39Signpost2Script: ; 0x1a5beb
	jumptext UnknownText_0x1a5fe3
; 0x1a5bee

MapRoute39Signpost1Script: ; 0x1a5bee
	jumptext UnknownText_0x1a600a
; 0x1a5bf1

MapRoute39Signpost0Script: ; 0x1a5bf1
	jumptext UnknownText_0x1a6036
; 0x1a5bf4

UnknownScript_0x1a5bf4: ; 0x1a5bf4
	fruittree $f
; 0x1a5bf6

MapRoute39SignpostItem3: ; 0x1a5bf6
	dw $00aa
	db NUGGET
	
; 0x1a5bf9

UnknownText_0x1a5bf9: ; 0x1a5bf9
	db $0, "MILTANK: Mooo!", $57
; 0x1a5c09

SailorEugeneSeenText: ; 0x1a5c09
	db $0, "I just got back to", $4f
	db "OLIVINE.", $51
	db "So how about a", $4f
	db "#MON battle?", $57
; 0x1a5c42

SailorEugeneBeatenText: ; 0x1a5c42
	db $0, "Awaaargh!", $57
; 0x1a5c4d

UnknownText_0x1a5c4d: ; 0x1a5c4d
	db $0, "My #MON were", $4f
	db "caught and raised", $55
	db "overseas.", $51
	db "They're my compan-", $4f
	db "ions on those long", $55
	db "voyages.", $57
; 0x1a5ca5

PokefanmDerek1SeenText: ; 0x1a5ca5
	db $0, "This is a good", $4f
	db "time to brag about", $55
	db "my PIKACHU!", $57
; 0x1a5cd4

PokefanmDerek1BeatenText: ; 0x1a5cd4
	db $0, "I had no time to", $4f
	db "show off PIKACHU…", $57
; 0x1a5cf8

UnknownText_0x1a5cf8: ; 0x1a5cf8
	db $0, "I'm not listening", $4f
	db "to your bragging!", $51
	db "We # FANS have", $4f
	db "a policy of not", $51
	db "listening to other", $4f
	db "people brag!", $57
; 0x1a5d5b

PokefanfRuthSeenText: ; 0x1a5d5b
	db $0, "Such darling", $4f
	db "#MON.", $51
	db "Let's show our", $4f
	db "#MON together", $55
	db "at the same time.", $57
; 0x1a5d9d

PokefanfRuthBeatenText: ; 0x1a5d9d
	db $0, "I don't mind", $4f
	db "losing.", $57
; 0x1a5db2

UnknownText_0x1a5db2: ; 0x1a5db2
	db $0, "Do you know about", $4f
	db "baby #MON?", $51
	db "I bet they're just", $4f
	db "adorable!", $57
; 0x1a5dec

UnknownText_0x1a5dec: ; 0x1a5dec
	db $0, "PIKACHU is it!", $4f
	db "Don't you agree?", $57
; 0x1a5e0c

PsychicNormanSeenText: ; 0x1a5e0c
	db $0, "Let me see what", $4f
	db "your #MON are", $55
	db "capable of.", $57
; 0x1a5e37

PsychicNormanBeatenText: ; 0x1a5e37
	db $0, "Ooh, your #MON", $4f
	db "have potential.", $57
; 0x1a5e57

UnknownText_0x1a5e57: ; 0x1a5e57
	db $0, "You know how #-", $4f
	db "MON have different", $55
	db "abilities?", $51
	db "People are like", $4f
	db "that too. Every-", $55
	db "one has different", $55
	db "potential.", $57
; 0x1a5ec4

UnknownText_0x1a5ec4: ; 0x1a5ec4
	db $0, "Ufufufu… I hope it", $4f
	db "gets dark soon.", $57
; 0x1a5ee8

UnknownText_0x1a5ee8: ; 0x1a5ee8
	db $0, "You came at just", $4f
	db "the right time.", $51
	db "Let's battle.", $57
; 0x1a5f17

UnknownText_0x1a5f17: ; 0x1a5f17
	db $0, "Oh, how disap-", $4f
	db "pointing…", $57
; 0x1a5f31

UnknownText_0x1a5f31: ; 0x1a5f31
	db $0, "I met my MEOWTH at", $4f
	db "night, right here", $55
	db "on ROUTE 39.", $51
	db "I'm not sure why,", $4f
	db "but it seems to", $51
	db "like it when I", $4f
	db "train here.", $51
	db "It seems to become", $4f
	db "friendlier by", $51
	db "training here than", $4f
	db "anywhere else.", $57
; 0x1a5fe3

UnknownText_0x1a5fe3: ; 0x1a5fe3
	db $0, "ROUTE 39", $51
	db "OLIVINE CITY -", $4f
	db "ECRUTEAK CITY", $57
; 0x1a600a

UnknownText_0x1a600a: ; 0x1a600a
	db $0, "MOOMOO FARM", $51
	db "Enjoy Our Fresh", $4f
	db "and Tasty Milk", $57
; 0x1a6036

UnknownText_0x1a6036: ; 0x1a6036
	db $0, "TRAINER TIPS", $51
	db "Use HEADBUTT on", $4f
	db "trees to shake", $55
	db "#MON out.", $51
	db "Different kinds of", $4f
	db "#MON drop out", $55
	db "of trees.", $51
	db "Use HEADBUTT on", $4f
	db "any tree you see!", $57
; 0x1a60ba

Route39_MapEventHeader: ; 0x1a60ba
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $1, 1, GROUP_ROUTE_39_BARN, MAP_ROUTE_39_BARN
	warp_def $3, $5, 1, GROUP_ROUTE_39_FARMHOUSE, MAP_ROUTE_39_FARMHOUSE

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 31, 5, $0, MapRoute39Signpost0Script
	signpost 5, 9, $0, MapRoute39Signpost1Script
	signpost 7, 15, $0, MapRoute39Signpost2Script
	signpost 13, 5, $7, MapRoute39SignpostItem3

	; people-events
	db 10
	person_event $49, 33, 17, $8, $0, 255, 255, $92, 5, TrainerSailorEugene, $ffff
	person_event $2d, 26, 14, $7, $0, 255, 255, $82, 4, TrainerPokefanmDerek1, $ffff
	person_event $2e, 23, 15, $9, $0, 255, 255, $82, 4, TrainerPokefanfRuth, $ffff
	person_event $99, 16, 7, $16, $0, 255, 255, $0, 0, UnknownScript_0x1a5af5, $ffff
	person_event $99, 15, 10, $16, $0, 255, 255, $0, 0, UnknownScript_0x1a5af5, $ffff
	person_event $99, 19, 8, $16, $0, 255, 255, $0, 0, UnknownScript_0x1a5af5, $ffff
	person_event $99, 17, 12, $16, $0, 255, 255, $0, 0, UnknownScript_0x1a5af5, $ffff
	person_event $66, 11, 17, $a, $0, 255, 255, $92, 1, TrainerPsychicNorman, $ffff
	person_event $5d, 7, 13, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a5bf4, $ffff
	person_event $2e, 26, 8, $6, $0, 255, 255, $80, 0, UnknownScript_0x1a5bbe, $ffff
; 0x1a6160

Route40_MapScriptHeader: ; 0x1a6160
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x1a6165
; 0x1a6165

UnknownScript_0x1a6165: ; 0x1a6165
	clearbit1 $07cf
	checkcode $b
	if_equal MONDAY, UnknownScript_0x1a6171
	disappear $a
	return
; 0x1a6171

UnknownScript_0x1a6171: ; 0x1a6171
	appear $a
	return
; 0x1a6174

TrainerSwimmerfElaine: ; 0x1a6174
	; bit/flag number
	dw $3e8

	; trainer group && trainer id
	db SWIMMERF, ELAINE

	; text when seen
	dw SwimmerfElaineSeenText

	; text when trainer beaten
	dw SwimmerfElaineBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfElaineScript
; 0x1a6180

SwimmerfElaineScript: ; 0x1a6180
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a637b
	closetext
	loadmovesprites
	end
; 0x1a6188

TrainerSwimmerfPaula: ; 0x1a6188
	; bit/flag number
	dw $3e9

	; trainer group && trainer id
	db SWIMMERF, PAULA

	; text when seen
	dw SwimmerfPaulaSeenText

	; text when trainer beaten
	dw SwimmerfPaulaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfPaulaScript
; 0x1a6194

SwimmerfPaulaScript: ; 0x1a6194
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a63f5
	closetext
	loadmovesprites
	end
; 0x1a619c

TrainerSwimmermSimon: ; 0x1a619c
	; bit/flag number
	dw $595

	; trainer group && trainer id
	db SWIMMERM, SIMON

	; text when seen
	dw SwimmermSimonSeenText

	; text when trainer beaten
	dw SwimmermSimonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermSimonScript
; 0x1a61a8

SwimmermSimonScript: ; 0x1a61a8
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a6282
	closetext
	loadmovesprites
	end
; 0x1a61b0

TrainerSwimmermRandall: ; 0x1a61b0
	; bit/flag number
	dw $596

	; trainer group && trainer id
	db SWIMMERM, RANDALL

	; text when seen
	dw SwimmermRandallSeenText

	; text when trainer beaten
	dw SwimmermRandallBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermRandallScript
; 0x1a61bc

SwimmermRandallScript: ; 0x1a61bc
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a62fa
	closetext
	loadmovesprites
	end
; 0x1a61c4

UnknownScript_0x1a61c4: ; 0x1a61c4
	jumptextfaceplayer UnknownText_0x1a6429
; 0x1a61c7

UnknownScript_0x1a61c7: ; 0x1a61c7
	special $00a0
	iftrue UnknownScript_0x1a61d0
	jumptextfaceplayer UnknownText_0x1a646a
; 0x1a61d0

UnknownScript_0x1a61d0: ; 0x1a61d0
	jumptextfaceplayer UnknownText_0x1a649b
; 0x1a61d3

UnknownScript_0x1a61d3: ; 0x1a61d3
	jumptextfaceplayer UnknownText_0x1a64e6
; 0x1a61d6

UnknownScript_0x1a61d6: ; 0x1a61d6
	jumptextfaceplayer UnknownText_0x1a6564
; 0x1a61d9

UnknownScript_0x1a61d9: ; 0x1a61d9
	faceplayer
	loadfont
	checkbit1 $006f
	iftrue UnknownScript_0x1a6207
	checkcode $b
	if_not_equal MONDAY, UnknownScript_0x1a620d
	checkbit1 $006e
	iftrue UnknownScript_0x1a61f4
	2writetext UnknownText_0x1a6606
	keeptextopen
	setbit1 $006e
UnknownScript_0x1a61f4: ; 0x1a61f4
	2writetext UnknownText_0x1a6636
	keeptextopen
	verbosegiveitem SHARP_BEAK, 1
	iffalse UnknownScript_0x1a620b
	setbit1 $006f
	2writetext UnknownText_0x1a666c
	closetext
	loadmovesprites
	end
; 0x1a6207

UnknownScript_0x1a6207: ; 0x1a6207
	2writetext UnknownText_0x1a66dc
	closetext
UnknownScript_0x1a620b: ; 0x1a620b
	loadmovesprites
	end
; 0x1a620d

UnknownScript_0x1a620d: ; 0x1a620d
	2writetext UnknownText_0x1a6737
	closetext
	loadmovesprites
	end
; 0x1a6213

MapRoute40Signpost0Script: ; 0x1a6213
	jumptext UnknownText_0x1a6767
; 0x1a6216

UnknownScript_0x1a6216: ; 0x1a6216
	jumpstd $000f
; 0x1a6219

MapRoute40SignpostItem1: ; 0x1a6219
	dw $00ab
	db HYPER_POTION
; 0x1a621c

MovementData_0x1a621c: ; 0x1a621c
	step_right
	step_up
	step_up
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x1a6224

MovementData_0x1a6224: ; 0x1a6224
	step_up
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x1a622a

MovementData_0x1a622a: ; 0x1a622a
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x1a622f

SwimmermSimonSeenText: ; 0x1a622f
	db $0, "You have to warm", $4f
	db "up before going", $55
	db "into the water.", $51
	db "That's basic.", $57
; 0x1a626e

SwimmermSimonBeatenText: ; 0x1a626e
	db $0, "OK! Uncle! I give!", $57
; 0x1a6282

UnknownText_0x1a6282: ; 0x1a6282
	db $0, "CIANWOOD CITY is", $4f
	db "a good distance", $55
	db "away from here.", $57
; 0x1a62b4

SwimmermRandallSeenText: ; 0x1a62b4
	db $0, "Hey, you're young", $4f
	db "and fit!", $51
	db "Don't ride your", $4f
	db "#MON! Swim!", $57
; 0x1a62ea

SwimmermRandallBeatenText: ; 0x1a62ea
	db $0, "Uh-oh. I lost…", $57
; 0x1a62fa

UnknownText_0x1a62fa: ; 0x1a62fa
	db $0, "Swimming exercises", $4f
	db "your entire body.", $55
	db "It's healthy.", $57
; 0x1a632d

SwimmerfElaineSeenText: ; 0x1a632d
	db $0, "Are you going to", $4f
	db "CIANWOOD?", $51
	db "How about a quick", $4f
	db "battle first?", $57
; 0x1a6369

SwimmerfElaineBeatenText: ; 0x1a6369
	db $0, "I lost that one!", $57
; 0x1a637b

UnknownText_0x1a637b: ; 0x1a637b
	db $0, "I'd say I'm a bet-", $4f
	db "ter swimmer than", $55
	db "you. Yeah!", $57
; 0x1a63a9

SwimmerfPaulaSeenText: ; 0x1a63a9
	db $0, "No inner tube for", $4f
	db "me.", $51
	db "I'm hanging on to", $4f
	db "a sea #MON!", $57
; 0x1a63dd

SwimmerfPaulaBeatenText: ; 0x1a63dd
	db $0, "Ooh, I'm feeling", $4f
	db "dizzy!", $57
; 0x1a63f5

UnknownText_0x1a63f5: ; 0x1a63f5
	db $0, "While I float like", $4f
	db "this, the waves", $55
	db "carry me along.", $57
; 0x1a6429

UnknownText_0x1a6429: ; 0x1a6429
	db $0, "Although you can't", $4f
	db "see it from here,", $51
	db "CIANWOOD is across", $4f
	db "the sea.", $57
; 0x1a646a

UnknownText_0x1a646a: ; 0x1a646a
	db $0, "Hm! There's a big", $4f
	db "building up ahead!", $51
	db "What is it?", $57
; 0x1a649b

UnknownText_0x1a649b: ; 0x1a649b
	db $0, "Hm! Look at all", $4f
	db "those serious-", $55
	db "looking trainers", $55
	db "streaming in.", $51
	db "What? What?", $57
; 0x1a64e6

UnknownText_0x1a64e6: ; 0x1a64e6
	db $0, "I came to OLIVINE", $4f
	db "by ship to see the", $51
	db "sights and soak up", $4f
	db "the atmosphere.", $51
	db "Being a port, it", $4f
	db "feels so different", $55
	db "from a big city.", $57
; 0x1a6564

UnknownText_0x1a6564: ; 0x1a6564
	db $0, "Have you gone to", $4f
	db "the BATTLE TOWER?", $51
	db "I think a lot of", $4f
	db "tough trainers", $51
	db "have gathered", $4f
	db "there already.", $51
	db "But since you have", $4f
	db "so many BADGES,", $51
	db "you shouldn't do", $4f
	db "badly at all.", $57
; 0x1a6606

UnknownText_0x1a6606: ; 0x1a6606
	db $0, "MONICA: Glad to", $4f
	db "meet you. I'm", $51
	db "MONICA of Monday.", $57
; 0x1a6636

UnknownText_0x1a6636: ; 0x1a6636
	db $0, "As a token of our", $4f
	db "friendship, I have", $55
	db "a gift for you!", $57
; 0x1a666c

UnknownText_0x1a666c: ; 0x1a666c
	db $0, "MONICA: It's an", $4f
	db "item that raises", $51
	db "the power of fly-", $4f
	db "ing-type moves.", $51
	db "You should equip a", $4f
	db "bird #MON with", $55
	db "that item.", $57
; 0x1a66dc

UnknownText_0x1a66dc: ; 0x1a66dc
	db $0, "MONICA: My broth-", $4f
	db "ers and sisters", $51
	db "are all over the", $4f
	db "place.", $51
	db "See if you could", $4f
	db "find them all!", $57
; 0x1a6737

UnknownText_0x1a6737: ; 0x1a6737
	db $0, "MONICA: I don't", $4f
	db "think today is", $55
	db "Monday. How sad…", $57
; 0x1a6767

UnknownText_0x1a6767: ; 0x1a6767
	db $0, "ROUTE 40", $51
	db "CIANWOOD CITY -", $4f
	db "OLIVINE CITY", $57
; 0x1a678e

Route40_MapEventHeader: ; 0x1a678e
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $5, $9, 1, GROUP_ROUTE_40_BATTLE_TOWER_GATE, MAP_ROUTE_40_BATTLE_TOWER_GATE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 10, 14, $0, MapRoute40Signpost0Script
	signpost 8, 7, $7, MapRoute40SignpostItem1

	; people-events
	db 12
	person_event $f5, 19, 18, $9, $0, 255, 255, $82, 4, TrainerSwimmermSimon, $ffff
	person_event $f5, 34, 22, $8, $0, 255, 255, $82, 5, TrainerSwimmermRandall, $ffff
	person_event $32, 23, 7, $9, $0, 255, 255, $a2, 4, TrainerSwimmerfElaine, $ffff
	person_event $32, 29, 14, $1f, $0, 255, 255, $a2, 3, TrainerSwimmerfPaula, $ffff
	person_event $59, 15, 11, $18, $0, 255, 255, $0, 0, UnknownScript_0x1a6216, $ffff
	person_event $59, 13, 10, $18, $0, 255, 255, $0, 0, UnknownScript_0x1a6216, $ffff
	person_event $59, 12, 11, $18, $0, 255, 255, $0, 0, UnknownScript_0x1a6216, $ffff
	person_event $28, 17, 15, $6, $0, 255, 255, $0, 0, UnknownScript_0x1a61c4, $ffff
	person_event $2a, 14, 12, $3, $0, 255, 255, $0, 0, UnknownScript_0x1a61d9, $075e
	person_event $2d, 10, 11, $9, $0, 255, 255, $0, 0, UnknownScript_0x1a61c7, $ffff
	person_event $28, 8, 17, $3, $0, 255, 255, $a0, 0, UnknownScript_0x1a61d3, $ffff
	person_event $66, 13, 20, $3, $0, 255, 255, $90, 0, UnknownScript_0x1a61d6, $07cf
; 0x1a683f

Route41_MapScriptHeader: ; 0x1a683f
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a6841

TrainerSwimmerfKaylee: ; 0x1a6841
	; bit/flag number
	dw $3ea

	; trainer group && trainer id
	db SWIMMERF, KAYLEE

	; text when seen
	dw SwimmerfKayleeSeenText

	; text when trainer beaten
	dw SwimmerfKayleeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfKayleeScript
; 0x1a684d

SwimmerfKayleeScript: ; 0x1a684d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a6c7f
	closetext
	loadmovesprites
	end
; 0x1a6855

TrainerSwimmerfSusie: ; 0x1a6855
	; bit/flag number
	dw $3eb

	; trainer group && trainer id
	db SWIMMERF, SUSIE

	; text when seen
	dw SwimmerfSusieSeenText

	; text when trainer beaten
	dw SwimmerfSusieBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfSusieScript
; 0x1a6861

SwimmerfSusieScript: ; 0x1a6861
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a6d11
	closetext
	loadmovesprites
	end
; 0x1a6869

TrainerSwimmerfDenise: ; 0x1a6869
	; bit/flag number
	dw $3ec

	; trainer group && trainer id
	db SWIMMERF, DENISE

	; text when seen
	dw SwimmerfDeniseSeenText

	; text when trainer beaten
	dw SwimmerfDeniseBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfDeniseScript
; 0x1a6875

SwimmerfDeniseScript: ; 0x1a6875
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a6d79
	closetext
	loadmovesprites
	end
; 0x1a687d

TrainerSwimmerfKara: ; 0x1a687d
	; bit/flag number
	dw $3ed

	; trainer group && trainer id
	db SWIMMERF, KARA

	; text when seen
	dw SwimmerfKaraSeenText

	; text when trainer beaten
	dw SwimmerfKaraBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfKaraScript
; 0x1a6889

SwimmerfKaraScript: ; 0x1a6889
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a6e58
	closetext
	loadmovesprites
	end
; 0x1a6891

TrainerSwimmerfWendy: ; 0x1a6891
	; bit/flag number
	dw $3ee

	; trainer group && trainer id
	db SWIMMERF, WENDY

	; text when seen
	dw SwimmerfWendySeenText

	; text when trainer beaten
	dw SwimmerfWendyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfWendyScript
; 0x1a689d

SwimmerfWendyScript: ; 0x1a689d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a6ec2
	closetext
	loadmovesprites
	end
; 0x1a68a5

TrainerSwimmermCharlie: ; 0x1a68a5
	; bit/flag number
	dw $597

	; trainer group && trainer id
	db SWIMMERM, CHARLIE

	; text when seen
	dw SwimmermCharlieSeenText

	; text when trainer beaten
	dw SwimmermCharlieBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermCharlieScript
; 0x1a68b1

SwimmermCharlieScript: ; 0x1a68b1
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a696e
	closetext
	loadmovesprites
	end
; 0x1a68b9

TrainerSwimmermGeorge: ; 0x1a68b9
	; bit/flag number
	dw $598

	; trainer group && trainer id
	db SWIMMERM, GEORGE

	; text when seen
	dw SwimmermGeorgeSeenText

	; text when trainer beaten
	dw SwimmermGeorgeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermGeorgeScript
; 0x1a68c5

SwimmermGeorgeScript: ; 0x1a68c5
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a69d4
	closetext
	loadmovesprites
	end
; 0x1a68cd

TrainerSwimmermBerke: ; 0x1a68cd
	; bit/flag number
	dw $599

	; trainer group && trainer id
	db SWIMMERM, BERKE

	; text when seen
	dw SwimmermBerkeSeenText

	; text when trainer beaten
	dw SwimmermBerkeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermBerkeScript
; 0x1a68d9

SwimmermBerkeScript: ; 0x1a68d9
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a6aa4
	closetext
	loadmovesprites
	end
; 0x1a68e1

TrainerSwimmermKirk: ; 0x1a68e1
	; bit/flag number
	dw $59a

	; trainer group && trainer id
	db SWIMMERM, KIRK

	; text when seen
	dw SwimmermKirkSeenText

	; text when trainer beaten
	dw SwimmermKirkBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermKirkScript
; 0x1a68ed

SwimmermKirkScript: ; 0x1a68ed
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a6b6c
	closetext
	loadmovesprites
	end
; 0x1a68f5

TrainerSwimmermMathew: ; 0x1a68f5
	; bit/flag number
	dw $59b

	; trainer group && trainer id
	db SWIMMERM, MATHEW

	; text when seen
	dw SwimmermMathewSeenText

	; text when trainer beaten
	dw SwimmermMathewBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermMathewScript
; 0x1a6901

SwimmermMathewScript: ; 0x1a6901
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a6bed
	closetext
	loadmovesprites
	end
; 0x1a6909

UnknownScript_0x1a6909: ; 0x1a6909
	jumpstd $000f
; 0x1a690c

MapRoute41SignpostItem0: ; 0x1a690c
	dw $00ac
	db MAX_ETHER
; 0x1a690f

SwimmermCharlieSeenText: ; 0x1a690f
	db $0, "The water's warm", $4f
	db "here. I'm loose", $55
	db "and limber.", $51
	db "Sure, I'll take", $4f
	db "you on!", $57
; 0x1a6952

SwimmermCharlieBeatenText: ; 0x1a6952
	db $0, "Yikes! I've got", $4f
	db "prune skin!", $57
; 0x1a696e

UnknownText_0x1a696e: ; 0x1a696e
	db $0, "Isn't it relaxing", $4f
	db "just floating like", $55
	db "this?", $57
; 0x1a6999

SwimmermGeorgeSeenText: ; 0x1a6999
	db $0, "I'm a bit tired.", $4f
	db "If I win, lend me", $55
	db "your #MON.", $57
; 0x1a69c7

SwimmermGeorgeBeatenText: ; 0x1a69c7
	db $0, "Pant, pant…", $57
; 0x1a69d4

UnknownText_0x1a69d4: ; 0x1a69d4
	db $0, "It's so far to", $4f
	db "CIANWOOD.", $51
	db "But it's no easy", $4f
	db "return trip to", $55
	db "OLIVINE either.", $51
	db "What should I do?", $57
; 0x1a6a2e

SwimmermBerkeSeenText: ; 0x1a6a2e
	db $0, "See those islands", $4f
	db "that are blocked", $55
	db "by whirlpools?", $51
	db "There just has to", $4f
	db "be a secret!", $57
; 0x1a6a80

SwimmermBerkeBeatenText: ; 0x1a6a80
	db $0, "What's the secret", $4f
	db "to your strength?", $57
; 0x1a6aa4

UnknownText_0x1a6aa4: ; 0x1a6aa4
	db $0, "It was a dark and", $4f
	db "stormy night…", $51
	db "I saw this giant", $4f
	db "#MON flying", $55
	db "from the islands.", $51
	db "It was scattering", $4f
	db "feathers from its", $55
	db "silver wings.", $57
; 0x1a6b26

SwimmermKirkSeenText: ; 0x1a6b26
	db $0, "The waves are wild", $4f
	db "here.", $51
	db "They tire you out", $4f
	db "while you swim.", $57
; 0x1a6b62

SwimmermKirkBeatenText: ; 0x1a6b62
	db $0, "I'm beat!", $57
; 0x1a6b6c

UnknownText_0x1a6b6c: ; 0x1a6b6c
	db $0, "The currents keep", $4f
	db "me from reaching", $55
	db "that island.", $57
; 0x1a6b9d

SwimmermMathewSeenText: ; 0x1a6b9d
	db $0, "Are you seeking", $4f
	db "the secrets of", $55
	db "WHIRL ISLANDS?", $57
; 0x1a6bcc

SwimmermMathewBeatenText: ; 0x1a6bcc
	db $0, "Ooh, you've got", $4f
	db "great endurance!", $57
; 0x1a6bed

UnknownText_0x1a6bed: ; 0x1a6bed
	db $0, "A secret about", $4f
	db "WHIRL ISLANDS…", $51
	db "It's pitch-black", $4f
	db "inside!", $57
; 0x1a6c24

SwimmerfKayleeSeenText: ; 0x1a6c24
	db $0, "I'm on my way to", $4f
	db "WHIRL ISLANDS.", $51
	db "I'm going explor-", $4f
	db "ing with friends.", $57
; 0x1a6c67

SwimmerfKayleeBeatenText: ; 0x1a6c67
	db $0, "Is that how you do", $4f
	db "it?", $57
; 0x1a6c7f

UnknownText_0x1a6c7f: ; 0x1a6c7f
	db $0, "There's supposed", $4f
	db "to be a big #-", $55
	db "MON deep beneath", $55
	db "WHIRL ISLANDS.", $51
	db "I wonder what it", $4f
	db "could be?", $57
; 0x1a6cda

SwimmerfSusieSeenText: ; 0x1a6cda
	db $0, "You look so ele-", $4f
	db "gant, riding your", $55
	db "#MON.", $57
; 0x1a6d04

SwimmerfSusieBeatenText: ; 0x1a6d04
	db $0, "I'm crushed…", $57
; 0x1a6d11

UnknownText_0x1a6d11: ; 0x1a6d11
	db $0, "Wasn't there a hit", $4f
	db "song about a boy", $55
	db "riding a LAPRAS?", $57
; 0x1a6d46

SwimmerfDeniseSeenText: ; 0x1a6d46
	db $0, "The weather is so", $4f
	db "beautiful, I'm in", $55
	db "a daze!", $57
; 0x1a6d72

SwimmerfDeniseBeatenText: ; 0x1a6d72
	db $0, "Ohhh!", $57
; 0x1a6d79

UnknownText_0x1a6d79: ; 0x1a6d79
	db $0, "A sunburn is the", $4f
	db "worst for skin.", $51
	db "But I don't use a", $4f
	db "sunblock.", $51
	db "I won't pollute", $4f
	db "the water.", $57
; 0x1a6dd0

SwimmerfKaraSeenText: ; 0x1a6dd0
	db $0, "If you need to", $4f
	db "rest, just tread", $55
	db "water.", $51
	db "You'll get your", $4f
	db "wind back, so you", $51
	db "can keep on going", $4f
	db "strong.", $57
; 0x1a6e33

SwimmerfKaraBeatenText: ; 0x1a6e33
	db $0, "Oh! You have more", $4f
	db "energy than I do.", $57
; 0x1a6e58

UnknownText_0x1a6e58: ; 0x1a6e58
	db $0, "I heard roars from", $4f
	db "deep inside the", $55
	db "ISLANDS.", $57
; 0x1a6e85

SwimmerfWendySeenText: ; 0x1a6e85
	db $0, "At night, STARYU", $4f
	db "gather near the", $55
	db "water's surface.", $57
; 0x1a6eb7

SwimmerfWendyBeatenText: ; 0x1a6eb7
	db $0, "Oh, dear…", $57
; 0x1a6ec2

UnknownText_0x1a6ec2: ; 0x1a6ec2
	db $0, "The clusters of", $4f
	db "STARYU light up", $55
	db "at the same time.", $51
	db "It's so beautiful,", $4f
	db "it's scary.", $57
; 0x1a6f12

Route41_MapEventHeader: ; 0x1a6f12
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $11, $c, 1, GROUP_WHIRL_ISLAND_NW, MAP_WHIRL_ISLAND_NW
	warp_def $13, $24, 1, GROUP_WHIRL_ISLAND_NE, MAP_WHIRL_ISLAND_NE
	warp_def $25, $c, 1, GROUP_WHIRL_ISLAND_SW, MAP_WHIRL_ISLAND_SW
	warp_def $2d, $24, 1, GROUP_WHIRL_ISLAND_SE, MAP_WHIRL_ISLAND_SE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 35, 9, $7, MapRoute41SignpostItem0

	; people-events
	db 10
	person_event $f5, 10, 36, $a, $0, 255, 255, $82, 3, TrainerSwimmermCharlie, $ffff
	person_event $f5, 12, 50, $a, $0, 255, 255, $82, 3, TrainerSwimmermGeorge, $ffff
	person_event $f5, 30, 24, $1e, $0, 255, 255, $82, 3, TrainerSwimmermBerke, $ffff
	person_event $f5, 34, 36, $1f, $0, 255, 255, $82, 3, TrainerSwimmermKirk, $ffff
	person_event $f5, 50, 23, $1e, $0, 255, 255, $82, 3, TrainerSwimmermMathew, $ffff
	person_event $32, 8, 21, $a, $0, 255, 255, $a2, 3, TrainerSwimmerfKaylee, $ffff
	person_event $32, 23, 27, $7, $0, 255, 255, $a2, 3, TrainerSwimmerfSusie, $ffff
	person_event $32, 38, 31, $8, $0, 255, 255, $a2, 3, TrainerSwimmerfDenise, $ffff
	person_event $32, 32, 48, $9, $0, 255, 255, $a2, 4, TrainerSwimmerfKara, $ffff
	person_event $32, 54, 13, $a, $0, 255, 255, $a2, 2, TrainerSwimmerfWendy, $ffff
; 0x1a6fb3

Route12_MapScriptHeader: ; 0x1a6fb3
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a6fb5

TrainerFisherKyle: ; 0x1a6fb5
	; bit/flag number
	dw $451

	; trainer group && trainer id
	db FISHER, KYLE

	; text when seen
	dw FisherKyleSeenText

	; text when trainer beaten
	dw FisherKyleBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherKyleScript
; 0x1a6fc1

FisherKyleScript: ; 0x1a6fc1
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a7238
	closetext
	loadmovesprites
	end
; 0x1a6fc9

TrainerFisherMartin: ; 0x1a6fc9
	; bit/flag number
	dw $45a

	; trainer group && trainer id
	db FISHER, MARTIN

	; text when seen
	dw FisherMartinSeenText

	; text when trainer beaten
	dw FisherMartinBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherMartinScript
; 0x1a6fd5

FisherMartinScript: ; 0x1a6fd5
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a704c
	closetext
	loadmovesprites
	end
; 0x1a6fdd

TrainerFisherStephen: ; 0x1a6fdd
	; bit/flag number
	dw $45b

	; trainer group && trainer id
	db FISHER, STEPHEN

	; text when seen
	dw FisherStephenSeenText

	; text when trainer beaten
	dw FisherStephenBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherStephenScript
; 0x1a6fe9

FisherStephenScript: ; 0x1a6fe9
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a70d4
	closetext
	loadmovesprites
	end
; 0x1a6ff1

TrainerFisherBarney: ; 0x1a6ff1
	; bit/flag number
	dw $45c

	; trainer group && trainer id
	db FISHER, BARNEY

	; text when seen
	dw FisherBarneySeenText

	; text when trainer beaten
	dw FisherBarneyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherBarneyScript
; 0x1a6ffd

FisherBarneyScript: ; 0x1a6ffd
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a716d
	closetext
	loadmovesprites
	end
; 0x1a7005

MapRoute12Signpost0Script: ; 0x1a7005
	jumptext UnknownText_0x1a72a0
; 0x1a7008

MapRoute12Signpost1Script: ; 0x1a7008
	jumptext UnknownText_0x1a72c1
; 0x1a700b

ItemFragment_0x1a700b: ; 0x1a700b
	db CALCIUM, 1
; 0x1a700d

ItemFragment_0x1a700d: ; 0x1a700d
	db NUGGET, 1
; 0x1a700f

MapRoute12SignpostItem2: ; 0x1a700f
	dw $00f3
	db ELIXER
	
; 0x1a7012

FisherMartinSeenText: ; 0x1a7012
	db $0, "Patience is the", $4f
	db "key to both fish-", $55
	db "ing and #MON.", $57
; 0x1a7043

FisherMartinBeatenText: ; 0x1a7043
	db $0, "Gwaaah!", $57
; 0x1a704c

UnknownText_0x1a704c: ; 0x1a704c
	db $0, "I'm too impatient", $4f
	db "for fishing…", $57
; 0x1a706b

FisherStephenSeenText: ; 0x1a706b
	db $0, "I feel so content,", $4f
	db "fishing while lis-", $55
	db "tening to some", $55
	db "tunes on my radio.", $57
; 0x1a70b4

FisherStephenBeatenText: ; 0x1a70b4
	db $0, "My stupid radio", $4f
	db "distracted me!", $57
; 0x1a70d4

UnknownText_0x1a70d4: ; 0x1a70d4
	db $0, "Have you checked", $4f
	db "out KANTO's radio", $51
	db "programs? We get a", $4f
	db "good variety here.", $57
; 0x1a711d

FisherBarneySeenText: ; 0x1a711d
	db $0, "What's most impor-", $4f
	db "tant in our every-", $55
	db "day lives?", $57
; 0x1a714e

FisherBarneyBeatenText: ; 0x1a714e
	db $0, "The answer is", $4f
	db "coming up next!", $57
; 0x1a716d

UnknownText_0x1a716d: ; 0x1a716d
	db $0, "I think electric-", $4f
	db "ity is the most", $51
	db "important thing in", $4f
	db "our daily lives.", $51
	db "If it weren't,", $4f
	db "people wouldn't", $51
	db "have made such a", $4f
	db "fuss when the", $51
	db "POWER PLANT went", $4f
	db "out of commission.", $57
; 0x1a7214

FisherKyleSeenText: ; 0x1a7214
	db $0, "Do you remember?", $57
; 0x1a7226

FisherKyleBeatenText: ; 0x1a7226
	db $0, "You do remember?", $57
; 0x1a7238

UnknownText_0x1a7238: ; 0x1a7238
	db $0, "The tug you feel", $4f
	db "on the ROD when", $51
	db "you hook a #-", $4f
	db "MON…", $51
	db "That's the best", $4f
	db "feeling ever for", $55
	db "an angler like me.", $57
; 0x1a72a0

UnknownText_0x1a72a0: ; 0x1a72a0
	db $0, "ROUTE 12", $51
	db "NORTH TO LAVENDER", $4f
	db "TOWN", $57
; 0x1a72c1

UnknownText_0x1a72c1: ; 0x1a72c1
	db $0, "FISHING SPOT", $57
; 0x1a72cf

Route12_MapEventHeader: ; 0x1a72cf
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $21, $b, 1, GROUP_ROUTE_12_SUPER_ROD_HOUSE, MAP_ROUTE_12_SUPER_ROD_HOUSE

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 27, 11, $0, MapRoute12Signpost0Script
	signpost 9, 13, $0, MapRoute12Signpost1Script
	signpost 13, 14, $7, MapRoute12SignpostItem2

	; people-events
	db 6
	person_event $3a, 17, 9, $a, $0, 255, 255, $a2, 1, TrainerFisherMartin, $ffff
	person_event $3a, 27, 18, $6, $0, 255, 255, $a2, 1, TrainerFisherStephen, $ffff
	person_event $3a, 42, 14, $8, $0, 255, 255, $a2, 5, TrainerFisherBarney, $ffff
	person_event $3a, 11, 10, $9, $0, 255, 255, $a2, 3, TrainerFisherKyle, $ffff
	person_event $54, 47, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a700b, $0788
	person_event $54, 55, 9, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a700d, $0789
; 0x1a7337

SECTION "bank6A",DATA,BANK[$6A]

NewBarkTown_MapScriptHeader: ; 0x1a8000
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1a800d, $0000
	dw UnknownScript_0x1a800e, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1a800f
; 0x1a800d

UnknownScript_0x1a800d: ; 0x1a800d
	end
; 0x1a800e

UnknownScript_0x1a800e: ; 0x1a800e
	end
; 0x1a800f

UnknownScript_0x1a800f: ; 0x1a800f
	setbit2 $0041
	clearbit1 $0076
	return
; 0x1a8016

UnknownScript_0x1a8016: ; 0x1a8016
	playmusic $004e
	spriteface $2, $2
	loadfont
	2writetext UnknownText_0x1a8134
	closetext
	loadmovesprites
	spriteface $0, $3
	applymovement $2, MovementData_0x1a80d4
	loadfont
	2writetext UnknownText_0x1a813e
	closetext
	loadmovesprites
	follow $2, $0
	applymovement $2, MovementData_0x1a80e0
	stopfollow
	loadfont
	2writetext UnknownText_0x1a815e
	closetext
	loadmovesprites
	special $003d
	end
; 0x1a8041

UnknownScript_0x1a8041: ; 0x1a8041
	playmusic $004e
	spriteface $2, $2
	loadfont
	2writetext UnknownText_0x1a8134
	closetext
	loadmovesprites
	spriteface $0, $3
	applymovement $2, MovementData_0x1a80d9
	spriteface $0, $1
	loadfont
	2writetext UnknownText_0x1a813e
	closetext
	loadmovesprites
	follow $2, $0
	applymovement $2, MovementData_0x1a80e6
	stopfollow
	loadfont
	2writetext UnknownText_0x1a815e
	closetext
	loadmovesprites
	special $003d
	end
; 0x1a806f

UnknownScript_0x1a806f: ; 0x1a806f
	faceplayer
	loadfont
	checkbit1 $0040
	iftrue UnknownScript_0x1a8095
	checkbit1 $001f
	iftrue UnknownScript_0x1a808f
	checkbit1 $001a
	iftrue UnknownScript_0x1a8089
	2writetext UnknownText_0x1a80f7
	closetext
	loadmovesprites
	end
; 0x1a8089

UnknownScript_0x1a8089: ; 0x1a8089
	2writetext UnknownText_0x1a81c4
	closetext
	loadmovesprites
	end
; 0x1a808f

UnknownScript_0x1a808f: ; 0x1a808f
	2writetext UnknownText_0x1a81f2
	closetext
	loadmovesprites
	end
; 0x1a8095

UnknownScript_0x1a8095: ; 0x1a8095
	2writetext UnknownText_0x1a8236
	closetext
	loadmovesprites
	end
; 0x1a809b

UnknownScript_0x1a809b: ; 0x1a809b
	jumptextfaceplayer UnknownText_0x1a8274
; 0x1a809e

UnknownScript_0x1a809e: ; 0x1a809e
	loadfont
	2writetext UnknownText_0x1a82a6
	closetext
	loadmovesprites
	spriteface $4, $2
	loadfont
	2writetext UnknownText_0x1a82cd
	closetext
	loadmovesprites
	follow $0, $4
	applymovement $0, MovementData_0x1a80ed
	stopfollow
	pause 5
	spriteface $4, $0
	pause 5
	playsound $0041
	applymovement $0, MovementData_0x1a80f0
	applymovement $4, MovementData_0x1a80f5
	end
; 0x1a80c8

MapNewBarkTownSignpost0Script: ; 0x1a80c8
	jumptext UnknownText_0x1a82e8
; 0x1a80cb

MapNewBarkTownSignpost1Script: ; 0x1a80cb
	jumptext UnknownText_0x1a8328
; 0x1a80ce

MapNewBarkTownSignpost2Script: ; 0x1a80ce
	jumptext UnknownText_0x1a8332
; 0x1a80d1

MapNewBarkTownSignpost3Script: ; 0x1a80d1
	jumptext UnknownText_0x1a8340
; 0x1a80d4

MovementData_0x1a80d4: ; 0x1a80d4
	step_left
	step_left
	step_left
	step_left
	step_end
; 0x1a80d9

MovementData_0x1a80d9: ; 0x1a80d9
	step_left
	step_left
	step_left
	step_left
	step_left
	turn_head_down
	step_end
; 0x1a80e0

MovementData_0x1a80e0: ; 0x1a80e0
	step_right
	step_right
	step_right
	step_right
	turn_head_left
	step_end
; 0x1a80e6

MovementData_0x1a80e6: ; 0x1a80e6
	step_right
	step_right
	step_right
	step_right
	step_right
	turn_head_left
	step_end
; 0x1a80ed

MovementData_0x1a80ed: ; 0x1a80ed
	turn_head_up
	step_down
	step_end
; 0x1a80f0

MovementData_0x1a80f0: ; 0x1a80f0
	turn_head_up
	fix_facing
	jump_step_down
	remove_fixed_facing
	step_end
; 0x1a80f5

MovementData_0x1a80f5: ; 0x1a80f5
	step_right
	step_end
; 0x1a80f7

UnknownText_0x1a80f7: ; 0x1a80f7
	db $0, "Wow, your #GEAR", $4f
	db "is impressive!", $51
	db "Did your mom get", $4f
	db "it for you?", $57
; 0x1a8134

UnknownText_0x1a8134: ; 0x1a8134
	db $0, "Wait, ", $14, "!", $57
; 0x1a813e

UnknownText_0x1a813e: ; 0x1a813e
	db $0, "What do you think", $4f
	db "you're doing?", $57
; 0x1a815e

UnknownText_0x1a815e: ; 0x1a815e
	db $0, "It's dangerous to", $4f
	db "go out without a", $55
	db "#MON!", $51
	db "Wild #MON", $4f
	db "jump out of the", $51
	db "grass on the way", $4f
	db "to the next town.", $57
; 0x1a81c4

UnknownText_0x1a81c4: ; 0x1a81c4
	db $0, "Oh! Your #MON", $4f
	db "is adorable!", $55
	db "I wish I had one!", $57
; 0x1a81f2

UnknownText_0x1a81f2: ; 0x1a81f2
	db $0, "Hi, ", $14, "!", $4f
	db "Leaving again?", $51
	db "You should tell", $4f
	db "your mom if you", $55
	db "are leaving.", $57
; 0x1a8236

UnknownText_0x1a8236: ; 0x1a8236
	db $0, "Call your mom on", $4f
	db "your #GEAR to", $51
	db "let her know how", $4f
	db "you're doing.", $57
; 0x1a8274

UnknownText_0x1a8274: ; 0x1a8274
	db $0, "Yo, ", $52, "!", $51
	db "I hear PROF.ELM", $4f
	db "discovered some", $55
	db "new #MON.", $57
; 0x1a82a6

UnknownText_0x1a82a6: ; 0x1a82a6
	db $0, $56, $51
	db "So this is the", $4f
	db "famous ELM #MON", $55
	db "LAB…", $57
; 0x1a82cd

UnknownText_0x1a82cd: ; 0x1a82cd
	db $0, "…What are you", $4f
	db "staring at?", $57
; 0x1a82e8

UnknownText_0x1a82e8: ; 0x1a82e8
	db $0, "NEW BARK TOWN", $51
	db "The Town Where the", $4f
	db "Winds of a New", $55
	db "Beginning Blow", $57
; 0x1a8328

UnknownText_0x1a8328: ; 0x1a8328
	db $0, $52, "'s House", $57
; 0x1a8332

UnknownText_0x1a8332: ; 0x1a8332
	db $0, "ELM #MON LAB", $57
; 0x1a8340

UnknownText_0x1a8340: ; 0x1a8340
	db $0, "ELM'S HOUSE", $57
; 0x1a834d

NewBarkTown_MapEventHeader: ; 0x1a834d
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $3, $6, 1, GROUP_ELMS_LAB, MAP_ELMS_LAB
	warp_def $5, $d, 1, GROUP_KRISS_HOUSE_1F, MAP_KRISS_HOUSE_1F
	warp_def $b, $3, 1, GROUP_KRISS_NEIGHBORS_HOUSE, MAP_KRISS_NEIGHBORS_HOUSE
	warp_def $d, $b, 1, GROUP_ELMS_HOUSE, MAP_ELMS_HOUSE

	; xy triggers
	db 2
	xy_trigger 0, $8, $1, $0, UnknownScript_0x1a8016, $0, $0
	xy_trigger 0, $9, $1, $0, UnknownScript_0x1a8041, $0, $0

	; signposts
	db 4
	signpost 8, 8, $0, MapNewBarkTownSignpost0Script
	signpost 5, 11, $0, MapNewBarkTownSignpost1Script
	signpost 3, 3, $0, MapNewBarkTownSignpost2Script
	signpost 13, 9, $0, MapNewBarkTownSignpost3Script

	; people-events
	db 3
	person_event $29, 12, 10, $3, $1, 255, 255, $0, 0, UnknownScript_0x1a806f, $ffff
	person_event $3a, 13, 16, $4, $10, 255, 255, $a0, 0, UnknownScript_0x1a809b, $ffff
	person_event $4, 6, 7, $9, $0, 255, 255, $0, 0, UnknownScript_0x1a809e, $06bd
; 0x1a83b2

VioletCity_MapScriptHeader: ; 0x1a83b2
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1a83b7
; 0x1a83b7

UnknownScript_0x1a83b7: ; 0x1a83b7
	setbit2 $0043
	return
; 0x1a83bb

UnknownScript_0x1a83bb: ; 0x1a83bb
	applymovement $2, MovementData_0x1a8465
	faceplayer
	loadfont
	2writetext UnknownText_0x1a8473
	yesorno
	iffalse UnknownScript_0x1a83d1
	2jump UnknownScript_0x1a83cb
; 0x1a83cb

UnknownScript_0x1a83cb: ; 0x1a83cb
	2writetext UnknownText_0x1a84ac
	closetext
	loadmovesprites
	end
; 0x1a83d1

UnknownScript_0x1a83d1: ; 0x1a83d1
	2writetext UnknownText_0x1a84cb
	closetext
	loadmovesprites
	playmusic $0011
	follow $2, $0
	applymovement $2, MovementData_0x1a842a
	spriteface $0, $1
	applymovement $2, MovementData_0x1a8465
	stopfollow
	special $003d
	loadfont
	2writetext UnknownText_0x1a84f9
	closetext
	loadmovesprites
	applymovement $2, MovementData_0x1a8465
	applymovement $2, MovementData_0x1a8463
	playsound $001f
	disappear $2
	clearbit1 $06cb
	waitbutton
	end
; 0x1a8403

UnknownScript_0x1a8403: ; 0x1a8403
	jumptextfaceplayer UnknownText_0x1a8529
; 0x1a8406

UnknownScript_0x1a8406: ; 0x1a8406
	jumptextfaceplayer UnknownText_0x1a8593
; 0x1a8409

UnknownScript_0x1a8409: ; 0x1a8409
	jumptextfaceplayer UnknownText_0x1a85ef
; 0x1a840c

UnknownScript_0x1a840c: ; 0x1a840c
	jumptextfaceplayer UnknownText_0x1a8665
; 0x1a840f

MapVioletCitySignpost0Script: ; 0x1a840f
	jumptext UnknownText_0x1a86b2
; 0x1a8412

MapVioletCitySignpost1Script: ; 0x1a8412
	jumptext UnknownText_0x1a86dc
; 0x1a8415

MapVioletCitySignpost2Script: ; 0x1a8415
	jumptext UnknownText_0x1a8724
; 0x1a8418

MapVioletCitySignpost3Script: ; 0x1a8418
	jumptext UnknownText_0x1a874d
; 0x1a841b

MapVioletCitySignpost4Script: ; 0x1a841b
	jumpstd $0010
; 0x1a841e

MapVioletCitySignpost5Script: ; 0x1a841e
	jumpstd $0011
; 0x1a8421

ItemFragment_0x1a8421: ; 0x1a8421
	db PP_UP, 1
; 0x1a8423

ItemFragment_0x1a8423: ; 0x1a8423
	db RARE_CANDY, 1
; 0x1a8425

UnknownScript_0x1a8425: ; 0x1a8425
	fruittree $9
; 0x1a8427

MapVioletCitySignpostItem6: ; 0x1a8427
	dw $00b0
	db HYPER_POTION
	
; 0x1a842a

MovementData_0x1a842a: ; 0x1a842a
	big_step_down
	big_step_down
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	big_step_down
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	big_step_right
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	big_step_up
	turn_head_down
	step_end
; 0x1a8463

MovementData_0x1a8463: ; 0x1a8463
	step_up
	step_end
; 0x1a8465

MovementData_0x1a8465: ; 0x1a8465
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	turn_head_left
	turn_head_up
	turn_head_right
	turn_head_down
	step_end
; 0x1a8473

UnknownText_0x1a8473: ; 0x1a8473
	db $0, "Hello!", $4f
	db "You are trainer?", $51
	db "Battle GYM LEADER,", $4f
	db "win you did?", $57
; 0x1a84ac

UnknownText_0x1a84ac: ; 0x1a84ac
	db $0, "Ooh, la la!", $4f
	db "Very indeed nice!", $57
; 0x1a84cb

UnknownText_0x1a84cb: ; 0x1a84cb
	db $0, "Is that so? Then", $4f
	db "study shall you!", $55
	db "Follow me!", $57
; 0x1a84f9

UnknownText_0x1a84f9: ; 0x1a84f9
	db $0, "Here, teacher I", $4f
	db "am. Good it is", $55
	db "you study here!", $57
; 0x1a8529

UnknownText_0x1a8529: ; 0x1a8529
	db $0, "Ghosts are rumored", $4f
	db "to appear in", $55
	db "SPROUT TOWER.", $51
	db "They said normal-", $4f
	db "type #MON moves", $51
	db "had no effect on", $4f
	db "ghosts.", $57
; 0x1a8593

UnknownText_0x1a8593: ; 0x1a8593
	db $0, "Hey, you're a", $4f
	db "#MON trainer?", $51
	db "If you beat the", $4f
	db "GYM LEADER here,", $51
	db "you'll be ready", $4f
	db "for prime time!", $57
; 0x1a85ef

UnknownText_0x1a85ef: ; 0x1a85ef
	db $0, "FALKNER, from the", $4f
	db "VIOLET #MON", $51
	db "GYM, is a fine", $4f
	db "trainer!", $51
	db "He inherited his", $4f
	db "father's gym and", $51
	db "has done a great", $4f
	db "job with it.", $57
; 0x1a8665

UnknownText_0x1a8665: ; 0x1a8665
	db $0, "I saw a wiggly", $4f
	db "tree up ahead!", $51
	db "If you touch it,", $4f
	db "it squirms and", $55
	db "dances! Cool!", $57
; 0x1a86b2

UnknownText_0x1a86b2: ; 0x1a86b2
	db $0, "VIOLET CITY", $51
	db "The City of", $4f
	db "Nostalgic Scents", $57
; 0x1a86dc

UnknownText_0x1a86dc: ; 0x1a86dc
	db $0, "VIOLET CITY", $4f
	db "#MON GYM", $55
	db "LEADER: FALKNER", $51
	db "The Elegant Master", $4f
	db "of Flying #MON", $57
; 0x1a8724

UnknownText_0x1a8724: ; 0x1a8724
	db $0, "SPROUT TOWER", $51
	db "Experience the", $4f
	db "Way of #MON", $57
; 0x1a874d

UnknownText_0x1a874d: ; 0x1a874d
	db $0, "EARL'S #MON", $4f
	db "ACADEMY", $57
; 0x1a8762

VioletCity_MapEventHeader: ; 0x1a8762
	; filler
	db 0, 0

	; warps
	db 9
	warp_def $11, $9, 2, GROUP_VIOLET_MART, MAP_VIOLET_MART
	warp_def $11, $12, 1, GROUP_VIOLET_GYM, MAP_VIOLET_GYM
	warp_def $11, $1e, 1, GROUP_EARLS_POKEMON_ACADEMY, MAP_EARLS_POKEMON_ACADEMY
	warp_def $f, $3, 1, GROUP_VIOLET_NICKNAME_SPEECH_HOUSE, MAP_VIOLET_NICKNAME_SPEECH_HOUSE
	warp_def $19, $1f, 1, GROUP_VIOLET_POKECENTER_1F, MAP_VIOLET_POKECENTER_1F
	warp_def $1d, $15, 1, GROUP_VIOLET_ONIX_TRADE_HOUSE, MAP_VIOLET_ONIX_TRADE_HOUSE
	warp_def $5, $17, 1, GROUP_SPROUT_TOWER_1F, MAP_SPROUT_TOWER_1F
	warp_def $18, $27, 1, GROUP_ROUTE_31_VIOLET_GATE, MAP_ROUTE_31_VIOLET_GATE
	warp_def $19, $27, 2, GROUP_ROUTE_31_VIOLET_GATE, MAP_ROUTE_31_VIOLET_GATE

	; xy triggers
	db 0

	; signposts
	db 7
	signpost 20, 24, $0, MapVioletCitySignpost0Script
	signpost 17, 15, $0, MapVioletCitySignpost1Script
	signpost 8, 24, $0, MapVioletCitySignpost2Script
	signpost 17, 27, $0, MapVioletCitySignpost3Script
	signpost 25, 32, $0, MapVioletCitySignpost4Script
	signpost 17, 10, $0, MapVioletCitySignpost5Script
	signpost 14, 37, $7, MapVioletCitySignpostItem6

	; people-events
	db 8
	person_event $3a, 20, 17, $3, $0, 255, 255, $a0, 0, UnknownScript_0x1a83bb, $06ca
	person_event $28, 32, 32, $2, $22, 255, 255, $a0, 0, UnknownScript_0x1a8403, $ffff
	person_event $2b, 18, 28, $2, $21, 255, 255, $80, 0, UnknownScript_0x1a8406, $ffff
	person_event $2f, 24, 21, $5, $1, 255, 255, $0, 0, UnknownScript_0x1a8409, $ffff
	person_event $27, 22, 9, $3, $0, 255, 255, $a0, 0, UnknownScript_0x1a840c, $ffff
	person_event $5d, 33, 18, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a8425, $ffff
	person_event $54, 5, 8, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a8421, $0643
	person_event $54, 9, 39, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a8423, $0644
; 0x1a8820

OlivineCity_MapScriptHeader: ; 0x1a8820
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1a882d, $0000
	dw UnknownScript_0x1a882e, $0000

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1a882f
; 0x1a882d

UnknownScript_0x1a882d: ; 0x1a882d
	end
; 0x1a882e

UnknownScript_0x1a882e: ; 0x1a882e
	end
; 0x1a882f

UnknownScript_0x1a882f: ; 0x1a882f
	setbit2 $0047
	return
; 0x1a8833

UnknownScript_0x1a8833: ; 0x1a8833
	spriteface $0, $2
	showemote $0, $0, 15
	special $006a
	pause 15
	playsound $001f
	appear $5
	waitbutton
	applymovement $5, MovementData_0x1a88d2
	playmusic $001f
	loadfont
	2writetext UnknownText_0x1a88fa
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x1a88f4
	spriteface $0, $3
	applymovement $5, MovementData_0x1a88db
	dotrigger $1
	disappear $5
	special $003d
	variablesprite $5, $31
	special $005e
	end
; 0x1a886b

UnknownScript_0x1a886b: ; 0x1a886b
	spriteface $0, $2
	showemote $0, $0, 15
	special $006a
	pause 15
	playsound $001f
	appear $5
	waitbutton
	applymovement $5, MovementData_0x1a88d6
	playmusic $001f
	loadfont
	2writetext UnknownText_0x1a88fa
	closetext
	loadmovesprites
	applymovement $0, MovementData_0x1a88f7
	spriteface $0, $3
	applymovement $5, MovementData_0x1a88e8
	disappear $5
	dotrigger $1
	special $003d
	variablesprite $5, $31
	special $005e
	end
; 0x1a88a3

UnknownScript_0x1a88a3: ; 0x1a88a3
	jumptextfaceplayer UnknownText_0x1a8a58
; 0x1a88a6

UnknownScript_0x1a88a6: ; 0x1a88a6
	faceplayer
	loadfont
	random $2
	if_equal $0, UnknownScript_0x1a88b4
	2writetext UnknownText_0x1a8b04
	closetext
	loadmovesprites
	end
; 0x1a88b4

UnknownScript_0x1a88b4: ; 0x1a88b4
	2writetext UnknownText_0x1a8b41
	closetext
	loadmovesprites
	end
; 0x1a88ba

UnknownScript_0x1a88ba: ; 0x1a88ba
	jumptextfaceplayer UnknownText_0x1a8b71
; 0x1a88bd

MapOlivineCitySignpost0Script: ; 0x1a88bd
	jumptext UnknownText_0x1a8bd0
; 0x1a88c0

MapOlivineCitySignpost1Script: ; 0x1a88c0
	jumptext UnknownText_0x1a8c00
; 0x1a88c3

MapOlivineCitySignpost2Script: ; 0x1a88c3
	jumptext UnknownText_0x1a8c1d
; 0x1a88c6

MapOlivineCitySignpost3Script: ; 0x1a88c6
	jumptext UnknownText_0x1a8c60
; 0x1a88c9

MapOlivineCitySignpost4Script: ; 0x1a88c9
	jumptext UnknownText_0x1a8c99
; 0x1a88cc

MapOlivineCitySignpost5Script: ; 0x1a88cc
	jumpstd $0010
; 0x1a88cf

MapOlivineCitySignpost6Script: ; 0x1a88cf
	jumpstd $0011
; 0x1a88d2

MovementData_0x1a88d2: ; 0x1a88d2
	step_down
	step_right
	step_right
	step_end
; 0x1a88d6

MovementData_0x1a88d6: ; 0x1a88d6
	step_down
	step_down
	step_right
	step_right
	step_end
; 0x1a88db

MovementData_0x1a88db: ; 0x1a88db
	step_right
	step_right
	step_right
	step_right
	step_right
	step_right
	step_up
	step_up
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x1a88e8

MovementData_0x1a88e8: ; 0x1a88e8
	step_right
	step_right
	step_right
	step_right
	step_right
	step_right
	step_up
	step_up
	step_up
	step_up
	step_up
	step_end
; 0x1a88f4

MovementData_0x1a88f4: ; 0x1a88f4
	step_down
	turn_head_up
	step_end
; 0x1a88f7

MovementData_0x1a88f7: ; 0x1a88f7
	step_up
	turn_head_down
	step_end
; 0x1a88fa

UnknownText_0x1a88fa: ; 0x1a88fa
	db $0, "…", $51
	db "You again?", $51
	db "There's no need to", $4f
	db "panic. I don't", $51
	db "bother with wimps", $4f
	db "like you.", $51
	db "Speaking of weak-", $4f
	db "lings, the city's", $51
	db "GYM LEADER isn't", $4f
	db "here.", $51
	db "Supposedly taking", $4f
	db "care of a sick", $51
	db "#MON at the", $4f
	db "LIGHTHOUSE.", $51
	db "Humph! Boo-hoo!", $4f
	db "Just let sick", $55
	db "#MON go!", $51
	db "A #MON that", $4f
	db "can't battle is", $55
	db "worthless!", $51
	db "Why don't you go", $4f
	db "train at the", $55
	db "LIGHTHOUSE?", $51
	db "Who knows. It may", $4f
	db "make you a bit", $55
	db "less weak!", $57
; 0x1a8a58

UnknownText_0x1a8a58: ; 0x1a8a58
	db $0, "Dark roads are", $4f
	db "dangerous at", $55
	db "night.", $51
	db "But in the pitch-", $4f
	db "black of night,", $51
	db "the sea is even", $4f
	db "more treacherous!", $51
	db "Without the beacon", $4f
	db "of the LIGHTHOUSE", $51
	db "to guide it, no", $4f
	db "ship can sail.", $57
; 0x1a8b04

UnknownText_0x1a8b04: ; 0x1a8b04
	db $0, "That thing you", $4f
	db "have--it's a #-", $55
	db "GEAR, right? Wow,", $55
	db "that's cool.", $57
; 0x1a8b41

UnknownText_0x1a8b41: ; 0x1a8b41
	db $0, "Wow, you have a", $4f
	db "#DEX!", $51
	db "That is just so", $4f
	db "awesome.", $57
; 0x1a8b71

UnknownText_0x1a8b71: ; 0x1a8b71
	db $0, "The sea is sweet!", $51
	db "Sunsets on the sea", $4f
	db "are marvelous!", $51
	db "Sing with me! ", $4f
	db "Yo-ho! Blow the", $55
	db "man down!…", $57
; 0x1a8bd0

UnknownText_0x1a8bd0: ; 0x1a8bd0
	db $0, "OLIVINE CITY", $51
	db "The Port Closest", $4f
	db "to Foreign Lands", $57
; 0x1a8c00

UnknownText_0x1a8c00: ; 0x1a8c00
	db $0, "OLIVINE PORT", $4f
	db "FAST SHIP PIER", $57
; 0x1a8c1d

UnknownText_0x1a8c1d: ; 0x1a8c1d
	db $0, "OLIVINE CITY", $4f
	db "#MON GYM", $55
	db "LEADER: JASMINE", $51
	db "The Steel-Clad", $4f
	db "Defense Girl", $57
; 0x1a8c60

UnknownText_0x1a8c60: ; 0x1a8c60
	db $0, "OLIVINE LIGHTHOUSE", $4f
	db "Also known as the", $55
	db "GLITTER LIGHTHOUSE", $57
; 0x1a8c99

UnknownText_0x1a8c99: ; 0x1a8c99
	db $0, "BATTLE TOWER AHEAD", $4f
	db "Opening Now!", $57
; 0x1a8cba

UnknownText_0x1a8cba: ; 0x1a8cba
	db $0, "BATTLE TOWER AHEAD", $57
; 0x1a8cce

OlivineCity_MapEventHeader: ; 0x1a8cce
	; filler
	db 0, 0

	; warps
	db 11
	warp_def $15, $d, 1, GROUP_OLIVINE_POKECENTER_1F, MAP_OLIVINE_POKECENTER_1F
	warp_def $b, $a, 1, GROUP_OLIVINE_GYM, MAP_OLIVINE_GYM
	warp_def $b, $19, 1, GROUP_OLIVINE_VOLTORB_HOUSE, MAP_OLIVINE_VOLTORB_HOUSE
	warp_def $0, $0, 1, GROUP_OLIVINE_HOUSE_BETA, MAP_OLIVINE_HOUSE_BETA
	warp_def $b, $1d, 1, GROUP_OLIVINE_PUNISHMENT_SPEECH_HOUSE, MAP_OLIVINE_PUNISHMENT_SPEECH_HOUSE
	warp_def $f, $d, 1, GROUP_OLIVINE_GOOD_ROD_HOUSE, MAP_OLIVINE_GOOD_ROD_HOUSE
	warp_def $15, $7, 1, GROUP_OLIVINE_CAFE, MAP_OLIVINE_CAFE
	warp_def $11, $13, 2, GROUP_OLIVINE_MART, MAP_OLIVINE_MART
	warp_def $1b, $1d, 1, GROUP_OLIVINE_LIGHTHOUSE_1F, MAP_OLIVINE_LIGHTHOUSE_1F
	warp_def $1b, $13, 1, GROUP_OLIVINE_PORT_PASSAGE, MAP_OLIVINE_PORT_PASSAGE
	warp_def $1b, $14, 2, GROUP_OLIVINE_PORT_PASSAGE, MAP_OLIVINE_PORT_PASSAGE

	; xy triggers
	db 2
	xy_trigger 0, $c, $d, $0, UnknownScript_0x1a8833, $0, $0
	xy_trigger 0, $d, $d, $0, UnknownScript_0x1a886b, $0, $0

	; signposts
	db 7
	signpost 11, 17, $0, MapOlivineCitySignpost0Script
	signpost 24, 20, $0, MapOlivineCitySignpost1Script
	signpost 11, 7, $0, MapOlivineCitySignpost2Script
	signpost 28, 30, $0, MapOlivineCitySignpost3Script
	signpost 23, 3, $0, MapOlivineCitySignpost4Script
	signpost 21, 14, $0, MapOlivineCitySignpost5Script
	signpost 17, 20, $0, MapOlivineCitySignpost6Script

	; people-events
	db 4
	person_event $49, 31, 30, $4, $10, 255, 255, $0, 0, UnknownScript_0x1a88a3, $ffff
	person_event $66, 17, 24, $3, $0, 255, 255, $80, 0, UnknownScript_0x1a88a6, $ffff
	person_event $49, 25, 21, $2, $11, 255, 255, $0, 0, UnknownScript_0x1a88ba, $ffff
	person_event $f5, 15, 14, $6, $0, 255, 255, $0, 0, ObjectEvent, $06c3
; 0x1a8d72

Route37_MapScriptHeader: ; 0x1a8d72
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 2, UnknownScript_0x1a8d77
; 0x1a8d77

UnknownScript_0x1a8d77: ; 0x1a8d77
	checkcode $b
	if_equal SUNDAY, UnknownScript_0x1a8d80
	disappear $6
	return
; 0x1a8d80

UnknownScript_0x1a8d80: ; 0x1a8d80
	appear $6
	return
; 0x1a8d83

TrainerTwinsAnnandanne1: ; 0x1a8d83
	; bit/flag number
	dw $465

	; trainer group && trainer id
	db TWINS, ANNANDANNE1

	; text when seen
	dw TwinsAnnandanne1SeenText

	; text when trainer beaten
	dw TwinsAnnandanne1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TwinsAnnandanne1Script
; 0x1a8d8f

TwinsAnnandanne1Script: ; 0x1a8d8f
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a8e62
	closetext
	loadmovesprites
	end
; 0x1a8d97

TrainerTwinsAnnandanne2: ; 0x1a8d97
	; bit/flag number
	dw $465

	; trainer group && trainer id
	db TWINS, ANNANDANNE2

	; text when seen
	dw TwinsAnnandanne2SeenText

	; text when trainer beaten
	dw TwinsAnnandanne2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TwinsAnnandanne2Script
; 0x1a8da3

TwinsAnnandanne2Script: ; 0x1a8da3
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a8eec
	closetext
	loadmovesprites
	end
; 0x1a8dab

TrainerPsychicGreg: ; 0x1a8dab
	; bit/flag number
	dw $43e

	; trainer group && trainer id
	db PSYCHIC_T, GREG

	; text when seen
	dw PsychicGregSeenText

	; text when trainer beaten
	dw PsychicGregBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PsychicGregScript
; 0x1a8db7

PsychicGregScript: ; 0x1a8db7
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a8f80
	closetext
	loadmovesprites
	end
; 0x1a8dbf

UnknownScript_0x1a8dbf: ; 0x1a8dbf
	faceplayer
	loadfont
	checkbit1 $0069
	iftrue UnknownScript_0x1a8dfa
	checkcode $b
	if_not_equal SUNDAY, UnknownScript_0x1a8e00
	checkbit1 $0068
	iftrue UnknownScript_0x1a8dda
	2writetext UnknownText_0x1a8fc8
	keeptextopen
	setbit1 $0068
UnknownScript_0x1a8dda: ; 0x1a8dda
	checkbit2 $0063
	iftrue UnknownScript_0x1a8de7
	2writetext UnknownText_0x1a9004
	keeptextopen
	2jump UnknownScript_0x1a8deb
; 0x1a8de7

UnknownScript_0x1a8de7: ; 0x1a8de7
	2writetext UnknownText_0x1a902f
	keeptextopen
UnknownScript_0x1a8deb: ; 0x1a8deb
	verbosegiveitem MAGNET, 1
	iffalse UnknownScript_0x1a8dfe
	setbit1 $0069
	2writetext UnknownText_0x1a905a
	closetext
	loadmovesprites
	end
; 0x1a8dfa

UnknownScript_0x1a8dfa: ; 0x1a8dfa
	2writetext UnknownText_0x1a90fc
	closetext
UnknownScript_0x1a8dfe: ; 0x1a8dfe
	loadmovesprites
	end
; 0x1a8e00

UnknownScript_0x1a8e00: ; 0x1a8e00
	2writetext UnknownText_0x1a916e
	closetext
	loadmovesprites
	end
; 0x1a8e06

MapRoute37Signpost0Script: ; 0x1a8e06
	jumptext UnknownText_0x1a9197
; 0x1a8e09

UnknownScript_0x1a8e09: ; 0x1a8e09
	fruittree $11
; 0x1a8e0b

UnknownScript_0x1a8e0b: ; 0x1a8e0b
	fruittree $12
; 0x1a8e0d

UnknownScript_0x1a8e0d: ; 0x1a8e0d
	fruittree $13
; 0x1a8e0f

MapRoute37SignpostItem1: ; 0x1a8e0f
	dw $00a9
	db ETHER
	
; 0x1a8e12

TwinsAnnandanne1SeenText: ; 0x1a8e12
	db $0, "ANN: ANNE and I", $4f
	db "are in this to-", $55
	db "gether!", $57
; 0x1a8e3b

TwinsAnnandanne1BeatenText: ; 0x1a8e3b
	db $0, "ANN & ANNE: Nnn… A", $4f
	db "little too strong.", $57
; 0x1a8e62

UnknownText_0x1a8e62: ; 0x1a8e62
	db $0, "ANN: I can tell", $4f
	db "what my sister and", $51
	db "my #MON are", $4f
	db "thinking.", $57
; 0x1a8e9c

TwinsAnnandanne2SeenText: ; 0x1a8e9c
	db $0, "ANNE: ANN and I", $4f
	db "are in this to-", $55
	db "gether!", $57
; 0x1a8ec5

TwinsAnnandanne2BeatenText: ; 0x1a8ec5
	db $0, "ANN & ANNE: Nnn… A", $4f
	db "little too strong.", $57
; 0x1a8eec

UnknownText_0x1a8eec: ; 0x1a8eec
	db $0, "ANNE: We share the", $4f
	db "same feelings as", $55
	db "our #MON.", $57
; 0x1a8f1b

PsychicGregSeenText: ; 0x1a8f1b
	db $0, "#MON can't do a", $4f
	db "thing if they are", $55
	db "asleep.", $51
	db "I'll show you how", $4f
	db "scary that is!", $57
; 0x1a8f65

PsychicGregBeatenText: ; 0x1a8f65
	db $0, "I lost. That's", $4f
	db "pretty sad…", $57
; 0x1a8f80

UnknownText_0x1a8f80: ; 0x1a8f80
	db $0, "Putting #MON to", $4f
	db "sleep or paralyz-", $55
	db "ing them are good", $55
	db "battle techniques.", $57
; 0x1a8fc8

UnknownText_0x1a8fc8: ; 0x1a8fc8
	db $0, "SUNNY: Hi!", $51
	db "I'm SUNNY of Sun-", $4f
	db "day, meaning it's", $55
	db "Sunday today!", $57
; 0x1a9004

UnknownText_0x1a9004: ; 0x1a9004
	db $0, "I was told to give", $4f
	db "you this if I saw", $55
	db "you!", $57
; 0x1a902f

UnknownText_0x1a902f: ; 0x1a902f
	db $0, "I was told to give", $4f
	db "you this if I saw", $55
	db "you!", $57
; 0x1a905a

UnknownText_0x1a905a: ; 0x1a905a
	db $0, "SUNNY: That thing…", $51
	db "Um…", $51
	db "… What was it now…", $51
	db "…", $51
	db "Oh! I remember", $4f
	db "now!", $51
	db "A #MON that", $4f
	db "knows electric", $51
	db "moves should hold", $4f
	db "it.", $51
	db "My sis MONICA said", $4f
	db "it powers up", $55
	db "electric moves!", $57
; 0x1a90fc

UnknownText_0x1a90fc: ; 0x1a90fc
	db $0, "SUNNY: My sisters", $4f
	db "and brothers are", $55
	db "MONICA, TUSCANY,", $55
	db "WESLEY, ARTHUR,", $55
	db "FRIEDA and SANTOS.", $51
	db "They're all older", $4f
	db "than me!", $57
; 0x1a916e

UnknownText_0x1a916e: ; 0x1a916e
	db $0, "SUNNY: Isn't today", $4f
	db "Sunday?", $55
	db "Um… I forgot!", $57
; 0x1a9197

UnknownText_0x1a9197: ; 0x1a9197
	db $0, "ROUTE 37", $57
; 0x1a91a1

Route37_MapEventHeader: ; 0x1a91a1
	; filler
	db 0, 0

	; warps
	db 0

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 3, 5, $0, MapRoute37Signpost0Script
	signpost 2, 4, $7, MapRoute37SignpostItem1

	; people-events
	db 7
	person_event $f4, 16, 10, $6, $0, 255, 255, $82, 1, TrainerTwinsAnnandanne1, $ffff
	person_event $f4, 16, 11, $6, $0, 255, 255, $82, 1, TrainerTwinsAnnandanne2, $ffff
	person_event $27, 10, 10, $a, $0, 255, 255, $92, 1, TrainerPsychicGreg, $ffff
	person_event $5d, 9, 17, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a8e09, $ffff
	person_event $25, 12, 20, $2, $11, 255, 255, $0, 0, UnknownScript_0x1a8dbf, $075b
	person_event $5d, 9, 20, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a8e0b, $ffff
	person_event $5d, 11, 19, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a8e0d, $ffff
; 0x1a920c

Route42_MapScriptHeader: ; 0x1a920c
	; trigger count
	db 2

	; triggers
	dw UnknownScript_0x1a9216, $0000
	dw UnknownScript_0x1a9217, $0000

	; callback count
	db 0
; 0x1a9216

UnknownScript_0x1a9216: ; 0x1a9216
	end
; 0x1a9217

UnknownScript_0x1a9217: ; 0x1a9217
	end
; 0x1a9218

UnknownScript_0x1a9218: ; 0x1a9218
	showemote $0, $0, 15
	pause 15
	playsound $0014
	applymovement $a, MovementData_0x1a9356
	disappear $a
	pause 10
	dotrigger $0
	clearbit1 $07b0
	domaptrigger GROUP_ROUTE_36, MAP_ROUTE_36, $1
	end
; 0x1a9233

TrainerFisherTully1: ; 0x1a9233
	; bit/flag number
	dw $454

	; trainer group && trainer id
	db FISHER, TULLY1

	; text when seen
	dw FisherTully1SeenText

	; text when trainer beaten
	dw FisherTully1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherTully1Script
; 0x1a923f

FisherTully1Script: ; 0x1a923f
	writecode $17, $1d
	talkaftercancel
	loadfont
	checkbit2 $0076
	iftrue UnknownScript_0x1a927f
	checkbit2 $0084
	iftrue UnknownScript_0x1a92dc
	checkcellnum $1d
	iftrue UnknownScript_0x1a92fd
	checkbit1 $028f
	iftrue UnknownScript_0x1a9268
	2writetext UnknownText_0x1a93ab
	keeptextopen
	setbit1 $028f
	2call UnknownScript_0x1a92f1
	2jump UnknownScript_0x1a926b
; 0x1a9268

UnknownScript_0x1a9268: ; 0x1a9268
	2call UnknownScript_0x1a92f5
UnknownScript_0x1a926b: ; 0x1a926b
	askforphonenumber $1d
	if_equal $1, UnknownScript_0x1a9305
	if_equal $2, UnknownScript_0x1a9301
	trainertotext FISHER, TULLY1, $0
	2call UnknownScript_0x1a92f9
	2jump UnknownScript_0x1a92fd
; 0x1a927f

UnknownScript_0x1a927f: ; 0x1a927f
	2call UnknownScript_0x1a9309
	winlosstext FisherTully1BeatenText, $0000
	copybytetovar $da06
	if_equal $3, UnknownScript_0x1a929a
	if_equal $2, UnknownScript_0x1a92a0
	if_equal $1, UnknownScript_0x1a92a6
	if_equal $0, UnknownScript_0x1a92ac
UnknownScript_0x1a929a: ; 0x1a929a
	checkbit1 $00cd
	iftrue UnknownScript_0x1a92d3
UnknownScript_0x1a92a0: ; 0x1a92a0
	checkbit1 $0044
	iftrue UnknownScript_0x1a92c6
UnknownScript_0x1a92a6: ; 0x1a92a6
	checkbit1 $0022
	iftrue UnknownScript_0x1a92b9
UnknownScript_0x1a92ac: ; 0x1a92ac
	loadtrainer FISHER, TULLY1
	startbattle
	returnafterbattle
	loadvar $da06, $1
	clearbit2 $0076
	end
; 0x1a92b9

UnknownScript_0x1a92b9: ; 0x1a92b9
	loadtrainer FISHER, TULLY2
	startbattle
	returnafterbattle
	loadvar $da06, $2
	clearbit2 $0076
	end
; 0x1a92c6

UnknownScript_0x1a92c6: ; 0x1a92c6
	loadtrainer FISHER, TULLY3
	startbattle
	returnafterbattle
	loadvar $da06, $3
	clearbit2 $0076
	end
; 0x1a92d3

UnknownScript_0x1a92d3: ; 0x1a92d3
	loadtrainer FISHER, TULLY4
	startbattle
	returnafterbattle
	clearbit2 $0076
	end
; 0x1a92dc

UnknownScript_0x1a92dc: ; 0x1a92dc
	2call UnknownScript_0x1a930d
	verbosegiveitem WATER_STONE, 1
	iffalse UnknownScript_0x1a92ee
	clearbit2 $0084
	setbit1 $0103
	2jump UnknownScript_0x1a92fd
; 0x1a92ee

UnknownScript_0x1a92ee: ; 0x1a92ee
	2jump UnknownScript_0x1a9311
; 0x1a92f1

UnknownScript_0x1a92f1: ; 0x1a92f1
	jumpstd $0019
	end
; 0x1a92f5

UnknownScript_0x1a92f5: ; 0x1a92f5
	jumpstd $001a
	end
; 0x1a92f9

UnknownScript_0x1a92f9: ; 0x1a92f9
	jumpstd $001b
	end
; 0x1a92fd

UnknownScript_0x1a92fd: ; 0x1a92fd
	jumpstd $001c
	end
; 0x1a9301

UnknownScript_0x1a9301: ; 0x1a9301
	jumpstd $001d
	end
; 0x1a9305

UnknownScript_0x1a9305: ; 0x1a9305
	jumpstd $001e
	end
; 0x1a9309

UnknownScript_0x1a9309: ; 0x1a9309
	jumpstd $001f
	end
; 0x1a930d

UnknownScript_0x1a930d: ; 0x1a930d
	jumpstd $0020
	end
; 0x1a9311

UnknownScript_0x1a9311: ; 0x1a9311
	jumpstd $0021
	end
; 0x1a9315

TrainerPokemaniacShane: ; 0x1a9315
	; bit/flag number
	dw $4e7

	; trainer group && trainer id
	db POKEMANIAC, SHANE

	; text when seen
	dw PokemaniacShaneSeenText

	; text when trainer beaten
	dw PokemaniacShaneBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokemaniacShaneScript
; 0x1a9321

PokemaniacShaneScript: ; 0x1a9321
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a94d6
	closetext
	loadmovesprites
	end
; 0x1a9329

TrainerHikerBenjamin: ; 0x1a9329
	; bit/flag number
	dw $529

	; trainer group && trainer id
	db HIKER, BENJAMIN

	; text when seen
	dw HikerBenjaminSeenText

	; text when trainer beaten
	dw HikerBenjaminBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerBenjaminScript
; 0x1a9335

HikerBenjaminScript: ; 0x1a9335
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a943f
	closetext
	loadmovesprites
	end
; 0x1a933d

MapRoute42Signpost0Script: ; 0x1a933d
	jumptext UnknownText_0x1a9537
; 0x1a9340

MapRoute42Signpost1Script: ; 0x1a9340
	jumptext UnknownText_0x1a955f
; 0x1a9343

MapRoute42Signpost2Script: ; 0x1a9343
	jumptext UnknownText_0x1a9580
; 0x1a9346

MapRoute42Signpost3Script: ; 0x1a9346
	jumptext UnknownText_0x1a95a1
; 0x1a9349

ItemFragment_0x1a9349: ; 0x1a9349
	db ULTRA_BALL, 1
; 0x1a934b

ItemFragment_0x1a934b: ; 0x1a934b
	db SUPER_POTION, 1
; 0x1a934d

UnknownScript_0x1a934d: ; 0x1a934d
	fruittree $15
; 0x1a934f

UnknownScript_0x1a934f: ; 0x1a934f
	fruittree $16
; 0x1a9351

UnknownScript_0x1a9351: ; 0x1a9351
	fruittree $17
; 0x1a9353

MapRoute42SignpostItem4: ; 0x1a9353
	dw $00ad
	db MAX_POTION
	
; 0x1a9356

MovementData_0x1a9356: ; 0x1a9356
	db $39 ; movement
	fast_jump_step_up
	fast_jump_step_up
	fast_jump_step_up
	fast_jump_step_right
	fast_jump_step_right
	fast_jump_step_right
	db $38 ; movement
	step_end
; 0x1a935f

FisherTully1SeenText: ; 0x1a935f
	db $0, "Let me demonstrate", $4f
	db "the power of the", $55
	db "#MON I caught!", $57
; 0x1a9393

FisherTully1BeatenText: ; 0x1a9393
	db $0, "What? That's not", $4f
	db "right.", $57
; 0x1a93ab

UnknownText_0x1a93ab: ; 0x1a93ab
	db $0, "I want to become", $4f
	db "the trainer CHAMP", $51
	db "using the #MON", $4f
	db "I caught.", $51
	db "That's the best", $4f
	db "part of fishing!", $57
; 0x1a9408

HikerBenjaminSeenText: ; 0x1a9408
	db $0, "Ah, it's good to", $4f
	db "be outside!", $55
	db "I feel so free!", $57
; 0x1a9435

HikerBenjaminBeatenText: ; 0x1a9435
	db $0, "Gahahah!", $57
; 0x1a943f

UnknownText_0x1a943f: ; 0x1a943f
	db $0, "Losing feels in-", $4f
	db "significant if you", $51
	db "look up at the big", $4f
	db "sky!", $57
; 0x1a947c

PokemaniacShaneSeenText: ; 0x1a947c
	db $0, "HEY!", $51
	db "This is my secret", $4f
	db "place! Get lost,", $55
	db "you outsider!", $57
; 0x1a94b3

PokemaniacShaneBeatenText: ; 0x1a94b3
	db $0, "I should have used", $4f
	db "my MOON STONE…", $57
; 0x1a94d6

UnknownText_0x1a94d6: ; 0x1a94d6
	db $0, "You're working on", $4f
	db "a #DEX?", $51
	db "Wow, you must know", $4f
	db "some pretty rare", $55
	db "#MON!", $51
	db "May I please see", $4f
	db "it. Please?", $57
; 0x1a9537

UnknownText_0x1a9537: ; 0x1a9537
	db $0, "ROUTE 42", $51
	db "ECRUTEAK CITY -", $4f
	db "MAHOGANY TOWN", $57
; 0x1a955f

UnknownText_0x1a955f: ; 0x1a955f
	db $0, "MT.MORTAR", $51
	db "WATERFALL CAVE", $4f
	db "INSIDE", $57
; 0x1a9580

UnknownText_0x1a9580: ; 0x1a9580
	db $0, "MT.MORTAR", $51
	db "WATERFALL CAVE", $4f
	db "INSIDE", $57
; 0x1a95a1

UnknownText_0x1a95a1: ; 0x1a95a1
	db $0, "ROUTE 42", $51
	db "ECRUTEAK CITY -", $4f
	db "MAHOGANY TOWN", $57
; 0x1a95c9

Route42_MapEventHeader: ; 0x1a95c9
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $8, $0, 3, GROUP_ROUTE_42_ECRUTEAK_GATE, MAP_ROUTE_42_ECRUTEAK_GATE
	warp_def $9, $0, 4, GROUP_ROUTE_42_ECRUTEAK_GATE, MAP_ROUTE_42_ECRUTEAK_GATE
	warp_def $5, $a, 1, GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE
	warp_def $9, $1c, 2, GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE
	warp_def $7, $2e, 3, GROUP_MOUNT_MORTAR_1F_OUTSIDE, MAP_MOUNT_MORTAR_1F_OUTSIDE

	; xy triggers
	db 1
	xy_trigger 1, $e, $18, $0, UnknownScript_0x1a9218, $0, $0

	; signposts
	db 5
	signpost 10, 4, $0, MapRoute42Signpost0Script
	signpost 5, 7, $0, MapRoute42Signpost1Script
	signpost 9, 45, $0, MapRoute42Signpost2Script
	signpost 8, 54, $0, MapRoute42Signpost3Script
	signpost 11, 16, $7, MapRoute42SignpostItem4

	; people-events
	db 9
	person_event $3a, 14, 44, $8, $0, 255, 255, $a2, 1, TrainerFisherTully1, $ffff
	person_event $2d, 13, 55, $a, $0, 255, 255, $b2, 3, TrainerHikerBenjamin, $ffff
	person_event $2b, 12, 51, $6, $0, 255, 255, $92, 3, TrainerPokemaniacShane, $ffff
	person_event $5d, 20, 31, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a934d, $ffff
	person_event $5d, 20, 32, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a934f, $ffff
	person_event $5d, 20, 33, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a9351, $ffff
	person_event $54, 8, 10, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a9349, $06b3
	person_event $54, 12, 37, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a934b, $06b4
	person_event $63, 20, 30, $1, $0, 255, 255, $90, 0, ObjectEvent, $07af
; 0x1a967e

Route46_MapScriptHeader: ; 0x1a967e
	; trigger count
	db 0

	; callback count
	db 0
; 0x1a9680

TrainerCamperTed: ; 0x1a9680
	; bit/flag number
	dw $424

	; trainer group && trainer id
	db CAMPER, TED

	; text when seen
	dw CamperTedSeenText

	; text when trainer beaten
	dw CamperTedBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperTedScript
; 0x1a968c

CamperTedScript: ; 0x1a968c
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a9851
	closetext
	loadmovesprites
	end
; 0x1a9694

TrainerPicnickerErin1: ; 0x1a9694
	; bit/flag number
	dw $487

	; trainer group && trainer id
	db PICNICKER, ERIN1

	; text when seen
	dw PicnickerErin1SeenText

	; text when trainer beaten
	dw PicnickerErin1BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerErin1Script
; 0x1a96a0

PicnickerErin1Script: ; 0x1a96a0
	writecode $17, $24
	talkaftercancel
	loadfont
	checkbit2 $007c
	iftrue UnknownScript_0x1a96da
	checkcellnum $24
	iftrue UnknownScript_0x1a975b
	checkbit1 $029d
	iftrue UnknownScript_0x1a96c3
	2writetext UnknownText_0x1a98c6
	keeptextopen
	setbit1 $029d
	2call UnknownScript_0x1a974f
	2jump UnknownScript_0x1a96c6
; 0x1a96c3

UnknownScript_0x1a96c3: ; 0x1a96c3
	2call UnknownScript_0x1a9753
UnknownScript_0x1a96c6: ; 0x1a96c6
	askforphonenumber $24
	if_equal $1, UnknownScript_0x1a9763
	if_equal $2, UnknownScript_0x1a975f
	trainertotext PICNICKER, ERIN1, $0
	2call UnknownScript_0x1a9757
	2jump UnknownScript_0x1a975b
; 0x1a96da

UnknownScript_0x1a96da: ; 0x1a96da
	2call UnknownScript_0x1a9767
	winlosstext PicnickerErin1BeatenText, $0000
	copybytetovar $da0d
	if_equal $2, UnknownScript_0x1a96f1
	if_equal $1, UnknownScript_0x1a96f7
	if_equal $0, UnknownScript_0x1a96fd
UnknownScript_0x1a96f1: ; 0x1a96f1
	checkbit1 $00cd
	iftrue UnknownScript_0x1a9717
UnknownScript_0x1a96f7: ; 0x1a96f7
	checkbit1 $0044
	iftrue UnknownScript_0x1a970a
UnknownScript_0x1a96fd: ; 0x1a96fd
	loadtrainer PICNICKER, ERIN1
	startbattle
	returnafterbattle
	loadvar $da0d, $1
	clearbit2 $007c
	end
; 0x1a970a

UnknownScript_0x1a970a: ; 0x1a970a
	loadtrainer PICNICKER, ERIN2
	startbattle
	returnafterbattle
	loadvar $da0d, $2
	clearbit2 $007c
	end
; 0x1a9717

UnknownScript_0x1a9717: ; 0x1a9717
	loadtrainer PICNICKER, ERIN3
	startbattle
	returnafterbattle
	clearbit2 $007c
	checkbit1 $033b
	iftrue UnknownScript_0x1a973b
	checkbit1 $0269
	iftrue UnknownScript_0x1a973a
	2call UnknownScript_0x1a9772
	verbosegiveitem CALCIUM, 1
	iffalse UnknownScript_0x1a976b
	setbit1 $0269
	2jump UnknownScript_0x1a975b
; 0x1a973a

UnknownScript_0x1a973a: ; 0x1a973a
	end
; 0x1a973b

UnknownScript_0x1a973b: ; 0x1a973b
	loadfont
	2writetext UnknownText_0x1a9927
	closetext
	verbosegiveitem CALCIUM, 1
	iffalse UnknownScript_0x1a976b
	clearbit1 $033b
	setbit1 $0269
	2jump UnknownScript_0x1a975b
; 0x1a974f

UnknownScript_0x1a974f: ; 0x1a974f
	jumpstd $0023
	end
; 0x1a9753

UnknownScript_0x1a9753: ; 0x1a9753
	jumpstd $0024
	end
; 0x1a9757

UnknownScript_0x1a9757: ; 0x1a9757
	jumpstd $0025
	end
; 0x1a975b

UnknownScript_0x1a975b: ; 0x1a975b
	jumpstd $0026
	end
; 0x1a975f

UnknownScript_0x1a975f: ; 0x1a975f
	jumpstd $0027
	end
; 0x1a9763

UnknownScript_0x1a9763: ; 0x1a9763
	jumpstd $0028
	end
; 0x1a9767

UnknownScript_0x1a9767: ; 0x1a9767
	jumpstd $0029
	end
; 0x1a976b

UnknownScript_0x1a976b: ; 0x1a976b
	setbit1 $033b
	jumpstd $002b
	end
; 0x1a9772

UnknownScript_0x1a9772: ; 0x1a9772
	jumpstd $002c
	end
; 0x1a9776

TrainerHikerBailey: ; 0x1a9776
	; bit/flag number
	dw $52e

	; trainer group && trainer id
	db HIKER, BAILEY

	; text when seen
	dw HikerBaileySeenText

	; text when trainer beaten
	dw HikerBaileyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerBaileyScript
; 0x1a9782

HikerBaileyScript: ; 0x1a9782
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1a97e8
	closetext
	loadmovesprites
	end
; 0x1a978a

MapRoute46Signpost0Script: ; 0x1a978a
	jumptext UnknownText_0x1a99be
; 0x1a978d

ItemFragment_0x1a978d: ; 0x1a978d
	db X_SPEED, 1
; 0x1a978f

UnknownScript_0x1a978f: ; 0x1a978f
	fruittree $4
; 0x1a9791

UnknownScript_0x1a9791: ; 0x1a9791
	fruittree $a
; 0x1a9793

HikerBaileySeenText: ; 0x1a9793
	db $0, "Awright! I'll show", $4f
	db "you the power of", $55
	db "mountain #MON!", $57
; 0x1a97c6

HikerBaileyBeatenText: ; 0x1a97c6
	db $0, "Mercy! You showed", $4f
	db "me your power!", $57
; 0x1a97e8

UnknownText_0x1a97e8: ; 0x1a97e8
	db $0, "It's over. I don't", $4f
	db "mind. We HIKERS", $55
	db "are like that.", $57
; 0x1a9819

CamperTedSeenText: ; 0x1a9819
	db $0, "I'm raising #-", $4f
	db "MON too!", $51
	db "Will you battle", $4f
	db "with me?", $57
; 0x1a984a

CamperTedBeatenText: ; 0x1a984a
	db $0, "Wha…?", $57
; 0x1a9851

UnknownText_0x1a9851: ; 0x1a9851
	db $0, "I did my best but", $4f
	db "came up short.", $51
	db "No excuses--I", $4f
	db "admit I lost.", $57
; 0x1a988f

PicnickerErin1SeenText: ; 0x1a988f
	db $0, "I raise #MON", $4f
	db "too!", $51
	db "Will you battle", $4f
	db "with me?", $57
; 0x1a98bb

PicnickerErin1BeatenText: ; 0x1a98bb
	db $0, "Oh, rats!", $57
; 0x1a98c6

UnknownText_0x1a98c6: ; 0x1a98c6
	db $0, "I've been to many", $4f
	db "GYMS, but the GYM", $51
	db "in GOLDENROD is my", $4f
	db "favorite.", $51
	db "It's filled with", $4f
	db "pretty flowers!", $57
; 0x1a9927

UnknownText_0x1a9927: ; 0x1a9927
	db $0, "Aww… I keep losing", $4f
	db "all the time!", $51
	db "I'll just have to", $4f
	db "try harder!", $51
	db "Anyway, thanks for", $4f
	db "battling me again", $51
	db "and again. Here's", $4f
	db "that present from", $55
	db "the other time.", $57
; 0x1a99be

UnknownText_0x1a99be: ; 0x1a99be
	db $0, "ROUTE 46", $4f
	db "MOUNTAIN RD. AHEAD", $57
; 0x1a99db

Route46_MapEventHeader: ; 0x1a99db
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $21, $7, 1, GROUP_ROUTE_29_46_GATE, MAP_ROUTE_29_46_GATE
	warp_def $21, $8, 2, GROUP_ROUTE_29_46_GATE, MAP_ROUTE_29_46_GATE
	warp_def $5, $e, 3, GROUP_DARK_CAVE_VIOLET_ENTRANCE, MAP_DARK_CAVE_VIOLET_ENTRANCE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 27, 9, $0, MapRoute46Signpost0Script

	; people-events
	db 6
	person_event $2d, 23, 16, $8, $0, 255, 255, $b2, 2, TrainerHikerBailey, $ffff
	person_event $27, 18, 8, $7, $0, 255, 255, $a2, 2, TrainerCamperTed, $ffff
	person_event $28, 17, 6, $6, $0, 255, 255, $a2, 2, TrainerPicnickerErin1, $ffff
	person_event $5d, 9, 11, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a978f, $ffff
	person_event $5d, 10, 12, $1, $0, 255, 255, $0, 0, UnknownScript_0x1a9791, $ffff
	person_event $54, 19, 5, $1, $0, 255, 255, $1, 0, ItemFragment_0x1a978d, $06bc
; 0x1a9a43

ViridianCity_MapScriptHeader: ; 0x1a9a43
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1a9a48
; 0x1a9a48

UnknownScript_0x1a9a48: ; 0x1a9a48
	setbit2 $0036
	return
; 0x1a9a4c

UnknownScript_0x1a9a4c: ; 0x1a9a4c
	faceplayer
	loadfont
	2writetext UnknownText_0x1a9aa5
	yesorno
	iffalse UnknownScript_0x1a9a5b
	2writetext UnknownText_0x1a9b6f
	closetext
	loadmovesprites
	end
; 0x1a9a5b

UnknownScript_0x1a9a5b: ; 0x1a9a5b
	2writetext UnknownText_0x1a9bb7
	closetext
	loadmovesprites
	end
; 0x1a9a61

UnknownScript_0x1a9a61: ; 0x1a9a61
	faceplayer
	loadfont
	checkbit1 $0775
	iftrue UnknownScript_0x1a9a6f
	2writetext UnknownText_0x1a9c11
	closetext
	loadmovesprites
	end
; 0x1a9a6f

UnknownScript_0x1a9a6f: ; 0x1a9a6f
	2writetext UnknownText_0x1a9c7e
	closetext
	loadmovesprites
	end
; 0x1a9a75

UnknownScript_0x1a9a75: ; 0x1a9a75
	faceplayer
	loadfont
	checkbit1 $00e0
	iftrue UnknownScript_0x1a9a8a
	2writetext UnknownText_0x1a9cc4
	keeptextopen
	verbosegiveitem TM_42, 1
	iffalse UnknownScript_0x1a9a8e
	setbit1 $00e0
UnknownScript_0x1a9a8a: ; 0x1a9a8a
	2writetext UnknownText_0x1a9d86
	closetext
UnknownScript_0x1a9a8e: ; 0x1a9a8e
	loadmovesprites
	end
; 0x1a9a90

UnknownScript_0x1a9a90: ; 0x1a9a90
	jumptextfaceplayer UnknownText_0x1a9daa
; 0x1a9a93

MapViridianCitySignpost0Script: ; 0x1a9a93
	jumptext UnknownText_0x1a9def
; 0x1a9a96

MapViridianCitySignpost1Script: ; 0x1a9a96
	jumptext UnknownText_0x1a9e1b
; 0x1a9a99

MapViridianCitySignpost2Script: ; 0x1a9a99
	jumptext UnknownText_0x1a9e60
; 0x1a9a9c

MapViridianCitySignpost3Script: ; 0x1a9a9c
	jumptext UnknownText_0x1a9e99
; 0x1a9a9f

MapViridianCitySignpost4Script: ; 0x1a9a9f
	jumpstd $0010
; 0x1a9aa2

MapViridianCitySignpost5Script: ; 0x1a9aa2
	jumpstd $0011
; 0x1a9aa5

UnknownText_0x1a9aa5: ; 0x1a9aa5
	db $0, "Hey, kid! I just", $4f
	db "had a double shot", $51
	db "of espresso, and", $4f
	db "I am wired!", $51
	db "I need to talk to", $4f
	db "someone, so you'll", $55
	db "have to do!", $51
	db "I might not look", $4f
	db "like much now, but", $51
	db "I was an expert at", $4f
	db "catching #MON.", $51
	db "Do you believe me?", $57
; 0x1a9b6f

UnknownText_0x1a9b6f: ; 0x1a9b6f
	db $0, "Good, good. Yes, I", $4f
	db "was something out", $51
	db "of the ordinary,", $4f
	db "let me tell you!", $57
; 0x1a9bb7

UnknownText_0x1a9bb7: ; 0x1a9bb7
	db $0, "What? You little", $4f
	db "whelp!", $51
	db "If I were just a", $4f
	db "bit younger, I'd", $51
	db "show you a thing", $4f
	db "or two. Humph!", $57
; 0x1a9c11

UnknownText_0x1a9c11: ; 0x1a9c11
	db $0, "This GYM didn't", $4f
	db "have a LEADER", $55
	db "until recently.", $51
	db "A young man from", $4f
	db "PALLET became the", $51
	db "LEADER, but he's", $4f
	db "often away.", $57
; 0x1a9c7e

UnknownText_0x1a9c7e: ; 0x1a9c7e
	db $0, "Are you going to", $4f
	db "battle the LEADER?", $51
	db "Good luck to you.", $4f
	db "You'll need it.", $57
; 0x1a9cc4

UnknownText_0x1a9cc4: ; 0x1a9cc4
	db $0, "Yawn!", $51
	db "I must have dozed", $4f
	db "off in the sun.", $51
	db "…I had this dream", $4f
	db "about a DROWZEE", $51
	db "eating my dream.", $4f
	db "Weird, huh?", $51
	db "Huh?", $4f
	db "What's this?", $51
	db "Where did this TM", $4f
	db "come from?", $51
	db "This is spooky!", $4f
	db "Here, you can have", $55
	db "this TM.", $57
; 0x1a9d86

UnknownText_0x1a9d86: ; 0x1a9d86
	db $0, "TM42 contains", $4f
	db "DREAM EATER…", $51
	db "…Zzzzz…", $57
; 0x1a9daa

UnknownText_0x1a9daa: ; 0x1a9daa
	db $0, "I heard that there", $4f
	db "are many items on", $51
	db "the ground in", $4f
	db "VIRIDIAN FOREST.", $57
; 0x1a9def

UnknownText_0x1a9def: ; 0x1a9def
	db $0, "VIRIDIAN CITY", $51
	db "The Eternally", $4f
	db "Green Paradise", $57
; 0x1a9e1b

UnknownText_0x1a9e1b: ; 0x1a9e1b
	db $0, "VIRIDIAN CITY", $4f
	db "#MON GYM", $55
	db "LEADER: …", $51
	db "The rest of the", $4f
	db "text is illegible…", $57
; 0x1a9e60

UnknownText_0x1a9e60: ; 0x1a9e60
	db $0, "WELCOME TO", $4f
	db "VIRIDIAN CITY,", $51
	db "THE GATEWAY TO", $4f
	db "INDIGO PLATEAU", $57
; 0x1a9e99

UnknownText_0x1a9e99: ; 0x1a9e99
	db $0, "TRAINER HOUSE", $51
	db "The Club for Top", $4f
	db "Trainer Battles", $57
; 0x1a9ec9

ViridianCity_MapEventHeader: ; 0x1a9ec9
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $7, $20, 1, GROUP_VIRIDIAN_GYM, MAP_VIRIDIAN_GYM
	warp_def $9, $15, 1, GROUP_VIRIDIAN_NICKNAME_SPEECH_HOUSE, MAP_VIRIDIAN_NICKNAME_SPEECH_HOUSE
	warp_def $f, $17, 1, GROUP_TRAINER_HOUSE_1F, MAP_TRAINER_HOUSE_1F
	warp_def $13, $1d, 2, GROUP_VIRIDIAN_MART, MAP_VIRIDIAN_MART
	warp_def $19, $17, 1, GROUP_VIRIDIAN_POKECENTER_1F, MAP_VIRIDIAN_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 17, 17, $0, MapViridianCitySignpost0Script
	signpost 7, 27, $0, MapViridianCitySignpost1Script
	signpost 1, 19, $0, MapViridianCitySignpost2Script
	signpost 15, 21, $0, MapViridianCitySignpost3Script
	signpost 25, 24, $0, MapViridianCitySignpost4Script
	signpost 19, 30, $0, MapViridianCitySignpost5Script

	; people-events
	db 4
	person_event $2f, 9, 22, $2, $22, 255, 255, $0, 0, UnknownScript_0x1a9a4c, $ffff
	person_event $2f, 12, 34, $6, $0, 255, 255, $90, 0, UnknownScript_0x1a9a61, $ffff
	person_event $3a, 27, 10, $6, $0, 255, 255, $80, 0, UnknownScript_0x1a9a75, $ffff
	person_event $27, 25, 21, $2, $33, 255, 255, $a0, 0, UnknownScript_0x1a9a90, $ffff
; 0x1a9f3a

CeladonCity_MapScriptHeader: ; 0x1a9f3a
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1a9f3f
; 0x1a9f3f

UnknownScript_0x1a9f3f: ; 0x1a9f3f
	setbit2 $003d
	return
; 0x1a9f43

UnknownScript_0x1a9f43: ; 0x1a9f43
	jumptextfaceplayer UnknownText_0x1a9f7d
; 0x1a9f46

UnknownScript_0x1a9f46: ; 0x1a9f46
	loadfont
	2writetext UnknownText_0x1a9fcb
	cry POLIWRATH
	closetext
	loadmovesprites
	end
; 0x1a9f50

UnknownScript_0x1a9f50: ; 0x1a9f50
	jumptextfaceplayer UnknownText_0x1a9fde
; 0x1a9f53

UnknownScript_0x1a9f53: ; 0x1a9f53
	jumptextfaceplayer UnknownText_0x1aa043
; 0x1a9f56

UnknownScript_0x1a9f56: ; 0x1a9f56
	jumptextfaceplayer UnknownText_0x1aa0dc
; 0x1a9f59

UnknownScript_0x1a9f59: ; 0x1a9f59
	jumptextfaceplayer UnknownText_0x1aa115
; 0x1a9f5c

UnknownScript_0x1a9f5c: ; 0x1a9f5c
	jumptextfaceplayer UnknownText_0x1aa155
; 0x1a9f5f

UnknownScript_0x1a9f5f: ; 0x1a9f5f
	jumptextfaceplayer UnknownText_0x1aa1bd
; 0x1a9f62

UnknownScript_0x1a9f62: ; 0x1a9f62
	jumptextfaceplayer UnknownText_0x1aa306
; 0x1a9f65

MapCeladonCitySignpost0Script: ; 0x1a9f65
	jumptext UnknownText_0x1aa340
; 0x1a9f68

MapCeladonCitySignpost1Script: ; 0x1a9f68
	jumptext UnknownText_0x1aa369
; 0x1a9f6b

MapCeladonCitySignpost2Script: ; 0x1a9f6b
	jumptext UnknownText_0x1aa3a9
; 0x1a9f6e

MapCeladonCitySignpost3Script: ; 0x1a9f6e
	jumptext UnknownText_0x1aa3d4
; 0x1a9f71

MapCeladonCitySignpost4Script: ; 0x1a9f71
	jumptext UnknownText_0x1aa3e5
; 0x1a9f74

MapCeladonCitySignpost5Script: ; 0x1a9f74
	jumptext UnknownText_0x1aa418
; 0x1a9f77

MapCeladonCitySignpost6Script: ; 0x1a9f77
	jumpstd $0010
; 0x1a9f7a

MapCeladonCitySignpostItem7: ; 0x1a9f7a
	dw $00fd
	db PP_UP
	
; 0x1a9f7d

UnknownText_0x1a9f7d: ; 0x1a9f7d
	db $0, "This POLIWRATH is", $4f
	db "my partner.", $51
	db "I wonder if it'll", $4f
	db "ever evolve into a", $55
	db "frog #MON.", $57
; 0x1a9fcb

UnknownText_0x1a9fcb: ; 0x1a9fcb
	db $0, "POLIWRATH: Croak!", $57
; 0x1a9fde

UnknownText_0x1a9fde: ; 0x1a9fde
	db $0, "I lost at the slot", $4f
	db "machines again…", $51
	db "We girls also play", $4f
	db "the slots now.", $51
	db "You should check", $4f
	db "them out too.", $57
; 0x1aa043

UnknownText_0x1aa043: ; 0x1aa043
	db $0, "GRIMER have been", $4f
	db "appearing lately.", $51
	db "See that pond out", $4f
	db "in front of the", $51
	db "house? GRIMER live", $4f
	db "there now.", $51
	db "Where did they", $4f
	db "come from? This is", $55
	db "a serious problem…", $57
; 0x1aa0dc

UnknownText_0x1aa0dc: ; 0x1aa0dc
	db $0, "Nihihi! This GYM", $4f
	db "is great! Only", $51
	db "girls are allowed", $4f
	db "here!", $57
; 0x1aa115

UnknownText_0x1aa115: ; 0x1aa115
	db $0, "Want to know a", $4f
	db "secret?", $51
	db "CELADON MANSION", $4f
	db "has a hidden back", $55
	db "door.", $57
; 0x1aa155

UnknownText_0x1aa155: ; 0x1aa155
	db $0, "They're holding an", $4f
	db "eating contest at", $55
	db "the restaurant.", $51
	db "Just watching them", $4f
	db "go at it makes me", $55
	db "feel bloated…", $57
; 0x1aa1bd

UnknownText_0x1aa1bd: ; 0x1aa1bd
	db $0, "CELADON DEPT.STORE", $4f
	db "has the biggest", $51
	db "and best selection", $4f
	db "of merchandise.", $51
	db "If you can't get", $4f
	db "it there, you", $51
	db "can't get it any-", $4f
	db "where.", $51
	db "Gee… I sound like", $4f
	db "a sales clerk.", $57
; 0x1aa25b

; possibly unused
UnknownText_0x1aa25b: ; 0x1aa25b
	db $0, "I love being", $4f
	db "surrounded by tall", $55
	db "buildings!", $51
	db "Isn't it true that", $4f
	db "GOLDENROD #MON", $51
	db "CENTER was made", $4f
	db "much, much bigger?", $51
	db "That is so neat!", $4f
	db "I wish we had a", $51
	db "place like that in", $4f
	db "KANTO…", $57
; 0x1aa306

UnknownText_0x1aa306: ; 0x1aa306
	db $0, "Looking at the", $4f
	db "ground while I was", $51
	db "walking made me", $4f
	db "dizzy.", $57
; 0x1aa340

UnknownText_0x1aa340: ; 0x1aa340
	db $0, "CELADON CITY", $51
	db "The City of", $4f
	db "Rainbow Dreams", $57
; 0x1aa369

UnknownText_0x1aa369: ; 0x1aa369
	db $0, "CELADON CITY", $4f
	db "#MON GYM", $55
	db "LEADER: ERIKA", $51
	db "The Nature-Loving", $4f
	db "Princess", $57
; 0x1aa3a9

UnknownText_0x1aa3a9: ; 0x1aa3a9
	db $0, "Find What You", $4f
	db "Need at CELADON", $55
	db "DEPT.STORE!", $57
; 0x1aa3d4

UnknownText_0x1aa3d4: ; 0x1aa3d4
	db $0, "CELADON MANSION", $57
; 0x1aa3e5

UnknownText_0x1aa3e5: ; 0x1aa3e5
	db $0, "The Playground for", $4f
	db "Everybody--CELADON", $55
	db "GAME CORNER", $57
; 0x1aa418

UnknownText_0x1aa418: ; 0x1aa418
	db $0, "TRAINER TIPS", $51
	db "GUARD SPEC.", $4f
	db "protects #MON", $51
	db "against SPECIAL", $4f
	db "attacks such as", $55
	db "fire and water.", $51
	db "Get your items at", $4f
	db "CELADON DEPT.", $55
	db "STORE!", $57
; 0x1aa497

CeladonCity_MapEventHeader: ; 0x1aa497
	; filler
	db 0, 0

	; warps
	db 9
	warp_def $9, $4, 1, GROUP_CELADON_DEPT_STORE_1F, MAP_CELADON_DEPT_STORE_1F
	warp_def $9, $10, 1, GROUP_CELADON_MANSION_1F, MAP_CELADON_MANSION_1F
	warp_def $3, $10, 3, GROUP_CELADON_MANSION_1F, MAP_CELADON_MANSION_1F
	warp_def $3, $11, 3, GROUP_CELADON_MANSION_1F, MAP_CELADON_MANSION_1F
	warp_def $9, $1d, 1, GROUP_CELADON_POKECENTER_1F, MAP_CELADON_POKECENTER_1F
	warp_def $13, $12, 1, GROUP_CELADON_GAME_CORNER, MAP_CELADON_GAME_CORNER
	warp_def $13, $17, 1, GROUP_CELADON_GAME_CORNER_PRIZE_ROOM, MAP_CELADON_GAME_CORNER_PRIZE_ROOM
	warp_def $1d, $a, 1, GROUP_CELADON_GYM, MAP_CELADON_GYM
	warp_def $1d, $19, 1, GROUP_CELADON_CAFE, MAP_CELADON_CAFE

	; xy triggers
	db 0

	; signposts
	db 8
	signpost 21, 23, $0, MapCeladonCitySignpost0Script
	signpost 31, 11, $0, MapCeladonCitySignpost1Script
	signpost 9, 6, $0, MapCeladonCitySignpost2Script
	signpost 9, 13, $0, MapCeladonCitySignpost3Script
	signpost 21, 19, $0, MapCeladonCitySignpost4Script
	signpost 21, 29, $0, MapCeladonCitySignpost5Script
	signpost 9, 30, $0, MapCeladonCitySignpost6Script
	signpost 21, 37, $7, MapCeladonCitySignpostItem7

	; people-events
	db 9
	person_event $3a, 15, 30, $9, $0, 255, 255, $a0, 0, UnknownScript_0x1a9f43, $ffff
	person_event $8d, 15, 31, $16, $0, 255, 255, $90, 0, UnknownScript_0x1a9f46, $ffff
	person_event $29, 28, 24, $5, $2, 255, 255, $80, 0, UnknownScript_0x1a9f50, $ffff
	person_event $2f, 20, 18, $6, $0, 255, 255, $b0, 0, UnknownScript_0x1a9f53, $ffff
	person_event $2f, 35, 12, $7, $0, 255, 255, $80, 0, UnknownScript_0x1a9f56, $ffff
	person_event $27, 17, 22, $5, $2, 255, 255, $90, 0, UnknownScript_0x1a9f59, $ffff
	person_event $27, 37, 28, $7, $0, 255, 255, $a0, 0, UnknownScript_0x1a9f5c, $ffff
	person_event $29, 18, 10, $2, $22, 255, 255, $a0, 0, UnknownScript_0x1a9f5f, $ffff
	person_event $28, 26, 11, $4, $20, 255, 255, $80, 0, UnknownScript_0x1a9f62, $ffff
; 0x1aa567

Route15_MapScriptHeader: ; 0x1aa567
	; trigger count
	db 0

	; callback count
	db 0
; 0x1aa569

TrainerTeacherColette: ; 0x1aa569
	; bit/flag number
	dw $5b5

	; trainer group && trainer id
	db TEACHER, COLETTE

	; text when seen
	dw TeacherColetteSeenText

	; text when trainer beaten
	dw TeacherColetteBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TeacherColetteScript
; 0x1aa575

TeacherColetteScript: ; 0x1aa575
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1aa60d
	closetext
	loadmovesprites
	end
; 0x1aa57d

TrainerTeacherHillary: ; 0x1aa57d
	; bit/flag number
	dw $5b6

	; trainer group && trainer id
	db TEACHER, HILLARY

	; text when seen
	dw TeacherHillarySeenText

	; text when trainer beaten
	dw TeacherHillaryBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw TeacherHillaryScript
; 0x1aa589

TeacherHillaryScript: ; 0x1aa589
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1aa6ca
	closetext
	loadmovesprites
	end
; 0x1aa591

TrainerSchoolboyKipp: ; 0x1aa591
	; bit/flag number
	dw $46d

	; trainer group && trainer id
	db SCHOOLBOY, KIPP

	; text when seen
	dw SchoolboyKippSeenText

	; text when trainer beaten
	dw SchoolboyKippBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyKippScript
; 0x1aa59d

SchoolboyKippScript: ; 0x1aa59d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1aa740
	closetext
	loadmovesprites
	end
; 0x1aa5a5

TrainerSchoolboyTommy: ; 0x1aa5a5
	; bit/flag number
	dw $471

	; trainer group && trainer id
	db SCHOOLBOY, TOMMY

	; text when seen
	dw SchoolboyTommySeenText

	; text when trainer beaten
	dw SchoolboyTommyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyTommyScript
; 0x1aa5b1

SchoolboyTommyScript: ; 0x1aa5b1
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1aa7bc
	closetext
	loadmovesprites
	end
; 0x1aa5b9

TrainerSchoolboyJohnny: ; 0x1aa5b9
	; bit/flag number
	dw $46f

	; trainer group && trainer id
	db SCHOOLBOY, JOHNNY

	; text when seen
	dw SchoolboyJohnnySeenText

	; text when trainer beaten
	dw SchoolboyJohnnyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyJohnnyScript
; 0x1aa5c5

SchoolboyJohnnyScript: ; 0x1aa5c5
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1aa84a
	closetext
	loadmovesprites
	end
; 0x1aa5cd

TrainerSchoolboyBilly: ; 0x1aa5cd
	; bit/flag number
	dw $474

	; trainer group && trainer id
	db SCHOOLBOY, BILLY

	; text when seen
	dw SchoolboyBillySeenText

	; text when trainer beaten
	dw SchoolboyBillyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyBillyScript
; 0x1aa5d9

SchoolboyBillyScript: ; 0x1aa5d9
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1aa8b0
	closetext
	loadmovesprites
	end
; 0x1aa5e1

MapRoute15Signpost0Script: ; 0x1aa5e1
	jumptext UnknownText_0x1aa8e3
; 0x1aa5e4

ItemFragment_0x1aa5e4: ; 0x1aa5e4
	db PP_UP, 1
; 0x1aa5e6

TeacherColetteSeenText: ; 0x1aa5e6
	db $0, "Have you forgotten", $4f
	db "anything?", $57
; 0x1aa604

TeacherColetteBeatenText: ; 0x1aa604
	db $0, "Kyaaah!", $57
; 0x1aa60d

UnknownText_0x1aa60d: ; 0x1aa60d
	db $0, "Before I became a", $4f
	db "teacher, I used to", $51
	db "forget a lot of", $4f
	db "things.", $57
; 0x1aa64b

TeacherHillarySeenText: ; 0x1aa64b
	db $0, "On sunny days, I", $4f
	db "think that the", $51
	db "kids would rather", $4f
	db "be playing in the", $51
	db "schoolyard than", $4f
	db "studying in class.", $57
; 0x1aa6b3

TeacherHillaryBeatenText: ; 0x1aa6b3
	db $0, "I didn't want to", $4f
	db "lose…", $57
; 0x1aa6ca

UnknownText_0x1aa6ca: ; 0x1aa6ca
	db $0, "Studying is impor-", $4f
	db "tant, but exercise", $55
	db "is just as vital.", $57
; 0x1aa703

SchoolboyKippSeenText: ; 0x1aa703
	db $0, "Hang on. I have to", $4f
	db "phone my mom.", $57
; 0x1aa725

SchoolboyKippBeatenText: ; 0x1aa725
	db $0, "Sorry, Mom!", $4f
	db "I was beaten!", $57
; 0x1aa740

UnknownText_0x1aa740: ; 0x1aa740
	db $0, "My mom worries so", $4f
	db "much about me, I", $51
	db "have to phone her", $4f
	db "all the time.", $57
; 0x1aa784

SchoolboyTommySeenText: ; 0x1aa784
	db $0, "Let's battle.", $4f
	db "I won't lose!", $57
; 0x1aa79f

SchoolboyTommyBeatenText: ; 0x1aa79f
	db $0, "I forgot to do my", $4f
	db "homework!", $57
; 0x1aa7bc

UnknownText_0x1aa7bc: ; 0x1aa7bc
	db $0, "Sayonara! I just", $4f
	db "learned that in my", $55
	db "Japanese class.", $57
; 0x1aa7f1

SchoolboyJohnnySeenText: ; 0x1aa7f1
	db $0, "We're on a field", $4f
	db "trip to LAVENDER", $51
	db "RADIO TOWER for", $4f
	db "social studies.", $57
; 0x1aa833

SchoolboyJohnnyBeatenText: ; 0x1aa833
	db $0, "You're wickedly", $4f
	db "tough!", $57
; 0x1aa84a

UnknownText_0x1aa84a: ; 0x1aa84a
	db $0, "I'm tired of walk-", $4f
	db "ing. I need to", $55
	db "take a break.", $57
; 0x1aa87a

SchoolboyBillySeenText: ; 0x1aa87a
	db $0, "My favorite class", $4f
	db "is gym!", $57
; 0x1aa895

SchoolboyBillyBeatenText: ; 0x1aa895
	db $0, "Oh, no!", $4f
	db "How could I lose?", $57
; 0x1aa8b0

UnknownText_0x1aa8b0: ; 0x1aa8b0
	db $0, "If #MON were a", $4f
	db "subject at school,", $55
	db "I'd be the best!", $57
; 0x1aa8e3

UnknownText_0x1aa8e3: ; 0x1aa8e3
	db $0, "ROUTE 15", $51
	db "FUCHSIA CITY -", $4f
	db "LAVENDER TOWN", $57
; 0x1aa90a

Route15_MapEventHeader: ; 0x1aa90a
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $4, $2, 3, GROUP_ROUTE_15_FUCHSIA_GATE, MAP_ROUTE_15_FUCHSIA_GATE
	warp_def $5, $2, 4, GROUP_ROUTE_15_FUCHSIA_GATE, MAP_ROUTE_15_FUCHSIA_GATE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 9, 19, $0, MapRoute15Signpost0Script

	; people-events
	db 7
	person_event $27, 14, 14, $9, $0, 255, 255, $92, 4, TrainerSchoolboyKipp, $ffff
	person_event $27, 17, 19, $7, $0, 255, 255, $92, 3, TrainerSchoolboyTommy, $ffff
	person_event $27, 14, 37, $6, $0, 255, 255, $92, 3, TrainerSchoolboyJohnny, $ffff
	person_event $27, 14, 31, $6, $0, 255, 255, $92, 3, TrainerSchoolboyBilly, $ffff
	person_event $29, 16, 34, $7, $0, 255, 255, $82, 4, TrainerTeacherColette, $ffff
	person_event $29, 14, 24, $a, $0, 255, 255, $82, 3, TrainerTeacherHillary, $ffff
	person_event $54, 9, 16, $1, $0, 255, 255, $1, 0, ItemFragment_0x1aa5e4, $078a
; 0x1aa97a

VermilionCity_MapScriptHeader: ; 0x1aa97a
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1aa97f
; 0x1aa97f

UnknownScript_0x1aa97f: ; 0x1aa97f
	setbit2 $003a
	return
; 0x1aa983

UnknownScript_0x1aa983: ; 0x1aa983
	jumptextfaceplayer UnknownText_0x1aaa15
; 0x1aa986

UnknownScript_0x1aa986: ; 0x1aa986
	jumptextfaceplayer UnknownText_0x1aaa6f
; 0x1aa989

UnknownScript_0x1aa989: ; 0x1aa989
	loadfont
	2writetext UnknownText_0x1aaaca
	cry MACHOP
	closetext
	loadmovesprites
	earthquake 30
	loadfont
	2writetext UnknownText_0x1aaae2
	closetext
	loadmovesprites
	end
; 0x1aa99b

UnknownScript_0x1aa99b: ; 0x1aa99b
	jumptextfaceplayer UnknownText_0x1aab1a
; 0x1aa99e

UnknownScript_0x1aa99e: ; 0x1aa99e
	loadfont
	special $0060
	iftrue UnknownScript_0x1aa9ab
	2writetext UnknownText_0x1aab64
	closetext
	loadmovesprites
	end
; 0x1aa9ab

UnknownScript_0x1aa9ab: ; 0x1aa9ab
	2writetext UnknownText_0x1aab84
	pause 15
	cry SNORLAX
	loadmovesprites
	writecode $3, $a
	loadpokedata SNORLAX, 50
	startbattle
	disappear $6
	setbit1 $0750
	returnafterbattle
	end
; 0x1aa9c2

UnknownScript_0x1aa9c2: ; 0x1aa9c2
	faceplayer
	loadfont
	checkbit1 $00e2
	iftrue UnknownScript_0x1aa9f7
	checkcode $7
	if_equal $10, UnknownScript_0x1aa9ea
	if_less_than $d, UnknownScript_0x1aa9e4
	if_less_than $9, UnknownScript_0x1aa9de
	2writetext UnknownText_0x1aabc8
	closetext
	loadmovesprites
	end
; 0x1aa9de

UnknownScript_0x1aa9de: ; 0x1aa9de
	2writetext UnknownText_0x1aac2b
	closetext
	loadmovesprites
	end
; 0x1aa9e4

UnknownScript_0x1aa9e4: ; 0x1aa9e4
	2writetext UnknownText_0x1aac88
	closetext
	loadmovesprites
	end
; 0x1aa9ea

UnknownScript_0x1aa9ea: ; 0x1aa9ea
	2writetext UnknownText_0x1aacf3
	keeptextopen
	verbosegiveitem HP_UP, 1
	iffalse UnknownScript_0x1aa9fb
	setbit1 $00e2
UnknownScript_0x1aa9f7: ; 0x1aa9f7
	2writetext UnknownText_0x1aad4a
	closetext
UnknownScript_0x1aa9fb: ; 0x1aa9fb
	loadmovesprites
	end
; 0x1aa9fd

MapVermilionCitySignpost0Script: ; 0x1aa9fd
	jumptext UnknownText_0x1aadb9
; 0x1aaa00

MapVermilionCitySignpost1Script: ; 0x1aaa00
	jumptext UnknownText_0x1aade7
; 0x1aaa03

MapVermilionCitySignpost2Script: ; 0x1aaa03
	jumptext UnknownText_0x1aae28
; 0x1aaa06

MapVermilionCitySignpost3Script: ; 0x1aaa06
	jumptext UnknownText_0x1aae4e
; 0x1aaa09

MapVermilionCitySignpost4Script: ; 0x1aaa09
	jumptext UnknownText_0x1aae5e
; 0x1aaa0c

MapVermilionCitySignpost5Script: ; 0x1aaa0c
	jumpstd $0010
; 0x1aaa0f

MapVermilionCitySignpost6Script: ; 0x1aaa0f
	jumpstd $0011
; 0x1aaa12

MapVermilionCitySignpostItem7: ; 0x1aaa12
	dw $00fc
	db FULL_HEAL
	
; 0x1aaa15

UnknownText_0x1aaa15: ; 0x1aaa15
	db $0, "VERMILION PORT is", $4f
	db "KANTO's seaside", $55
	db "gateway.", $51
	db "Luxury liners from", $4f
	db "around the world", $55
	db "dock here.", $57
; 0x1aaa6f

UnknownText_0x1aaa6f: ; 0x1aaa6f
	db $0, "My #MON is", $4f
	db "preparing the land", $55
	db "for construction.", $51
	db "But I have no", $4f
	db "money to start the", $55
	db "project…", $57
; 0x1aaaca

UnknownText_0x1aaaca: ; 0x1aaaca
	db $0, "MACHOP: Guooh", $4f
	db "gogogoh!", $57
; 0x1aaae2

UnknownText_0x1aaae2: ; 0x1aaae2
	db $0, "A MACHOP is growl-", $4f
	db "ing while stomping", $55
	db "the ground flat.", $57
; 0x1aab1a

UnknownText_0x1aab1a: ; 0x1aab1a
	db $0, "There are eight", $4f
	db "GYMS in KANTO.", $51
	db "That big building", $4f
	db "is VERMILION's", $55
	db "#MON GYM.", $57
; 0x1aab64

UnknownText_0x1aab64: ; 0x1aab64
	db $0, "SNORLAX is snoring", $4f
	db "peacefully…", $57
; 0x1aab84

UnknownText_0x1aab84: ; 0x1aab84
	db $0, "The #GEAR was", $4f
	db "placed near the", $55
	db "sleeping SNORLAX…", $51
	db "…", $51
	db "SNORLAX woke up!", $57
; 0x1aabc8

UnknownText_0x1aabc8: ; 0x1aabc8
	db $0, "Skilled trainers", $4f
	db "gather in KANTO.", $51
	db "GYM LEADERS are", $4f
	db "especially strong.", $51
	db "They won't be easy", $4f
	db "to defeat.", $57
; 0x1aac2b

UnknownText_0x1aac2b: ; 0x1aac2b
	db $0, "You've started to", $4f
	db "collect KANTO GYM", $55
	db "BADGES?", $51
	db "Don't you agree", $4f
	db "that the trainers", $55
	db "here are tough?", $57
; 0x1aac88

UnknownText_0x1aac88: ; 0x1aac88
	db $0, "I guess you'll be", $4f
	db "finished with your", $51
	db "conquest of KANTO", $4f
	db "GYMS soon.", $51
	db "Let me know if", $4f
	db "you get all eight", $55
	db "BADGES.", $57
; 0x1aacf3

UnknownText_0x1aacf3: ; 0x1aacf3
	db $0, "Congratulations!", $51
	db "You got all the", $4f
	db "KANTO GYM BADGES.", $51
	db "I've got a reward", $4f
	db "for your efforts.", $57
; 0x1aad4a

UnknownText_0x1aad4a: ; 0x1aad4a
	db $0, "Having a variety", $4f
	db "of #MON types", $51
	db "should give you an", $4f
	db "edge in battle.", $51
	db "I'm sure the KANTO", $4f
	db "GYM BADGES will", $55
	db "help you.", $57
; 0x1aadb9

UnknownText_0x1aadb9: ; 0x1aadb9
	db $0, "VERMILION CITY", $51
	db "The Port of", $4f
	db "Exquisite Sunsets", $57
; 0x1aade7

UnknownText_0x1aade7: ; 0x1aade7
	db $0, "VERMILION CITY", $4f
	db "#MON GYM", $55
	db "LEADER: LT.SURGE", $51
	db "The Lightning", $4f
	db "American", $57
; 0x1aae28

UnknownText_0x1aae28: ; 0x1aae28
	db $0, "#MON FAN CLUB", $51
	db "All #MON Fans", $4f
	db "Welcome!", $57
; 0x1aae4e

UnknownText_0x1aae4e: ; 0x1aae4e
	db $0, "DIGLETT'S CAVE", $57
; 0x1aae5e

UnknownText_0x1aae5e: ; 0x1aae5e
	db $0, "VERMILION PORT", $4f
	db "ENTRANCE", $57
; 0x1aae77

VermilionCity_MapEventHeader: ; 0x1aae77
	; filler
	db 0, 0

	; warps
	db 10
	warp_def $5, $5, 1, GROUP_VERMILION_HOUSE_FISHING_SPEECH_HOUSE, MAP_VERMILION_HOUSE_FISHING_SPEECH_HOUSE
	warp_def $5, $9, 1, GROUP_VERMILION_POKECENTER_1F, MAP_VERMILION_POKECENTER_1F
	warp_def $d, $7, 1, GROUP_POKEMON_FAN_CLUB, MAP_POKEMON_FAN_CLUB
	warp_def $d, $d, 1, GROUP_VERMILION_MAGNET_TRAIN_SPEECH_HOUSE, MAP_VERMILION_MAGNET_TRAIN_SPEECH_HOUSE
	warp_def $d, $15, 2, GROUP_VERMILION_MART, MAP_VERMILION_MART
	warp_def $11, $15, 1, GROUP_VERMILION_HOUSE_DIGLETTS_CAVE_SPEECH_HOUSE, MAP_VERMILION_HOUSE_DIGLETTS_CAVE_SPEECH_HOUSE
	warp_def $13, $a, 1, GROUP_VERMILION_GYM, MAP_VERMILION_GYM
	warp_def $1f, $13, 1, GROUP_VERMILION_PORT_PASSAGE, MAP_VERMILION_PORT_PASSAGE
	warp_def $1f, $14, 2, GROUP_VERMILION_PORT_PASSAGE, MAP_VERMILION_PORT_PASSAGE
	warp_def $7, $22, 1, GROUP_DIGLETTS_CAVE, MAP_DIGLETTS_CAVE

	; xy triggers
	db 0

	; signposts
	db 8
	signpost 3, 25, $0, MapVermilionCitySignpost0Script
	signpost 19, 5, $0, MapVermilionCitySignpost1Script
	signpost 13, 5, $0, MapVermilionCitySignpost2Script
	signpost 9, 33, $0, MapVermilionCitySignpost3Script
	signpost 15, 27, $0, MapVermilionCitySignpost4Script
	signpost 5, 10, $0, MapVermilionCitySignpost5Script
	signpost 13, 22, $0, MapVermilionCitySignpost6Script
	signpost 19, 12, $7, MapVermilionCitySignpostItem7

	; people-events
	db 6
	person_event $29, 13, 22, $2, $11, 255, 255, $0, 0, UnknownScript_0x1aa983, $ffff
	person_event $2f, 10, 27, $9, $0, 255, 255, $0, 0, UnknownScript_0x1aa986, $ffff
	person_event $9a, 11, 30, $16, $0, 255, 255, $90, 0, UnknownScript_0x1aa989, $ffff
	person_event $2b, 20, 18, $2, $11, 255, 255, $a0, 0, UnknownScript_0x1aa99b, $ffff
	person_event $33, 12, 38, $15, $0, 255, 255, $0, 0, UnknownScript_0x1aa99e, $0770
	person_event $2d, 16, 35, $6, $0, 255, 255, $80, 0, UnknownScript_0x1aa9c2, $ffff
; 0x1aaf25

Route9_MapScriptHeader: ; 0x1aaf25
	; trigger count
	db 0

	; callback count
	db 0
; 0x1aaf27

TrainerCamperDean: ; 0x1aaf27
	; bit/flag number
	dw $420

	; trainer group && trainer id
	db CAMPER, DEAN

	; text when seen
	dw CamperDeanSeenText

	; text when trainer beaten
	dw CamperDeanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperDeanScript
; 0x1aaf33

CamperDeanScript: ; 0x1aaf33
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1aafd9
	closetext
	loadmovesprites
	end
; 0x1aaf3b

TrainerPicnickerHeidi: ; 0x1aaf3b
	; bit/flag number
	dw $48a

	; trainer group && trainer id
	db PICNICKER, HEIDI

	; text when seen
	dw PicnickerHeidiSeenText

	; text when trainer beaten
	dw PicnickerHeidiBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerHeidiScript
; 0x1aaf47

PicnickerHeidiScript: ; 0x1aaf47
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ab07c
	closetext
	loadmovesprites
	end
; 0x1aaf4f

TrainerCamperSid: ; 0x1aaf4f
	; bit/flag number
	dw $421

	; trainer group && trainer id
	db CAMPER, SID

	; text when seen
	dw CamperSidSeenText

	; text when trainer beaten
	dw CamperSidBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CamperSidScript
; 0x1aaf5b

CamperSidScript: ; 0x1aaf5b
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ab0f6
	closetext
	loadmovesprites
	end
; 0x1aaf63

TrainerPicnickerEdna: ; 0x1aaf63
	; bit/flag number
	dw $48b

	; trainer group && trainer id
	db PICNICKER, EDNA

	; text when seen
	dw PicnickerEdnaSeenText

	; text when trainer beaten
	dw PicnickerEdnaBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerEdnaScript
; 0x1aaf6f

PicnickerEdnaScript: ; 0x1aaf6f
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ab15f
	closetext
	loadmovesprites
	end
; 0x1aaf77

TrainerHikerTim: ; 0x1aaf77
	; bit/flag number
	dw $530

	; trainer group && trainer id
	db HIKER, TIM

	; text when seen
	dw HikerTimSeenText

	; text when trainer beaten
	dw HikerTimBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerTimScript
; 0x1aaf83

HikerTimScript: ; 0x1aaf83
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ab210
	closetext
	loadmovesprites
	end
; 0x1aaf8b

TrainerHikerSidney: ; 0x1aaf8b
	; bit/flag number
	dw $532

	; trainer group && trainer id
	db HIKER, SIDNEY

	; text when seen
	dw HikerSidneySeenText

	; text when trainer beaten
	dw HikerSidneyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerSidneyScript
; 0x1aaf97

HikerSidneyScript: ; 0x1aaf97
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ab278
	closetext
	loadmovesprites
	end
; 0x1aaf9f

MapRoute9Signpost0Script: ; 0x1aaf9f
	jumptext UnknownText_0x1ab2a2
; 0x1aafa2

MapRoute9SignpostItem1: ; 0x1aafa2
	dw $00f2
	db ETHER
	
; 0x1aafa5

CamperDeanSeenText: ; 0x1aafa5
	db $0, "I came to explore", $4f
	db "ROCK TUNNEL.", $57
; 0x1aafc5

CamperDeanBeatenText: ; 0x1aafc5
	db $0, "Whoa! Danger, man.", $57
; 0x1aafd9

UnknownText_0x1aafd9: ; 0x1aafd9
	db $0, "My #MON were", $4f
	db "hurt before even", $51
	db "entering ROCK", $4f
	db "TUNNEL.", $51
	db "I'd better take", $4f
	db "them to a #MON", $55
	db "CENTER right away.", $57
; 0x1ab03f

PicnickerHeidiSeenText: ; 0x1ab03f
	db $0, "Have you ever been", $4f
	db "to a picnic?", $51
	db "They're so much", $4f
	db "fun!", $57
; 0x1ab074

PicnickerHeidiBeatenText: ; 0x1ab074
	db $0, "Ohhhh!", $57
; 0x1ab07c

UnknownText_0x1ab07c: ; 0x1ab07c
	db $0, "We bake lots of", $4f
	db "goodies and share", $51
	db "them all around.", $4f
	db "They're delicious!", $57
; 0x1ab0c2

CamperSidSeenText: ; 0x1ab0c2
	db $0, "Hey, you!", $4f
	db "Don't litter!", $57
; 0x1ab0da

CamperSidBeatenText: ; 0x1ab0da
	db $0, "I was just point-", $4f
	db "ing out…", $57
; 0x1ab0f6

UnknownText_0x1ab0f6: ; 0x1ab0f6
	db $0, "Sorry. You weren't", $4f
	db "littering. It was", $55
	db "my mistake.", $57
; 0x1ab127

PicnickerEdnaSeenText: ; 0x1ab127
	db $0, "People shouldn't", $4f
	db "leave any litter", $55
	db "behind.", $57
; 0x1ab151

PicnickerEdnaBeatenText: ; 0x1ab151
	db $0, "Ohh… I lost…", $57
; 0x1ab15f

UnknownText_0x1ab15f: ; 0x1ab15f
	db $0, "Conserving energy", $4f
	db "is important, but", $51
	db "the environment is", $4f
	db "even more vital.", $57
; 0x1ab1a8

HikerTimSeenText: ; 0x1ab1a8
	db $0, "She'll be coming", $4f
	db "'round MT.SILVER", $55
	db "when she comes…", $51
	db "MT.SILVER is in", $4f
	db "JOHTO, right?", $57
; 0x1ab1f7

HikerTimBeatenText: ; 0x1ab1f7
	db $0, "I was too busy", $4f
	db "singing…", $57
; 0x1ab210

UnknownText_0x1ab210: ; 0x1ab210
	db $0, "Battles are about", $4f
	db "concentration.", $57
; 0x1ab232

HikerSidneySeenText: ; 0x1ab232
	db $0, "I'll tell you a", $4f
	db "secret.", $51
	db "But first, we", $4f
	db "battle!", $57
; 0x1ab260

HikerSidneyBeatenText: ; 0x1ab260
	db $0, "Oh, dang!", $4f
	db "I lost that…", $57
; 0x1ab278

UnknownText_0x1ab278: ; 0x1ab278
	db $0, "The POWER PLANT is", $4f
	db "across a small", $55
	db "river.", $57
; 0x1ab2a2

UnknownText_0x1ab2a2: ; 0x1ab2a2
	db $0, "ROUTE 9", $51
	db "CERULEAN CITY -", $4f
	db "ROCK TUNNEL", $57
; 0x1ab2c7

Route9_MapEventHeader: ; 0x1ab2c7
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $f, $30, 1, GROUP_ROCK_TUNNEL_1F, MAP_ROCK_TUNNEL_1F

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 7, 15, $0, MapRoute9Signpost0Script
	signpost 15, 41, $7, MapRoute9SignpostItem1

	; people-events
	db 6
	person_event $27, 15, 27, $8, $0, 255, 255, $a2, 3, TrainerCamperDean, $ffff
	person_event $28, 12, 43, $a, $0, 255, 255, $a2, 3, TrainerPicnickerHeidi, $ffff
	person_event $27, 8, 15, $a, $0, 255, 255, $a2, 5, TrainerCamperSid, $ffff
	person_event $28, 19, 16, $7, $0, 255, 255, $a2, 1, TrainerPicnickerEdna, $ffff
	person_event $2d, 7, 32, $9, $0, 255, 255, $b2, 2, TrainerHikerTim, $ffff
	person_event $2d, 19, 40, $9, $0, 255, 255, $b2, 4, TrainerHikerSidney, $ffff
; 0x1ab32a

CinnabarPokeCenter1F_MapScriptHeader: ; 0x1ab32a
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ab32c

UnknownScript_0x1ab32c: ; 0x1ab32c
	jumpstd $0000
; 0x1ab32f

UnknownScript_0x1ab32f: ; 0x1ab32f
	jumptextfaceplayer UnknownText_0x1ab335
; 0x1ab332

UnknownScript_0x1ab332: ; 0x1ab332
	jumptextfaceplayer UnknownText_0x1ab37f
; 0x1ab335

UnknownText_0x1ab335: ; 0x1ab335
	db $0, "CINNABAR GYM's", $4f
	db "BLAINE apparently", $51
	db "lives alone in the", $4f
	db "SEAFOAM ISLANDS", $55
	db "cave…", $57
; 0x1ab37f

UnknownText_0x1ab37f: ; 0x1ab37f
	db $0, "It's been a year", $4f
	db "since the volcano", $55
	db "erupted.", $57
; 0x1ab3ab

CinnabarPokeCenter1F_MapEventHeader: ; 0x1ab3ab
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_CINNABAR_ISLAND, MAP_CINNABAR_ISLAND
	warp_def $7, $4, 1, GROUP_CINNABAR_ISLAND, MAP_CINNABAR_ISLAND
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x1ab32c, $ffff
	person_event $24, 10, 11, $5, $2, 255, 255, $80, 0, UnknownScript_0x1ab32f, $ffff
	person_event $3a, 8, 6, $6, $0, 255, 255, $a0, 0, UnknownScript_0x1ab332, $ffff
; 0x1ab3e7

CinnabarPokeCenter2FBeta_MapScriptHeader: ; 0x1ab3e7
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ab3e9

CinnabarPokeCenter2FBeta_MapEventHeader: ; 0x1ab3e9
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $0, 3, GROUP_CINNABAR_POKECENTER_1F, MAP_CINNABAR_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 0
; 0x1ab3f4

Route19FuchsiaGate_MapScriptHeader: ; 0x1ab3f4
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ab3f6

UnknownScript_0x1ab3f6: ; 0x1ab3f6
	faceplayer
	loadfont
	checkbit1 $00d7
	iftrue UnknownScript_0x1ab404
	2writetext UnknownText_0x1ab40a
	closetext
	loadmovesprites
	end
; 0x1ab404

UnknownScript_0x1ab404: ; 0x1ab404
	2writetext UnknownText_0x1ab48a
	closetext
	loadmovesprites
	end
; 0x1ab40a

UnknownText_0x1ab40a: ; 0x1ab40a
	db $0, "CINNABAR's volcano", $4f
	db "erupted.", $51
	db "It hurled boulders", $4f
	db "that cut off ROUTE", $55
	db "19 indefinitely.", $51
	db "I wonder if the", $4f
	db "people of CINNABAR", $55
	db "are safe…", $57
; 0x1ab48a

UnknownText_0x1ab48a: ; 0x1ab48a
	db $0, "No CINNABAR citi-", $4f
	db "zens were injured", $51
	db "by the eruption.", $4f
	db "That's great!", $57
; 0x1ab4cd

Route19FuchsiaGate_MapEventHeader: ; 0x1ab4cd
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $0, $4, 10, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $0, $5, 11, GROUP_FUCHSIA_CITY, MAP_FUCHSIA_CITY
	warp_def $7, $4, 1, GROUP_ROUTE_19, MAP_ROUTE_19
	warp_def $7, $5, 1, GROUP_ROUTE_19, MAP_ROUTE_19

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $43, 8, 4, $9, $0, 255, 255, $90, 0, UnknownScript_0x1ab3f6, $ffff
; 0x1ab4f4

SeafoamGym_MapScriptHeader: ; 0x1ab4f4
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x1ab4fa, $0000

	; callback count
	db 0
; 0x1ab4fa

UnknownScript_0x1ab4fa: ; 0x1ab4fa
	end
; 0x1ab4fb

UnknownScript_0x1ab4fb: ; 0x1ab4fb
	faceplayer
	loadfont
	checkbit2 $0029
	iftrue UnknownScript_0x1ab52b
	2writetext UnknownText_0x1ab548
	closetext
	loadmovesprites
	winlosstext UnknownText_0x1ab646, $0000
	loadtrainer BLAINE, 1
	startbattle
	iftrue UnknownScript_0x1ab516
	appear $3
UnknownScript_0x1ab516: ; 0x1ab516
	returnafterbattle
	setbit1 $04cb
	loadfont
	2writetext UnknownText_0x1ab683
	playsound $009c
	waitbutton
	setbit2 $0029
	2writetext UnknownText_0x1ab69d
	closetext
	loadmovesprites
	end
; 0x1ab52b

UnknownScript_0x1ab52b: ; 0x1ab52b
	2writetext UnknownText_0x1ab71c
	closetext
	loadmovesprites
	end
; 0x1ab531

SeafoamGymGuyScript: ; 0x1ab531
	faceplayer
	loadfont
	checkbit1 $00d5
	iftrue .TalkedToSeafoamGymGuyScript
	2writetext SeafoamGymGuyWinText
	closetext
	loadmovesprites
	setbit1 $00d5
	end

.TalkedToSeafoamGymGuyScript
	2writetext SeafoamGymGuyWinText2
	closetext
	loadmovesprites
	end
; 0x1ab548

UnknownText_0x1ab548: ; 0x1ab548
	db $0, "BLAINE: Waaah!", $51
	db "My GYM in CINNABAR", $4f
	db "burned down.", $51
	db "My fire-breathing", $4f
	db "#MON and I are", $51
	db "homeless because", $4f
	db "of the volcano.", $51
	db "Waaah!", $51
	db "But I'm back in", $4f
	db "business as a GYM", $51
	db "LEADER here in", $4f
	db "this cave.", $51
	db "If you can beat", $4f
	db "me, I'll give you", $55
	db "a BADGE.", $51
	db "Ha! You'd better", $4f
	db "have BURN HEAL!", $57
; 0x1ab646

UnknownText_0x1ab646: ; 0x1ab646
	db $0, "BLAINE: Awesome.", $4f
	db "I've burned out…", $51
	db "You've earned", $4f
	db "VOLCANOBADGE!", $57
; 0x1ab683

UnknownText_0x1ab683: ; 0x1ab683
	db $0, $52, " received", $4f
	db "VOLCANOBADGE.", $57
; 0x1ab69d

UnknownText_0x1ab69d: ; 0x1ab69d
	db $0, "BLAINE: I did lose", $4f
	db "this time, but I'm", $51
	db "going to win the", $4f
	db "next time.", $51
	db "When I rebuild my", $4f
	db "CINNABAR GYM,", $51
	db "we'll have to have", $4f
	db "a rematch.", $57
; 0x1ab71c

UnknownText_0x1ab71c: ; 0x1ab71c
	db $0, "BLAINE: My fire", $4f
	db "#MON will be", $51
	db "even stronger.", $4f
	db "Just you watch!", $57
; 0x1ab759

SeafoamGymGuyWinText: ; 0x1ab759
	db $0, "Yo!", $51
	db "… Huh? It's over", $4f
	db "already?", $51
	db "Sorry, sorry!", $51
	db "CINNABAR GYM was", $4f
	db "gone, so I didn't", $51
	db "know where to find", $4f
	db "you.", $51
	db "But, hey, you're", $4f
	db "plenty strong even", $51
	db "without my advice.", $4f
	db "I knew you'd win!", $57
; 0x1ab806

SeafoamGymGuyWinText2: ; 0x1ab806
	db $0, "A #MON GYM can", $4f
	db "be anywhere as", $51
	db "long as the GYM", $4f
	db "LEADER is there.", $51
	db "There's no need", $4f
	db "for a building.", $57
; 0x1ab865

SeafoamGym_MapEventHeader: ; 0x1ab865
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $5, $5, 1, GROUP_ROUTE_20, MAP_ROUTE_20

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $d, 6, 9, $6, $0, 255, 255, $b0, 0, UnknownScript_0x1ab4fb, $ffff
	person_event $48, 9, 10, $7, $0, 255, 255, $90, 0, SeafoamGymGuyScript, $0777
; 0x1ab88a

SECTION "bank6B",DATA,BANK[$6B]

Route33_MapScriptHeader: ; 0x1ac000
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ac002

UnknownScript_0x1ac002: ; 0x1ac002
	jumptextfaceplayer UnknownText_0x1ac1e7
; 0x1ac005

TrainerHikerAnthony2: ; 0x1ac005
	; bit/flag number
	dw $528

	; trainer group && trainer id
	db HIKER, ANTHONY2

	; text when seen
	dw HikerAnthony2SeenText

	; text when trainer beaten
	dw HikerAnthony2BeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerAnthony2Script
; 0x1ac011

HikerAnthony2Script: ; 0x1ac011
	writecode $17, $13
	talkaftercancel
	loadfont
	checkbit2 $006f
	iftrue UnknownScript_0x1ac051
	checkbit2 $00a0
	iftrue UnknownScript_0x1ac0c5
	checkcellnum $13
	iftrue UnknownScript_0x1ac0d7
	checkbit1 $027b
	iftrue UnknownScript_0x1ac03a
	2writetext UnknownText_0x1ac153
	keeptextopen
	setbit1 $027b
	2call UnknownScript_0x1ac0cb
	2jump UnknownScript_0x1ac03d
; 0x1ac03a

UnknownScript_0x1ac03a: ; 0x1ac03a
	2call UnknownScript_0x1ac0cf
UnknownScript_0x1ac03d: ; 0x1ac03d
	askforphonenumber $13
	if_equal $1, UnknownScript_0x1ac0df
	if_equal $2, UnknownScript_0x1ac0db
	trainertotext HIKER, ANTHONY2, $0
	2call UnknownScript_0x1ac0d3
	2jump UnknownScript_0x1ac0d7
; 0x1ac051

UnknownScript_0x1ac051: ; 0x1ac051
	2call UnknownScript_0x1ac0e3
	winlosstext HikerAnthony2BeatenText, $0000
	copybytetovar $d9fd
	if_equal $4, UnknownScript_0x1ac070
	if_equal $3, UnknownScript_0x1ac076
	if_equal $2, UnknownScript_0x1ac07c
	if_equal $1, UnknownScript_0x1ac082
	if_equal $0, UnknownScript_0x1ac088
UnknownScript_0x1ac070: ; 0x1ac070
	checkbit1 $00cd
	iftrue UnknownScript_0x1ac0bc
UnknownScript_0x1ac076: ; 0x1ac076
	checkbit1 $0044
	iftrue UnknownScript_0x1ac0af
UnknownScript_0x1ac07c: ; 0x1ac07c
	checkbit1 $0021
	iftrue UnknownScript_0x1ac0a2
UnknownScript_0x1ac082: ; 0x1ac082
	checkbit2 $0047
	iftrue UnknownScript_0x1ac095
UnknownScript_0x1ac088: ; 0x1ac088
	loadtrainer HIKER, ANTHONY2
	startbattle
	returnafterbattle
	loadvar $d9fd, $1
	clearbit2 $006f
	end
; 0x1ac095

UnknownScript_0x1ac095: ; 0x1ac095
	loadtrainer HIKER, ANTHONY1
	startbattle
	returnafterbattle
	loadvar $d9fd, $2
	clearbit2 $006f
	end
; 0x1ac0a2

UnknownScript_0x1ac0a2: ; 0x1ac0a2
	loadtrainer HIKER, ANTHONY3
	startbattle
	returnafterbattle
	loadvar $d9fd, $3
	clearbit2 $006f
	end
; 0x1ac0af

UnknownScript_0x1ac0af: ; 0x1ac0af
	loadtrainer HIKER, ANTHONY4
	startbattle
	returnafterbattle
	loadvar $d9fd, $4
	clearbit2 $006f
	end
; 0x1ac0bc

UnknownScript_0x1ac0bc: ; 0x1ac0bc
	loadtrainer HIKER, ANTHONY5
	startbattle
	returnafterbattle
	clearbit2 $006f
	end
; 0x1ac0c5

UnknownScript_0x1ac0c5: ; 0x1ac0c5
	2writetext UnknownText_0x1ac180
	closetext
	loadmovesprites
	end
; 0x1ac0cb

UnknownScript_0x1ac0cb: ; 0x1ac0cb
	jumpstd $0019
	end
; 0x1ac0cf

UnknownScript_0x1ac0cf: ; 0x1ac0cf
	jumpstd $001a
	end
; 0x1ac0d3

UnknownScript_0x1ac0d3: ; 0x1ac0d3
	jumpstd $001b
	end
; 0x1ac0d7

UnknownScript_0x1ac0d7: ; 0x1ac0d7
	jumpstd $001c
	end
; 0x1ac0db

UnknownScript_0x1ac0db: ; 0x1ac0db
	jumpstd $001d
	end
; 0x1ac0df

UnknownScript_0x1ac0df: ; 0x1ac0df
	jumpstd $001e
	end
; 0x1ac0e3

UnknownScript_0x1ac0e3: ; 0x1ac0e3
	jumpstd $001f
	end
; 0x1ac0e7

MapRoute33Signpost0Script: ; 0x1ac0e7
	jumptext UnknownText_0x1ac279
; 0x1ac0ea

UnknownScript_0x1ac0ea: ; 0x1ac0ea
	fruittree $6
; 0x1ac0ec

HikerAnthony2SeenText: ; 0x1ac0ec
	db $0, "I came through the", $4f
	db "tunnel, but I", $51
	db "still have plenty", $4f
	db "of energy left.", $57
; 0x1ac130

HikerAnthony2BeatenText: ; 0x1ac130
	db $0, "Whoa! You've got", $4f
	db "more zip than me!", $57
; 0x1ac153

UnknownText_0x1ac153: ; 0x1ac153
	db $0, "We HIKERS are at", $4f
	db "our best in the", $55
	db "mountains.", $57
; 0x1ac180

UnknownText_0x1ac180: ; 0x1ac180
	db $0, "Hey, did you get a", $4f
	db "DUNSPARCE?", $51
	db "I caught one too.", $51
	db "Take a look at it", $4f
	db "in the light. It's", $55
	db "got a funny face!", $57
; 0x1ac1e7

UnknownText_0x1ac1e7: ; 0x1ac1e7
	db $0, "Pant, pant…", $51
	db "I finally got", $4f
	db "through that cave.", $51
	db "It was much bigger", $4f
	db "than I'd expected.", $51
	db "I got too tired to", $4f
	db "explore the whole", $51
	db "thing, so I came", $4f
	db "outside.", $57
; 0x1ac279

UnknownText_0x1ac279: ; 0x1ac279
	db $0, "ROUTE 33", $57
; 0x1ac283

Route33_MapEventHeader: ; 0x1ac283
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $9, $b, 3, GROUP_UNION_CAVE_1F, MAP_UNION_CAVE_1F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 11, 11, $0, MapRoute33Signpost0Script

	; people-events
	db 3
	person_event $2d, 17, 10, $a, $0, 255, 255, $b2, 2, TrainerHikerAnthony2, $ffff
	person_event $28, 20, 17, $2, $11, 255, 255, $90, 0, UnknownScript_0x1ac002, $ffff
	person_event $5d, 20, 18, $1, $0, 255, 255, $0, 0, UnknownScript_0x1ac0ea, $ffff
; 0x1ac2ba

Route2_MapScriptHeader: ; 0x1ac2ba
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ac2bc

TrainerBug_catcherRob: ; 0x1ac2bc
	; bit/flag number
	dw $539

	; trainer group && trainer id
	db BUG_CATCHER, ROB

	; text when seen
	dw Bug_catcherRobSeenText

	; text when trainer beaten
	dw Bug_catcherRobBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherRobScript
; 0x1ac2c8

Bug_catcherRobScript: ; 0x1ac2c8
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ac34d
	closetext
	loadmovesprites
	end
; 0x1ac2d0

TrainerBug_catcherEd: ; 0x1ac2d0
	; bit/flag number
	dw $53a

	; trainer group && trainer id
	db BUG_CATCHER, ED

	; text when seen
	dw Bug_catcherEdSeenText

	; text when trainer beaten
	dw Bug_catcherEdBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherEdScript
; 0x1ac2dc

Bug_catcherEdScript: ; 0x1ac2dc
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ac3cf
	closetext
	loadmovesprites
	end
; 0x1ac2e4

TrainerBug_catcherDoug: ; 0x1ac2e4
	; bit/flag number
	dw $543

	; trainer group && trainer id
	db BUG_CATCHER, DOUG

	; text when seen
	dw Bug_catcherDougSeenText

	; text when trainer beaten
	dw Bug_catcherDougBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bug_catcherDougScript
; 0x1ac2f0

Bug_catcherDougScript: ; 0x1ac2f0
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ac423
	closetext
	loadmovesprites
	end
; 0x1ac2f8

MapRoute2Signpost0Script: ; 0x1ac2f8
	jumptext UnknownText_0x1ac47a
; 0x1ac2fb

MapRoute2Signpost1Script: ; 0x1ac2fb
	jumptext UnknownText_0x1ac49f
; 0x1ac2fe

ItemFragment_0x1ac2fe: ; 0x1ac2fe
	db DIRE_HIT, 1
; 0x1ac300

ItemFragment_0x1ac300: ; 0x1ac300
	db MAX_POTION, 1
; 0x1ac302

ItemFragment_0x1ac302: ; 0x1ac302
	db CARBOS, 1
; 0x1ac304

ItemFragment_0x1ac304: ; 0x1ac304
	db ELIXER, 1
; 0x1ac306

UnknownScript_0x1ac306: ; 0x1ac306
	fruittree $19
; 0x1ac308

MapRoute2SignpostItem2: ; 0x1ac308
	dw $00ed
	db MAX_ETHER
	
; 0x1ac30b

MapRoute2SignpostItem3: ; 0x1ac30b
	dw $00ee
	db FULL_HEAL
	
; 0x1ac30e

MapRoute2SignpostItem4: ; 0x1ac30e
	dw $00ef
	db FULL_RESTORE
	
; 0x1ac311

MapRoute2SignpostItem5: ; 0x1ac311
	dw $00f0
	db REVIVE
	
; 0x1ac314

Bug_catcherRobSeenText: ; 0x1ac314
	db $0, "My bug #MON are", $4f
	db "tough. Prepare to", $55
	db "lose!", $57
; 0x1ac33d

Bug_catcherRobBeatenText: ; 0x1ac33d
	db $0, "I was whipped…", $57
; 0x1ac34d

UnknownText_0x1ac34d: ; 0x1ac34d
	db $0, "I'm going to look", $4f
	db "for stronger bug", $55
	db "#MON.", $57
; 0x1ac376

Bug_catcherEdSeenText: ; 0x1ac376
	db $0, "If you walk in", $4f
	db "tall grass wearing", $51
	db "shorts, do you get", $4f
	db "nicks and cuts?", $57
; 0x1ac3bc

Bug_catcherEdBeatenText: ; 0x1ac3bc
	db $0, "Ouch, ouch, ouch!", $57
; 0x1ac3cf

UnknownText_0x1ac3cf: ; 0x1ac3cf
	db $0, "They'll really", $4f
	db "sting when you", $55
	db "take a bath.", $57
; 0x1ac3fa

Bug_catcherDougSeenText: ; 0x1ac3fa
	db $0, "Why don't girls", $4f
	db "like bug #MON?", $57
; 0x1ac419

Bug_catcherDougBeatenText: ; 0x1ac419
	db $0, "No good!", $57
; 0x1ac423

UnknownText_0x1ac423: ; 0x1ac423
	db $0, "Bug #MON squish", $4f
	db "like plush toys", $51
	db "when you squeeze", $4f
	db "their bellies.", $51
	db "I love how they", $4f
	db "feel!", $57
; 0x1ac47a

UnknownText_0x1ac47a: ; 0x1ac47a
	db $0, "ROUTE 2", $51
	db "VIRIDIAN CITY -", $4f
	db "PEWTER CITY", $57
; 0x1ac49f

UnknownText_0x1ac49f: ; 0x1ac49f
	db $0, "DIGLETT'S CAVE", $57
; 0x1ac4af

Route2_MapEventHeader: ; 0x1ac4af
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $f, $f, 1, GROUP_ROUTE_2_NUGGET_SPEECH_HOUSE, MAP_ROUTE_2_NUGGET_SPEECH_HOUSE
	warp_def $1f, $f, 3, GROUP_ROUTE_2_GATE, MAP_ROUTE_2_GATE
	warp_def $1b, $10, 1, GROUP_ROUTE_2_GATE, MAP_ROUTE_2_GATE
	warp_def $1b, $11, 2, GROUP_ROUTE_2_GATE, MAP_ROUTE_2_GATE
	warp_def $7, $c, 3, GROUP_DIGLETTS_CAVE, MAP_DIGLETTS_CAVE

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 51, 7, $0, MapRoute2Signpost0Script
	signpost 9, 11, $0, MapRoute2Signpost1Script
	signpost 23, 7, $7, MapRoute2SignpostItem2
	signpost 14, 4, $7, MapRoute2SignpostItem3
	signpost 27, 4, $7, MapRoute2SignpostItem4
	signpost 30, 11, $7, MapRoute2SignpostItem5

	; people-events
	db 8
	person_event $25, 49, 14, $8, $0, 255, 255, $b2, 5, TrainerBug_catcherRob, $ffff
	person_event $25, 8, 10, $1f, $0, 255, 255, $b2, 3, TrainerBug_catcherEd, $ffff
	person_event $25, 44, 4, $9, $0, 255, 255, $b2, 3, TrainerBug_catcherDoug, $ffff
	person_event $54, 33, 4, $1, $0, 255, 255, $1, 0, ItemFragment_0x1ac2fe, $0783
	person_event $54, 27, 6, $1, $0, 255, 255, $1, 0, ItemFragment_0x1ac300, $0784
	person_event $54, 6, 23, $1, $0, 255, 255, $1, 0, ItemFragment_0x1ac302, $0785
	person_event $54, 54, 18, $1, $0, 255, 255, $1, 0, ItemFragment_0x1ac304, $0786
	person_event $5d, 18, 14, $1, $0, 255, 255, $0, 0, UnknownScript_0x1ac306, $ffff
; 0x1ac554

Route1_MapScriptHeader: ; 0x1ac554
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ac556

TrainerSchoolboyDanny: ; 0x1ac556
	; bit/flag number
	dw $470

	; trainer group && trainer id
	db SCHOOLBOY, DANNY

	; text when seen
	dw SchoolboyDannySeenText

	; text when trainer beaten
	dw SchoolboyDannyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SchoolboyDannyScript
; 0x1ac562

SchoolboyDannyScript: ; 0x1ac562
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ac5d7
	closetext
	loadmovesprites
	end
; 0x1ac56a

TrainerCooltrainerfQuinn: ; 0x1ac56a
	; bit/flag number
	dw $568

	; trainer group && trainer id
	db COOLTRAINERF, QUINN

	; text when seen
	dw CooltrainerfQuinnSeenText

	; text when trainer beaten
	dw CooltrainerfQuinnBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw CooltrainerfQuinnScript
; 0x1ac576

CooltrainerfQuinnScript: ; 0x1ac576
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ac640
	closetext
	loadmovesprites
	end
; 0x1ac57e

MapRoute1Signpost0Script: ; 0x1ac57e
	jumptext UnknownText_0x1ac675
; 0x1ac581

UnknownScript_0x1ac581: ; 0x1ac581
	fruittree $1a
; 0x1ac583

SchoolboyDannySeenText: ; 0x1ac583
	db $0, "If trainers meet,", $4f
	db "the first thing to", $55
	db "do is battle.", $57
; 0x1ac5b7

SchoolboyDannyBeatenText: ; 0x1ac5b7
	db $0, "Awww… I've got a", $4f
	db "losing record…", $57
; 0x1ac5d7

UnknownText_0x1ac5d7: ; 0x1ac5d7
	db $0, "For trainers, it's", $4f
	db "a given that we'll", $51
	db "battle whenever we", $4f
	db "meet.", $57
; 0x1ac615

CooltrainerfQuinnSeenText: ; 0x1ac615
	db $0, "You there!", $4f
	db "Want to battle?", $57
; 0x1ac631

CooltrainerfQuinnBeatenText: ; 0x1ac631
	db $0, "Down and out…", $57
; 0x1ac640

UnknownText_0x1ac640: ; 0x1ac640
	db $0, "You're strong.", $51
	db "You obviously must", $4f
	db "have trained hard.", $57
; 0x1ac675

UnknownText_0x1ac675: ; 0x1ac675
	db $0, "ROUTE 1", $51
	db "PALLET TOWN -", $4f
	db "VIRIDIAN CITY", $57
; 0x1ac69a

Route1_MapEventHeader: ; 0x1ac69a
	; filler
	db 0, 0

	; warps
	db 0

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 27, 7, $0, MapRoute1Signpost0Script

	; people-events
	db 3
	person_event $27, 16, 8, $9, $0, 255, 255, $92, 4, TrainerSchoolboyDanny, $ffff
	person_event $24, 29, 13, $a, $0, 255, 255, $82, 2, TrainerCooltrainerfQuinn, $ffff
	person_event $5d, 11, 7, $1, $0, 255, 255, $0, 0, UnknownScript_0x1ac581, $ffff
; 0x1ac6cc

PalletTown_MapScriptHeader: ; 0x1ac6cc
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1ac6d1
; 0x1ac6d1

UnknownScript_0x1ac6d1: ; 0x1ac6d1
	setbit2 $0035
	return
; 0x1ac6d5

UnknownScript_0x1ac6d5: ; 0x1ac6d5
	jumptextfaceplayer UnknownText_0x1ac6e7
; 0x1ac6d8

UnknownScript_0x1ac6d8: ; 0x1ac6d8
	jumptextfaceplayer UnknownText_0x1ac720
; 0x1ac6db

MapPalletTownSignpost0Script: ; 0x1ac6db
	jumptext UnknownText_0x1ac76b
; 0x1ac6de

MapPalletTownSignpost1Script: ; 0x1ac6de
	jumptext UnknownText_0x1ac79d
; 0x1ac6e1

MapPalletTownSignpost2Script: ; 0x1ac6e1
	jumptext UnknownText_0x1ac7aa
; 0x1ac6e4

MapPalletTownSignpost3Script: ; 0x1ac6e4
	jumptext UnknownText_0x1ac7c1
; 0x1ac6e7

UnknownText_0x1ac6e7: ; 0x1ac6e7
	db $0, "I'm raising #-", $4f
	db "MON too.", $51
	db "They serve as my", $4f
	db "private guards.", $57
; 0x1ac720

UnknownText_0x1ac720: ; 0x1ac720
	db $0, "Technology is", $4f
	db "incredible!", $51
	db "You can now trade", $4f
	db "#MON across", $55
	db "time like e-mail.", $57
; 0x1ac76b

UnknownText_0x1ac76b: ; 0x1ac76b
	db $0, "PALLET TOWN", $51
	db "A Tranquil Setting", $4f
	db "of Peace & Purity", $57
; 0x1ac79d

UnknownText_0x1ac79d: ; 0x1ac79d
	db $0, "RED'S HOUSE", $57
; 0x1ac7aa

UnknownText_0x1ac7aa: ; 0x1ac7aa
	db $0, "OAK #MON", $4f
	db "RESEARCH LAB", $57
; 0x1ac7c1

UnknownText_0x1ac7c1: ; 0x1ac7c1
	db $0, "BLUE'S HOUSE", $57
; 0x1ac7cf

PalletTown_MapEventHeader: ; 0x1ac7cf
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $5, $5, 1, GROUP_REDS_HOUSE_1F, MAP_REDS_HOUSE_1F
	warp_def $5, $d, 1, GROUP_BLUES_HOUSE, MAP_BLUES_HOUSE
	warp_def $b, $c, 1, GROUP_OAKS_LAB, MAP_OAKS_LAB

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 9, 7, $0, MapPalletTownSignpost0Script
	signpost 5, 3, $0, MapPalletTownSignpost1Script
	signpost 13, 13, $0, MapPalletTownSignpost2Script
	signpost 5, 11, $0, MapPalletTownSignpost3Script

	; people-events
	db 2
	person_event $29, 12, 7, $2, $22, 255, 255, $0, 0, UnknownScript_0x1ac6d5, $ffff
	person_event $3a, 18, 16, $5, $2, 255, 255, $a0, 0, UnknownScript_0x1ac6d8, $ffff
; 0x1ac812

Route21_MapScriptHeader: ; 0x1ac812
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ac814

TrainerSwimmermSeth: ; 0x1ac814
	; bit/flag number
	dw $5a5

	; trainer group && trainer id
	db SWIMMERM, SETH

	; text when seen
	dw SwimmermSethSeenText

	; text when trainer beaten
	dw SwimmermSethBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermSethScript
; 0x1ac820

SwimmermSethScript: ; 0x1ac820
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ac873
	closetext
	loadmovesprites
	end
; 0x1ac828

TrainerSwimmerfNikki: ; 0x1ac828
	; bit/flag number
	dw $3f8

	; trainer group && trainer id
	db SWIMMERF, NIKKI

	; text when seen
	dw SwimmerfNikkiSeenText

	; text when trainer beaten
	dw SwimmerfNikkiBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfNikkiScript
; 0x1ac834

SwimmerfNikkiScript: ; 0x1ac834
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ac8f1
	closetext
	loadmovesprites
	end
; 0x1ac83c

TrainerFisherArnold: ; 0x1ac83c
	; bit/flag number
	dw $450

	; trainer group && trainer id
	db FISHER, ARNOLD

	; text when seen
	dw FisherArnoldSeenText

	; text when trainer beaten
	dw FisherArnoldBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FisherArnoldScript
; 0x1ac848

FisherArnoldScript: ; 0x1ac848
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ac95c
	closetext
	loadmovesprites
	end
; 0x1ac850

SwimmermSethSeenText: ; 0x1ac850
	db $0, "Land ho! Gotta", $4f
	db "keep going!", $57
; 0x1ac86c

SwimmermSethBeatenText: ; 0x1ac86c
	db $0, "Glug…", $57
; 0x1ac873

UnknownText_0x1ac873: ; 0x1ac873
	db $0, "This arrogant guy", $4f
	db "was at CINNABAR's", $55
	db "volcano.", $57
; 0x1ac8a0

SwimmerfNikkiSeenText: ; 0x1ac8a0
	db $0, "If I win, you have", $4f
	db "to help me with my", $55
	db "suntan lotion!", $57
; 0x1ac8d6

SwimmerfNikkiBeatenText: ; 0x1ac8d6
	db $0, "I'm worried about", $4f
	db "sunburn…", $57
; 0x1ac8f1

UnknownText_0x1ac8f1: ; 0x1ac8f1
	db $0, "I have to watch", $4f
	db "out for blemishes", $55
	db "caused by the sun.", $57
; 0x1ac927

FisherArnoldSeenText: ; 0x1ac927
	db $0, "I'm bored by fish-", $4f
	db "ing. Let's battle!", $57
; 0x1ac94c

FisherArnoldBeatenText: ; 0x1ac94c
	db $0, "Utter failure…", $57
; 0x1ac95c

UnknownText_0x1ac95c: ; 0x1ac95c
	db $0, "I'll just go back", $4f
	db "to fishing…", $57
; 0x1ac97a

Route21_MapEventHeader: ; 0x1ac97a
	; filler
	db 0, 0

	; warps
	db 0

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 3
	person_event $32, 20, 15, $a, $0, 255, 255, $a2, 3, TrainerSwimmerfNikki, $ffff
	person_event $31, 34, 6, $9, $0, 255, 255, $82, 4, TrainerSwimmermSeth, $ffff
	person_event $3a, 26, 18, $7, $0, 255, 255, $a2, 1, TrainerFisherArnold, $ffff
; 0x1ac9a7

CinnabarIsland_MapScriptHeader: ; 0x1ac9a7
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1ac9ac
; 0x1ac9ac

UnknownScript_0x1ac9ac: ; 0x1ac9ac
	setbit2 $003f
	return
; 0x1ac9b0

UnknownScript_0x1ac9b0: ; 0x1ac9b0
	faceplayer
	loadfont
	2writetext UnknownText_0x1ac9d2
	closetext
	loadmovesprites
	playsound $0013
	applymovement $2, MovementData_0x1ac9d0
	disappear $2
	clearbit1 $0776
	end
; 0x1ac9c4

MapCinnabarIslandSignpost1Script: ; 0x1ac9c4
	jumptext UnknownText_0x1acc73
; 0x1ac9c7

MapCinnabarIslandSignpost2Script: ; 0x1ac9c7
	jumptext UnknownText_0x1accc2
; 0x1ac9ca

MapCinnabarIslandSignpost0Script: ; 0x1ac9ca
	jumpstd $0010
; 0x1ac9cd

MapCinnabarIslandSignpostItem3: ; 0x1ac9cd
	dw $00fe
	db RARE_CANDY
	
; 0x1ac9d0

MovementData_0x1ac9d0: ; 0x1ac9d0
	teleport_from
	step_end
; 0x1ac9d2

UnknownText_0x1ac9d2: ; 0x1ac9d2
	db $0, "Who are you?", $51
	db "Well, it's plain", $4f
	db "to see that you're", $55
	db "a trainer…", $51
	db "My name's BLUE.", $51
	db "I was once the", $4f
	db "CHAMPION, although", $51
	db "it was for only a", $4f
	db "short time…", $51
	db "That meddling RED", $4f
	db "did me in…", $51
	db "Anyway, what do", $4f
	db "you want? You want", $51
	db "to challenge me or", $4f
	db "something?", $51
	db "…I hate to say", $4f
	db "it, but I'm not in", $51
	db "the mood for a", $4f
	db "battle now.", $51
	db "Take a good look", $4f
	db "around you…", $51
	db "A volcano erupts,", $4f
	db "and just like", $51
	db "that, a whole town", $4f
	db "disappears.", $51
	db "We can go on win-", $4f
	db "ning and losing in", $51
	db "#MON. But if", $4f
	db "nature so much as", $51
	db "twitches, we can", $4f
	db "lose in a second.", $51
	db "…", $51
	db "That's the way it", $4f
	db "is…", $51
	db "But, anyway, I'm", $4f
	db "still a trainer.", $51
	db "If I see a strong", $4f
	db "opponent, it makes", $55
	db "me want to battle.", $51
	db "If you want to", $4f
	db "battle me, come to", $55
	db "the VIRIDIAN GYM.", $51
	db "I'll take you on", $4f
	db "then.", $57
; 0x1acc73

UnknownText_0x1acc73: ; 0x1acc73
	db $0, "There's a notice", $4f
	db "here…", $51
	db "CINNABAR GYM has", $4f
	db "relocated to SEA-", $55
	db "FOAM ISLANDS.", $51
	db "BLAINE", $57
; 0x1accc2

UnknownText_0x1accc2: ; 0x1accc2
	db $0, "CINNABAR ISLAND", $51
	db "The Fiery Town of", $4f
	db "Burning Desire", $57
; 0x1accf4

CinnabarIsland_MapEventHeader: ; 0x1accf4
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $b, $b, 1, GROUP_CINNABAR_POKECENTER_1F, MAP_CINNABAR_POKECENTER_1F

	; xy triggers
	db 0

	; signposts
	db 4
	signpost 11, 12, $0, MapCinnabarIslandSignpost0Script
	signpost 11, 9, $0, MapCinnabarIslandSignpost1Script
	signpost 7, 7, $0, MapCinnabarIslandSignpost2Script
	signpost 1, 9, $7, MapCinnabarIslandSignpostItem3

	; people-events
	db 1
	person_event $7, 10, 13, $3, $0, 255, 255, $0, 0, UnknownScript_0x1ac9b0, $0775
; 0x1acd20

Route20_MapScriptHeader: ; 0x1acd20
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1acd25
; 0x1acd25

UnknownScript_0x1acd25: ; 0x1acd25
	setbit1 $00d7
	return
; 0x1acd29

TrainerSwimmerfNicole: ; 0x1acd29
	; bit/flag number
	dw $3f5

	; trainer group && trainer id
	db SWIMMERF, NICOLE

	; text when seen
	dw SwimmerfNicoleSeenText

	; text when trainer beaten
	dw SwimmerfNicoleBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfNicoleScript
; 0x1acd35

SwimmerfNicoleScript: ; 0x1acd35
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1acd93
	closetext
	loadmovesprites
	end
; 0x1acd3d

TrainerSwimmerfLori: ; 0x1acd3d
	; bit/flag number
	dw $3f6

	; trainer group && trainer id
	db SWIMMERF, LORI

	; text when seen
	dw SwimmerfLoriSeenText

	; text when trainer beaten
	dw SwimmerfLoriBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmerfLoriScript
; 0x1acd49

SwimmerfLoriScript: ; 0x1acd49
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ace15
	closetext
	loadmovesprites
	end
; 0x1acd51

TrainerSwimmermCameron: ; 0x1acd51
	; bit/flag number
	dw $5a4

	; trainer group && trainer id
	db SWIMMERM, CAMERON

	; text when seen
	dw SwimmermCameronSeenText

	; text when trainer beaten
	dw SwimmermCameronBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw SwimmermCameronScript
; 0x1acd5d

SwimmermCameronScript: ; 0x1acd5d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ace8b
	closetext
	loadmovesprites
	end
; 0x1acd65

MapRoute20Signpost0Script: ; 0x1acd65
	jumptext UnknownText_0x1acec2
; 0x1acd68

SwimmerfNicoleSeenText: ; 0x1acd68
	db $0, "I feel so much", $4f
	db "lighter in water.", $57
; 0x1acd8a

SwimmerfNicoleBeatenText: ; 0x1acd8a
	db $0, "Oh, no!", $57
; 0x1acd93

UnknownText_0x1acd93: ; 0x1acd93
	db $0, "Swimming exercises", $4f
	db "your full body.", $51
	db "It's really good", $4f
	db "for you.", $57
; 0x1acdd0

SwimmerfLoriSeenText: ; 0x1acdd0
	db $0, "What an impressive", $4f
	db "collection of GYM", $51
	db "BADGES. We should", $4f
	db "battle!", $57
; 0x1ace10

SwimmerfLoriBeatenText: ; 0x1ace10
	db $0, "No!", $57
; 0x1ace15

UnknownText_0x1ace15: ; 0x1ace15
	db $0, "SURF is no longer", $4f
	db "the only HM move", $55
	db "you use in water.", $57
; 0x1ace4b

SwimmermCameronSeenText: ; 0x1ace4b
	db $0, "I guess it's im-", $4f
	db "possible to swim", $51
	db "all the way to", $4f
	db "JOHTO.", $57
; 0x1ace83

SwimmermCameronBeatenText: ; 0x1ace83
	db $0, "Aiyah!", $57
; 0x1ace8b

UnknownText_0x1ace8b: ; 0x1ace8b
	db $0, "Besides the sea, I", $4f
	db "can also swim in", $55
	db "ponds and rivers.", $57
; 0x1acec2

UnknownText_0x1acec2: ; 0x1acec2
	db $0, "What does this", $4f
	db "sign say?", $51
	db "CINNABAR GYM", $4f
	db "LEADER: BLAINE", $57
; 0x1acef8

Route20_MapEventHeader: ; 0x1acef8
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $7, $26, 1, GROUP_SEAFOAM_GYM, MAP_SEAFOAM_GYM

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 11, 37, $0, MapRoute20Signpost0Script

	; people-events
	db 3
	person_event $32, 12, 56, $a, $0, 255, 255, $a2, 3, TrainerSwimmerfNicole, $ffff
	person_event $32, 17, 49, $a, $0, 255, 255, $a2, 3, TrainerSwimmerfLori, $ffff
	person_event $31, 17, 16, $a, $0, 255, 255, $82, 3, TrainerSwimmermCameron, $ffff
; 0x1acf2f

Route18_MapScriptHeader: ; 0x1acf2f
	; trigger count
	db 0

	; callback count
	db 0
; 0x1acf31

TrainerBird_keeperBoris: ; 0x1acf31
	; bit/flag number
	dw $404

	; trainer group && trainer id
	db BIRD_KEEPER, BORIS

	; text when seen
	dw Bird_keeperBorisSeenText

	; text when trainer beaten
	dw Bird_keeperBorisBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperBorisScript
; 0x1acf3d

Bird_keeperBorisScript: ; 0x1acf3d
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1acfa5
	closetext
	loadmovesprites
	end
; 0x1acf45

TrainerBird_keeperBob: ; 0x1acf45
	; bit/flag number
	dw $405

	; trainer group && trainer id
	db BIRD_KEEPER, BOB

	; text when seen
	dw Bird_keeperBobSeenText

	; text when trainer beaten
	dw Bird_keeperBobBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperBobScript
; 0x1acf51

Bird_keeperBobScript: ; 0x1acf51
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ad00d
	closetext
	loadmovesprites
	end
; 0x1acf59

MapRoute18Signpost0Script: ; 0x1acf59
	jumptext UnknownText_0x1ad051
; 0x1acf5c

Bird_keeperBorisSeenText: ; 0x1acf5c
	db $0, "If you're looking", $4f
	db "for #MON, you", $51
	db "have to look in", $4f
	db "the tall grass.", $57
; 0x1acf9c

Bird_keeperBorisBeatenText: ; 0x1acf9c
	db $0, "Ayieee!", $57
; 0x1acfa5

UnknownText_0x1acfa5: ; 0x1acfa5
	db $0, "Since you're so", $4f
	db "strong, it must be", $55
	db "fun to battle.", $57
; 0x1acfd7

Bird_keeperBobSeenText: ; 0x1acfd7
	db $0, "CYCLING ROAD is a", $4f
	db "quick shortcut to", $55
	db "CELADON.", $57
; 0x1ad005

Bird_keeperBobBeatenText: ; 0x1ad005
	db $0, "…Whew!", $57
; 0x1ad00d

UnknownText_0x1ad00d: ; 0x1ad00d
	db $0, "If you don't have", $4f
	db "a BICYCLE, you're", $51
	db "not allowed to use", $4f
	db "the shortcut.", $57
; 0x1ad051

UnknownText_0x1ad051: ; 0x1ad051
	db $0, "ROUTE 18", $51
	db "CELADON CITY -", $4f
	db "FUCHSIA CITY", $57
; 0x1ad077

Route18_MapEventHeader: ; 0x1ad077
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $6, $2, 3, GROUP_ROUTE_17_18_GATE, MAP_ROUTE_17_18_GATE
	warp_def $7, $2, 4, GROUP_ROUTE_17_18_GATE, MAP_ROUTE_17_18_GATE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 5, 9, $0, MapRoute18Signpost0Script

	; people-events
	db 2
	person_event $27, 16, 13, $a, $0, 255, 255, $92, 3, TrainerBird_keeperBoris, $ffff
	person_event $27, 10, 17, $6, $0, 255, 255, $92, 3, TrainerBird_keeperBob, $ffff
; 0x1ad0a6

Route17_MapScriptHeader: ; 0x1ad0a6
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1ad0ab
; 0x1ad0ab

UnknownScript_0x1ad0ab: ; 0x1ad0ab
	setbit2 $0019
	setbit2 $001a
	return
; 0x1ad0b2

TrainerBikerCharles: ; 0x1ad0b2
	; bit/flag number
	dw $436

	; trainer group && trainer id
	db BIKER, CHARLES

	; text when seen
	dw BikerCharlesSeenText

	; text when trainer beaten
	dw BikerCharlesBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BikerCharlesScript
; 0x1ad0be

BikerCharlesScript: ; 0x1ad0be
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ad293
	closetext
	loadmovesprites
	end
; 0x1ad0c6

TrainerBikerRiley: ; 0x1ad0c6
	; bit/flag number
	dw $437

	; trainer group && trainer id
	db BIKER, RILEY

	; text when seen
	dw BikerRileySeenText

	; text when trainer beaten
	dw BikerRileyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BikerRileyScript
; 0x1ad0d2

BikerRileyScript: ; 0x1ad0d2
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ad13b
	closetext
	loadmovesprites
	end
; 0x1ad0da

TrainerBikerJoel: ; 0x1ad0da
	; bit/flag number
	dw $438

	; trainer group && trainer id
	db BIKER, JOEL

	; text when seen
	dw BikerJoelSeenText

	; text when trainer beaten
	dw BikerJoelBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BikerJoelScript
; 0x1ad0e6

BikerJoelScript: ; 0x1ad0e6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ad196
	closetext
	loadmovesprites
	end
; 0x1ad0ee

TrainerBikerGlenn: ; 0x1ad0ee
	; bit/flag number
	dw $439

	; trainer group && trainer id
	db BIKER, GLENN

	; text when seen
	dw BikerGlennSeenText

	; text when trainer beaten
	dw BikerGlennBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw BikerGlennScript
; 0x1ad0fa

BikerGlennScript: ; 0x1ad0fa
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ad225
	closetext
	loadmovesprites
	end
; 0x1ad102

MapRoute17SignpostItem0: ; 0x1ad102
	dw $00f6
	db MAX_ETHER
	
; 0x1ad105

MapRoute17SignpostItem1: ; 0x1ad105
	dw $00f7
	db MAX_ELIXER
	
; 0x1ad108

BikerRileySeenText: ; 0x1ad108
	db $0, "Hey, you! You're", $4f
	db "from JOHTO, huh?", $57
; 0x1ad12a

BikerRileyBeatenText: ; 0x1ad12a
	db $0, "Whoa, you kick!", $57
; 0x1ad13b

UnknownText_0x1ad13b: ; 0x1ad13b
	db $0, "Don't get cocky,", $4f
	db "you JOHTO punk!", $57
; 0x1ad15c

BikerJoelSeenText: ; 0x1ad15c
	db $0, "Wow. That's a cool", $4f
	db "BICYCLE!", $57
; 0x1ad178

BikerJoelBeatenText: ; 0x1ad178
	db $0, "But you don't just", $4f
	db "look cool…", $57
; 0x1ad196

UnknownText_0x1ad196: ; 0x1ad196
	db $0, "I look cool, but", $4f
	db "I'm weak, so I'm", $55
	db "not really cool.", $51
	db "I have to train", $4f
	db "harder…", $57
; 0x1ad1e0

BikerGlennSeenText: ; 0x1ad1e0
	db $0, "Hey! Want to have", $4f
	db "a speed battle?", $57
; 0x1ad203

BikerGlennBeatenText: ; 0x1ad203
	db $0, "Yikes! You've got", $4f
	db "awesome torque!", $57
; 0x1ad225

UnknownText_0x1ad225: ; 0x1ad225
	db $0, "Hands-free riding", $4f
	db "is considered cool", $55
	db "on CYCLING ROAD.", $57
; 0x1ad25c

BikerCharlesSeenText: ; 0x1ad25c
	db $0, "We're fearless", $4f
	db "highway stars!", $57
; 0x1ad27a

BikerCharlesBeatenText: ; 0x1ad27a
	db $0, "Arrrgh! Crash and", $4f
	db "burn!", $57
; 0x1ad293

UnknownText_0x1ad293: ; 0x1ad293
	db $0, "Reckless driving", $4f
	db "causes accidents!", $55
	db "Take it easy!", $57
; 0x1ad2c5

Route17_MapEventHeader: ; 0x1ad2c5
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $52, $11, 1, GROUP_ROUTE_17_18_GATE, MAP_ROUTE_17_18_GATE
	warp_def $53, $11, 2, GROUP_ROUTE_17_18_GATE, MAP_ROUTE_17_18_GATE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 54, 9, $7, MapRoute17SignpostItem0
	signpost 77, 8, $7, MapRoute17SignpostItem1

	; people-events
	db 4
	person_event $4a, 21, 8, $a, $0, 255, 255, $b2, 4, TrainerBikerRiley, $ffff
	person_event $4a, 72, 13, $6, $0, 255, 255, $b2, 1, TrainerBikerJoel, $ffff
	person_event $4a, 57, 7, $a, $0, 255, 255, $b2, 3, TrainerBikerGlenn, $ffff
	person_event $4a, 84, 10, $9, $0, 255, 255, $b2, 4, TrainerBikerCharles, $ffff
; 0x1ad313

Route16_MapScriptHeader: ; 0x1ad313
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1ad318
; 0x1ad318

UnknownScript_0x1ad318: ; 0x1ad318
	checkcode $13
	if_greater_than $5, UnknownScript_0x1ad328
	checkcode $12
	if_less_than $d, UnknownScript_0x1ad328
	setbit2 $0019
	return
; 0x1ad328

UnknownScript_0x1ad328: ; 0x1ad328
	clearbit2 $0019
	return
; 0x1ad32c

MapRoute16Signpost0Script: ; 0x1ad32c
	jumptext UnknownText_0x1ad32f
; 0x1ad32f

UnknownText_0x1ad32f: ; 0x1ad32f
	db $0, "CYCLING ROAD", $51
	db "DOWNHILL COASTING", $4f
	db "ALL THE WAY!", $57
; 0x1ad35c

Route16_MapEventHeader: ; 0x1ad35c
	; filler
	db 0, 0

	; warps
	db 5
	warp_def $1, $3, 1, GROUP_ROUTE_16_FUCHSIA_SPEECH_HOUSE, MAP_ROUTE_16_FUCHSIA_SPEECH_HOUSE
	warp_def $6, $e, 3, GROUP_ROUTE_16_GATE, MAP_ROUTE_16_GATE
	warp_def $7, $e, 4, GROUP_ROUTE_16_GATE, MAP_ROUTE_16_GATE
	warp_def $6, $9, 1, GROUP_ROUTE_16_GATE, MAP_ROUTE_16_GATE
	warp_def $7, $9, 2, GROUP_ROUTE_16_GATE, MAP_ROUTE_16_GATE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 5, 5, $0, MapRoute16Signpost0Script

	; people-events
	db 0
; 0x1ad380

Route7_MapScriptHeader: ; 0x1ad380
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ad382

MapRoute7Signpost0Script: ; 0x1ad382
	jumptext UnknownText_0x1ad388
; 0x1ad385

MapRoute7Signpost1Script: ; 0x1ad385
	jumptext UnknownText_0x1ad456
; 0x1ad388

UnknownText_0x1ad388: ; 0x1ad388
	db $0, "What's this flyer?", $51
	db "… Uncouth trainers", $4f
	db "have been holding", $51
	db "battles in the", $4f
	db "UNDERGROUND PATH.", $51
	db "Because of rising", $4f
	db "complaints by lo-", $55
	db "cal residents, the", $55
	db "UNDERGROUND PATH", $55
	db "has been sealed", $55
	db "indefinitely.", $51
	db "CELADON POLICE", $57
; 0x1ad456

UnknownText_0x1ad456: ; 0x1ad456
	db $0, "It's locked…", $57
; 0x1ad463

Route7_MapEventHeader: ; 0x1ad463
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $6, $f, 1, GROUP_ROUTE_7_SAFFRON_GATE, MAP_ROUTE_7_SAFFRON_GATE
	warp_def $7, $f, 2, GROUP_ROUTE_7_SAFFRON_GATE, MAP_ROUTE_7_SAFFRON_GATE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 11, 5, $0, MapRoute7Signpost0Script
	signpost 9, 6, $0, MapRoute7Signpost1Script

	; people-events
	db 0
; 0x1ad47d

Route14_MapScriptHeader: ; 0x1ad47d
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ad47f

UnknownScript_0x1ad47f: ; 0x1ad47f
	faceplayer
	loadfont
	trade $5
	closetext
	loadmovesprites
	end
; 0x1ad486

TrainerPokefanmCarter: ; 0x1ad486
	; bit/flag number
	dw $4d1

	; trainer group && trainer id
	db POKEFANM, CARTER

	; text when seen
	dw PokefanmCarterSeenText

	; text when trainer beaten
	dw PokefanmCarterBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmCarterScript
; 0x1ad492

PokefanmCarterScript: ; 0x1ad492
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ad508
	closetext
	loadmovesprites
	end
; 0x1ad49a

TrainerBird_keeperRoy: ; 0x1ad49a
	; bit/flag number
	dw $403

	; trainer group && trainer id
	db BIRD_KEEPER, ROY

	; text when seen
	dw Bird_keeperRoySeenText

	; text when trainer beaten
	dw Bird_keeperRoyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperRoyScript
; 0x1ad4a6

Bird_keeperRoyScript: ; 0x1ad4a6
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ad5a4
	closetext
	loadmovesprites
	end
; 0x1ad4ae

TrainerPokefanmTrevor: ; 0x1ad4ae
	; bit/flag number
	dw $4d2

	; trainer group && trainer id
	db POKEFANM, TREVOR

	; text when seen
	dw PokefanmTrevorSeenText

	; text when trainer beaten
	dw PokefanmTrevorBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmTrevorScript
; 0x1ad4ba

PokefanmTrevorScript: ; 0x1ad4ba
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ad660
	closetext
	loadmovesprites
	end
; 0x1ad4c2

PokefanmCarterSeenText: ; 0x1ad4c2
	db $0, "Let me tell you,", $4f
	db "I had a hard time", $51
	db "catching my prized", $4f
	db "#MON.", $57
; 0x1ad4ff

PokefanmCarterBeatenText: ; 0x1ad4ff
	db $0, "Awaaah!", $57
; 0x1ad508

UnknownText_0x1ad508: ; 0x1ad508
	db $0, "SQUIRTLE, CHARMAN-", $4f
	db "DER and BULBASAUR…", $51
	db "I think that's a", $4f
	db "well-balanced mix.", $57
; 0x1ad552

Bird_keeperRoySeenText: ; 0x1ad552
	db $0, "My dream is to fly", $4f
	db "with my beloved", $55
	db "bird #MON.", $57
; 0x1ad581

Bird_keeperRoyBeatenText: ; 0x1ad581
	db $0, "I can dream, but I", $4f
	db "can't ever fly…", $57
; 0x1ad5a4

UnknownText_0x1ad5a4: ; 0x1ad5a4
	db $0, "You have #MON", $4f
	db "that know the HM", $51
	db "move FLY, don't", $4f
	db "you? I envy you.", $57
; 0x1ad5e4

PokefanmTrevorSeenText: ; 0x1ad5e4
	db $0, "Hi. Did you know…?", $51
	db "#MON get more", $4f
	db "friendly if you", $51
	db "train them in a", $4f
	db "place that they", $55
	db "remember.", $57
; 0x1ad640

PokefanmTrevorBeatenText: ; 0x1ad640
	db $0, "Where did I meet", $4f
	db "this PSYDUCK?", $57
; 0x1ad660

UnknownText_0x1ad660: ; 0x1ad660
	db $0, "If only there were", $4f
	db "an easy way to", $51
	db "identify where I", $4f
	db "got my #MON…", $57
; 0x1ad6a1

Route14_MapEventHeader: ; 0x1ad6a1
	; filler
	db 0, 0

	; warps
	db 0

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 4
	person_event $2d, 19, 15, $9, $0, 255, 255, $82, 3, TrainerPokefanmCarter, $ffff
	person_event $27, 31, 15, $a, $0, 255, 255, $92, 3, TrainerBird_keeperRoy, $ffff
	person_event $2d, 15, 10, $a, $0, 255, 255, $82, 3, TrainerPokefanmTrevor, $ffff
	person_event $29, 9, 11, $5, $1, 255, 255, $a0, 4, UnknownScript_0x1ad47f, $ffff
; 0x1ad6db

LavenderTown_MapScriptHeader: ; 0x1ad6db
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1ad6e0
; 0x1ad6e0

UnknownScript_0x1ad6e0: ; 0x1ad6e0
	setbit2 $003b
	return
; 0x1ad6e4

UnknownScript_0x1ad6e4: ; 0x1ad6e4
	jumptextfaceplayer UnknownText_0x1ad702
; 0x1ad6e7

UnknownScript_0x1ad6e7: ; 0x1ad6e7
	jumptextfaceplayer UnknownText_0x1ad73a
; 0x1ad6ea

UnknownScript_0x1ad6ea: ; 0x1ad6ea
	jumptextfaceplayer UnknownText_0x1ad75c
; 0x1ad6ed

UnknownScript_0x1ad6ed: ; 0x1ad6ed
	jumptextfaceplayer UnknownText_0x1ad7ac
; 0x1ad6f0

MapLavenderTownSignpost0Script: ; 0x1ad6f0
	jumptext UnknownText_0x1ad7f7
; 0x1ad6f3

MapLavenderTownSignpost1Script: ; 0x1ad6f3
	jumptext UnknownText_0x1ad81c
; 0x1ad6f6

MapLavenderTownSignpost2Script: ; 0x1ad6f6
	jumptext UnknownText_0x1ad861
; 0x1ad6f9

MapLavenderTownSignpost3Script: ; 0x1ad6f9
	jumptext UnknownText_0x1ad880
; 0x1ad6fc

MapLavenderTownSignpost4Script: ; 0x1ad6fc
	jumpstd $0010
; 0x1ad6ff

MapLavenderTownSignpost5Script: ; 0x1ad6ff
	jumpstd $0011
; 0x1ad702

UnknownText_0x1ad702: ; 0x1ad702
	db $0, "That's quite some", $4f
	db "building, eh?", $51
	db "It's KANTO's RADIO", $4f
	db "TOWER.", $57
; 0x1ad73a

UnknownText_0x1ad73a: ; 0x1ad73a
	db $0, "KANTO has many", $4f
	db "good radio shows.", $57
; 0x1ad75c

UnknownText_0x1ad75c: ; 0x1ad75c
	db $0, "People come from", $4f
	db "all over to pay", $51
	db "their respects to", $4f
	db "the departed souls", $55
	db "of #MON.", $57
; 0x1ad7ac

UnknownText_0x1ad7ac: ; 0x1ad7ac
	db $0, "You need a #", $4f
	db "FLUTE to wake", $55
	db "sleeping #MON.", $51
	db "Every trainer has", $4f
	db "to know that!", $57
; 0x1ad7f7

UnknownText_0x1ad7f7: ; 0x1ad7f7
	db $0, "LAVENDER TOWN", $51
	db "The Noble Purple", $4f
	db "Town", $57
; 0x1ad81c

UnknownText_0x1ad81c: ; 0x1ad81c
	db $0, "KANTO RADIO", $4f
	db "STATION", $51
	db "Your Favorite", $4f
	db "Programs On-Air", $55
	db "Around the Clock!", $57
; 0x1ad861

UnknownText_0x1ad861: ; 0x1ad861
	db $0, "LAVENDER VOLUNTEER", $4f
	db "#MON HOUSE", $57
; 0x1ad880

UnknownText_0x1ad880: ; 0x1ad880
	db $0, "SOUL HOUSE", $51
	db "May the Souls of", $4f
	db "#MON Rest Easy", $57
; 0x1ad8ac

LavenderTown_MapEventHeader: ; 0x1ad8ac
	; filler
	db 0, 0

	; warps
	db 7
	warp_def $5, $5, 1, GROUP_LAVENDER_POKECENTER_1F, MAP_LAVENDER_POKECENTER_1F
	warp_def $9, $5, 1, GROUP_MR_FUJIS_HOUSE, MAP_MR_FUJIS_HOUSE
	warp_def $d, $3, 1, GROUP_LAVENDER_TOWN_SPEECH_HOUSE, MAP_LAVENDER_TOWN_SPEECH_HOUSE
	warp_def $d, $7, 1, GROUP_LAVENDER_NAME_RATER, MAP_LAVENDER_NAME_RATER
	warp_def $5, $1, 2, GROUP_LAVENDER_MART, MAP_LAVENDER_MART
	warp_def $b, $d, 1, GROUP_SOUL_HOUSE, MAP_SOUL_HOUSE
	warp_def $5, $e, 1, GROUP_LAV_RADIO_TOWER_1F, MAP_LAV_RADIO_TOWER_1F

	; xy triggers
	db 0

	; signposts
	db 6
	signpost 3, 11, $0, MapLavenderTownSignpost0Script
	signpost 7, 15, $0, MapLavenderTownSignpost1Script
	signpost 9, 3, $0, MapLavenderTownSignpost2Script
	signpost 13, 15, $0, MapLavenderTownSignpost3Script
	signpost 5, 6, $0, MapLavenderTownSignpost4Script
	signpost 5, 2, $0, MapLavenderTownSignpost5Script

	; people-events
	db 4
	person_event $2d, 11, 16, $5, $1, 255, 255, $80, 0, UnknownScript_0x1ad6e4, $ffff
	person_event $29, 19, 6, $5, $1, 255, 255, $90, 0, UnknownScript_0x1ad6e7, $ffff
	person_event $2f, 16, 18, $7, $0, 255, 255, $0, 0, UnknownScript_0x1ad6ea, $ffff
	person_event $27, 15, 10, $5, $1, 255, 255, $a0, 1, UnknownScript_0x1ad6ed, $ffff
; 0x1ad927

Route6_MapScriptHeader: ; 0x1ad927
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ad929

TrainerPokefanmRex: ; 0x1ad929
	; bit/flag number
	dw $5c7

	; trainer group && trainer id
	db POKEFANM, REX

	; text when seen
	dw PokefanmRexSeenText

	; text when trainer beaten
	dw PokefanmRexBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmRexScript
; 0x1ad935

PokefanmRexScript: ; 0x1ad935
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ad9ff
	closetext
	loadmovesprites
	end
; 0x1ad93d

TrainerPokefanmAllan: ; 0x1ad93d
	; bit/flag number
	dw $5c8

	; trainer group && trainer id
	db POKEFANM, ALLAN

	; text when seen
	dw PokefanmAllanSeenText

	; text when trainer beaten
	dw PokefanmAllanBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmAllanScript
; 0x1ad949

PokefanmAllanScript: ; 0x1ad949
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ada88
	closetext
	loadmovesprites
	end
; 0x1ad951

UnknownScript_0x1ad951: ; 0x1ad951
	jumptextfaceplayer UnknownText_0x1ad957
; 0x1ad954

MapRoute6Signpost0Script: ; 0x1ad954
	jumptext UnknownText_0x1ad99b
; 0x1ad957

UnknownText_0x1ad957: ; 0x1ad957
	db $0, "The road is closed", $4f
	db "until the problem", $51
	db "at the POWER PLANT", $4f
	db "is solved.", $57
; 0x1ad99b

UnknownText_0x1ad99b: ; 0x1ad99b
	db $0, "UNDERGROUND PATH", $51
	db "CERULEAN CITY -", $4f
	db "VERMILION CITY", $57
; 0x1ad9cc

PokefanmRexSeenText: ; 0x1ad9cc
	db $0, "My PHANPY is the", $4f
	db "cutest in the", $55
	db "world.", $57
; 0x1ad9f3

PokefanmRexBeatenText: ; 0x1ad9f3
	db $0, "My PHANPY!", $57
; 0x1ad9ff

UnknownText_0x1ad9ff: ; 0x1ad9ff
	db $0, "Look how adorable", $4f
	db "my PHANPY acts!", $51
	db "Isn't it cute", $4f
	db "enough to make", $55
	db "your heart melt?", $57
; 0x1ada4f

PokefanmAllanSeenText: ; 0x1ada4f
	db $0, "My TEDDIURSA is", $4f
	db "the cutest in the", $55
	db "world.", $57
; 0x1ada79

PokefanmAllanBeatenText: ; 0x1ada79
	db $0, "My TEDDIURSA!", $57
; 0x1ada88

UnknownText_0x1ada88: ; 0x1ada88
	db $0, "Look how adorable", $4f
	db "my TEDDIURSA acts!", $51
	db "Isn't it cute", $4f
	db "enough to make", $55
	db "your heart melt?", $57
; 0x1adadb

Route6_MapEventHeader: ; 0x1adadb
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $3, $11, 1, GROUP_ROUTE_6_UNDERGROUND_ENTRANCE, MAP_ROUTE_6_UNDERGROUND_ENTRANCE
	warp_def $1, $6, 3, GROUP_ROUTE_6_SAFFRON_GATE, MAP_ROUTE_6_SAFFRON_GATE

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 5, 19, $0, MapRoute6Signpost0Script

	; people-events
	db 3
	person_event $2d, 8, 21, $6, $0, 255, 255, $b0, 2, UnknownScript_0x1ad951, $0771
	person_event $2d, 16, 13, $9, $0, 255, 255, $82, 0, TrainerPokefanmRex, $ffff
	person_event $2d, 16, 14, $8, $0, 255, 255, $82, 0, TrainerPokefanmAllan, $ffff
; 0x1adb17

Route5_MapScriptHeader: ; 0x1adb17
	; trigger count
	db 0

	; callback count
	db 0
; 0x1adb19

UnknownScript_0x1adb19: ; 0x1adb19
	jumptextfaceplayer UnknownText_0x1adb22
; 0x1adb1c

MapRoute5Signpost0Script: ; 0x1adb1c
	jumptext UnknownText_0x1adb66
; 0x1adb1f

MapRoute5Signpost1Script: ; 0x1adb1f
	jumptext UnknownText_0x1adb97
; 0x1adb22

UnknownText_0x1adb22: ; 0x1adb22
	db $0, "The road is closed", $4f
	db "until the problem", $51
	db "at the POWER PLANT", $4f
	db "is solved.", $57
; 0x1adb66

UnknownText_0x1adb66: ; 0x1adb66
	db $0, "UNDERGROUND PATH", $51
	db "CERULEAN CITY -", $4f
	db "VERMILION CITY", $57
; 0x1adb97

UnknownText_0x1adb97: ; 0x1adb97
	db $0, "What's this?", $51
	db "House for Sale…", $4f
	db "Nobody lives here.", $57
; 0x1adbc7

Route5_MapEventHeader: ; 0x1adbc7
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $f, $11, 1, GROUP_ROUTE_5_UNDERGROUND_ENTRANCE, MAP_ROUTE_5_UNDERGROUND_ENTRANCE
	warp_def $11, $8, 1, GROUP_ROUTE_5_SAFFRON_CITY_GATE, MAP_ROUTE_5_SAFFRON_CITY_GATE
	warp_def $11, $9, 2, GROUP_ROUTE_5_SAFFRON_CITY_GATE, MAP_ROUTE_5_SAFFRON_CITY_GATE
	warp_def $b, $a, 1, GROUP_ROUTE_5_CLEANSE_TAG_SPEECH_HOUSE, MAP_ROUTE_5_CLEANSE_TAG_SPEECH_HOUSE

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 17, 17, $0, MapRoute5Signpost0Script
	signpost 11, 10, $0, MapRoute5Signpost1Script

	; people-events
	db 1
	person_event $2d, 20, 21, $6, $0, 255, 255, $80, 0, UnknownScript_0x1adb19, $0771
; 0x1adbf8

Route24_MapScriptHeader: ; 0x1adbf8
	; trigger count
	db 0

	; callback count
	db 0
; 0x1adbfa

UnknownScript_0x1adbfa: ; 0x1adbfa
	faceplayer
	playmusic $0039
	loadfont
	2writetext UnknownText_0x1adc2e
	closetext
	loadmovesprites
	winlosstext UnknownText_0x1add67, $ffff
	loadtrainer GRUNTM, 31
	startbattle
	reloadmapmusic
	returnafterbattle
	playmusic $0039
	loadfont
	2writetext UnknownText_0x1addc0
	keeptextopen
	special $006a
	2writetext UnknownText_0x1adee1
	closetext
	loadmovesprites
	special $0030
	special $0033
	disappear $2
	pause 25
	special $0032
	playmapmusic
	end
; 0x1adc2e

UnknownText_0x1adc2e: ; 0x1adc2e
	db $0, "Hey, kid! Me am a", $4f
	db "TEAM ROCKET member", $55
	db "kind of guy!", $51
	db "Come from another", $4f
	db "country, a trainer", $55
	db "number one, me!", $51
	db "Think I did, if", $4f
	db "stop the energy,", $51
	db "be big panic for", $4f
	db "here people!", $51
	db "Secret it is my", $4f
	db "mission, so tell", $55
	db "you I not!", $51
	db "But! If win you do", $4f
	db "versus me, a man I", $51
	db "be and mine secret", $4f
	db "to you I tell.", $51
	db "Hey, kid! Battle", $4f
	db "begin we do!", $57
; 0x1add67

UnknownText_0x1add67: ; 0x1add67
	db $0, "Ayieeeh! No, no,", $4f
	db "no, believe it I", $55
	db "can't!", $51
	db "Strong very much", $4f
	db "be you! Match I am", $55
	db "not to you!", $57
; 0x1addc0

UnknownText_0x1addc0: ; 0x1addc0
	db $0, "OK. Tell you mine", $4f
	db "secret will I.", $51
	db "MACHINE PART steal", $4f
	db "by me, hide it I", $51
	db "did in GYM of the", $4f
	db "CERULEAN.", $51
	db "Inside water put", $4f
	db "it I did. Look for", $51
	db "in water center of", $4f
	db "GYM at.", $51
	db "But you forget me", $4f
	db "not!", $51
	db "Beat you for sure", $4f
	db "will TEAM ROCKET.", $51
	db "Come from JOHTO", $4f
	db "will they, mine", $51
	db "friends, yes. Will", $4f
	db "revenge they are.", $57
; 0x1adee1

UnknownText_0x1adee1: ; 0x1adee1
	db $0, "…", $51
	db "You say what? TEAM", $4f
	db "ROCKET bye-bye a", $51
	db "go-go? Broken it", $4f
	db "is says you?", $51
	db "Oh, no! Should I", $4f
	db "do what now on", $55
	db "from, me?", $57
; 0x1adf50

Route24_MapEventHeader: ; 0x1adf50
	; filler
	db 0, 0

	; warps
	db 0

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 1
	person_event $35, 11, 12, $3, $0, 255, 255, $0, 0, UnknownScript_0x1adbfa, $076c
; 0x1adf63

Route3_MapScriptHeader: ; 0x1adf63
	; trigger count
	db 0

	; callback count
	db 0
; 0x1adf65

TrainerFirebreatherOtis: ; 0x1adf65
	; bit/flag number
	dw $446

	; trainer group && trainer id
	db FIREBREATHER, OTIS

	; text when seen
	dw FirebreatherOtisSeenText

	; text when trainer beaten
	dw FirebreatherOtisBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FirebreatherOtisScript
; 0x1adf71

FirebreatherOtisScript: ; 0x1adf71
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1adff7
	closetext
	loadmovesprites
	end
; 0x1adf79

TrainerYoungsterWarren: ; 0x1adf79
	; bit/flag number
	dw $5b1

	; trainer group && trainer id
	db YOUNGSTER, WARREN

	; text when seen
	dw YoungsterWarrenSeenText

	; text when trainer beaten
	dw YoungsterWarrenBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterWarrenScript
; 0x1adf85

YoungsterWarrenScript: ; 0x1adf85
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ae051
	closetext
	loadmovesprites
	end
; 0x1adf8d

TrainerYoungsterJimmy: ; 0x1adf8d
	; bit/flag number
	dw $5b2

	; trainer group && trainer id
	db YOUNGSTER, JIMMY

	; text when seen
	dw YoungsterJimmySeenText

	; text when trainer beaten
	dw YoungsterJimmyBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw YoungsterJimmyScript
; 0x1adf99

YoungsterJimmyScript: ; 0x1adf99
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ae0a9
	closetext
	loadmovesprites
	end
; 0x1adfa1

TrainerFirebreatherBurt: ; 0x1adfa1
	; bit/flag number
	dw $449

	; trainer group && trainer id
	db FIREBREATHER, BURT

	; text when seen
	dw FirebreatherBurtSeenText

	; text when trainer beaten
	dw FirebreatherBurtBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw FirebreatherBurtScript
; 0x1adfad

FirebreatherBurtScript: ; 0x1adfad
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ae118
	closetext
	loadmovesprites
	end
; 0x1adfb5

MapRoute3Signpost0Script: ; 0x1adfb5
	jumptext UnknownText_0x1ae163
; 0x1adfb8

FirebreatherOtisSeenText: ; 0x1adfb8
	db $0, "Ah! The weather's", $4f
	db "as fine as ever.", $57
; 0x1adfdb

FirebreatherOtisBeatenText: ; 0x1adfdb
	db $0, "It's sunny, but", $4f
	db "I'm all wet…", $57
; 0x1adff7

UnknownText_0x1adff7: ; 0x1adff7
	db $0, "When it rains,", $4f
	db "it's hard to get", $55
	db "ignition…", $57
; 0x1ae021

YoungsterWarrenSeenText: ; 0x1ae021
	db $0, "Hmmm… I don't know", $4f
	db "what to do…", $57
; 0x1ae040

YoungsterWarrenBeatenText: ; 0x1ae040
	db $0, "I knew I'd lose…", $57
; 0x1ae051

UnknownText_0x1ae051: ; 0x1ae051
	db $0, "You looked strong.", $51
	db "I was afraid to", $4f
	db "take you on…", $57
; 0x1ae082

YoungsterJimmySeenText: ; 0x1ae082
	db $0, "I can run like the", $4f
	db "wind!", $57
; 0x1ae09c

YoungsterJimmyBeatenText: ; 0x1ae09c
	db $0, "Blown away!", $57
; 0x1ae0a9

UnknownText_0x1ae0a9: ; 0x1ae0a9
	db $0, "I wear shorts the", $4f
	db "whole year round.", $51
	db "That's my fashion", $4f
	db "policy.", $57
; 0x1ae0e7

FirebreatherBurtSeenText: ; 0x1ae0e7
	db $0, "Step right up and", $4f
	db "take a look!", $57
; 0x1ae107

FirebreatherBurtBeatenText: ; 0x1ae107
	db $0, "Yow! That's hot!", $57
; 0x1ae118

UnknownText_0x1ae118: ; 0x1ae118
	db $0, "The greatest fire-", $4f
	db "breather in KANTO,", $55
	db "that's me.", $51
	db "But not the best", $4f
	db "trainer…", $57
; 0x1ae163

UnknownText_0x1ae163: ; 0x1ae163
	db $0, "MT.MOON SQUARE", $51
	db "Just go up the", $4f
	db "stairs.", $57
; 0x1ae18a

Route3_MapEventHeader: ; 0x1ae18a
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $1, $34, 1, GROUP_MOUNT_MOON, MAP_MOUNT_MOON

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 13, 49, $0, MapRoute3Signpost0Script

	; people-events
	db 4
	person_event $3a, 16, 30, $7, $0, 255, 255, $82, 2, TrainerFirebreatherOtis, $ffff
	person_event $27, 11, 14, $8, $0, 255, 255, $92, 3, TrainerYoungsterWarren, $ffff
	person_event $27, 7, 20, $a, $0, 255, 255, $92, 1, TrainerYoungsterJimmy, $ffff
	person_event $3a, 9, 53, $a, $0, 255, 255, $82, 3, TrainerFirebreatherBurt, $ffff
; 0x1ae1ce

Route4_MapScriptHeader: ; 0x1ae1ce
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ae1d0

TrainerBird_keeperHank: ; 0x1ae1d0
	; bit/flag number
	dw $402

	; trainer group && trainer id
	db BIRD_KEEPER, HANK

	; text when seen
	dw Bird_keeperHankSeenText

	; text when trainer beaten
	dw Bird_keeperHankBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw Bird_keeperHankScript
; 0x1ae1dc

Bird_keeperHankScript: ; 0x1ae1dc
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ae258
	closetext
	loadmovesprites
	end
; 0x1ae1e4

TrainerPicnickerHope: ; 0x1ae1e4
	; bit/flag number
	dw $483

	; trainer group && trainer id
	db PICNICKER, HOPE

	; text when seen
	dw PicnickerHopeSeenText

	; text when trainer beaten
	dw PicnickerHopeBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerHopeScript
; 0x1ae1f0

PicnickerHopeScript: ; 0x1ae1f0
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ae320
	closetext
	loadmovesprites
	end
; 0x1ae1f8

TrainerPicnickerSharon: ; 0x1ae1f8
	; bit/flag number
	dw $484

	; trainer group && trainer id
	db PICNICKER, SHARON

	; text when seen
	dw PicnickerSharonSeenText

	; text when trainer beaten
	dw PicnickerSharonBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PicnickerSharonScript
; 0x1ae204

PicnickerSharonScript: ; 0x1ae204
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ae369
	closetext
	loadmovesprites
	end
; 0x1ae20c

MapRoute4Signpost0Script: ; 0x1ae20c
	jumptext UnknownText_0x1ae384
; 0x1ae20f

ItemFragment_0x1ae20f: ; 0x1ae20f
	db HP_UP, 1
; 0x1ae211

MapRoute4SignpostItem1: ; 0x1ae211
	dw $00f1
	db ULTRA_BALL
	
; 0x1ae214

Bird_keeperHankSeenText: ; 0x1ae214
	db $0, "I'm raising my", $4f
	db "#MON. Want to", $55
	db "battle with me?", $57
; 0x1ae241

Bird_keeperHankBeatenText: ; 0x1ae241
	db $0, "Ack! I lost that", $4f
	db "one…", $57
; 0x1ae258

UnknownText_0x1ae258: ; 0x1ae258
	db $0, "If you have a", $4f
	db "specific #MON", $51
	db "that you want to", $4f
	db "raise, put it out", $51
	db "first, then switch", $4f
	db "it right away.", $51
	db "That's how to do", $4f
	db "it.", $57
; 0x1ae2ce

PicnickerHopeSeenText: ; 0x1ae2ce
	db $0, "I have a feeling", $4f
	db "that I can win.", $51
	db "Let's see if I'm", $4f
	db "right!", $57
; 0x1ae306

PicnickerHopeBeatenText: ; 0x1ae306
	db $0, "Aww, you are too", $4f
	db "strong.", $57
; 0x1ae320

UnknownText_0x1ae320: ; 0x1ae320
	db $0, "I heard CLEFAIRY", $4f
	db "appear at MT.MOON.", $51
	db "But where could", $4f
	db "they be?", $57
; 0x1ae35e

PicnickerSharonSeenText: ; 0x1ae35e
	db $0, "Um…", $4f
	db "I…", $57
; 0x1ae366

PicnickerSharonBeatenText: ; 0x1ae366
	db $0, "…", $57
; 0x1ae369

UnknownText_0x1ae369: ; 0x1ae369
	db $0, "……I'll go train", $4f
	db "some more…", $57
; 0x1ae384

UnknownText_0x1ae384: ; 0x1ae384
	db $0, "MT.MOON SQUARE", $51
	db "Just go up the", $4f
	db "stairs.", $57
; 0x1ae3ab

Route4_MapEventHeader: ; 0x1ae3ab
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $5, $2, 2, GROUP_MOUNT_MOON, MAP_MOUNT_MOON

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 7, 3, $0, MapRoute4Signpost0Script
	signpost 3, 10, $7, MapRoute4SignpostItem1

	; people-events
	db 4
	person_event $27, 13, 21, $6, $0, 255, 255, $92, 3, TrainerBird_keeperHank, $ffff
	person_event $28, 12, 13, $8, $0, 255, 255, $a2, 4, TrainerPicnickerHope, $ffff
	person_event $28, 10, 25, $9, $0, 255, 255, $a2, 4, TrainerPicnickerSharon, $ffff
	person_event $54, 7, 30, $1, $0, 255, 255, $1, 0, ItemFragment_0x1ae20f, $0787
; 0x1ae3f4

Route10South_MapScriptHeader: ; 0x1ae3f4
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ae3f6

TrainerHikerJim: ; 0x1ae3f6
	; bit/flag number
	dw $534

	; trainer group && trainer id
	db HIKER, JIM

	; text when seen
	dw HikerJimSeenText

	; text when trainer beaten
	dw HikerJimBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw HikerJimScript
; 0x1ae402

HikerJimScript: ; 0x1ae402
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ae43b
	closetext
	loadmovesprites
	end
; 0x1ae40a

TrainerPokefanmRobert: ; 0x1ae40a
	; bit/flag number
	dw $4cf

	; trainer group && trainer id
	db POKEFANM, ROBERT

	; text when seen
	dw PokefanmRobertSeenText

	; text when trainer beaten
	dw PokefanmRobertBeatenText

	; script when lost
	dw $0000

	; script when talk again
	dw PokefanmRobertScript
; 0x1ae416

PokefanmRobertScript: ; 0x1ae416
	talkaftercancel
	loadfont
	2writetext UnknownText_0x1ae4a9
	closetext
	loadmovesprites
	end
; 0x1ae41e

MapRoute10SouthSignpost0Script: ; 0x1ae41e
	jumptext UnknownText_0x1ae4dc
; 0x1ae421

HikerJimSeenText: ; 0x1ae421
	db $0, "Hahahah!", $57
; 0x1ae42b

HikerJimBeatenText: ; 0x1ae42b
	db $0, "Hahaha-hachoo!", $57
; 0x1ae43b

UnknownText_0x1ae43b: ; 0x1ae43b
	db $0, "Hay fever is", $4f
	db "making me sneeze!", $55
	db "Ahahah-CHOO!", $57
; 0x1ae468

PokefanmRobertSeenText: ; 0x1ae468
	db $0, "You like #MON,", $4f
	db "don't you?", $51
	db "Me too!", $57
; 0x1ae48a

PokefanmRobertBeatenText: ; 0x1ae48a
	db $0, "I'd have to say", $4f
	db "that's my loss.", $57
; 0x1ae4a9

UnknownText_0x1ae4a9: ; 0x1ae4a9
	db $0, "Look what you did", $4f
	db "to my #MON…", $51
	db "I won't forget", $4f
	db "this…", $57
; 0x1ae4dc

UnknownText_0x1ae4dc: ; 0x1ae4dc
	db $0, "ROUTE 10", $51
	db "CERULEAN CITY -", $4f
	db "LAVENDER TOWN", $57
; 0x1ae504

Route10South_MapEventHeader: ; 0x1ae504
	; filler
	db 0, 0

	; warps
	db 1
	warp_def $1, $6, 2, GROUP_ROCK_TUNNEL_1F, MAP_ROCK_TUNNEL_1F

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 3, 5, $0, MapRoute10SouthSignpost0Script

	; people-events
	db 2
	person_event $2d, 7, 21, $8, $0, 255, 255, $b2, 3, TrainerHikerJim, $ffff
	person_event $2d, 14, 12, $a, $0, 255, 255, $82, 3, TrainerPokefanmRobert, $ffff
; 0x1ae52e

Route23_MapScriptHeader: ; 0x1ae52e
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1ae533
; 0x1ae533

UnknownScript_0x1ae533: ; 0x1ae533
	setbit2 $0040
	return
; 0x1ae537

MapRoute23Signpost0Script: ; 0x1ae537
	jumptext UnknownText_0x1ae53a
; 0x1ae53a

UnknownText_0x1ae53a: ; 0x1ae53a
	db $0, "INDIGO PLATEAU", $51
	db "The Ultimate Goal", $4f
	db "for Trainers!", $51
	db "#MON LEAGUE HQ", $57
; 0x1ae579

Route23_MapEventHeader: ; 0x1ae579
	; filler
	db 0, 0

	; warps
	db 4
	warp_def $5, $9, 1, GROUP_INDIGO_PLATEAU_POKECENTER_1F, MAP_INDIGO_PLATEAU_POKECENTER_1F
	warp_def $5, $a, 2, GROUP_INDIGO_PLATEAU_POKECENTER_1F, MAP_INDIGO_PLATEAU_POKECENTER_1F
	warp_def $d, $9, 10, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD
	warp_def $d, $a, 10, GROUP_VICTORY_ROAD, MAP_VICTORY_ROAD

	; xy triggers
	db 0

	; signposts
	db 1
	signpost 7, 11, $0, MapRoute23Signpost0Script

	; people-events
	db 0
; 0x1ae598

SilverCavePokeCenter1F_MapScriptHeader: ; 0x1ae598
	; trigger count
	db 0

	; callback count
	db 0
; 0x1ae59a

UnknownScript_0x1ae59a: ; 0x1ae59a
	jumpstd $0000
; 0x1ae59d

UnknownScript_0x1ae59d: ; 0x1ae59d
	jumptextfaceplayer UnknownText_0x1ae5a0
; 0x1ae5a0

UnknownText_0x1ae5a0: ; 0x1ae5a0
	db $0, "Trainers who seek", $4f
	db "power climb MT.", $51
	db "SILVER despite its", $4f
	db "many dangers…", $51
	db "With their trusted", $4f
	db "#MON, they must", $51
	db "feel they can go", $4f
	db "anywhere…", $57
; 0x1ae622

SilverCavePokeCenter1F_MapEventHeader: ; 0x1ae622
	; filler
	db 0, 0

	; warps
	db 3
	warp_def $7, $3, 1, GROUP_SILVER_CAVE_OUTSIDE, MAP_SILVER_CAVE_OUTSIDE
	warp_def $7, $4, 1, GROUP_SILVER_CAVE_OUTSIDE, MAP_SILVER_CAVE_OUTSIDE
	warp_def $7, $0, 1, GROUP_POKECENTER_2F, MAP_POKECENTER_2F

	; xy triggers
	db 0

	; signposts
	db 0

	; people-events
	db 2
	person_event $37, 5, 7, $6, $0, 255, 255, $0, 0, UnknownScript_0x1ae59a, $ffff
	person_event $30, 9, 5, $8, $12, 255, 255, $0, 0, UnknownScript_0x1ae59d, $ffff
; 0x1ae651

Route28FamousSpeechHouse_MapScriptHeader: ; 0x1ae651
	; trigger count
	db 1

	; triggers
	dw UnknownScript_0x1ae657, $0000

	; callback count
	db 0
; 0x1ae657

UnknownScript_0x1ae657: ; 0x1ae657
	end
; 0x1ae658

UnknownScript_0x1ae658: ; 0x1ae658
	faceplayer
	loadfont
	checkbit1 $0074
	iftrue UnknownScript_0x1ae66f
	2writetext UnknownText_0x1ae682
	keeptextopen
	verbosegiveitem TM_47, 1
	iffalse UnknownScript_0x1ae66d
	setbit1 $0074
UnknownScript_0x1ae66d: ; 0x1ae66d
	loadmovesprites
	end
; 0x1ae66f

UnknownScript_0x1ae66f: ; 0x1ae66f
	2writetext UnknownText_0x1ae6f0
	closetext
	loadmovesprites
	end
; 0x1ae675

UnknownScript_0x1ae675: ; 0x1ae675
	loadfont
	2writetext UnknownText_0x1ae752
	cry FEAROW
	closetext
	loadmovesprites
	end
; 0x1ae67f

MapRoute28FamousSpeechHouseSignpost1Script: ; 0x1ae67f
	jumpstd $0003
; 0x1ae682

UnknownText_0x1ae682: ; 0x1ae682
	db $0, "Oh, dear.", $4f
	db "You've found me.", $51
	db "Please don't tell", $4f
	db "anyone about me.", $51
	db "I'll give you this", $4f
	db "for keeping my", $55
	db "secret. Please?", $57
; 0x1ae6f0

UnknownText_0x1ae6f0: ; 0x1ae6f0
	db $0, "It's tough being a", $4f
	db "top celebrity.", $51
	db "Everywhere I go,", $4f
	db "people chase me.", $51
	db "I just want to be", $4f
	db "left alone…", $57
; 0x1ae752

UnknownText_0x1ae752: ; 0x1ae752
	db $0, "FEAROW: Feero!", $57
; 0x1ae762

Route28FamousSpeechHouse_MapEventHeader: ; 0x1ae762
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $7, $2, 1, GROUP_ROUTE_28, MAP_ROUTE_28
	warp_def $7, $3, 1, GROUP_ROUTE_28, MAP_ROUTE_28

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 1, 0, $0, MapRoute28FamousSpeechHouseSignpost1Script
	signpost 1, 1, $0, MapRoute28FamousSpeechHouseSignpost1Script

	; people-events
	db 2
	person_event $24, 7, 6, $6, $0, 255, 255, $a0, 0, UnknownScript_0x1ae658, $ffff
	person_event $9e, 9, 10, $16, $0, 255, 255, $b0, 0, UnknownScript_0x1ae675, $ffff
; 0x1ae796

SECTION "bank6C",DATA,BANK[$6C]

INCBIN "baserom.gbc",$1b0000,$1b2042 - $1b0000

SilverCaveOutside_MapScriptHeader: ; 0x1b2042
	; trigger count
	db 0

	; callback count
	db 1

	; callbacks

	dbw 5, UnknownScript_0x1b2047
; 0x1b2047

UnknownScript_0x1b2047: ; 0x1b2047
	setbit2 $004c
	return
; 0x1b204b

MapSilverCaveOutsideSignpost0Script: ; 0x1b204b
	jumpstd $0010
; 0x1b204e

MapSilverCaveOutsideSignpost1Script: ; 0x1b204e
	jumptext UnknownText_0x1b2054
; 0x1b2051

MapSilverCaveOutsideSignpostItem2: ; 0x1b2051
	dw $00b8
	db FULL_RESTORE
	
; 0x1b2054

UnknownText_0x1b2054: ; 0x1b2054
	db $0, "MT.SILVER", $57
; 0x1b205f

SilverCaveOutside_MapEventHeader: ; 0x1b205f
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $13, $17, 1, GROUP_SILVER_CAVE_POKECENTER_1F, MAP_SILVER_CAVE_POKECENTER_1F
	warp_def $b, $12, 1, GROUP_SILVER_CAVE_ROOM_1, MAP_SILVER_CAVE_ROOM_1

	; xy triggers
	db 0

	; signposts
	db 3
	signpost 19, 24, $0, MapSilverCaveOutsideSignpost0Script
	signpost 13, 17, $0, MapSilverCaveOutsideSignpost1Script
	signpost 25, 9, $7, MapSilverCaveOutsideSignpostItem2

	; people-events
	db 0
; 0x1b207e

Route10North_MapScriptHeader: ; 0x1b207e
	; trigger count
	db 0

	; callback count
	db 0
; 0x1b2080

MapRoute10NorthSignpost0Script: ; 0x1b2080
	jumptext UnknownText_0x1b2086
; 0x1b2083

MapRoute10NorthSignpost1Script: ; 0x1b2083
	jumpstd $0010
; 0x1b2086

UnknownText_0x1b2086: ; 0x1b2086
	db $0, "KANTO POWER PLANT", $57
; 0x1b2099

Route10North_MapEventHeader: ; 0x1b2099
	; filler
	db 0, 0

	; warps
	db 2
	warp_def $1, $b, 1, GROUP_ROUTE_10_POKECENTER_1F, MAP_ROUTE_10_POKECENTER_1F
	warp_def $9, $3, 1, GROUP_POWER_PLANT, MAP_POWER_PLANT

	; xy triggers
	db 0

	; signposts
	db 2
	signpost 11, 5, $0, MapRoute10NorthSignpost0Script
	signpost 1, 12, $0, MapRoute10NorthSignpost1Script

	; people-events
	db 0
; 0x1b20b3

SECTION "bank6D",DATA,BANK[$6D]

INCBIN "baserom.gbc",$1B4000,$4000

SECTION "bank6E",DATA,BANK[$6E]

AlakazamPokedexEntry: ; 0x1b8000
	db "PSI@" ; species name
	dw 411, 1060; height, width
	
	db "It has an IQ of", $4e, "5000. It calcu-", $4e, "lates many things@"
	db "in order to gain", $4e, "the edge in every", $4e, "battle.@"
; 0x1b8065

MachopPokedexEntry: ; 0x1b8065
	db "SUPERPOWER@" ; species name
	dw 207, 430; height, width
	
	db "It trains by", $4e, "lifting rocks in", $4e, "the mountains. It@"
	db "can even pick up a", $4e, "GRAVELER with", $4e, "ease.@"
; 0x1b80cb

MachokePokedexEntry: ; 0x1b80cb
	db "SUPERPOWER@" ; species name
	dw 411, 1550; height, width
	
	db "This tough #MON", $4e, "always stays in", $4e, "the zone. Its@"
	db "muscles become", $4e, "thicker after", $4e, "every battle.@"
; 0x1b8133

MachampPokedexEntry: ; 0x1b8133
	db "SUPERPOWER@" ; species name
	dw 503, 2870; height, width
	
	db "With four arms", $4e, "that react more", $4e, "quickly than it@"
	db "can think, it can", $4e, "execute many", $4e, "punches at once.@"
; 0x1b81a1

BellsproutPokedexEntry: ; 0x1b81a1
	db "FLOWER@" ; species name
	dw 204, 90; height, width
	
	db "If it notices", $4e, "anything that", $4e, "moves, it@"
	db "immediately flings", $4e, "its vine at the", $4e, "object.@"
; 0x1b81fd

WeepinbellPokedexEntry: ; 0x1b81fd
	db "FLYCATCHER@" ; species name
	dw 303, 140; height, width
	
	db "When it's hungry,", $4e, "it swings its", $4e, "razor-sharp@"
	db "leaves, slicing up", $4e, "any unlucky object", $4e, "nearby for food.@"
; 0x1b826e

VictreebelPokedexEntry: ; 0x1b826e
	db "FLYCATCHER@" ; species name
	dw 507, 340; height, width
	
	db "Once ingested into", $4e, "this #MON's", $4e, "body, even the@"
	db "hardest object", $4e, "will melt into", $4e, "nothing.@"
; 0x1b82d1

TentacoolPokedexEntry: ; 0x1b82d1
	db "JELLYFISH@" ; species name
	dw 211, 1000; height, width
	
	db "As it floats along", $4e, "on the waves, it", $4e, "uses its toxic@"
	db "feelers to stab", $4e, "anything it", $4e, "touches.@"
; 0x1b8337

TentacruelPokedexEntry: ; 0x1b8337
	db "JELLYFISH@" ; species name
	dw 503, 1210; height, width
	
	db "When its 80 feel-", $4e, "ers absorb water,", $4e, "it stretches to@"
	db "become like a net", $4e, "to entangle its", $4e, "prey.@"
; 0x1b83a1

GeodudePokedexEntry: ; 0x1b83a1
	db "ROCK@" ; species name
	dw 104, 440; height, width
	
	db "Proud of their", $4e, "sturdy bodies,", $4e, "they bash against@"
	db "each other in a", $4e, "contest to prove", $4e, "whose is harder.@"
; 0x1b840c

GravelerPokedexEntry: ; 0x1b840c
	db "ROCK@" ; species name
	dw 303, 2320; height, width
	
	db "It travels by rol-", $4e, "ling on mountain", $4e, "paths. If it gains@"
	db "too much speed, it", $4e, "stops by running", $4e, "into huge rocks.@"
; 0x1b8481

GolemPokedexEntry: ; 0x1b8481
	db "MEGATON@" ; species name
	dw 407, 6620; height, width
	
	db "Its rock-like body", $4e, "is so durable,", $4e, "even high-powered@"
	db "dynamite blasts", $4e, "fail to scratch", $4e, "its rugged hide.@"
; 0x1b84f2

PonytaPokedexEntry: ; 0x1b84f2
	db "FIRE HORSE@" ; species name
	dw 303, 660; height, width
	
	db "Training by", $4e, "jumping over grass", $4e, "that grows longer@"
	db "every day has made", $4e, "it a world-class", $4e, "jumper.@"
; 0x1b855e

RapidashPokedexEntry: ; 0x1b855e
	db "FIRE HORSE@" ; species name
	dw 507, 2090; height, width
	
	db "It just loves to", $4e, "gallop. The faster", $4e, "it goes, the long-@"
	db "er the swaying", $4e, "flames of its mane", $4e, "will become.@"
; 0x1b85d3

SlowpokePokedexEntry: ; 0x1b85d3
	db "DOPEY@" ; species name
	dw 311, 790; height, width
	
	db "It is always so", $4e, "absent-minded that", $4e, "it won't react,@"
	db "even if its", $4e, "flavorful tail is", $4e, "bitten.@"
; 0x1b8635

SlowbroPokedexEntry: ; 0x1b8635
	db "HERMITCRAB@" ; species name
	dw 503, 1730; height, width
	
	db "An attached", $4e, "SHELLDER won't let", $4e, "go because of the@"
	db "tasty flavor that", $4e, "oozes out of its", $4e, "tail.@"
; 0x1b869d

MagnemitePokedexEntry: ; 0x1b869d
	db "MAGNET@" ; species name
	dw 100, 130; height, width
	
	db "The electricity", $4e, "emitted by the", $4e, "units on each side@"
	db "of its body cause", $4e, "it to become a", $4e, "strong magnet.@"
; 0x1b870a

MagnetonPokedexEntry: ; 0x1b870a
	db "MAGNET@" ; species name
	dw 303, 1320; height, width
	
	db "When many", $4e, "MAGNETON gather", $4e, "together, the@"
	db "resulting magnetic", $4e, "storm disrupts", $4e, "radio waves.@"
; 0x1b876c

FarfetchDPokedexEntry: ; 0x1b876c
	db "WILD DUCK@" ; species name
	dw 207, 330; height, width
	
	db "In order to pre-", $4e, "vent their", $4e, "extinction, more@"
	db "people have made", $4e, "an effort to breed", $4e, "these #MON.@"
; 0x1b87d7

DoduoPokedexEntry: ; 0x1b87d7
	db "TWIN BIRD@" ; species name
	dw 407, 860; height, width
	
	db "It lives on a", $4e, "grassy plain where", $4e, "it can see a long@"
	db "way. If it sees an", $4e, "enemy, it runs", $4e, "away at 60 mph.@"
; 0x1b884a

DodrioPokedexEntry: ; 0x1b884a
	db "TRIPLEBIRD@" ; species name
	dw 511, 1880; height, width
	
	db "An enemy that", $4e, "takes its eyes off", $4e, "any of the three@"
	db "heads--even for a", $4e, "second--will get", $4e, "pecked severely.@"
; 0x1b88bf

SeelPokedexEntry: ; 0x1b88bf
	db "SEA LION@" ; species name
	dw 307, 1980; height, width
	
	db "The light blue fur", $4e, "that covers it", $4e, "keeps it protected@"
	db "against the cold.", $4e, "It loves iceberg-", $4e, "filled oceans.@"
; 0x1b8934

DewgongPokedexEntry: ; 0x1b8934
	db "SEA LION@" ; species name
	dw 507, 2650; height, width
	
	db "It sleeps under", $4e, "shallow ocean", $4e, "waters during the@"
	db "day, then looks", $4e, "for food at night", $4e, "when it's cold.@"
; 0x1b89a2

GrimerPokedexEntry: ; 0x1b89a2
	db "SLUDGE@" ; species name
	dw 211, 660; height, width
	
	db "When two of these", $4e, "#MON's bodies", $4e, "are combined@"
	db "together, new", $4e, "poisons are", $4e, "created.@"
; 0x1b89fc

MukPokedexEntry: ; 0x1b89fc
	db "SLUDGE@" ; species name
	dw 311, 660; height, width
	
	db "As it moves, a", $4e, "very strong poison", $4e, "leaks from it,@"
	db "making the ground", $4e, "there barren for", $4e, "three years.@"
; 0x1b8a68

ShellderPokedexEntry: ; 0x1b8a68
	db "BIVALVE@" ; species name
	dw 100, 90; height, width
	
	db "Clamping on to an", $4e, "opponent reveals", $4e, "its vulnerable@"
	db "parts, so it uses", $4e, "this move only as", $4e, "a last resort.@"
; 0x1b8ad9

CloysterPokedexEntry: ; 0x1b8ad9
	db "BIVALVE@" ; species name
	dw 411, 2920; height, width
	
	db "Even a missile", $4e, "can't break the", $4e, "spikes it uses to@"
	db "stab opponents.", $4e, "They're even hard-", $4e, "er than its shell.@"
; 0x1b8b4a

GastlyPokedexEntry: ; 0x1b8b4a
	db "GAS@" ; species name
	dw 403, 2; height, width
	
	db "It wraps its op-", $4e, "ponent in its gas-", $4e, "like body, slowly@"
	db "weakening its prey", $4e, "by poisoning it", $4e, "through the skin.@"
; 0x1b8bbd

HaunterPokedexEntry: ; 0x1b8bbd
	db "GAS@" ; species name
	dw 503, 2; height, width
	
	db "It hides in the", $4e, "dark, planning to", $4e, "take the life of@"
	db "the next living", $4e, "thing that wanders", $4e, "close by.@"
; 0x1b8c25

GengarPokedexEntry: ; 0x1b8c25
	db "SHADOW@" ; species name
	dw 411, 890; height, width
	
	db "Hiding in people's", $4e, "shadows at night,", $4e, "it absorbs their@"
	db "heat. The chill it", $4e, "causes makes the", $4e, "victims shake.@"
; 0x1b8c98

OnixPokedexEntry: ; 0x1b8c98
	db "ROCK SNAKE@" ; species name
	dw 2810, 4630; height, width
	
	db "As it digs through", $4e, "the ground, it", $4e, "absorbs many hard@"
	db "objects. This is", $4e, "what makes its", $4e, "body so solid.@"
; 0x1b8d0a

DrowzeePokedexEntry: ; 0x1b8d0a
	db "HYPNOSIS@" ; species name
	dw 303, 710; height, width
	
	db "When it twitches", $4e, "its nose, it can", $4e, "tell where someone@"
	db "is sleeping and", $4e, "what that person", $4e, "is dreaming about.@"
; 0x1b8d80

HypnoPokedexEntry: ; 0x1b8d80
	db "HYPNOSIS@" ; species name
	dw 503, 1670; height, width
	
	db "The longer it", $4e, "swings its", $4e, "pendulum, the@"
	db "longer the effects", $4e, "of its hypnosis", $4e, "last.@"
; 0x1b8ddd

KrabbyPokedexEntry: ; 0x1b8ddd
	db "RIVER CRAB@" ; species name
	dw 104, 140; height, width
	
	db "If it is unable", $4e, "to find food, it", $4e, "will absorb@"
	db "nutrients by", $4e, "swallowing a", $4e, "mouthful of sand.@"
; 0x1b8e45

KinglerPokedexEntry: ; 0x1b8e45
	db "PINCER@" ; species name
	dw 403, 1320; height, width
	
	db "Its oversized claw", $4e, "is very powerful,", $4e, "but when it's not@"
	db "in battle, the", $4e, "claw just gets in", $4e, "the way.@"
; 0x1b8eb0

VoltorbPokedexEntry: ; 0x1b8eb0
	db "BALL@" ; species name
	dw 108, 230; height, width
	
	db "During the study", $4e, "of this #MON,", $4e, "it was discovered@"
	db "that its compo-", $4e, "nents are not", $4e, "found in nature.@"
; 0x1b8f19

ElectrodePokedexEntry: ; 0x1b8f19
	db "BALL@" ; species name
	dw 311, 1470; height, width
	
	db "The more energy it", $4e, "charges up, the", $4e, "faster it gets.@"
	db "But this also", $4e, "makes it more", $4e, "likely to explode.@"
; 0x1b8f84

ExeggcutePokedexEntry: ; 0x1b8f84
	db "EGG@" ; species name
	dw 104, 60; height, width
	
	db "If even one is", $4e, "separated from the", $4e, "group, the energy@"
	db "bond between the", $4e, "six will make them", $4e, "rejoin instantly.@"
; 0x1b8ff6

ExeggutorPokedexEntry: ; 0x1b8ff6
	db "COCONUT@" ; species name
	dw 607, 2650; height, width
	
	db "Living in a good", $4e, "environment makes", $4e, "it grow lots of@"
	db "heads. A head that", $4e, "drops off becomes", $4e, "an EXEGGCUTE.@"
; 0x1b9068

CubonePokedexEntry: ; 0x1b9068
	db "LONELY@" ; species name
	dw 104, 140; height, width
	
	db "It lost its mother", $4e, "after its birth.", $4e, "It wears its@"
	db "mother's skull,", $4e, "never revealing", $4e, "its true face.@"
; 0x1b90d2

MarowakPokedexEntry: ; 0x1b90d2
	db "BONEKEEPER@" ; species name
	dw 303, 990; height, width
	
	db "Somewhere in the", $4e, "world is a ceme-", $4e, "tery just for@"
	db "MAROWAK. It gets", $4e, "its bones from", $4e, "those graves.@"
; 0x1b913f

HitmonleePokedexEntry: ; 0x1b913f
	db "KICKING@" ; species name
	dw 411, 1100; height, width
	
	db "It is also called", $4e, "the Kick Master.", $4e, "It uses its@"
	db "elastic legs to", $4e, "execute every", $4e, "known kick.@"
; 0x1b91a4

HitmonchanPokedexEntry: ; 0x1b91a4
	db "PUNCHING@" ; species name
	dw 407, 1110; height, width
	
	db "To increase the", $4e, "strength of all", $4e, "its punch moves,@"
	db "it spins its arms", $4e, "just before making", $4e, "contact.@"
; 0x1b9210

LickitungPokedexEntry: ; 0x1b9210
	db "LICKING@" ; species name
	dw 311, 1440; height, width
	
	db "It has a tongue", $4e, "that is over 6'6''", $4e, "long. It uses this@"
	db "long tongue to", $4e, "lick its body", $4e, "clean.@"
; 0x1b9276

KoffingPokedexEntry: ; 0x1b9276
	db "POISON GAS@" ; species name
	dw 200, 20; height, width
	
	db "If one gets close", $4e, "enough to it when", $4e, "it expels poison-@"
	db "ous gas, the gas", $4e, "swirling inside it", $4e, "can be seen.@"
; 0x1b92ec

WeezingPokedexEntry: ; 0x1b92ec
	db "POISON GAS@" ; species name
	dw 311, 210; height, width
	
	db "When it inhales", $4e, "poisonous gases", $4e, "from garbage, its@"
	db "body expands, and", $4e, "its insides smell", $4e, "much worse.@"
; 0x1b935d

RhyhornPokedexEntry: ; 0x1b935d
	db "SPIKES@" ; species name
	dw 303, 2540; height, width
	
	db "It can remember", $4e, "only one thing at", $4e, "a time. Once it@"
	db "starts rushing, it", $4e, "forgets why it", $4e, "started.@"
; 0x1b93c5

RhydonPokedexEntry: ; 0x1b93c5
	db "DRILL@" ; species name
	dw 603, 2650; height, width
	
	db "By lightly spin-", $4e, "ning its drill-", $4e, "like horn, it can@"
	db "easily shatter", $4e, "even a diamond in", $4e, "the rough.@"
; 0x1b942e

ChanseyPokedexEntry: ; 0x1b942e
	db "EGG@" ; species name
	dw 307, 760; height, width
	
	db "People try to", $4e, "catch it for its", $4e, "extremely@"
	db "nutritious eggs,", $4e, "but it rarely can", $4e, "be found.@"
; 0x1b948c

TangelaPokedexEntry: ; 0x1b948c
	db "VINE@" ; species name
	dw 303, 770; height, width
	
	db "During battle, it", $4e, "constantly moves", $4e, "the vines that@"
	db "cover its body in", $4e, "order to annoy its", $4e, "opponent.@"
; 0x1b94f6

KangaskhanPokedexEntry: ; 0x1b94f6
	db "PARENT@" ; species name
	dw 703, 1760; height, width
	
	db "To avoid", $4e, "crushing the", $4e, "baby it carries in@"
	db "its pouch, it", $4e, "always sleeps", $4e, "standing up.@"
; 0x1b9553

HorseaPokedexEntry: ; 0x1b9553
	db "DRAGON@" ; species name
	dw 104, 180; height, width
	
	db "When they're in a", $4e, "safe location,", $4e, "they can be seen@"
	db "playfully tangling", $4e, "their tails", $4e, "together.@"
; 0x1b95b8

SeadraPokedexEntry: ; 0x1b95b8
	db "DRAGON@" ; species name
	dw 311, 550; height, width
	
	db "The male raises", $4e, "the young. If it", $4e, "is approached, it@"
	db "uses its toxic", $4e, "spikes to fend off", $4e, "the intruder.@"
; 0x1b9626

GoldeenPokedexEntry: ; 0x1b9626
	db "GOLDFISH@" ; species name
	dw 200, 330; height, width
	
	db "During spawning", $4e, "season, they swim", $4e, "gracefully in the@"
	db "water, searching", $4e, "for their perfect", $4e, "mate.@"
; 0x1b9690

SeakingPokedexEntry: ; 0x1b9690
	db "GOLDFISH@" ; species name
	dw 403, 860; height, width
	
	db "When autumn comes,", $4e, "the males patrol", $4e, "the area around@"
	db "their nests in", $4e, "order to protect", $4e, "their offspring.@"
; 0x1b9702

StaryuPokedexEntry: ; 0x1b9702
	db "STARSHAPE@" ; species name
	dw 207, 760; height, width
	
	db "When the stars", $4e, "twinkle at night,", $4e, "it floats up from@"
	db "the sea floor, and", $4e, "its body's center", $4e, "core flickers.@"
; 0x1b9776

StarmiePokedexEntry: ; 0x1b9776
	db "MYSTERIOUS@" ; species name
	dw 307, 1760; height, width
	
	db "It is said that it", $4e, "uses the seven-", $4e, "colored core of@"
	db "its body to send", $4e, "electric waves", $4e, "into outer space.@"
; 0x1b97ea

MrMimePokedexEntry: ; 0x1b97ea
	db "BARRIER@" ; species name
	dw 403, 1200; height, width
	
	db "It uses the", $4e, "mysterious", $4e, "power it has in@"
	db "its fingers to", $4e, "solidify air into", $4e, "an invisible wall.@"
; 0x1b9851

ScytherPokedexEntry: ; 0x1b9851
	db "MANTIS@" ; species name
	dw 411, 1230; height, width
	
	db "It's very proud of", $4e, "its speed. It", $4e, "moves so fast that@"
	db "its opponent does", $4e, "not even know what", $4e, "knocked it down.@"
; 0x1b98c5

JynxPokedexEntry: ; 0x1b98c5
	db "HUMANSHAPE@" ; species name
	dw 407, 900; height, width
	
	db "It has several", $4e, "different cry pat-", $4e, "terns, each of@"
	db "which seems to", $4e, "have its own", $4e, "meaning.@"
; 0x1b992a

ElectabuzzPokedexEntry: ; 0x1b992a
	db "ELECTRIC@" ; species name
	dw 307, 660; height, width
	
	db "When two", $4e, "ELECTABUZZ touch,", $4e, "they control the@"
	db "electric currents", $4e, "to communicate", $4e, "their feelings.@"
; 0x1b9994

MagmarPokedexEntry: ; 0x1b9994
	db "SPITFIRE@" ; species name
	dw 403, 980; height, width
	
	db "It moves more", $4e, "frequently in hot", $4e, "areas. It can heal@"
	db "itself by dipping", $4e, "its wound into", $4e, "lava.@"
; 0x1b99fb

PinsirPokedexEntry: ; 0x1b99fb
	db "STAGBEETLE@" ; species name
	dw 411, 1210; height, width
	
	db "When the tempera-", $4e, "ture drops at", $4e, "night, it sleeps@"
	db "on treetops or", $4e, "among roots where", $4e, "it is well hidden.@"
; 0x1b9a6f

TaurosPokedexEntry: ; 0x1b9a6f
	db "WILD BULL@" ; species name
	dw 407, 1950; height, width
	
	db "These violent", $4e, "#MON fight", $4e, "with other mem-@"
	db "bers of their herd", $4e, "in order to prove", $4e, "their strength.@"
; 0x1b9adb

INCBIN "baserom.gbc",$1b9adb,$2525

SECTION "bank6F",DATA,BANK[$6F]

INCBIN "baserom.gbc",$1BC000,$4000

SECTION "bank70",DATA,BANK[$70]

UnknownText_0x1c0000: ; 1c0000
	db $0, "Oh, no picture?", $4f
	db "Come again, OK?", $57
; 1c0021

UnknownText_0x1c0021: ; 1c0021
	db $0, "An EGG? My talent", $4f
	db "is worth more…", $57
; 1c0043

UnknownText_0x1c0043: ; 1c0043
	db $0, "Hello, hello! I'm", $4f
	db "the NAME RATER.", $51
	db "I rate the names", $4f
	db "of #MON.", $51
	db "Would you like me", $4f
	db "to rate names?", $57
; 1c00a0

UnknownText_0x1c00a0: ; 1c00a0
	db $0, "Which #MON's", $4f
	db "nickname should I", $55
	db "rate for you?", $58
; 1c00cd

UnknownText_0x1c00cd: ; 1c00cd
	db $0, "Hm… @"
	text_from_ram $d073
	db $0, "…", $4f
	db "That's a fairly", $55
	db "decent name.", $51
	db "But, how about a", $4f
	db "slightly better", $55
	db "nickname?", $51
	db "Want me to give it", $4f
	db "a better name?", $57
; 1c0142

UnknownText_0x1c0142: ; 1c0142
	db $0, "All right. What", $4f
	db "name should we", $55
	db "give it, then?", $58
; 1c0171

UnknownText_0x1c0171: ; 1c0171
	db $0, "That's a better", $4f
	db "name than before!", $51
	db "Well done!", $57
; 1c019e

UnknownText_0x1c019e: ; 1c019e
	db $0, "OK, then. Come", $4f
	db "again sometime.", $57
; 1c01be

UnknownText_0x1c01be: ; 1c01be
	db $0, "Hm… @"
	text_from_ram $d073
	db $0, "?", $4f
	db "What a great name!", $55
	db "It's perfect.", $51
	db "Treat @"
	text_from_ram $d073
	db $0, $4f
	db "with loving care.", $57
; 1c0208

UnknownText_0x1c0208: ; 1c0208
	db $0, "Whoa… That's just", $4f
	db "an EGG.", $57
; 1c0222

UnknownText_0x1c0222: ; 1c0222
	db $0, "It might look the", $4f
	db "same as before,", $51
	db "but this new name", $4f
	db "is much better!", $51
	db "Well done!", $57
; 1c0272

UnknownText_0x1c0272: ; 1c0272
	db $0, "All right. This", $4f
	db "#MON is now", $55
	db "named @"
	text_from_ram $d073
	db $0, ".", $58
; 1c029c

UnknownText_0x1c029c: ; 1c029c
	text_from_ram $d073
	db $0, " gained@"
	db "@"
; 1c02a9

UnknownText_0x1c02a9: ; 1c02a9
	db $0, $4f
	db "a boosted", $55
	db "@"
	deciram $d086, $24
	db $0, " EXP. Points!", $58
; 1c02c9

UnknownText_0x1c02c9: ; 1c02c9
	db $0, $4f
	db "@"
	deciram $d086, $24
	db $0, " EXP. Points!", $58
; 1c02df

UnknownText_0x1c02df: ; 1c02df
	db $0, "Go! @"
	db "@"
; 1c02e6

UnknownText_0x1c02e6: ; 1c02e6
	db $0, "Do it! @"
	db "@"
; 1c02f0

UnknownText_0x1c02f0: ; 1c02f0
	db $0, "Go for it,", $4f
	db "@"
	db "@"
; 1c02fe

UnknownText_0x1c02fe: ; 1c02fe
	db $0, "Your foe's weak!", $4f
	db "Get'm, @"
	db "@"
; 1c0317

UnknownText_0x1c0317: ; 1c0317
	text_from_ram $c621
	db $0, "!", $57
; 1c031d

UnknownText_0x1c031d: ; 1c031d
	text_from_ram $c621
	db $0, ",@"
	db "@"
; 1c0324

UnknownText_0x1c0324: ; 1c0324
	db $0, " that's", $4f
	db "enough! Come back!@"
	db "@"
; 1c0340

UnknownText_0x1c0340: ; 1c0340
	db $0, " OK!", $4f
	db "Come back!@"
	db "@"
; 1c0352

UnknownText_0x1c0352: ; 1c0352
	db $0, " good!", $4f
	db "Come back!@"
	db "@"
; 1c0366

UnknownText_0x1c0366: ; 1c0366
	db $0, " come", $4f
	db "back!", $57
; 1c0373

UnknownText_0x1c0373: ; 1c0373
	db $0, "Booted up a TM.", $58
; 1c0384

UnknownText_0x1c0384: ; 1c0384
	db $0, "Booted up an HM.", $58
; 1c0396

UnknownText_0x1c0396: ; 1c0396
	db $0, "It contained", $4f
	db "@"
	text_from_ram $d086
	db $0, ".", $51
	db "Teach @"
	text_from_ram $d086
	db $0, $4f
	db "to a #MON?", $57
; 1c03c2

UnknownText_0x1c03c2: ; 1c03c2
	text_from_ram $d086
	db $0, " is", $4f
	db "not compatible", $55
	db "with @"
	text_from_ram $d073
	db $0, ".", $51
	db "It can't learn", $4f
	db "@"
	text_from_ram $d086
	db $0, ".", $58
; 1c03fa

UnknownText_0x1c03fa: ; 1c03fa
	db $0, "You have no room", $4f
	db "for any more", $55
	db "@"
	text_from_ram $d073
	db $0, "S.", $58
; 1c0421

UnknownText_0x1c0421: ; 1c0421
	db $0, "You received", $4f
	db "@"
	text_from_ram $d073
	db $0, "!", $58
; 1c0436

UnknownText_0x1c0436: ; 1c0436
	db $0, "The link has been", $4f
	db "cancelled.", $58
; 1c0454

UnknownText_0x1c0454: ; 1c0454
	db $0, "Communication", $4f
	db "error.", $58
; 1c046a

UnknownText_0x1c046a: ; 1c046a
	db $0, "Must retrieve GIFT", $4f
	db "at #MON CENTER.", $58
; 1c048e

UnknownText_0x1c048e: ; 1c048e
	db $0, "Your friend isn't", $4f
	db "ready.", $58
; 1c04a7

UnknownText_0x1c04a7: ; 1c04a7
	db $0, "Sorry--only five", $4f
	db "GIFTS a day.", $58
; 1c04c6

UnknownText_0x1c04c6: ; 1c04c6
	db $0, "Sorry. One GIFT", $4f
	db "a day per person.", $58
; 1c04e9

UnknownText_0x1c04e9: ; 1c04e9
	text_from_ram $c903
	db $0, " sent", $4f
	db "@"
	text_from_ram $d073
	db $0, ".", $58
; 1c04fa

UnknownText_0x1c04fa: ; 1c04fa
	text_from_ram $c903
	db $0, " sent", $4f
	db "@"
	text_from_ram $d073
	db $0, $55
	db "to @"
	text_from_ram $c953
	db $0, "'s home.", $58
; 1c051a

UnknownText_0x1c051a: ; 1c051a
	db $0, "Received", $4f
	db "@"
	text_from_ram $c850
	db $0, "'s CARD.", $58
; 1c0531

UnknownText_0x1c0531: ; 1c0531
	text_from_ram $c850
	db $0, "'s CARD was", $4f
	db "listed as no.@"
	deciram $d265, $12
	db $0, ".", $58
; 1c0555

UnknownText_0x1c0555: ; 1c0555
	db $0, "The CARD was not", $4f
	db "registered.", $58
; 1c0573

UnknownText_0x1c0573: ; 1c0573
	db $0, "The link has been", $4f
	db "cancelled.", $58
; 1c0591

UnknownText_0x1c0591: ; 1c0591
	db $0, "Communication", $4f
	db "error.", $58
; 1c05a7

_BadgeRequiredText: ; 1c05a7
	db $0, "Sorry! A new BADGE", $4f
	db "is required.", $58
; 1c05c8

UnknownText_0x1c05c8: ; 1c05c8
	db $0, "Can't use that", $4f
	db "here.", $58
; 1c05dd

UnknownText_0x1c05dd: ; 1c05dd
	text_from_ram $d086
	db $0, " used", $4f
	db "CUT!", $58
; 1c05ec

UnknownText_0x1c05ec: ; 1c05ec
	db $0, "There's nothing to", $4f
	db "CUT here.", $58
; 1c0609

UnknownText_0x1c0609: ; 1c0609
	db $0, "A blinding FLASH", $4f
	db "lights the area!@"
	text_waitbutton
	db "@"
; 1c062e

UnknownText_0x1c062e: ; 1c062e
	db "@"
; 1c062f

_UsedSurfText: ; 1c062f
	text_from_ram $d086
	db $0, " used", $4f
	db "SURF!", $57
; 1c063f

_CantSurfText: ; 1c063f
	db $0, "You can't SURF", $4f
	db "here.", $58
; 1c0654

_AlreadySurfingText: ; 1c0654
	db $0, "You're already", $4f
	db "SURFING.", $58
; 1c066c

_AskSurfText: ; 1c066c
	db $0, "The water is calm.", $4f
	db "Want to SURF?", $57
; 1c068e

UnknownText_0x1c068e: ; 1c068e
	text_from_ram $d086
	db $0, " used", $4f
	db "WATERFALL!", $57
; 1c06a3

UnknownText_0x1c06a3: ; 1c06a3
	db $0, "Wow, it's a huge", $4f
	db "waterfall.", $57
; 1c06bf

UnknownText_0x1c06bf: ; 1c06bf
	db $0, "Do you want to use", $4f
	db "WATERFALL?", $57
; 1c06de

UnknownText_0x1c06de: ; 1c06de
	text_from_ram $d086
	db $0, " used", $4f
	db "DIG!", $57
; 1c06ed

UnknownText_0x1c06ed: ; 1c06ed
	db $0, $52, " used an", $4f
	db "ESCAPE ROPE.", $57
; 1c0705

UnknownText_0x1c0705: ; 1c0705
	db $0, "Can't use that", $4f
	db "here.", $57
; 1c071a

UnknownText_0x1c071a: ; 1c071a
	db $0, "Return to the last", $4f
	db "#MON CENTER.", $57
; 1c073b

UnknownText_0x1c073b: ; 1c073b
	db $0, "Can't use that", $4f
	db "here.", $51
	db $57
; 1c0751

UnknownText_0x1c0751: ; 1c0751
	db $0, "A #MON is using", $4f
	db "STRENGTH already.", $58
; 1c0774

UnknownText_0x1c0774: ; 1c0774
	text_from_ram $d086
	db $0, " used", $4f
	db "STRENGTH!", $57
; 1c0788

UnknownText_0x1c0788: ; 1c0788
	text_from_ram $d073
	db $0, " can", $4f
	db "move boulders.", $58
; 1c07a0

UnknownText_0x1c07a0: ; 1c07a0
	db $0, "A #MON may be", $4f
	db "able to move this.", $51
	db "Want to use", $4f
	db "STRENGTH?", $57
; 1c07d8

UnknownText_0x1c07d8: ; 1c07d8
	db $0, "Boulders may now", $4f
	db "be moved!", $57
; 1c07f4

UnknownText_0x1c07f4: ; 1c07f4
	db $0, "A #MON may be", $4f
	db "able to move this.", $57
; 1c0816

UnknownText_0x1c0816: ; 1c0816
	text_from_ram $d086
	db $0, " used", $4f
	db "WHIRLPOOL!", $58
; 1c082b

UnknownText_0x1c082b: ; 1c082b
	db $0, "It's a vicious", $4f
	db "whirlpool!", $51
	db "A #MON may be", $4f
	db "able to pass it.", $57
; 1c0864

UnknownText_0x1c0864: ; 1c0864
	db $0, "A whirlpool is in", $4f
	db "the way.", $51
	db "Want to use", $4f
	db "WHIRLPOOL?", $57
; 1c0897

UnknownText_0x1c0897: ; 1c0897
	text_from_ram $d086
	db $0, " did a", $4f
	db "HEADBUTT!", $58
; 1c08ac

UnknownText_0x1c08ac: ; 1c08ac
	db $0, "Nope. Nothing…", $57
; 1c08bc

UnknownText_0x1c08bc: ; 1c08bc
	db $0, "A #MON could be", $4f
	db "in this tree.", $51
	db "Want to HEADBUTT", $4f
	db "it?", $57
; 1c08f0

UnknownText_0x1c08f0: ; 1c08f0
	text_from_ram $d086
	db $0, " used", $4f
	db "ROCK SMASH!", $58
; 1c0906

UnknownText_0x1c0906: ; 1c0906
	db $0, "Maybe a #MON", $4f
	db "can break this.", $57
; 1c0924

UnknownText_0x1c0924: ; 1c0924
	db $0, "This rock looks", $4f
	db "breakable.", $51
	db "Want to use ROCK", $4f
	db "SMASH?", $57
; 1c0958

UnknownText_0x1c0958: ; 1c0958
	db $0, "Oh!", $4f
	db "A bite!", $58
; 1c0965

UnknownText_0x1c0965: ; 1c0965
	db $0, "Not even a nibble!", $58
; 1c0979

UnknownText_0x1c0979: ; 1c0979
	db $0, "Looks like there's", $4f
	db "nothing here.", $58
; 1c099a

UnknownText_0x1c099a: ; 1c099a
	db $0, "You can't get off", $4f
	db "here!", $57
; 1c09b2

UnknownText_0x1c09b2: ; 1c09b2
	db $0, $52, " got on the", $4f
	db "@"
	text_from_ram $d086
	db $0, ".", $57
; 1c09c7

UnknownText_0x1c09c7: ; 1c09c7
	db $0, $52, " got off", $4f
	db "the @"
	text_from_ram $d086
	db $0, ".", $57
; 1c09dd

UnknownText_0x1c09dd: ; 1c09dd
	db $0, "This tree can be", $4f
	db "CUT!", $51
	db "Want to use CUT?", $57
; 1c0a05

UnknownText_0x1c0a05: ; 1c0a05
	db $0, "This tree can be", $4f
	db "CUT!", $57
; 1c0a1c

UnknownText_0x1c0a1c: ; 1c0a1c
	db $0, $52, " found", $4f
	db "@"
	text_from_ram $d099
	db $0, "!", $57
; 1c0a2c

UnknownText_0x1c0a2c: ; 1c0a2c
	db $0, "But ", $52, " can't", $4f
	db "carry any more", $55
	db "items.", $57
; 1c0a4e

UnknownText_0x1c0a4e: ; 1c0a4e
	db $0, $52, " is out of", $4f
	db "useable #MON!", $51
	db $52, " whited", $4f
	db "out!", $57
; 1c0a77

UnknownText_0x1c0a77: ; 1c0a77
	db $0, "Yes! ITEMFINDER", $4f
	db "indicates there's", $55
	db "an item nearby.", $58
; 1c0aa9

UnknownText_0x1c0aa9: ; 1c0aa9
	db $0, "Nope! ITEMFINDER", $4f
	db "isn't responding.", $58
; 1c0acc

UnknownText_0x1c0acc: ; 1c0acc
	text_from_ram $d099
	db $0, $4f
	db "fainted!", $58
; 1c0ada

UnknownText_0x1c0ada: ; 1c0ada
	db $0, $52, " is out of", $4f
	db "useable #MON!", $51
	db $52, " whited", $4f
	db "out!", $58
; 1c0b03

UnknownText_0x1c0b03: ; 1c0b03
	text_from_ram $d099
	db $0, " used", $4f
	db "SWEET SCENT!", $57
; 1c0b1a

UnknownText_0x1c0b1a: ; 1c0b1a
	db $0, "Looks like there's", $4f
	db "nothing here…", $57
; 1c0b3b

UnknownText_0x1c0b3b: ; 1c0b3b
	db $0, $52, " sprinkled", $4f
	db "water.", $51
	db "But nothing", $4f
	db "happened…", $57
; 1c0b65

UnknownText_0x1c0b65: ; 1c0b65
	db $0, $52, "'s #MON", $4f
	db "were all healed!", $57
; 1c0b7f

UnknownText_0x1c0b7f: ; 1c0b7f
	db $0, "An EGG can't hold", $4f
	db "an item.", $58
; 1c0b9a

UnknownText_0x1c0b9a: ; 1c0b9a
	db $0, "No items.", $57
; 1c0ba5

UnknownText_0x1c0ba5: ; 1c0ba5
	db $0, "Throw away how", $4f
	db "many?", $57
; 1c0bbb

UnknownText_0x1c0bbb: ; 1c0bbb
	db $0, "Throw away @"
	deciram $d10c, $12
	db $0, $4f
	db "@"
	text_from_ram $d086
	db $0, "(S)?", $57
; 1c0bd8

UnknownText_0x1c0bd8: ; 1c0bd8
	db $0, "Threw away", $4f
	db "@"
	text_from_ram $d086
	db $0, "(S).", $58
; 1c0bee

UnknownText_0x1c0bee: ; 1c0bee
	db $0, "OAK: ", $52, "!", $4f
	db "This isn't the", $55
	db "time to use that!", $58
; 1c0c17

UnknownText_0x1c0c17: ; 1c0c17
	db $0, "You don't have a", $4f
	db "#MON!", $58
; 1c0c2e

UnknownText_0x1c0c2e: ; 1c0c2e
	db $0, "Registered the", $4f
	db "@"
	text_from_ram $d086
	db $0, ".", $58
; 1c0c45

UnknownText_0x1c0c45: ; 1c0c45
	db $0, "You can't register", $4f
	db "that item.", $58
; 1c0c63

UnknownText_0x1c0c63: ; 1c0c63
	db $0, "Where should this", $4f
	db "be moved to?", $57
; 1c0c83

UnknownText_0x1c0c83: ; 1c0c83
	db $0, $57
; 1c0c85

UnknownText_0x1c0c85: ; 1c0c85
	db $0, "You can't use it", $4f
	db "in a battle.", $58
; 1c0ca3

UnknownText_0x1c0ca3: ; 1c0ca3
	db $0, "Are you a boy?", $4f
	db "Or are you a girl?", $57
; 1c0cc6

UnknownText_0x1c0cc6: ; 1c0cc6
	db $0, $5a, "'s", $4f
	db "@"
	text_from_ram $d086
	db "@"
; 1c0ccf

UnknownText_0x1c0ccf: ; 1c0ccf
	db "@"
; 1c0cd0

UnknownText_0x1c0cd0: ; 1c0cd0
	interpret_data
	db $0, $4c, "went way up!", $58
; 1c0ce0

UnknownText_0x1c0ce0: ; 1c0ce0
	db $0, " went up!", $58
; 1c0ceb

UnknownText_0x1c0ceb: ; 1c0ceb
	db $0, $59, "'s", $4f
	db "@"
	text_from_ram $d086
	db "@"
; 1c0cf4

UnknownText_0x1c0cf4: ; 1c0cf4
	db "@"
; 1c0cf5

UnknownText_0x1c0cf5: ; 1c0cf5
	interpret_data
	db $0, $4c, "sharply fell!", $58
; 1c0d06

UnknownText_0x1c0d06: ; 1c0d06
	db $0, " fell!", $58
; 1c0d0e

UnknownText_0x1c0d0e: ; 1c0d0e
	db $0, $5a, "@"
	db "@"
; 1c0d12

UnknownText_0x1c0d12: ; 1c0d12
	db $0, $4f
	db "made a whirlwind!", $58
; 1c0d26

UnknownText_0x1c0d26: ; 1c0d26
	db $0, $4f
	db "took in sunlight!", $58
; 1c0d3a

UnknownText_0x1c0d3a: ; 1c0d3a
	db $0, $4f
	db "lowered its head!", $58
; 1c0d4e

UnknownText_0x1c0d4e: ; 1c0d4e
	db $0, $4f
	db "is glowing!", $58
; 1c0d5c

UnknownText_0x1c0d5c: ; 1c0d5c
	db $0, $4f
	db "flew up high!", $58
; 1c0d6c

UnknownText_0x1c0d6c: ; 1c0d6c
	db $0, $4f
	db "dug a hole!", $58
; 1c0d7a

_ActorNameText: ; 1c0d7a
	db $0, $5a, "@"
	db "@"
; 1c0d7e

_UsedMove1Text: ; 1c0d7e
	db $0, $4f
	db "used @"
	db "@"
; 1c0d87

_UsedMove2Text: ; 1c0d87
	db $0, $4f
	db "used @"
	db "@"
; 1c0d90

_UsedInsteadText: ; 1c0d90
	db $0, "instead,", $55
	db "@"
	db "@"
; 1c0d9c

_MoveNameText: ; 1c0d9c
	text_from_ram StringBuffer2
	db "@"
; 1c0da0

UnknownText_0x1c0da0: ; 1c0da0
	db "@"
; 1c0da1

_EndUsedMove1Text: ; 1c0da1
	db $0, "!", $57
; 1c0da4

_EndUsedMove2Text: ; 1c0da4
	db $0, "!", $57
; 1c0da7

_EndUsedMove3Text: ; 1c0da7
	db $0, "!", $57
; 1c0daa

_EndUsedMove4Text: ; 1c0daa
	db $0, "!", $57
; 1c0dad

_EndUsedMove5Text: ; 1c0dad
	db $0, "!", $57
; 1c0db0

UnknownText_0x1c0db0: ; 1c0db0
	db $0, "Huh?", $51
	db "@"
	db "@"
; 1c0db8

UnknownText_0x1c0db8: ; 1c0db8
	db $0, $57
; 1c0dba

UnknownText_0x1c0dba: ; 1c0dba
	text_from_ram StringBuffer1
	db $0, " came", $4f
	db "out of its EGG!@"
	sound0x02
	text_waitbutton
	db "@"
; 1c0dd7

UnknownText_0x1c0dd7: ; 1c0dd7
	db "@"
; 1c0dd8

UnknownText_0x1c0dd8: ; 1c0dd8
	db $0, "Give a nickname to", $4f
	db "@"
	text_from_ram StringBuffer1
	db $0, "?", $57
; 1c0df3

UnknownText_0x1c0df3: ; 1c0df3
	db $0, "It's @"
	text_from_ram $df2f
	db $0, $4f
	db "that was left with", $55
	db "the DAY-CARE LADY.", $57
; 1c0e24

UnknownText_0x1c0e24: ; 1c0e24
	db $0, "It's @"
	text_from_ram $def6
	db $0, $4f
	db "that was left with", $55
	db "the DAY-CARE MAN.", $57
; 1c0e54

UnknownText_0x1c0e54: ; 1c0e54
	db $0, "It's brimming with", $4f
	db "energy.", $58
; 1c0e6f

UnknownText_0x1c0e6f: ; 1c0e6f
	db $0, "It has no interest", $4f
	db "in @"
	text_from_ram $d073
	db $0, ".", $58
; 1c0e8d

UnknownText_0x1c0e8d: ; 1c0e8d
	db $0, "It appears to care", $4f
	db "for @"
	text_from_ram $d073
	db $0, ".", $58
; 1c0eac

UnknownText_0x1c0eac: ; 1c0eac
	db $0, "It's friendly with", $4f
	db "@"
	text_from_ram $d073
	db $0, ".", $58
; 1c0ec6

UnknownText_0x1c0ec6: ; 1c0ec6
	db $0, "It shows interest", $4f
	db "in @"
	text_from_ram $d073
	db $0, ".", $58
; 1c0ee3

UnknownText_0x1c0ee3: ; 1c0ee3
	db $0, "There's no MAIL", $4f
	db "here.", $58
; 1c0ef9

UnknownText_0x1c0ef9: ; 1c0ef9
	db $0, "The cleared MAIL", $4f
	db "was put away.", $58
; 1c0f19

UnknownText_0x1c0f19: ; 1c0f19
	db $0, "The PACK is full.", $58
; 1c0f2c

UnknownText_0x1c0f2c: ; 1c0f2c
	db $0, "The MAIL's message", $4f
	db "will be lost. OK?", $57
; 1c0f51

UnknownText_0x1c0f51: ; 1c0f51
	db $0, "It's already hold-", $4f
	db "ing an item.", $58
; 1c0f71

UnknownText_0x1c0f71: ; 1c0f71
	db $0, "An EGG can't hold", $4f
	db "any MAIL.", $58
; 1c0f8d

UnknownText_0x1c0f8d: ; 1c0f8d
	db $0, "The MAIL was moved", $4f
	db "from the MAILBOX.", $58
; 1c0fb3

UnknownText_0x1c0fb3: ; 1c0fb3
	db $0, "Yes", $58
; 1c0fb8

UnknownText_0x1c0fb8: ; 1c0fb8
	db $0, "No", $58
; 1c0fbc

UnknownText_0x1c0fbc: ; 1c0fbc
	deciram $cf64, $13
	db $0, " @"
	text_from_ram $d073
	db $0, $4f
	db "Animation type @"
	text_from_ram $d086
	db "@"
; 1c0fdc

UnknownText_0x1c0fdc: ; 1c0fdc
	db "@"
; 1c0fdd

UnknownText_0x1c0fdd: ; 1c0fdd
	db $0, "#MON number?", $57
; 1c0feb

UnknownText_0x1c0feb: ; 1c0feb
	text_from_ram $d073
	db $0, " was", $4f
	db "sent to BILL's PC.", $58
; 1c1006

UnknownText_0x1c1006: ; 1c1006
	db $0, "You gotta have", $4f
	db "#MON to call!", $58
; 1c1024

UnknownText_0x1c1024: ; 1c1024
	db $0, "What?", $57
; 1c102b

UnknownText_0x1c102b: ; 1c102b
	db $0, "There is a #MON", $4f
	db "holding MAIL.", $51
	db "Please remove the", $4f
	db "MAIL.", $58
; 1c1062

UnknownText_0x1c1062: ; 1c1062
	db $0, "You don't have a", $4f
	db "single #MON!", $58
; 1c1080

UnknownText_0x1c1080: ; 1c1080
	db $0, "You can't deposit", $4f
	db "your last #MON!", $58
; 1c10a2

UnknownText_0x1c10a2: ; 1c10a2
	db $0, "You can't take any", $4f
	db "more #MON.", $58
; 1c10c0

UnknownText_0x1c10c0: ; 1c10c0
	db $0, "Caught @"
	text_from_ram $d073
	db $0, "!", $58
; 1c10cf

UnknownText_0x1c10cf: ; 1c10cf
	db $0, "Switch #MON?", $57
; 1c10dd

UnknownText_0x1c10dd: ; 1c10dd
	db $0, "You already caught", $4f
	db "a @"
	text_from_ram $d073
	db $0, ".", $58
; 1c10fa

UnknownText_0x1c10fa: ; 1c10fa
	db $0, "This Bug-Catching", $4f
	db "Contest winner is@"
	interpret_data
	db $0, "…", $51
	db "@"
	text_from_ram $d016
	db $0, ",", $4f
	db "who caught a", $55
	db "@"
	text_from_ram $d073
	db $0, "!@"
	db "@"
; 1c113f

UnknownText_0x1c113f: ; 1c113f
	db $0, $51
	db "The winning score", $4f
	db "was @"
	deciram $d004, $23
	db $0, " points!", $58
; 1c1166

UnknownText_0x1c1166: ; 1c1166
	db $0, "Placing second was", $4f
	db "@"
	text_from_ram $d016
	db $0, ",", $51
	db "who caught a", $4f
	db "@"
	text_from_ram $d073
	db $0, "!@"
	db "@"
; 1c1196

UnknownText_0x1c1196: ; 1c1196
	db $0, $51
	db "The score was", $4f
	db "@"
	deciram $d008, $23
	db $0, " points!", $58
; 1c11b5

UnknownText_0x1c11b5: ; 1c11b5
	db $0, "Placing third was", $4f
	db "@"
	text_from_ram $d016
	db $0, ",", $51
	db "who caught a", $4f
	db "@"
	text_from_ram $d073
	db $0, "!@"
	db "@"
; 1c11e4

UnknownText_0x1c11e4: ; 1c11e4
	db $0, $51
	db "The score was", $4f
	db "@"
	deciram $d00c, $23
	db $0, " points!", $58
; 1c1203

UnknownText_0x1c1203: ; 1c1203
	db $0, "Let me measure", $4f
	db "that MAGIKARP.", $51
	db "…Hm, it measures", $4f
	db "@"
	text_from_ram $d073
	db $0, ".", $58
; 1c123a

UnknownText_0x1c123a: ; 1c123a
	db $0, "CURRENT RECORD", $51
	db "@"
	text_from_ram $d073
	db $0, " caught by", $4f
	db "@"
	text_from_ram $dfea
	text_waitbutton
	db "@"
; 1c1260

UnknownText_0x1c1260: ; 1c1260
	db "@"
; 1c1261

UnknownText_0x1c1261: ; 1c1261
	db $0, "Congratulations!", $51
	db "We have a match", $4f
	db "with the ID number", $51
	db "of @"
	text_from_ram $d073
	db $0, " in", $4f
	db "your party.", $58
; 1c12ae

UnknownText_0x1c12ae: ; 1c12ae
	db $0, "Congratulations!", $51
	db "We have a match", $4f
	db "with the ID number", $51
	db "of @"
	text_from_ram $d073
	db $0, " in", $4f
	db "your PC BOX.", $58
; 1c12fc

UnknownText_0x1c12fc: ; 1c12fc
	db $0, "Give a nickname to", $4f
	db "the @"
	text_from_ram $d073
	db $0, " you", $55
	db "received?", $57
; 1c1328

UnknownText_0x1c1328: ; 1c1328
	db $0, "Bzzzzt! You must", $4f
	db "have a #MON to", $55
	db "use this!", $58
; 1c1353

UnknownText_0x1c1353: ; 1c1353
	db $0, $52, " turned on", $4f
	db "the PC.", $58
; 1c1368

UnknownText_0x1c1368: ; 1c1368
	db $0, "What do you want", $4f
	db "to do?", $57
; 1c1381

UnknownText_0x1c1381: ; 1c1381
	db $0, "How many do you", $4f
	db "want to withdraw?", $57
; 1c13a4

UnknownText_0x1c13a4: ; 1c13a4
	db $0, "Withdrew @"
	deciram $d10c, $12
	db $0, $4f
	db "@"
	text_from_ram $d086
	db $0, "(S).", $58
; 1c13bf

UnknownText_0x1c13bf: ; 1c13bf
	db $0, "There's no room", $4f
	db "for more items.", $58
; 1c13df

UnknownText_0x1c13df: ; 1c13df
	db $0, "No items here!", $58
; 1c13ef

UnknownText_0x1c13ef: ; 1c13ef
	db $0, "How many do you", $4f
	db "want to deposit?", $57
; 1c1411

UnknownText_0x1c1411: ; 1c1411
	db $0, "Deposited @"
	deciram $d10c, $12
	db $0, $4f
	db "@"
	text_from_ram $d086
	db $0, "(S).", $58
; 1c142d

UnknownText_0x1c142d: ; 1c142d
	db $0, "There's no room to", $4f
	db "store items.", $58
; 1c144d

UnknownText_0x1c144d: ; 1c144d
	db $0, $52, " turned on", $4f
	db "the PC.", $58
; 1c1462

UnknownText_0x1c1462: ; 1c1462
	db $0, "Access whose PC?", $57
; 1c1474

UnknownText_0x1c1474: ; 1c1474
	db $0, "BILL's PC", $4f
	db "accessed.", $51
	db "#MON Storage", $4f
	db "System opened.", $58
; 1c14a4

UnknownText_0x1c14a4: ; 1c14a4
	db $0, "Accessed own PC.", $51
	db "Item Storage", $4f
	db "System opened.", $58
; 1c14d2

UnknownText_0x1c14d2: ; 1c14d2
	db $0, "PROF.OAK's PC", $4f
	db "accessed.", $51
	db "#DEX Rating", $4f
	db "System opened.", $58
; 1c1505

UnknownText_0x1c1505: ; 1c1505
	db $0, "…", $4f
	db "Link closed…", $57
; 1c1515

UnknownText_0x1c1515: ; 1c1515
	db $0, "Want to get your", $4f
	db "#DEX rated?", $57
; 1c1533

UnknownText_0x1c1533: ; 1c1533
	db $0, "Current #DEX", $4f
	db "completion level:", $58
; 1c1553

UnknownText_0x1c1553: ; 1c1553
	text_from_ram $d099
	db $0, " #MON seen", $4f
	db "@"
	text_from_ram $d0ac
	db $0, " #MON owned", $51
	db "PROF.OAK's", $4f
	db "Rating:", $57
; 1c1585

UnknownText_0x1c1585: ; 1c1585
	db $0, "Look for #MON", $4f
	db "in grassy areas!", $57
; 1c15a5

UnknownText_0x1c15a5: ; 1c15a5
	db $0, "Good. I see you", $4f
	db "understand how to", $55
	db "use # BALLS.", $57
; 1c15d5

UnknownText_0x1c15d5: ; 1c15d5
	db $0, "You're getting", $4f
	db "good at this.", $51
	db "But you have a", $4f
	db "long way to go.", $57
; 1c1611

UnknownText_0x1c1611: ; 1c1611
	db $0, "You need to fill", $4f
	db "up the #DEX.", $51
	db "Catch different", $4f
	db "kinds of #MON!", $57
; 1c164f

UnknownText_0x1c164f: ; 1c164f
	db $0, "You're trying--I", $4f
	db "can see that.", $51
	db "Your #DEX is", $4f
	db "coming together.", $57
; 1c168c

UnknownText_0x1c168c: ; 1c168c
	db $0, "To evolve, some", $4f
	db "#MON grow,", $51
	db "others use the", $4f
	db "effects of STONES.", $57
; 1c16ca

UnknownText_0x1c16ca: ; 1c16ca
	db $0, "Have you gotten a", $4f
	db "fishing ROD? You", $51
	db "can catch #MON", $4f
	db "by fishing.", $57
; 1c1709

UnknownText_0x1c1709: ; 1c1709
	db $0, "Excellent! You", $4f
	db "seem to like col-", $55
	db "lecting things!", $57
; 1c173b

UnknownText_0x1c173b: ; 1c173b
	db $0, "Some #MON only", $4f
	db "appear during", $51
	db "certain times of", $4f
	db "the day.", $57
; 1c1773

UnknownText_0x1c1773: ; 1c1773
	db $0, "Your #DEX is", $4f
	db "filling up. Keep", $55
	db "up the good work!", $57
; 1c17a4

UnknownText_0x1c17a4: ; 1c17a4
	db $0, "I'm impressed.", $4f
	db "You're evolving", $51
	db "#MON, not just", $4f
	db "catching them.", $57
; 1c17e0

UnknownText_0x1c17e0: ; 1c17e0
	db $0, "Have you met KURT?", $4f
	db "His custom BALLS", $55
	db "should help.", $57
; 1c1812

UnknownText_0x1c1812: ; 1c1812
	db $0, "Wow. You've found", $4f
	db "more #MON than", $51
	db "the last #DEX", $4f
	db "research project.", $57
; 1c1853

UnknownText_0x1c1853: ; 1c1853
	db $0, "Are you trading", $4f
	db "your #MON?", $51
	db "It's tough to do", $4f
	db "this alone!", $57
; 1c188b

UnknownText_0x1c188b: ; 1c188b
	db $0, "Wow! You've hit", $4f
	db "200! Your #DEX", $55
	db "is looking great!", $57
; 1c18bc

UnknownText_0x1c18bc: ; 1c18bc
	db $0, "You've found so", $4f
	db "many #MON!", $51
	db "You've really", $4f
	db "helped my studies!", $57
; 1c18f7

UnknownText_0x1c18f7: ; 1c18f7
	db $0, "Magnificent! You", $4f
	db "could become a", $51
	db "#MON professor", $4f
	db "right now!", $57
; 1c1932

UnknownText_0x1c1932: ; 1c1932
	db $0, "Your #DEX is", $4f
	db "amazing! You're", $51
	db "ready to turn", $4f
	db "professional!", $57
; 1c196b

UnknownText_0x1c196b: ; 1c196b
	db $0, "Whoa! A perfect", $4f
	db "#DEX! I've", $51
	db "dreamt about this!", $4f
	db "Congratulations!", $57
; 1c19aa

UnknownText_0x1c19aa: ; 1c19aa
	db $0, "The link to PROF.", $4f
	db "OAK's PC closed.", $57
; 1c19cd

UnknownText_0x1c19cd: ; 1c19cd
	db $0, "Triple-theme", $4f
	db "trainer ranking!", $51
	db "The SAVE file you", $4f
	db "just sent might", $55
	db "make the rankings!", $51
	db $57
; 1c1a22

UnknownText_0x1c1a22: ; 1c1a22
	db $0, "There is no", $4f
	db "ranking data.", $51
	db "Link to obtain", $4f
	db "ranking data.", $51
	db $57
; 1c1a5b

UnknownText_0x1c1a5b: ; 1c1a5b
	db $0, " , yeah!", $57
; 1c1a65

UnknownText_0x1c1a65: ; 1c1a65
	db $0, "Darn…", $57
; 1c1a6c

UnknownText_0x1c1a6c: ; 1c1a6c
	db $0, "Would you like to", $4f
	db "end the Contest?", $57
; 1c1a90

UnknownText_0x1c1a90: ; 1c1a90
	db $0, "Toss out how many", $4f
	db "@"
	text_from_ram $d086
	db $0, "(S)?", $57
; 1c1aad

UnknownText_0x1c1aad: ; 1c1aad
	db $0, "Throw away @"
	deciram $d10c, $12
	db $0, $4f
	db "@"
	text_from_ram $d086
	db $0, "(S)?", $57
; 1c1aca

UnknownText_0x1c1aca: ; 1c1aca
	db $0, "Discarded", $4f
	db "@"
	text_from_ram $d073
	db $0, "(S).", $58
; 1c1adf

UnknownText_0x1c1adf: ; 1c1adf
	db $0, "That's too impor-", $4f
	db "tant to toss out!", $58
; 1c1b03

UnknownText_0x1c1b03: ; 1c1b03
	db $0, "OAK: ", $52, "!", $4f
	db "This isn't the", $55
	db "time to use that!", $57
; 1c1b2c

UnknownText_0x1c1b2c: ; 1c1b2c
	db $0, "Took @"
	text_from_ram $d050
	db $0, "'s", $4f
	db "@"
	text_from_ram $d073
	db $0, " and", $51
	db "made it hold", $4f
	db "@"
	text_from_ram $d086
	db $0, ".", $58
; 1c1b57

UnknownText_0x1c1b57: ; 1c1b57
	db $0, "Made @"
	text_from_ram $d050
	db $0, $4f
	db "hold @"
	text_from_ram $d086
	db $0, ".", $58
; 1c1b6f

UnknownText_0x1c1b6f: ; 1c1b6f
	db $0, "Please remove the", $4f
	db "MAIL first.", $58
; 1c1b8e

UnknownText_0x1c1b8e: ; 1c1b8e
	text_from_ram $d050
	db $0, " isn't", $4f
	db "holding anything.", $58
; 1c1baa

UnknownText_0x1c1baa: ; 1c1baa
	db $0, "Item storage space", $4f
	db "full.", $58
; 1c1bc4

UnknownText_0x1c1bc4: ; 1c1bc4
	db $0, "Took @"
	text_from_ram $d073
	db $0, $4f
	db "from @"
	text_from_ram $d050
	db $0, ".", $58
; 1c1bdc

UnknownText_0x1c1bdc: ; 1c1bdc
	text_from_ram $d050
	db $0, " is", $4f
	db "already holding", $51
	db "@"
	text_from_ram $d073
	db $0, ".", $4f
	db "Switch items?", $57
; 1c1c09

UnknownText_0x1c1c09: ; 1c1c09
	db $0, "This item can't be", $4f
	db "held.", $58
; 1c1c22

UnknownText_0x1c1c22: ; 1c1c22
	db $0, "The MAIL will lose", $4f
	db "its message. OK?", $57
; 1c1c47

UnknownText_0x1c1c47: ; 1c1c47
	db $0, "MAIL detached from", $4f
	db "@"
	text_from_ram $d073
	db $0, ".", $58
; 1c1c62

UnknownText_0x1c1c62: ; 1c1c62
	db $0, "There's no space", $4f
	db "for removing MAIL.", $58
; 1c1c86

UnknownText_0x1c1c86: ; 1c1c86
	db $0, "Send the removed", $4f
	db "MAIL to your PC?", $57
; 1c1ca9

UnknownText_0x1c1ca9: ; 1c1ca9
	db $0, "Your PC's MAILBOX", $4f
	db "is full.", $58
; 1c1cc4

UnknownText_0x1c1cc4: ; 1c1cc4
	db $0, "The MAIL was sent", $4f
	db "to your PC.", $58
; 1c1ce3

UnknownText_0x1c1ce3: ; 1c1ce3
	db $0, "Not enough HP!", $58
; 1c1cf3

UnknownText_0x1c1cf3: ; 1c1cf3
	db $0, "An item in your", $4f
	db "PACK may be", $51
	db "registered for use", $4f
	db "on SELECT Button.", $57
; 1c1d35

UnknownText_0x1c1d35: ; 1c1d35
	db $0, "Hello! Sorry to", $4f
	db "keep you waiting!", $51
	db "Welcome to the", $4f
	db "world of #MON!", $51
	db "My name is OAK.", $51
	db "People call me the", $4f
	db "#MON PROF.", $58
; 1c1da4

UnknownText_0x1c1da4: ; 1c1da4
	db $0, "This world is in-", $4f
	db "habited by crea-", $55
	db "tures that we call", $55
	db "#MON.@"
	db "@"
; 1c1de2

UnknownText_0x1c1de2: ; 1c1de2
	text_waitbutton
	db "@"
; 1c1de4

UnknownText_0x1c1de4: ; 1c1de4
	db "@"
; 1c1de5

UnknownText_0x1c1de5: ; 1c1de5
	db $0, "People and #MON", $4f
	db "live together by", $51
	db "supporting each", $4f
	db "other.", $51
	db "Some people play", $4f
	db "with #MON, some", $55
	db "battle with them.", $58
; 1c1e51

UnknownText_0x1c1e51: ; 1c1e51
	db $0, "But we don't know", $4f
	db "everything about", $55
	db "#MON yet.", $51
	db "There are still", $4f
	db "many mysteries to", $55
	db "solve.", $51
	db "That's why I study", $4f
	db "#MON every day.", $58
; 1c1ec9


SECTION "bank71",DATA,BANK[$71]

UnknownText_0x1c4000: ; 0x1c4000
	db $0, "Now, what did you", $4f
	db "say your name was?", $58
; 0x1c4026

UnknownText_0x1c4026: ; 0x1c4026
	db $0, $52, ", are you", $4f
	db "ready?", $51
	db "Your very own", $4f
	db "#MON story is", $55
	db "about to unfold.", $51
	db "You'll face fun", $4f
	db "times and tough", $55
	db "challenges.", $51
	db "A world of dreams", $4f
	db "and adventures", $51
	db "with #MON", $4f
	db "awaits! Let's go!", $51
	db "I'll be seeing you", $4f
	db "later!", $57
; 0x1c40e6

UnknownText_0x1c40e6: ; 0x1c40e6
	db $0, "The clock's time", $4f
	db "may be wrong.", $51
	db "Please reset the", $4f
	db "time.", $58
; 0x1c411c

UnknownText_0x1c411c: ; 0x1c411c
	db $0, "Set with the", $4f
	db "Control Pad.", $51
	db "Confirm: A Button", $4f
	db "Cancel:  B Button", $57
; 0x1c415b

UnknownText_0x1c415b: ; 0x1c415b
	db $0, "Is this OK?", $57
; 0x1c4168

UnknownText_0x1c4168: ; 0x1c4168
	db $0, "The clock has been", $4f
	db "reset.", $57
; 0x1c4183

UnknownText_0x1c4183: ; 0x1c4183
	db $0, "Too much time has", $4f
	db "elapsed. Please", $55
	db "try again.", $58
; 0x1c41b1

UnknownText_0x1c41b1: ; 0x1c41b1
	db $0, "If you trade that", $4f
	db "#MON, you won't", $55
	db "be able to battle.", $58
; 0x1c41e6

UnknownText_0x1c41e6: ; 0x1c41e6
	db $0, "Your friend's", $4f
	db "@"
	text_from_ram $d073
	db $0, " appears", $55
	db "to be abnormal!", $58
; 0x1c4212

UnknownText_0x1c4212: ; 0x1c4212
	db $0, "Trade @"
	text_from_ram $d004
	db $0, $4f
	db "for @"
	text_from_ram $d073
	db $0, "?", $57
; 0x1c422a

UnknownText_0x1c422a: ; 0x1c422a
	db $0, "To enter a mobile", $4f
	db "battle, you must", $51
	db "pick a team of", $4f
	db "three #MON.", $51
	db "Is that OK?", $57
; 0x1c4275

UnknownText_0x1c4275: ; 0x1c4275
	db $0, "Need more info on", $4f
	db "mobile battles?", $57
; 0x1c4298

UnknownText_0x1c4298: ; 0x1c4298
	db $0, "For a mobile", $4f
	db "battle, choose", $55
	db "three #MON.", $51
	db "The maximum daily", $4f
	db "play time is ten", $51
	db "minutes for each", $4f
	db "linked player.", $51
	db "If a battle isn't", $4f
	db "finished within", $51
	db "the time limit,", $4f
	db "the player with", $51
	db "the fewest fainted", $4f
	db "#MON wins.", $51
	db "If tied, the team", $4f
	db "that lost the", $51
	db "least amount of HP", $4f
	db "wins.", $57
; 0x1c439c

UnknownText_0x1c439c: ; 0x1c439c
	db $0, "Today's remaining", $4f
	db "time is @"
	deciram $d086, $12
	db $0, " min.", $51
	db "Would you like to", $4f
	db "battle?", $57
; 0x1c43dc

UnknownText_0x1c43dc: ; 0x1c43dc
	db $0, "There are only @"
	deciram $d086, $12
	db $0, $4f
	db "min. left today.", $51
	db "Want a quick", $4f
	db "battle?", $57
; 0x1c4419

UnknownText_0x1c4419: ; 0x1c4419
	db $0, "There is only", $4f
	db "1 min. left today!", $51
	db "Want to rush", $4f
	db "through a battle?", $57
; 0x1c445a

UnknownText_0x1c445a: ; 0x1c445a
	db $0, "There is less than", $4f
	db "1 min. left today!", $51
	db "Please try again", $4f
	db "tomorrow.", $57
; 0x1c449c

UnknownText_0x1c449c: ; 0x1c449c
	db $0, "Try again using", $4f
	db "the same settings?", $57
; 0x1c44c0

UnknownText_0x1c44c0: ; 0x1c44c0
	db $0, "There is less than", $4f
	db "1 min. left today!", $57
; 0x1c44e7

UnknownText_0x1c44e7: ; 0x1c44e7
	db $0, "No time left for", $4f
	db "linking today.", $57
; 0x1c4508

UnknownText_0x1c4508: ; 0x1c4508
	db $0, "Pick three #MON", $4f
	db "for battle.", $57
; 0x1c4525

UnknownText_0x1c4525: ; 0x1c4525
	db $0, "Today's remaining", $4f
	db "time is @"
	deciram $d086, $12
	db $0, " min.", $57
; 0x1c454b

UnknownText_0x1c454b: ; 0x1c454b
	db $0, "Would you like to", $4f
	db "save the game?", $57
; 0x1c456d

UnknownText_0x1c456d: ; 0x1c456d
	db $0, "SAVING… DON'T TURN", $4f
	db "OFF THE POWER.", $57
; 0x1c4590

UnknownText_0x1c4590: ; 0x1c4590
	db $0, $52, " saved", $4f
	db "the game.", $57
; 0x1c45a3

UnknownText_0x1c45a3: ; 0x1c45a3
	db $0, "There is already a", $4f
	db "save file. Is it", $55
	db "OK to overwrite?", $57
; 0x1c45d9

UnknownText_0x1c45d9: ; 0x1c45d9
	db $0, "There is another", $4f
	db "save file. Is it", $55
	db "OK to overwrite?", $57
; 0x1c460d

UnknownText_0x1c460d: ; 0x1c460d
	db $0, "The save file is", $4f
	db "corrupted!", $58
; 0x1c462a

UnknownText_0x1c462a: ; 0x1c462a
	db $0, "When you change a", $4f
	db "#MON BOX, data", $55
	db "will be saved. OK?", $57
; 0x1c465f

UnknownText_0x1c465f: ; 0x1c465f
	db $0, "Each time you move", $4f
	db "a #MON, data", $55
	db "will be saved. OK?", $57
; 0x1c4693

UnknownText_0x1c4693: ; 0x1c4693
	db $0, "The window save", $4f
	db "area was exceeded.", $57
; 0x1c46b7

UnknownText_0x1c46b7: ; 0x1c46b7
	db $0, "No windows avail-", $4f
	db "able for popping.", $57
; 0x1c46dc

UnknownText_0x1c46dc: ; 0x1c46dc
	db $0, "Corrupted event!", $58
; 0x1c46ee

_ObjectEventText: ; 0x1c46ee
	db $0, "Object event", $57
; 0x1c46fc

UnknownText_0x1c46fc: ; 0x1c46fc
	db $0, "BG event", $57
; 0x1c4706

UnknownText_0x1c4706: ; 0x1c4706
	db $0, "Coordinates event", $57
; 0x1c4719

UnknownText_0x1c4719: ; 0x1c4719
	db $0, $52, " received", $4f
	db "@"
	text_from_ram $d0ac
	db $0, ".", $57
; 0x1c472c

UnknownText_0x1c472c: ; 0x1c472c
	db $0, $52, " put the", $4f
	db "@"
	text_from_ram $d073
	db $0, " in", $55
	db "the @"
	text_from_ram $d099
	db $0, ".", $58
; 0x1c474b

UnknownText_0x1c474b: ; 0x1c474b
	db $0, "The @"
	text_from_ram $d099
	db $0, $4f
	db "is full…", $58
; 0x1c475f

UnknownText_0x1c475f: ; 0x1c475f
	db $0, "I see all.", $4f
	db "I know all…", $51
	db "Certainly, I know", $4f
	db "of your #MON!", $57
; 0x1c4797

UnknownText_0x1c4797: ; 0x1c4797
	db $0, "Whaaaat? I can't", $4f
	db "tell a thing!", $51
	db "How could I not", $4f
	db "know of this?", $57
; 0x1c47d4

UnknownText_0x1c47d4: ; 0x1c47d4
	db $0, "Hm… I see you met", $4f
	db "@"
	text_from_ram $d003
	db $0, " here:", $55
	db "@"
	text_from_ram $d00e
	db $0, "!", $58
; 0x1c47fa

UnknownText_0x1c47fa: ; 0x1c47fa
	db $0, "The time was", $4f
	db "@"
	text_from_ram $d01f
	db $0, "!", $51
	db "Its level was @"
	text_from_ram $d036
	db $0, "!", $51
	db "Am I good or what?", $58
; 0x1c4837

UnknownText_0x1c4837: ; 0x1c4837
	db $0, "Hm… @"
	text_from_ram $d003
	db $0, $4f
	db "came from @"
	text_from_ram $d02a
	db $0, $55
	db "in a trade?", $51
	db "@"
	text_from_ram $d00e
	db $0, $4f
	db "was where @"
	text_from_ram $d02a
	db $0, $55
	db "met @"
	text_from_ram $d003
	db $0, "!", $58
; 0x1c487f

UnknownText_0x1c487f: ; 0x1c487f
	db $0, "What!? Incredible!", $51
	db "I don't understand", $4f
	db "how, but it is", $51
	db "incredible!", $4f
	db "You are special.", $51
	db "I can't tell where", $4f
	db "you met it, but it", $55
	db "was at level @"
	text_from_ram $d036
	db $0, ".", $51
	db "Am I good or what?", $58
; 0x1c491d

UnknownText_0x1c491d: ; 0x1c491d
	db $0, "Hey!", $51
	db "That's an EGG!", $51
	db "You can't say that", $4f
	db "you've met it yet…", $57
; 0x1c4955

UnknownText_0x1c4955: ; 0x1c4955
	db $0, "Fufufu! I saw that", $4f
	db "you'd do nothing!", $57
; 0x1c497a

UnknownText_0x1c497a: ; 0x1c497a
	db $0, "Incidentally…", $51
	db "It would be wise", $4f
	db "to raise your", $51
	db "#MON with a", $4f
	db "little more care.", $57
; 0x1c49c6

UnknownText_0x1c49c6: ; 0x1c49c6
	db $0, "Incidentally…", $51
	db "It seems to have", $4f
	db "grown a little.", $51
	db "@"
	text_from_ram $d003
	db $0, " seems", $4f
	db "to be becoming", $55
	db "more confident.", $57
; 0x1c4a21

UnknownText_0x1c4a21: ; 0x1c4a21
	db $0, "Incidentally…", $51
	db "@"
	text_from_ram $d003
	db $0, " has", $4f
	db "grown. It's gained", $55
	db "much strength.", $57
; 0x1c4a5b

UnknownText_0x1c4a5b: ; 0x1c4a5b
	db $0, "Incidentally…", $51
	db "It certainly has", $4f
	db "grown mighty!", $51
	db "This @"
	text_from_ram $d003
	db $0, $4f
	db "must have come", $51
	db "through numerous", $4f
	db "#MON battles.", $51
	db "It looks brimming", $4f
	db "with confidence.", $57
; 0x1c4ae5

UnknownText_0x1c4ae5: ; 0x1c4ae5
	db $0, "Incidentally…", $51
	db "I'm impressed by", $4f
	db "your dedication.", $51
	db "It's been a long", $4f
	db "time since I've", $51
	db "seen a #MON as", $4f
	db "mighty as this", $55
	db "@"
	text_from_ram $d003
	db $0, ".", $51
	db "I'm sure that", $4f
	db "seeing @"
	text_from_ram $d003
	db $0, $51
	db "in battle would", $4f
	db "excite anyone.", $57
; 0x1c4b92

UnknownText_0x1c4b92: ; 0x1c4b92
	db $0, "Congratulations!", $4f
	db "Your @"
	text_from_ram $d086
	db $50
; 0x1c4bae

UnknownText_0x1c4bae: ; 0x1c4bae
	db $50
; 0x1c4baf

UnknownText_0x1c4baf: ; 0x1c4baf
	db $0, $51
	db "evolved into", $4f
	db "@"
	text_from_ram $d073
	db $0, "!", $57
; 0x1c4bc5

UnknownText_0x1c4bc5: ; 0x1c4bc5
	db $0, "Huh? @"
	text_from_ram $d086
	db $0, $4f
	db "stopped evolving!", $58
; 0x1c4be3

UnknownText_0x1c4be3: ; 0x1c4be3
	db $0, "What? @"
	text_from_ram $d086
	db $0, $4f
	db "is evolving!", $57
; 0x1c4bfd

UnknownText_0x1c4bfd: ; 0x1c4bfd
	db $0, "How many?", $57
; 0x1c4c08

UnknownText_0x1c4c08: ; 0x1c4c08
	deciram $d10c, $12
	db $0, " @"
	text_from_ram $d086
	db $0, "(S)", $4f
	db "will be ¥@"
	deciram $ffc3, $36
	db $0, ".", $57
; 0x1c4c28

UnknownText_0x1c4c28: ; 0x1c4c28
	db $0, "Hello, dear.", $51
	db "I sell inexpensive", $4f
	db "herbal medicine.", $51
	db "They're good, but", $4f
	db "a trifle bitter.", $51
	db "Your #MON may", $4f
	db "not like them.", $51
	db "Hehehehe…", $57
; 0x1c4ca3

UnknownText_0x1c4ca3: ; 0x1c4ca3
	db $0, "How many?", $57
; 0x1c4cae

UnknownText_0x1c4cae: ; 0x1c4cae
	deciram $d10c, $12
	db $0, " @"
	text_from_ram $d086
	db $0, "(S)", $4f
	db "will be ¥@"
	deciram $ffc3, $36
	db $0, ".", $57
; 0x1c4cce

UnknownText_0x1c4cce: ; 0x1c4cce
	db $0, "Thank you, dear.", $4f
	db "Hehehehe…", $57
; 0x1c4cea

UnknownText_0x1c4cea: ; 0x1c4cea
	db $0, "Oh? Your PACK is", $4f
	db "full, dear.", $57
; 0x1c4d08

UnknownText_0x1c4d08: ; 0x1c4d08
	db $0, "Hehehe… You don't", $4f
	db "have the money.", $57
; 0x1c4d2a

UnknownText_0x1c4d2a: ; 0x1c4d2a
	db $0, "Come again, dear.", $4f
	db "Hehehehe…", $57
; 0x1c4d47

UnknownText_0x1c4d47: ; 0x1c4d47
	db $0, "Hiya! Care to see", $4f
	db "some bargains?", $51
	db "I sell rare items", $4f
	db "that nobody else", $51
	db "carries--but only", $4f
	db "one of each item.", $57
; 0x1c4db0

UnknownText_0x1c4db0: ; 0x1c4db0
	text_from_ram $d086
	db $0, " costs", $4f
	db "¥@"
	deciram $ffc3, $36
	db $0, ". Want it?", $57
; 0x1c4dcd

UnknownText_0x1c4dcd: ; 0x1c4dcd
	db $0, "Thanks.", $57
; 0x1c4dd6

UnknownText_0x1c4dd6: ; 0x1c4dd6
	db $0, "Uh-oh, your PACK", $4f
	db "is chock-full.", $57
; 0x1c4df7

UnknownText_0x1c4df7: ; 0x1c4df7
	db $0, "You bought that", $4f
	db "already. I'm all", $55
	db "sold out of it.", $57
; 0x1c4e28

UnknownText_0x1c4e28: ; 0x1c4e28
	db $0, "Uh-oh, you're", $4f
	db "short on funds.", $57
; 0x1c4e46

UnknownText_0x1c4e46: ; 0x1c4e46
	db $0, "Come by again", $4f
	db "sometime.", $57
; 0x1c4e5f

UnknownText_0x1c4e5f: ; 0x1c4e5f
	db $0, "What's up? Need", $4f
	db "some medicine?", $57
; 0x1c4e7e

UnknownText_0x1c4e7e: ; 0x1c4e7e
	db $0, "How many?", $57
; 0x1c4e89

UnknownText_0x1c4e89: ; 0x1c4e89
	deciram $d10c, $12
	db $0, " @"
	text_from_ram $d086
	db $0, "(S)", $4f
	db "will cost ¥@"
	deciram $ffc3, $36
	db $0, ".", $57
; 0x1c4eab

UnknownText_0x1c4eab: ; 0x1c4eab
	db $0, "Thanks much!", $57
; 0x1c4eb9

UnknownText_0x1c4eb9: ; 0x1c4eb9
	db $0, "You don't have any", $4f
	db "more space.", $57
; 0x1c4ed8

UnknownText_0x1c4ed8: ; 0x1c4ed8
	db $0, "Huh? That's not", $4f
	db "enough money.", $57
; 0x1c4ef6

UnknownText_0x1c4ef6: ; 0x1c4ef6
	db $0, "All right.", $4f
	db "See you around.", $57
; 0x1c4f12

UnknownText_0x1c4f12: ; 0x1c4f12
	db $0, "You don't have", $4f
	db "anything to sell.", $58
; 0x1c4f33

UnknownText_0x1c4f33: ; 0x1c4f33
	db $0, "How many?", $57
; 0x1c4f3e

UnknownText_0x1c4f3e: ; 0x1c4f3e
	db $0, "I can pay you", $4f
	db "¥@"
	deciram $ffc3, $36
	db $0, ".", $51
	db "Is that OK?", $57
; 0x1c4f62

UnknownText_0x1c4f62: ; 0x1c4f62
	db $0, "Welcome! How may I", $4f
	db "help you?", $57
; 0x1c4f80

UnknownText_0x1c4f80: ; 0x1c4f80
	db $0, "Here you are.", $4f
	db "Thank you!", $57
; 0x1c4f9a

UnknownText_0x1c4f9a: ; 0x1c4f9a
	db $0, "You don't have", $4f
	db "enough money.", $57
; 0x1c4fb7

UnknownText_0x1c4fb7: ; 0x1c4fb7
	db $0, "You can't carry", $4f
	db "any more items.", $57
; 0x1c4fd7

UnknownText_0x1c4fd7: ; 0x1c4fd7
	db $0, "Sorry, I can't buy", $4f
	db "that from you.", $58
; 0x1c4ff9

UnknownText_0x1c4ff9: ; 0x1c4ff9
	db $0, "Please come again!", $57
; 0x1c500d

UnknownText_0x1c500d: ; 0x1c500d
	db $0, "Can I do anything", $4f
	db "else for you?", $57
; 0x1c502e

UnknownText_0x1c502e: ; 0x1c502e
	db $0, "Got ¥@"
	deciram $ffc3, $36
	db $0, " for", $4f
	db "@"
	text_from_ram $d086
	db $0, "(S).", $57
; 0x1c5049

UnknownText_0x1c5049: ; 0x1c5049
	db $0, "Bet how many", $4f
	db "coins?", $57
; 0x1c505e

UnknownText_0x1c505e: ; 0x1c505e
	db $0, "Start!", $57
; 0x1c5066

UnknownText_0x1c5066: ; 0x1c5066
	db $0, "Not enough", $4f
	db "coins.", $58
; 0x1c5079

UnknownText_0x1c5079: ; 0x1c5079
	db $0, "Darn… Ran out of", $4f
	db "coins…", $57
; 0x1c5092

UnknownText_0x1c5092: ; 0x1c5092
	db $0, "Play again?", $57
; 0x1c509f

UnknownText_0x1c509f: ; 0x1c509f
	db $0, "lined up!", $4f
	db "Won @"
	text_from_ram $d086
	db $0, " coins!", $57
; 0x1c50bb

UnknownText_0x1c50bb: ; 0x1c50bb
	db $0, "Darn!", $57
; 0x1c50c2

_MobileStadiumEntryText: ; 0x1c50c2
	db $0, "Data for use in", $4f
	db "the MOBILE STADIUM", $51
	db "of the N64 #MON", $4f
	db "STADIUM 2 can be", $55
	db "read here.", $51
	db "Read the data?", $57
; 0x1c5121

_MobileStadiumSuccessText: ; 0x1c5121
	db $0, "Data transfer is", $4f
	db "complete.", $51
	db "We hope you enjoy", $4f
	db "MOBILE STADIUM", $51
	db "battles in the N64", $4f
	db "#MON STADIUM 2.", $51
	db $57
; 0x1c5182

UnknownText_0x1c5182: ; 0x1c5182
	db $0, "Clock time unknown", $57
; 0x1c5196

UnknownText_0x1c5196: ; 0x1c5196
	db $0, "Delete the saved", $4f
	db "LOG-IN PASSWORD?", $57
; 0x1c51b9

UnknownText_0x1c51b9: ; 0x1c51b9
	db $0, "Deleted the LOG-IN", $4f
	db "PASSWORD.", $57
; 0x1c51d7

UnknownText_0x1c51d7: ; 0x1c51d7
	db $0, "Pick three #MON", $4f
	db "for battle.", $58
; 0x1c51f4

UnknownText_0x1c51f4: ; 0x1c51f4
	text_from_ram $d006
	db $0, ",", $4f
	db "@"
	text_from_ram $d00c
	db $0, " and", $55
	db "@"
	text_from_ram $d012
	db $0, ".", $51
	db "Use these three?", $57
; 0x1c521c

UnknownText_0x1c521c: ; 0x1c521c
	db $0, "Only three #MON", $4f
	db "may enter.", $58
; 0x1c5238

UnknownText_0x1c5238: ; 0x1c5238
	db $0, "The CARD FOLDER", $4f
	db "stores your and", $51
	db "your friends'", $4f
	db "CARDS.", $51
	db "A CARD contains", $4f
	db "information like", $51
	db "the person's name,", $4f
	db "phone number and", $55
	db "profile.", $51
	db $57
; 0x1c52bc

UnknownText_0x1c52bc: ; 0x1c52bc
	db $0, "This is your CARD.", $51
	db "Once you've", $4f
	db "entered your phone", $51
	db "number, you can", $4f
	db "trade CARDS with", $55
	db "your friends.", $51
	db $57
; 0x1c531e

UnknownText_0x1c531e: ; 0x1c531e
	db $0, "If you have your", $4f
	db "friend's CARD, you", $51
	db "can use it to make", $4f
	db "a call from a", $51
	db "mobile phone on", $4f
	db "the 2nd floor of a", $55
	db "#MON CENTER.", $51
	db $57
; 0x1c5394

UnknownText_0x1c5394: ; 0x1c5394
	db $0, "To safely store", $4f
	db "your collection of", $51
	db "CARDS, you must", $4f
	db "set a PASSCODE for", $55
	db "your CARD FOLDER.", $51
	db $57
; 0x1c53ee

UnknownText_0x1c53ee: ; 0x1c53ee
	db $0, "If the CARD FOLDER", $4f
	db "is deleted, all", $51
	db "its CARDS and the", $4f
	db "PASSCODE will also", $55
	db "be deleted.", $51
	db "Beware--a deleted", $4f
	db "CARD FOLDER can't", $55
	db "be restored.", $51
	db "Want to delete", $4f
	db "your CARD FOLDER?", $57
; 0x1c5494

UnknownText_0x1c5494: ; 0x1c5494
	db $0, "Are you sure you", $4f
	db "want to delete it?", $57
; 0x1c54b9

UnknownText_0x1c54b9: ; 0x1c54b9
	db $0, "The CARD FOLDER", $4f
	db "has been deleted.", $51
	db $57
; 0x1c54dd

UnknownText_0x1c54dd: ; 0x1c54dd
	db $0, "There is an older", $4f
	db "CARD FOLDER from a", $55
	db "previous journey.", $51
	db "Do you want to", $4f
	db "open it?", $57
; 0x1c552d

UnknownText_0x1c552d: ; 0x1c552d
	db $0, "Delete the old", $4f
	db "CARD FOLDER?", $57
; 0x1c554a

UnknownText_0x1c554a: ; 0x1c554a
	db $0, "Finish registering", $4f
	db "CARDS?", $57
; 0x1c5565

UnknownText_0x1c5565: ; 0x1c5565
	db $0, "Huh? Sorry, wrong", $4f
	db "number!", $57
; 0x1c5580

UnknownText_0x1c5580: ; 0x1c5580
	db $0, "Click!", $57
; 0x1c5588

UnknownText_0x1c5588: ; 0x1c5588
	db $0, $56, $57
; 0x1c558b

UnknownText_0x1c558b: ; 0x1c558b
	db $0, "That number is out", $4f
	db "of the area.", $57
; 0x1c55ac

UnknownText_0x1c55ac: ; 0x1c55ac
	db $0, "Just go talk to", $4f
	db "that person!", $57
; 0x1c55ca

UnknownText_0x1c55ca: ; 0x1c55ca
	db $0, "Thank you!", $57
; 0x1c55d6

UnknownText_0x1c55d6: ; 0x1c55d6
	db $0, "  :", $57
; 0x1c55db

UnknownText_0x1c55db: ; 0x1c55db
	db $0, "Password OK.", $4f
	db "Select CONTINUE &", $55
	db "reset settings.", $58
; 0x1c560b

UnknownText_0x1c560b: ; 0x1c560b
	db $0, "Wrong password!", $58
; 0x1c561c

UnknownText_0x1c561c: ; 0x1c561c
	db $0, "Reset the clock?", $57
; 0x1c562e

UnknownText_0x1c562e: ; 0x1c562e
	db $0, "Please enter the", $4f
	db "password.", $57
; 0x1c564a

UnknownText_0x1c564a: ; 0x1c564a
	db $0, "Clear all save", $4f
	db "data?", $57
; 0x1c5660

UnknownText_0x1c5660: ; 0x1c5660
	text_from_ram $d050
	db $0, " learned", $4f
	db "@"
	text_from_ram $d086
	db $0, "!@"
	sound0
	text_waitbutton
	db $50
; 0x1c5677

UnknownText_0x1c5677: ; 0x1c5677
	db $50
; 0x1c5678

UnknownText_0x1c5678: ; 0x1c5678
	db $0, "Which move should", $4e, "be forgotten?", $57
; 0x1c5699

UnknownText_0x1c5699: ; 0x1c5699
	db $0, "Stop learning", $4f
	db "@"
	text_from_ram $d086
	db $0, "?", $57
; 0x1c56af

UnknownText_0x1c56af: ; 0x1c56af
	text_from_ram $d050
	db $0, $4f
	db "did not learn", $55
	db "@"
	text_from_ram $d086
	db $0, ".", $58
; 0x1c56c9

UnknownText_0x1c56c9: ; 0x1c56c9
	text_from_ram $d050
	db $0, " is", $4f
	db "trying to learn", $55
	db "@"
	text_from_ram $d086
	db $0, ".", $51
	db "But @"
	text_from_ram $d050
	db $0, $4f
	db "can't learn more", $55
	db "than four moves.", $51
	db "Delete an older", $4f
	db "move to make room", $55
	db "for @"
	text_from_ram $d086
	db $0, "?", $57
; 0x1c5740

UnknownText_0x1c5740: ; 0x1c5740
	db $0, "1, 2 and…@"
	interpret_data
	db $50
; 0x1c574d

UnknownText_0x1c574d: ; 0x1c574d
	db $50
; 0x1c574e

UnknownText_0x1c574e: ; 0x1c574e
	db $0, " Poof!@"
	interpret_data
	db $0, $51
	db "@"
	text_from_ram $d050
	db $0, " forgot", $4f
	db "@"
	text_from_ram $d073
	db $0, ".", $51
	db "And…", $58
; 0x1c5772

UnknownText_0x1c5772: ; 0x1c5772
	db $0, "HM moves can't be", $4f
	db "forgotten now.", $58
; 0x1c5793

UnknownText_0x1c5793: ; 0x1c5793
	db $0, "Play with three", $4f
	db "coins?", $57
; 0x1c57ab

UnknownText_0x1c57ab: ; 0x1c57ab
	db $0, "Not enough coins…", $58
; 0x1c57be

UnknownText_0x1c57be: ; 0x1c57be
	db $0, "Choose a card.", $57
; 0x1c57ce

UnknownText_0x1c57ce: ; 0x1c57ce
	db $0, "Place your bet.", $57
; 0x1c57df

UnknownText_0x1c57df: ; 0x1c57df
	db $0, "Want to play", $4f
	db "again?", $57
; 0x1c57f4

UnknownText_0x1c57f4: ; 0x1c57f4
	db $0, "The cards have", $4f
	db "been shuffled.", $58
; 0x1c5813

UnknownText_0x1c5813: ; 0x1c5813
	db $0, "Yeah!", $57
; 0x1c581a

UnknownText_0x1c581a: ; 0x1c581a
	db $0, "Darn…", $57
; 0x1c5821

UnknownText_0x1c5821: ; 0x1c5821
	current_day
	db $50
; 0x1c5823

UnknownText_0x1c5823: ; 0x1c5823
	db $50
; 0x1c5824

UnknownText_0x1c5824: ; 0x1c5824
	db $0, $56, $57
; 0x1c5827

UnknownText_0x1c5827: ; 0x1c5827
	db $0, "You're out of the", $4f
	db "service area.", $58
; 0x1c5847

UnknownText_0x1c5847: ; 0x1c5847
	db $0, "Whom do you want", $4f
	db "to call?", $57
; 0x1c5862

UnknownText_0x1c5862: ; 0x1c5862
	db $0, "Press any button", $4f
	db "to exit.", $57
; 0x1c587d

UnknownText_0x1c587d: ; 0x1c587d
	db $0, "Delete this stored", $4f
	db "phone number?", $57
; 0x1c589f

UnknownText_0x1c589f: ; 0x1c589f
	db $0, "Which prize would", $4f
	db "you like?", $57
; 0x1c58bc

UnknownText_0x1c58bc: ; 0x1c58bc
	text_from_ram $d073
	db $0, "?", $4f
	db "Is that right?", $57
; 0x1c58d1

UnknownText_0x1c58d1: ; 0x1c58d1
	db $0, "Here you go!", $51
	db $57
; 0x1c58e0

UnknownText_0x1c58e0: ; 0x1c58e0
	db $0, "You don't have", $4f
	db "enough points.", $51
	db $57
; 0x1c58ff

UnknownText_0x1c58ff: ; 0x1c58ff
	db $0, "You have no room", $4f
	db "for it.", $51
	db $57
; 0x1c591a

UnknownText_0x1c591a: ; 0x1c591a
	db $0, "Oh. Please come", $4f
	db "back again!", $57
; 0x1c5937

UnknownText_0x1c5937: ; 0x1c5937
	db $0, "Excuse me!", $51
	db $57
; 0x1c5944

UnknownText_0x1c5944: ; 0x1c5944
	db $0, "Excuse me.", $4f
	db "You're not ready.", $51
	db $57
; 0x1c5962

UnknownText_0x1c5962: ; 0x1c5962
	db $0, "Please return when", $4f
	db "you're ready.", $57
; 0x1c5983

UnknownText_0x1c5983: ; 0x1c5983
	db $0, "You need at least", $4f
	db "three #MON.", $51
	db $57
; 0x1c59a3

UnknownText_0x1c59a3: ; 0x1c59a3
	db $0, "Sorry, an EGG", $4f
	db "doesn't qualify.", $51
	db $57
; 0x1c59c3

UnknownText_0x1c59c3: ; 0x1c59c3
	db $0, "Only three #MON", $4f
	db "may be entered.", $51
	db $57
; 0x1c59e5

UnknownText_0x1c59e5: ; 0x1c59e5
	db $0, "The @"
	text_from_ram $d086
	db $0, " #MON", $4f
	db "must all be", $55
	db "different kinds.", $51
	db $57
; 0x1c5a13

UnknownText_0x1c5a13: ; 0x1c5a13
	db $0, "The @"
	text_from_ram $d086
	db $0, " #MON", $4f
	db "must not hold the", $55
	db "same items.", $51
	db $57
; 0x1c5a42

UnknownText_0x1c5a42: ; 0x1c5a42
	db $0, "You can't take an", $4f
	db "EGG!", $51
	db $57
; 0x1c5a5a

UnknownText_0x1c5a5a: ; 0x1c5a5a
	db $0, "It dodged the", $4f
	db "thrown BALL!", $51
	db "This #MON", $4f
	db "can't be caught!", $58
; 0x1c5a90

UnknownText_0x1c5a90: ; 0x1c5a90
	db $0, "You missed the", $4f
	db "#MON!", $58
; 0x1c5aa6

UnknownText_0x1c5aa6: ; 0x1c5aa6
	db $0, "Oh no! The #MON", $4f
	db "broke free!", $58
; 0x1c5ac3

UnknownText_0x1c5ac3: ; 0x1c5ac3
	db $0, "Aww! It appeared", $4f
	db "to be caught!", $58
; 0x1c5ae3

UnknownText_0x1c5ae3: ; 0x1c5ae3
	db $0, "Aargh!", $4f
	db "Almost had it!", $58
; 0x1c5afa

UnknownText_0x1c5afa: ; 0x1c5afa
	db $0, "Shoot! It was so", $4f
	db "close too!", $58
; 0x1c5b17

UnknownText_0x1c5b17: ; 0x1c5b17
	db $0, "Gotcha! @"
	text_from_ram $c616
	db $0, $4f
	db "was caught!@"
	sound0x02
	db $50
; 0x1c5b34

UnknownText_0x1c5b34: ; 0x1c5b34
	db $50
; 0x1c5b35

UnknownText_0x1c5b35: ; 0x1c5b35
	text_waitbutton
	db $50
; 0x1c5b37

UnknownText_0x1c5b37: ; 0x1c5b37
	db $50
; 0x1c5b38

UnknownText_0x1c5b38: ; 0x1c5b38
	text_from_ram $d050
	db $0, " was", $4f
	db "sent to BILL's PC.", $58
; 0x1c5b53

UnknownText_0x1c5b53: ; 0x1c5b53
	text_from_ram $c616
	db $0, "'s data", $4f
	db "was newly added to", $55
	db "the #DEX.@"
	sound0x2C
	text_waitbutton
	db $50
; 0x1c5b7e

UnknownText_0x1c5b7e: ; 0x1c5b7e
	db $50
; 0x1c5b7f

UnknownText_0x1c5b7f: ; 0x1c5b7f
	db $0, "Give a nickname to", $4f
	db "@"
	text_from_ram $d073
	db $0, "?", $57
; 0x1c5b9a

UnknownText_0x1c5b9a: ; 0x1c5b9a
	text_from_ram $d073
	db $0, "'s", $4f
	db "@"
	text_from_ram $d086
	db $0, " rose.", $58
; 0x1c5bac

UnknownText_0x1c5bac: ; 0x1c5bac
	db $0, "That can't be used", $4f
	db "on this #MON.", $58
; 0x1c5bcd

UnknownText_0x1c5bcd: ; 0x1c5bcd
	db $0, "The REPEL used", $4f
	db "earlier is still", $55
	db "in effect.", $58
; 0x1c5bf9

UnknownText_0x1c5bf9: ; 0x1c5bf9
	db $0, "Played the #", $4f
	db "FLUTE.", $51
	db "Now, that's a", $4f
	db "catchy tune!", $58
; 0x1c5c28

UnknownText_0x1c5c28: ; 0x1c5c28
	db $0, "All sleeping", $4f
	db "#MON woke up.", $58
; 0x1c5c44

UnknownText_0x1c5c44: ; 0x1c5c44
	db $0, $52, " played the", $4f
	db "# FLUTE.@"
	text_waitbutton
	db $50
; 0x1c5c5d

UnknownText_0x1c5c5d: ; 0x1c5c5d
	db $50
; 0x1c5c5e

UnknownText_0x1c5c5e: ; 0x1c5c5e
	db $0, "You now have", $4f
	db "@"
	deciram $dc4b, $12
	db $0, " points.", $57
; 0x1c5c7b

UnknownText_0x1c5c7b: ; 0x1c5c7b
	db $0, "Coins:", $4f
	db "@"
	deciram $d855, $24
	db $50
; 0x1c5c89

UnknownText_0x1c5c89: ; 0x1c5c89
	db $50
; 0x1c5c8a

UnknownText_0x1c5c8a: ; 0x1c5c8a
	db $0, "Raise the PP of", $4f
	db "which move?", $57
; 0x1c5ca7

UnknownText_0x1c5ca7: ; 0x1c5ca7
	db $0, "Restore the PP of", $4f
	db "which move?", $57
; 0x1c5cc6

UnknownText_0x1c5cc6: ; 0x1c5cc6
	text_from_ram $d086
	db $0, "'s PP", $4f
	db "is maxed out.", $58
; 0x1c5cdd

UnknownText_0x1c5cdd: ; 0x1c5cdd
	text_from_ram $d086
	db $0, "'s PP", $4f
	db "increased.", $58
; 0x1c5cf1

UnknownText_0x1c5cf1: ; 0x1c5cf1
	db $0, "PP was restored.", $58
; 0x1c5d03

UnknownText_0x1c5d03: ; 0x1c5d03
	db $0, "There was a trophy", $4f
	db "inside!@"
	sound0
	db $0, $51
	db "@"
	text_from_ram PlayerName
	db $0, " sent the", $4f
	db "trophy home.", $58
; 0x1c5d3e

UnknownText_0x1c5d3e: ; 0x1c5d3e
	db $0, "It looks bitter…", $58
; 0x1c5d50

UnknownText_0x1c5d50: ; 0x1c5d50
	db $0, "That can't be used", $4f
	db "on an EGG.", $58
; 0x1c5d6e

UnknownText_0x1c5d6e: ; 0x1c5d6e
	db $0, "OAK: ", $52, "!", $4f
	db "This isn't the", $55
	db "time to use that!", $58
; 0x1c5d97

UnknownText_0x1c5d97: ; 0x1c5d97
	db $0, "That belongs to", $4f
	db "someone else!", $58
; 0x1c5db6

UnknownText_0x1c5db6: ; 0x1c5db6
	db $0, "It won't have any", $4f
	db "effect.", $58
; 0x1c5dd0

UnknownText_0x1c5dd0: ; 0x1c5dd0
	db $0, "The trainer", $4f
	db "blocked the BALL!", $58
; 0x1c5def

UnknownText_0x1c5def: ; 0x1c5def
	db $0, "Don't be a thief!", $58
; 0x1c5e01

UnknownText_0x1c5e01: ; 0x1c5e01
	db $0, "Cycling isn't", $4f
	db "allowed here.", $58
; 0x1c5e1d

UnknownText_0x1c5e1d: ; 0x1c5e1d
	db $0, "Can't get on your", $4f
	db "@"
	text_from_ram $d073
	db $0, " now.", $58
; 0x1c5e3a

UnknownText_0x1c5e3a: ; 0x1c5e3a
	db $0, "The #MON BOX", $4f
	db "is full. That", $55
	db "can't be used now.", $58
; 0x1c5e68

UnknownText_0x1c5e68: ; 0x1c5e68
	db $0, $52, " used the@"
	text_dunno1
	text_from_ram $d086
	db $0, ".", $57
; 0x1c5e7b

UnknownText_0x1c5e7b: ; 0x1c5e7b
	db $0, $52, " got on the@"
	text_dunno1
	text_from_ram $d086
	db $0, ".", $58
; 0x1c5e90

UnknownText_0x1c5e90: ; 0x1c5e90
	db $0, $52, " got off@"
	text_dunno1
	db $0, "the @"
	text_from_ram $d086
	db $0, ".", $58
; 0x1c5ea8

UnknownText_0x1c5ea8: ; 0x1c5ea8
	text_from_ram $d073
	db $0, " knows", $4f
	db "@"
	text_from_ram $d086
	db $0, ".", $58
; 0x1c5eba

UnknownText_0x1c5eba: ; 0x1c5eba
	db $0, "That #MON knows", $4f
	db "only one move.", $57
; 0x1c5eda

UnknownText_0x1c5eda: ; 0x1c5eda
	db $0, "Oh, make it forget", $4f
	db "@"
	text_from_ram $d073
	db $0, "?", $57
; 0x1c5ef5

UnknownText_0x1c5ef5: ; 0x1c5ef5
	db $0, "Done! Your #MON", $4f
	db "forgot the move.", $57
; 0x1c5f17

UnknownText_0x1c5f17: ; 0x1c5f17
	db $0, "An EGG doesn't", $4f
	db "know any moves!", $57
; 0x1c5f36

UnknownText_0x1c5f36: ; 0x1c5f36
	db $0, "No? Come visit me", $4f
	db "again.", $57
; 0x1c5f50

UnknownText_0x1c5f50: ; 0x1c5f50
	db $0, "Which move should", $4f
	db "it forget, then?", $58
; 0x1c5f74

UnknownText_0x1c5f74: ; 0x1c5f74
	db $0, "Um… Oh, yes, I'm", $4f
	db "the MOVE DELETER.", $51
	db "I can make #MON", $4f
	db "forget moves.", $51
	db "Shall I make a", $4f
	db "#MON forget?", $57
; 0x1c5fd1

UnknownText_0x1c5fd1: ; 0x1c5fd1
	db $0, "Which #MON?", $58
; 0x1c5fde

UnknownText_0x1c5fde: ; 0x1c5fde
	db $0, " DST,", $4f
	db "is that OK?", $57
; 0x1c5ff1

UnknownText_0x1c5ff1: ; 0x1c5ff1
	db $0, ",", $4f
	db "is that OK?", $57
; 0x1c6000

UnknownText_0x1c6000: ; 0x1c6000
	db $0, "Do you want to", $4f
	db "switch to Daylight", $55
	db "Saving Time?", $57
; 0x1c6030

UnknownText_0x1c6030: ; 0x1c6030
	db $0, "I set the clock", $4f
	db "forward by one", $55
	db "hour.", $58
; 0x1c6056

UnknownText_0x1c6056: ; 0x1c6056
	db $0, "Is Daylight Saving", $4f
	db "Time over?", $57
; 0x1c6075

UnknownText_0x1c6075: ; 0x1c6075
	db $0, "I put the clock", $4f
	db "back one hour.", $58
; 0x1c6095

UnknownText_0x1c6095: ; 0x1c6095
	db $0, "Do you want to", $4f
	db "adjust your clock", $51
	db "for Daylight", $4f
	db "Saving Time?", $57
; 0x1c60d1

UnknownText_0x1c60d1: ; 0x1c60d1
	db $0, "I lost the in-", $4f
	db "struction booklet", $55
	db "for the #GEAR.", $51
	db "Come back again in", $4f
	db "a while.", $58
; 0x1c611e

SECTION "bank72",DATA,BANK[$72]

ItemNames:
	db "MASTER BALL@"
	db "ULTRA BALL@"
	db "BRIGHTPOWDER@"
	db "GREAT BALL@"
	db "# BALL@"
	db "TERU-SAMA@"
	db "BICYCLE@"
	db "MOON STONE@"
	db "ANTIDOTE@"
	db "BURN HEAL@"
	db "ICE HEAL@"
	db "AWAKENING@"
	db "PARLYZ HEAL@"
	db "FULL RESTORE@"
	db "MAX POTION@"
	db "HYPER POTION@"
	db "SUPER POTION@"
	db "POTION@"
	db "ESCAPE ROPE@"
	db "REPEL@"
	db "MAX ELIXER@"
	db "FIRE STONE@"
	db "THUNDERSTONE@"
	db "WATER STONE@"
	db "TERU-SAMA@"
	db "HP UP@"
	db "PROTEIN@"
	db "IRON@"
	db "CARBOS@"
	db "LUCKY PUNCH@"
	db "CALCIUM@"
	db "RARE CANDY@"
	db "X ACCURACY@"
	db "LEAF STONE@"
	db "METAL POWDER@"
	db "NUGGET@"
	db "# DOLL@"
	db "FULL HEAL@"
	db "REVIVE@"
	db "MAX REVIVE@"
	db "GUARD SPEC.@"
	db "SUPER REPEL@"
	db "MAX REPEL@"
	db "DIRE HIT@"
	db "TERU-SAMA@"
	db "FRESH WATER@"
	db "SODA POP@"
	db "LEMONADE@"
	db "X ATTACK@"
	db "TERU-SAMA@"
	db "X DEFEND@"
	db "X SPEED@"
	db "X SPECIAL@"
	db "COIN CASE@"
	db "ITEMFINDER@"
	db "TERU-SAMA@"
	db "EXP.SHARE@"
	db "OLD ROD@"
	db "GOOD ROD@"
	db "SILVER LEAF@"
	db "SUPER ROD@"
	db "PP UP@"
	db "ETHER@"
	db "MAX ETHER@"
	db "ELIXER@"
	db "RED SCALE@"
	db "SECRETPOTION@"
	db "S.S.TICKET@"
	db "MYSTERY EGG@"
	db "CLEAR BELL@"
	db "SILVER WING@"
	db "MOOMOO MILK@"
	db "QUICK CLAW@"
	db "PSNCUREBERRY@"
	db "GOLD LEAF@"
	db "SOFT SAND@"
	db "SHARP BEAK@"
	db "PRZCUREBERRY@"
	db "BURNT BERRY@"
	db "ICE BERRY@"
	db "POISON BARB@"
	db "KING'S ROCK@"
	db "BITTER BERRY@"
	db "MINT BERRY@"
	db "RED APRICORN@"
	db "TINYMUSHROOM@"
	db "BIG MUSHROOM@"
	db "SILVERPOWDER@"
	db "BLU APRICORN@"
	db "TERU-SAMA@"
	db "AMULET COIN@"
	db "YLW APRICORN@"
	db "GRN APRICORN@"
	db "CLEANSE TAG@"
	db "MYSTIC WATER@"
	db "TWISTEDSPOON@"
	db "WHT APRICORN@"
	db "BLACKBELT@"
	db "BLK APRICORN@"
	db "TERU-SAMA@"
	db "PNK APRICORN@"
	db "BLACKGLASSES@"
	db "SLOWPOKETAIL@"
	db "PINK BOW@"
	db "STICK@"
	db "SMOKE BALL@"
	db "NEVERMELTICE@"
	db "MAGNET@"
	db "MIRACLEBERRY@"
	db "PEARL@"
	db "BIG PEARL@"
	db "EVERSTONE@"
	db "SPELL TAG@"
	db "RAGECANDYBAR@"
	db "GS BALL@"
	db "BLUE CARD@"
	db "MIRACLE SEED@"
	db "THICK CLUB@"
	db "FOCUS BAND@"
	db "TERU-SAMA@"
	db "ENERGYPOWDER@"
	db "ENERGY ROOT@"
	db "HEAL POWDER@"
	db "REVIVAL HERB@"
	db "HARD STONE@"
	db "LUCKY EGG@"
	db "CARD KEY@"
	db "MACHINE PART@"
	db "EGG TICKET@"
	db "LOST ITEM@"
	db "STARDUST@"
	db "STAR PIECE@"
	db "BASEMENT KEY@"
	db "PASS@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "CHARCOAL@"
	db "BERRY JUICE@"
	db "SCOPE LENS@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "METAL COAT@"
	db "DRAGON FANG@"
	db "TERU-SAMA@"
	db "LEFTOVERS@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "MYSTERYBERRY@"
	db "DRAGON SCALE@"
	db "BERSERK GENE@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "SACRED ASH@"
	db "HEAVY BALL@"
	db "FLOWER MAIL@"
	db "LEVEL BALL@"
	db "LURE BALL@"
	db "FAST BALL@"
	db "TERU-SAMA@"
	db "LIGHT BALL@"
	db "FRIEND BALL@"
	db "MOON BALL@"
	db "LOVE BALL@"
	db "NORMAL BOX@"
	db "GORGEOUS BOX@"
	db "SUN STONE@"
	db "POLKADOT BOW@"
	db "TERU-SAMA@"
	db "UP-GRADE@"
	db "BERRY@"
	db "GOLD BERRY@"
	db "SQUIRTBOTTLE@"
	db "TERU-SAMA@"
	db "PARK BALL@"
	db "RAINBOW WING@"
	db "TERU-SAMA@"
	db "BRICK PIECE@"
	db "SURF MAIL@"
	db "LITEBLUEMAIL@"
	db "PORTRAITMAIL@"
	db "LOVELY MAIL@"
	db "EON MAIL@"
	db "MORPH MAIL@"
	db "BLUESKY MAIL@"
	db "MUSIC MAIL@"
	db "MIRAGE MAIL@"
	db "TERU-SAMA@"
	db "TM01@"
	db "TM02@"
	db "TM03@"
	db "TM04@"
	db "TERU-SAMA@"
	db "TM05@"
	db "TM06@"
	db "TM07@"
	db "TM08@"
	db "TM09@"
	db "TM10@"
	db "TM11@"
	db "TM12@"
	db "TM13@"
	db "TM14@"
	db "TM15@"
	db "TM16@"
	db "TM17@"
	db "TM18@"
	db "TM19@"
	db "TM20@"
	db "TM21@"
	db "TM22@"
	db "TM23@"
	db "TM24@"
	db "TM25@"
	db "TM26@"
	db "TM27@"
	db "TM28@"
	db "TERU-SAMA@"
	db "TM29@"
	db "TM30@"
	db "TM31@"
	db "TM32@"
	db "TM33@"
	db "TM34@"
	db "TM35@"
	db "TM36@"
	db "TM37@"
	db "TM38@"
	db "TM39@"
	db "TM40@"
	db "TM41@"
	db "TM42@"
	db "TM43@"
	db "TM44@"
	db "TM45@"
	db "TM46@"
	db "TM47@"
	db "TM48@"
	db "TM49@"
	db "TM50@"
	db "HM01@"
	db "HM02@"
	db "HM03@"
	db "HM04@"
	db "HM05@"
	db "HM06@"
	db "HM07@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "TERU-SAMA@"
	db "?@"

GetItemDescription: ; 0x1c8955
	ld a, [$cf60]
	cp TM_01
	jr c, .nomovedesc ; if not a TM, use a predefined string
	ld [$d106], a
	push de
	ld a, $b     ; XXX replace this with BANK(label)
	ld hl, $47b6 ; XXX replace this with label
	rst $8
	pop hl
	ld a, [$d265]
	ld [$cf60], a
	ld a, $11
	call Predef
	ret

.nomovedesc
	push de
	ld hl, ItemDescriptions
	ld a, [$cf60]
	dec a
	ld c, a
	ld b, $0
	add hl, bc
	add hl, bc
	ld e, [hl]
	inc hl
	ld d, [hl]
	pop hl
	jp PlaceString
; 0x1c8987

ItemDescriptions:
	dw MasterBallDesc
	dw UltraBallDesc
	dw BrightpowderDesc
	dw GreatBallDesc
	dw PokeBallDesc
	dw TeruSama1Desc
	dw BicycleDesc
	dw MoonStoneDesc
	dw AntidoteDesc
	dw BurnHealDesc
	dw IceHealDesc
	dw AwakeningDesc
	dw ParlyzHealDesc
	dw FullRestoreDesc
	dw MaxPotionDesc
	dw HyperPotionDesc
	dw SuperPotionDesc
	dw PotionDesc
	dw EscapeRopeDesc
	dw RepelDesc
	dw MaxElixerDesc
	dw FireStoneDesc
	dw ThunderStoneDesc
	dw WaterStoneDesc
	dw TeruSama2Desc
	dw HPUpDesc
	dw ProteinDesc
	dw IronDesc
	dw CarbosDesc
	dw LuckyPunchDesc
	dw CalciumDesc
	dw RareCandyDesc
	dw XAccuracyDesc
	dw LeafStoneDesc
	dw MetalPowderDesc
	dw NuggetDesc
	dw PokeDollDesc
	dw FullHealDesc
	dw ReviveDesc
	dw MaxReviveDesc
	dw GuardSpecDesc
	dw SuperRepelDesc
	dw MaxRepelDesc
	dw DireHitDesc
	dw TeruSama3Desc
	dw FreshWaterDesc
	dw SodaPopDesc
	dw LemonadeDesc
	dw XAttackDesc
	dw TeruSama4Desc
	dw XDefendDesc
	dw XSpeedDesc
	dw XSpecialDesc
	dw CoinCaseDesc
	dw ItemfinderDesc
	dw TeruSama5Desc
	dw ExpShareDesc
	dw OldRodDesc
	dw GoodRodDesc
	dw SilverLeafDesc
	dw SuperRodDesc
	dw PPUpDesc
	dw EtherDesc
	dw MaxEtherDesc
	dw ElixerDesc
	dw RedScaleDesc
	dw SecretPotionDesc
	dw SSTicketDesc
	dw MysteryEggDesc
	dw ClearBellDesc
	dw SilverWingDesc
	dw MoomooMilkDesc
	dw QuickClawDesc
	dw PsnCureBerryDesc
	dw GoldLeafDesc
	dw SoftSandDesc
	dw SharpBeakDesc
	dw PrzCureBerryDesc
	dw BurntBerryDesc
	dw IceBerryDesc
	dw PoisonBarbDesc
	dw KingsRockDesc
	dw BitterBerryDesc
	dw MintBerryDesc
	dw RedApricornDesc
	dw TinyMushroomDesc
	dw BigMushroomDesc
	dw SilverPowderDesc
	dw BluApricornDesc
	dw TeruSama6Desc
	dw AmuletCoinDesc
	dw YlwApricornDesc
	dw GrnApricornDesc
	dw CleanseTagDesc
	dw MysticWaterDesc
	dw TwistedSpoonDesc
	dw WhtApricornDesc
	dw BlackbeltDesc
	dw BlkApricornDesc
	dw TeruSama7Desc
	dw PnkApricornDesc
	dw BlackGlassesDesc
	dw SlowpokeTailDesc
	dw PinkBowDesc
	dw StickDesc
	dw SmokeBallDesc
	dw NeverMeltIceDesc
	dw MagnetDesc
	dw MiracleBerryDesc
	dw PearlDesc
	dw BigPearlDesc
	dw EverStoneDesc
	dw SpellTagDesc
	dw RageCandyBarDesc
	dw GSBallDesc
	dw BlueCardDesc
	dw MiracleSeedDesc
	dw ThickClubDesc
	dw FocusBandDesc
	dw TeruSama8Desc
	dw EnergyPowderDesc
	dw EnergyRootDesc
	dw HealPowderDesc
	dw RevivalHerbDesc
	dw HardStoneDesc
	dw LuckyEggDesc
	dw CardKeyDesc
	dw MachinePartDesc
	dw EggTicketDesc
	dw LostItemDesc
	dw StardustDesc
	dw StarPieceDesc
	dw BasementKeyDesc
	dw PassDesc
	dw TeruSama9Desc
	dw TeruSama10Desc
	dw TeruSama11Desc
	dw CharcoalDesc
	dw BerryJuiceDesc
	dw ScopeLensDesc
	dw TeruSama12Desc
	dw TeruSama13Desc
	dw MetalCoatDesc
	dw DragonFangDesc
	dw TeruSama14Desc
	dw LeftoversDesc
	dw TeruSama15Desc
	dw TeruSama16Desc
	dw TeruSama17Desc
	dw MysteryBerryDesc
	dw DragonScaleDesc
	dw BerserkGeneDesc
	dw TeruSama18Desc
	dw TeruSama19Desc
	dw TeruSama20Desc
	dw SacredAshDesc
	dw HeavyBallDesc
	dw FlowerMailDesc
	dw LevelBallDesc
	dw LureBallDesc
	dw FastBallDesc
	dw TeruSama21Desc
	dw LightBallDesc
	dw FriendBallDesc
	dw MoonBallDesc
	dw LoveBallDesc
	dw NormalBoxDesc
	dw GorgeousBoxDesc
	dw SunStoneDesc
	dw PolkadotBowDesc
	dw TeruSama22Desc
	dw UpGradeDesc
	dw BerryDesc
	dw GoldBerryDesc
	dw SquirtBottleDesc
	dw TeruSama23Desc
	dw ParkBallDesc
	dw RainbowWingDesc
	dw TeruSama24Desc
	dw BrickPieceDesc
	dw SurfMailDesc
	dw LiteBlueMailDesc
	dw PortraitMailDesc
	dw LovelyMailDesc
	dw EonMailDesc
	dw MorphMailDesc
	dw BlueSkyMailDesc
	dw MusicMailDesc
	dw MewMailDesc
	dw TeruSama25Desc
	dw TeruSama26Desc
	dw TeruSama26Desc
	dw TeruSama26Desc
	dw TeruSama26Desc
	dw TeruSama26Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama27Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama28Desc
	dw TeruSama29Desc
	dw TeruSama30Desc
	dw TeruSama31Desc
	dw TeruSama32Desc
	dw TeruSama33Desc

MasterBallDesc:
	db "The best BALL. It",$4E
	db "never misses.@"

UltraBallDesc:
	db "A BALL with a high",$4E
	db "rate of success.@"

BrightpowderDesc:
	db "Lowers the foe's",$4E
	db "accuracy. (HOLD)@"

GreatBallDesc:
	db "A BALL with a de-",$4E
	db "cent success rate.@"

PokeBallDesc:
	db "An item for catch-",$4E
	db "ing #MON.@"

TeruSama1Desc:
	db "?@"

BicycleDesc:
	db "A collapsible bike",$4E
	db "for fast movement.@"

MoonStoneDesc:
	db "Evolves certain",$4E
	db "kinds of #MON.@"

AntidoteDesc:
	db "Cures poisoned",$4E
	db "#MON.@"

BurnHealDesc:
	db "Heals burned",$4E
	db "#MON.@"

IceHealDesc:
	db "Defrosts frozen",$4E
	db "#MON.@"

AwakeningDesc:
	db "Awakens sleeping",$4E
	db "#MON.@"

ParlyzHealDesc:
	db "Heals paralyzed",$4E
	db "#MON.@"

FullRestoreDesc:
	db "Fully restores HP",$4E
	db "& status.@"

MaxPotionDesc:
	db "Fully restores",$4E
	db "#MON HP.@"

HyperPotionDesc:
	db "Restores #MON",$4E
	db "HP by 200.@"

SuperPotionDesc:
	db "Restores #MON",$4E
	db "HP by 50.@"

PotionDesc:
	db "Restores #MON",$4E
	db "HP by 20.@"

EscapeRopeDesc:
	db "Use for escaping",$4E
	db "from caves, etc.@"

RepelDesc:
	db "Repels weak #-",$4E
	db "MON for 100 steps.@"

MaxElixerDesc:
	db "Fully restores the",$4E
	db "PP of one #MON.@"

FireStoneDesc:
	db "Evolves certain",$4E
	db "kinds of #MON.@"

ThunderStoneDesc:
	db "Evolves certain",$4E
	db "kinds of #MON.@"

WaterStoneDesc:
	db "Evolves certain",$4E
	db "kinds of #MON.@"

TeruSama2Desc:
	db "?@"

HPUpDesc:
	db "Raises the HP of",$4E
	db "one #MON.@"

ProteinDesc:
	db "Raises ATTACK of",$4E
	db "one #MON.@"

IronDesc:
	db "Raises DEFENSE of",$4E
	db "one #MON.@"

CarbosDesc:
	db "Raises SPEED of",$4E
	db "one #MON.@"

LuckyPunchDesc:
	db "Ups critical hit",$4E
	db "ratio of CHANSEY.@"

CalciumDesc:
	db "Ups SPECIAL stats",$4E
	db "of one #MON.@"

RareCandyDesc:
	db "Raises level of a",$4E
	db "#MON by one.@"

XAccuracyDesc:
	db "Raises accuracy.",$4E
	db "(1 BTL)@"

LeafStoneDesc:
	db "Evolves certain",$4E
	db "kinds of #MON.@"

MetalPowderDesc:
	db "Raises DEFENSE of",$4E
	db "DITTO. (HOLD)@"

NuggetDesc:
	db "Made of pure gold.",$4E
	db "Sell high.@"

PokeDollDesc:
	db "Use to escape from",$4E
	db "a wild #MON.@"

FullHealDesc:
	db "Eliminates all",$4E
	db "status problems.@"

ReviveDesc:
	db "Restores a fainted",$4E
	db "#MON to 1/2 HP.@"

MaxReviveDesc:
	db "Fully restores a",$4E
	db "fainted #MON.@"

GuardSpecDesc:
	db "Prevents stats",$4E
	db "reduction. (1 BTL)@"

SuperRepelDesc:
	db "Repels weak #-",$4E
	db "MON for 200 steps.@"

MaxRepelDesc:
	db "Repels weak #-",$4E
	db "MON for 250 steps.@"

DireHitDesc:
	db "Ups critical hit",$4E
	db "ratio. (1 BTL)@"

TeruSama3Desc:
	db "?@"

FreshWaterDesc:
	db "Restores #MON",$4E
	db "HP by 50.@"

SodaPopDesc:
	db "Restores #MON",$4E
	db "HP by 60.@"

LemonadeDesc:
	db "Restores #MON",$4E
	db "HP by 80.@"

XAttackDesc:
	db "Raises ATTACK.",$4E
	db "(1 BTL)@"

TeruSama4Desc:
	db "?@"

XDefendDesc:
	db "Raises DEFENSE.",$4E
	db "(1 BTL)@"

XSpeedDesc:
	db "Raises SPEED.",$4E
	db "(1 BTL)@"

XSpecialDesc:
	db "Raises SPECIAL",$4E
	db "ATTACK. (1 BTL)@"

CoinCaseDesc:
	db "Holds up to 9,999",$4E
	db "game coins.@"

ItemfinderDesc:
	db "Checks for unseen",$4E
	db "items in the area.@"

TeruSama5Desc:
	db "?@"

ExpShareDesc:
	db "Shares battle EXP.",$4E
	db "Points. (HOLD)@"

OldRodDesc:
	db "Use by water to",$4E
	db "fish for #MON.@"

GoodRodDesc:
	db "A good ROD for",$4E
	db "catching #MON.@"

SilverLeafDesc:
	db "A strange, silver-",$4E
	db "colored leaf.@"

SuperRodDesc:
	db "The best ROD for",$4E
	db "catching #MON.@"

PPUpDesc:
	db "Raises max PP of",$4E
	db "a selected move.@"

EtherDesc:
	db "Restores PP of one",$4E
	db "move by 10.@"

MaxEtherDesc:
	db "Fully restores PP",$4E
	db "of one move.@"

ElixerDesc:
	db "Restores PP of all",$4E
	db "moves by 10.@"

RedScaleDesc:
	db "A scale from the",$4E
	db "red GYARADOS.@"

SecretPotionDesc:
	db "Fully heals any",$4E
	db "#MON.@"

SSTicketDesc:
	db "A ticket for the",$4E
	db "S.S.AQUA.@"

MysteryEggDesc:
	db "An EGG obtained",$4E
	db "from MR.#MON.@"

ClearBellDesc:
	db "Makes a gentle",$4E
	db "ringing.@"

SilverWingDesc:
	db "A strange, silver-",$4E
	db "colored feather.@"

MoomooMilkDesc:
	db "Restores #MON",$4E
	db "HP by 100.@"

QuickClawDesc:
	db "Raises 1st strike",$4E
	db "ratio. (HOLD)@"

PsnCureBerryDesc:
	db "A self-cure for",$4E
	db "poison. (HOLD)@"

GoldLeafDesc:
	db "A strange, gold-",$4E
	db "colored leaf.@"

SoftSandDesc:
	db "Powers up ground-",$4E
	db "type moves. (HOLD)@"

SharpBeakDesc:
	db "Powers up flying-",$4E
	db "type moves. (HOLD)@"

PrzCureBerryDesc:
	db "A self-cure for",$4E
	db "paralysis. (HOLD)@"

BurntBerryDesc:
	db "A self-cure for",$4E
	db "freezing. (HOLD)@"

IceBerryDesc:
	db "A self-heal for a",$4E
	db "burn. (HOLD)@"

PoisonBarbDesc:
	db "Powers up poison-",$4E
	db "type moves. (HOLD)@"

KingsRockDesc:
	db "May make the foe",$4E
	db "flinch. (HOLD)@"

BitterBerryDesc:
	db "A self-cure for",$4E
	db "confusion. (HOLD)@"

MintBerryDesc:
	db "A self-awakening",$4E
	db "for sleep. (HOLD)@"

RedApricornDesc:
	db "A red APRICORN.@"

TinyMushroomDesc:
	db "An ordinary mush-",$4E
	db "room. Sell low.@"

BigMushroomDesc:
	db "A rare mushroom.",$4E
	db "Sell high.@"

SilverPowderDesc:
	db "Powers up bug-type",$4E
	db "moves. (HOLD)@"

BluApricornDesc:
	db "A blue APRICORN.@"

TeruSama6Desc:
	db "?@"

AmuletCoinDesc:
	db "Doubles monetary",$4E
	db "earnings. (HOLD)@"

YlwApricornDesc:
	db "A yellow APRICORN.@"

GrnApricornDesc:
	db "A green APRICORN.@"

CleanseTagDesc:
	db "Helps repel wild",$4E
	db "#MON. (HOLD)@"

MysticWaterDesc:
	db "Powers up water-",$4E
	db "type moves. (HOLD)@"

TwistedSpoonDesc:
	db "Powers up psychic-",$4E
	db "type moves. (HOLD)@"

WhtApricornDesc:
	db "A white APRICORN.@"

BlackbeltDesc:
	db "Boosts fighting-",$4E
	db "type moves. (HOLD)@"

BlkApricornDesc:
	db "A black APRICORN.",$4E
	db "@"

TeruSama7Desc:
	db "?@"

PnkApricornDesc:
	db "A pink APRICORN.",$4E
	db "@"

BlackGlassesDesc:
	db "Powers up dark-",$4E
	db "type moves. (HOLD)@"

SlowpokeTailDesc:
	db "Very tasty. Sell",$4E
	db "high.@"

PinkBowDesc:
	db "Powers up normal-",$4E
	db "type moves. (HOLD)@"

StickDesc:
	db "An ordinary stick.",$4E
	db "Sell low.@"

SmokeBallDesc:
	db "Escape from wild",$4E
	db "#MON. (HOLD)@"

NeverMeltIceDesc:
	db "Powers up ice-type",$4E
	db "moves. (HOLD)@"

MagnetDesc:
	db "Boosts electric-",$4E
	db "type moves. (HOLD)@"

MiracleBerryDesc:
	db "Cures all status",$4E
	db "problems. (HOLD)@"

PearlDesc:
	db "A beautiful pearl.",$4E
	db "Sell low.@"

BigPearlDesc:
	db "A big, beautiful",$4E
	db "pearl. Sell high.@"

EverStoneDesc:
	db "Stops evolution.",$4E
	db "(HOLD)@"

SpellTagDesc:
	db "Powers up ghost-",$4E
	db "type moves. (HOLD)@"

RageCandyBarDesc:
	db "Restores #MON",$4E
	db "HP by 20.@"

GSBallDesc:
	db "The mysterious",$4E
	db "BALL.@"

BlueCardDesc:
	db "Card to save",$4E
	db "points.@"

MiracleSeedDesc:
	db "Powers up grass-",$4E
	db "type moves. (HOLD)@"

ThickClubDesc:
	db "A bone of some",$4E
	db "sort. Sell low.@"

FocusBandDesc:
	db "May prevent faint-",$4E
	db "ing. (HOLD)@"

TeruSama8Desc:
	db "?@"

EnergyPowderDesc:
	db "Restores #MON",$4E
	db "HP by 50. Bitter.@"

EnergyRootDesc:
	db "Restores #MON",$4E
	db "HP by 200. Bitter.@"

HealPowderDesc:
	db "Cures all status",$4E
	db "problems. Bitter.@"

RevivalHerbDesc:
	db "Revives fainted",$4E
	db "#MON. Bitter.@"

HardStoneDesc:
	db "Powers up rock-",$4E
	db "type moves. (HOLD)@"

LuckyEggDesc:
	db "Earns extra EXP.",$4E
	db "points. (HOLD)@"

CardKeyDesc:
	db "Opens shutters in",$4E
	db "the RADIO TOWER.@"

MachinePartDesc:
	db "A machine part for",$4E
	db "the POWER PLANT.@"

EggTicketDesc:
	db "May use at Golden-",$4E
	db "rod trade corner.@"

LostItemDesc:
	db "The # DOLL lost",$4E
	db "by the COPYCAT.@"

StardustDesc:
	db "Pretty, red sand.",$4E
	db "Sell high.@"

StarPieceDesc:
	db "A hunk of red gem.",$4E
	db "Sell very high.@"

BasementKeyDesc:
	db "Opens doors.@"

PassDesc:
	db "A ticket for the",$4E
	db "MAGNET TRAIN.@"

TeruSama9Desc:
	db "?@"

TeruSama10Desc:
	db "?@"

TeruSama11Desc:
	db "?@"

CharcoalDesc:
	db "Powers up fire-",$4E
	db "type moves. (HOLD)@"

BerryJuiceDesc:
	db "Restores #MON",$4E
	db "HP by 20.@"

ScopeLensDesc:
	db "Raises critical",$4E
	db "hit ratio. (HOLD)@"

TeruSama12Desc:
	db "?@"

TeruSama13Desc:
	db "?@"

MetalCoatDesc:
	db "Powers up steel-",$4E
	db "type moves. (HOLD)@"

DragonFangDesc:
	db "Powers up dragon-",$4E
	db "type moves. (HOLD)@"

TeruSama14Desc:
	db "?@"

LeftoversDesc:
	db "Restores HP during",$4E
	db "battle. (HOLD)@"

TeruSama15Desc:
	db "?@"

TeruSama16Desc:
	db "?@"

TeruSama17Desc:
	db "?@"

MysteryBerryDesc:
	db "A self-restore",$4E
	db "for PP. (HOLD)@"

DragonScaleDesc:
	db "A rare dragon-type",$4E
	db "item.@"

BerserkGeneDesc:
	db "Boosts ATTACK but",$4E
	db "causes confusion.@"

TeruSama18Desc:
	db "?@"

TeruSama19Desc:
	db "?@"

TeruSama20Desc:
	db "?@"

SacredAshDesc:
	db "Fully revives all",$4E
	db "fainted #MON.@"

HeavyBallDesc:
	db "A BALL for catch-",$4E
	db "ing heavy #MON.@"

FlowerMailDesc:
	db "Flower-print MAIL.",$4E
	db "(HOLD)@"

LevelBallDesc:
	db "A BALL for lower-",$4E
	db "level #MON.@"

LureBallDesc:
	db "A BALL for #MON",$4E
	db "hooked by a ROD.@"

FastBallDesc:
	db "A BALL for catch-",$4E
	db "ing fast #MON.@"

TeruSama21Desc:
	db "?@"

LightBallDesc:
	db "An odd, electrical",$4E
	db "orb. (HOLD)@"

FriendBallDesc:
	db "A BALL that makes",$4E
	db "#MON friendly.@"

MoonBallDesc:
	db "A BALL for MOON",$4E
	db "STONE evolvers.@"

LoveBallDesc:
	db "For catching the",$4E
	db "opposite gender.@"

NormalBoxDesc:
	db "Open it and see",$4E
	db "what's inside.@"

GorgeousBoxDesc:
	db "Open it and see",$4E
	db "what's inside.@"

SunStoneDesc:
	db "Evolves certain",$4E
	db "kinds of #MON.@"

PolkadotBowDesc:
	db "Powers up normal-",$4E
	db "type moves. (HOLD)@"

TeruSama22Desc:
	db "?@"

UpGradeDesc:
	db "A mysterious box",$4E
	db "made by SILPH CO.@"

BerryDesc:
	db "A self-restore",$4E
	db "item. (10HP, HOLD)@"

GoldBerryDesc:
	db "A self-restore",$4E
	db "item. (30HP, HOLD)@"

SquirtBottleDesc:
	db "A bottle used for",$4E
	db "watering plants.@"

TeruSama23Desc:
	db "?@"

ParkBallDesc:
	db "The Bug-Catching",$4E
	db "Contest BALL.@"

RainbowWingDesc:
	db "A mystical feather",$4E
	db "of rainbow colors.@"

TeruSama24Desc:
	db "?@"

BrickPieceDesc:
	db "A rare chunk of",$4E
	db "tile.@"

SurfMailDesc:
	db "LAPRAS-print MAIL.",$4E
	db "(HOLD)@"

LiteBlueMailDesc:
	db "DRATINI-print",$4E
	db "MAIL. (HOLD)@"

PortraitMailDesc:
	db "MAIL featuring the",$4E
	db "holder's likeness.@"

LovelyMailDesc:
	db "Heart-print MAIL.",$4E
	db "(HOLD)@"

EonMailDesc:
	db "EEVEE-print MAIL.",$4E
	db "(HOLD)@"

MorphMailDesc:
	db "DITTO-print MAIL.",$4E
	db "(HOLD)@"

BlueSkyMailDesc:
	db "Sky-print MAIL.",$4E
	db "(HOLD)@"

MusicMailDesc:
	db "NATU-print MAIL.",$4E
	db "(HOLD)@"

MewMailDesc:
	db "MEW-print MAIL.",$4E
	db "(HOLD)@"

TeruSama25Desc:
	db "?@"

TeruSama26Desc:
	db "?@"

TeruSama27Desc:
	db "?@"

TeruSama28Desc:
	db "?@"

TeruSama29Desc:
	db "?@"

TeruSama30Desc:
	db "?@"

TeruSama31Desc:
	db "?@"

TeruSama32Desc:
	db "?@"

TeruSama33Desc:
	db "?@"

MoveNames:
	db "POUND@"
	db "KARATE CHOP@"
	db "DOUBLESLAP@"
	db "COMET PUNCH@"
	db "MEGA PUNCH@"
	db "PAY DAY@"
	db "FIRE PUNCH@"
	db "ICE PUNCH@"
	db "THUNDERPUNCH@"
	db "SCRATCH@"
	db "VICEGRIP@"
	db "GUILLOTINE@"
	db "RAZOR WIND@"
	db "SWORDS DANCE@"
	db "CUT@"
	db "GUST@"
	db "WING ATTACK@"
	db "WHIRLWIND@"
	db "FLY@"
	db "BIND@"
	db "SLAM@"
	db "VINE WHIP@"
	db "STOMP@"
	db "DOUBLE KICK@"
	db "MEGA KICK@"
	db "JUMP KICK@"
	db "ROLLING KICK@"
	db "SAND-ATTACK@"
	db "HEADBUTT@"
	db "HORN ATTACK@"
	db "FURY ATTACK@"
	db "HORN DRILL@"
	db "TACKLE@"
	db "BODY SLAM@"
	db "WRAP@"
	db "TAKE DOWN@"
	db "THRASH@"
	db "DOUBLE-EDGE@"
	db "TAIL WHIP@"
	db "POISON STING@"
	db "TWINEEDLE@"
	db "PIN MISSILE@"
	db "LEER@"
	db "BITE@"
	db "GROWL@"
	db "ROAR@"
	db "SING@"
	db "SUPERSONIC@"
	db "SONICBOOM@"
	db "DISABLE@"
	db "ACID@"
	db "EMBER@"
	db "FLAMETHROWER@"
	db "MIST@"
	db "WATER GUN@"
	db "HYDRO PUMP@"
	db "SURF@"
	db "ICE BEAM@"
	db "BLIZZARD@"
	db "PSYBEAM@"
	db "BUBBLEBEAM@"
	db "AURORA BEAM@"
	db "HYPER BEAM@"
	db "PECK@"
	db "DRILL PECK@"
	db "SUBMISSION@"
	db "LOW KICK@"
	db "COUNTER@"
	db "SEISMIC TOSS@"
	db "STRENGTH@"
	db "ABSORB@"
	db "MEGA DRAIN@"
	db "LEECH SEED@"
	db "GROWTH@"
	db "RAZOR LEAF@"
	db "SOLARBEAM@"
	db "POISONPOWDER@"
	db "STUN SPORE@"
	db "SLEEP POWDER@"
	db "PETAL DANCE@"
	db "STRING SHOT@"
	db "DRAGON RAGE@"
	db "FIRE SPIN@"
	db "THUNDERSHOCK@"
	db "THUNDERBOLT@"
	db "THUNDER WAVE@"
	db "THUNDER@"
	db "ROCK THROW@"
	db "EARTHQUAKE@"
	db "FISSURE@"
	db "DIG@"
	db "TOXIC@"
	db "CONFUSION@"
	db "PSYCHIC@"
	db "HYPNOSIS@"
	db "MEDITATE@"
	db "AGILITY@"
	db "QUICK ATTACK@"
	db "RAGE@"
	db "TELEPORT@"
	db "NIGHT SHADE@"
	db "MIMIC@"
	db "SCREECH@"
	db "DOUBLE TEAM@"
	db "RECOVER@"
	db "HARDEN@"
	db "MINIMIZE@"
	db "SMOKESCREEN@"
	db "CONFUSE RAY@"
	db "WITHDRAW@"
	db "DEFENSE CURL@"
	db "BARRIER@"
	db "LIGHT SCREEN@"
	db "HAZE@"
	db "REFLECT@"
	db "FOCUS ENERGY@"
	db "BIDE@"
	db "METRONOME@"
	db "MIRROR MOVE@"
	db "SELFDESTRUCT@"
	db "EGG BOMB@"
	db "LICK@"
	db "SMOG@"
	db "SLUDGE@"
	db "BONE CLUB@"
	db "FIRE BLAST@"
	db "WATERFALL@"
	db "CLAMP@"
	db "SWIFT@"
	db "SKULL BASH@"
	db "SPIKE CANNON@"
	db "CONSTRICT@"
	db "AMNESIA@"
	db "KINESIS@"
	db "SOFTBOILED@"
	db "HI JUMP KICK@"
	db "GLARE@"
	db "DREAM EATER@"
	db "POISON GAS@"
	db "BARRAGE@"
	db "LEECH LIFE@"
	db "LOVELY KISS@"
	db "SKY ATTACK@"
	db "TRANSFORM@"
	db "BUBBLE@"
	db "DIZZY PUNCH@"
	db "SPORE@"
	db "FLASH@"
	db "PSYWAVE@"
	db "SPLASH@"
	db "ACID ARMOR@"
	db "CRABHAMMER@"
	db "EXPLOSION@"
	db "FURY SWIPES@"
	db "BONEMERANG@"
	db "REST@"
	db "ROCK SLIDE@"
	db "HYPER FANG@"
	db "SHARPEN@"
	db "CONVERSION@"
	db "TRI ATTACK@"
	db "SUPER FANG@"
	db "SLASH@"
	db "SUBSTITUTE@"
	db "STRUGGLE@"
	db "SKETCH@"
	db "TRIPLE KICK@"
	db "THIEF@"
	db "SPIDER WEB@"
	db "MIND READER@"
	db "NIGHTMARE@"
	db "FLAME WHEEL@"
	db "SNORE@"
	db "CURSE@"
	db "FLAIL@"
	db "CONVERSION2@"
	db "AEROBLAST@"
	db "COTTON SPORE@"
	db "REVERSAL@"
	db "SPITE@"
	db "POWDER SNOW@"
	db "PROTECT@"
	db "MACH PUNCH@"
	db "SCARY FACE@"
	db "FAINT ATTACK@"
	db "SWEET KISS@"
	db "BELLY DRUM@"
	db "SLUDGE BOMB@"
	db "MUD-SLAP@"
	db "OCTAZOOKA@"
	db "SPIKES@"
	db "ZAP CANNON@"
	db "FORESIGHT@"
	db "DESTINY BOND@"
	db "PERISH SONG@"
	db "ICY WIND@"
	db "DETECT@"
	db "BONE RUSH@"
	db "LOCK-ON@"
	db "OUTRAGE@"
	db "SANDSTORM@"
	db "GIGA DRAIN@"
	db "ENDURE@"
	db "CHARM@"
	db "ROLLOUT@"
	db "FALSE SWIPE@"
	db "SWAGGER@"
	db "MILK DRINK@"
	db "SPARK@"
	db "FURY CUTTER@"
	db "STEEL WING@"
	db "MEAN LOOK@"
	db "ATTRACT@"
	db "SLEEP TALK@"
	db "HEAL BELL@"
	db "RETURN@"
	db "PRESENT@"
	db "FRUSTRATION@"
	db "SAFEGUARD@"
	db "PAIN SPLIT@"
	db "SACRED FIRE@"
	db "MAGNITUDE@"
	db "DYNAMICPUNCH@"
	db "MEGAHORN@"
	db "DRAGONBREATH@"
	db "BATON PASS@"
	db "ENCORE@"
	db "PURSUIT@"
	db "RAPID SPIN@"
	db "SWEET SCENT@"
	db "IRON TAIL@"
	db "METAL CLAW@"
	db "VITAL THROW@"
	db "MORNING SUN@"
	db "SYNTHESIS@"
	db "MOONLIGHT@"
	db "HIDDEN POWER@"
	db "CROSS CHOP@"
	db "TWISTER@"
	db "RAIN DANCE@"
	db "SUNNY DAY@"
	db "CRUNCH@"
	db "MIRROR COAT@"
	db "PSYCH UP@"
	db "EXTREMESPEED@"
	db "ANCIENTPOWER@"
	db "SHADOW BALL@"
	db "FUTURE SIGHT@"
	db "ROCK SMASH@"
	db "WHIRLPOOL@"
	db "BEAT UP@"

GetLandmarkCoords: ; 0x1ca896
; given a landmark id in e, return the y coord in d, and the x coord in e.
	push hl
	ld l, e
	ld h, $0
	add hl, hl
	add hl, hl
	ld de, Landmarks
	add hl, de
	ld a, [hli]
	ld e, a
	ld d, [hl]
	pop hl
	ret


GetLandmarkName: ; 0x1ca8a5
; given a landmark id in e, copy its name to $d073.
	push hl
	push de
	push bc
	ld l, e
	ld h, $0
	add hl, hl
	add hl, hl
	ld de, Landmarks + 2 ; skip the coordinates, we only want the string
	add hl, de
	ld a, [hli]
	ld h, [hl]
	ld l, a
	ld de, $d073
	ld c, 18
.loop
	ld a, [hli]
	ld [de], a
	inc de
	dec c
	jr nz, .loop
	pop bc
	pop de
	pop hl
	ret

Landmarks: ; 0x1ca8c3
;db x coord, y coord
;dw pointer to name 
	db 0,0
	dw SpecialMapString

	db 148,116
	dw NewBarkString

	db 136,116
	dw Route29String

	db 108,116
	dw CherrygroveString

	db 108,96
	dw Route30String

	db 104,76
	dw Route31String

	db 92,76
	dw VioletString

	db 93,74
	dw SproutString

	db 92,108
	dw Route32String

	db 84,92
	dw RuinsString

	db 92,140
	dw UnionString

	db 90,140
	dw Route33String

	db 76,140
	dw AzaleaString

	db 78,138
	dw WellString

	db 60,136
	dw IlexString

	db 60,128
	dw Route34String

	db 60,108
	dw GoldenrodString

	db 58,108
	dw RadioTowerString

	db 60,92
	dw Route35String

	db 60,76
	dw ParkString

	db 72,76
	dw Route36String

	db 76,68
	dw Route37String

	db 76,60
	dw EcruteakString

	db 78,58
	dw TinString

	db 74,58
	dw BurnedTowerString

	db 60,60
	dw Route38String

	db 44,64
	dw Route39String

	db 44,76
	dw OlivineString

	db 46,78
	dw LighthouseString

	db 36,72
	dw BattleTowerString

	db 36,80
	dw Route40String

	db 36,108
	dw WhirlString

	db 36,116
	dw Route41String

	db 28,116
	dw CianwoodString

	db 100,60
	dw Route42String

	db 92,60
	dw MortarString

	db 116,60
	dw MahoganyString

	db 116,52
	dw Route43String

	db 116,44
	dw LakeString

	db 128,60
	dw Route44String

	db 138,54
	dw PathString

	db 140,60
	dw BlackthornString

	db 140,52
	dw DenString

	db 140,80
	dw Route45String

	db 120,88
	dw DarkString

	db 132,104
	dw Route46String

	db 156,84
	dw SilverCaveString

	db 60,124
	dw PalletString

	db 60,108
	dw Route1String

	db 60,92
	dw ViridianString

	db 60,80
	dw Route2String

	db 60,68
	dw PewterString

	db 72,68
	dw Route3String

	db 84,68
	dw MoonString

	db 96,68
	dw Route4String

	db 108,68
	dw CeruleanString

	db 108,60
	dw Route24String

	db 116,52
	dw Route25String

	db 108,76
	dw Route5String

	db 116,92
	dw UndergroundString

	db 108,92
	dw Route6String

	db 108,100
	dw VermilionString

	db 96,76
	dw DiglettsCaveString

	db 96,84
	dw Route7String

	db 124,84
	dw Route8String

	db 124,68
	dw Route9String

	db 140,68
	dw TunnelString

	db 140,72
	dw Route10String

	db 140,76
	dw PlantString

	db 140,84
	dw LavenderString

	db 148,84
	dw LavTowerString

	db 84,84
	dw CeladonString

	db 108,84
	dw SaffronString

	db 124,100
	dw Route11String

	db 140,96
	dw Route12String

	db 132,116
	dw Route13String

	db 124,128
	dw Route14String

	db 112,132
	dw Route15String

	db 76,84
	dw Route16String

	db 76,108
	dw Route17String

	db 88,132
	dw Route18String

	db 100,132
	dw FuchsiaString

	db 100,144
	dw Route19String

	db 84,148
	dw Route20String

	db 76,148
	dw SeafoamString

	db 60,148
	dw CinnabarString

	db 60,136
	dw Route21String

	db 44,84
	dw Route22String

	db 36,68
	dw RoadString

	db 36,60
	dw Route23String

	db 36,52
	dw IndigoString

	db 36,108
	dw Route26String

	db 28,116
	dw Route27String

	db 20,116
	dw FallsString

	db 28,84
	dw Route28String

	db 148,132
	dw AquaString

NewBarkString:
	db "NEW BARK",$1F,"TOWN@"
CherrygroveString:
	db "CHERRYGROVE",$1F,"CITY@"
VioletString:
	db "VIOLET CITY@"
AzaleaString:
	db "AZALEA TOWN@"
GoldenrodString:
	db "GOLDENROD",$1F,"CITY@"
EcruteakString:
	db "ECRUTEAK",$1F,"CITY@"
OlivineString:
	db "OLIVINE",$1F,"CITY@"
CianwoodString:
	db "CIANWOOD",$1F,"CITY@"
MahoganyString:
	db "MAHOGANY",$1F,"TOWN@"
BlackthornString:
	db "BLACKTHORN",$1F,"CITY@"
LakeString:
	db "LAKE OF",$1F,"RAGE@"
SilverCaveString:
	db "SILVER CAVE@"
SproutString:
	db "SPROUT",$1F,"TOWER@"
RuinsString:
	db "RUINS",$1F,"OF ALPH@"
UnionString:
	db "UNION CAVE@"
WellString:
	db "SLOWPOKE",$1F,"WELL@"
RadioTowerString:
	db "RADIO TOWER@"
PlantString:
	db "POWER PLANT@"
ParkString:
	db "NATIONAL",$1F,"PARK@"
TinString:
	db "TIN TOWER@"
LighthouseString:
	db "LIGHTHOUSE@"
WhirlString:
	db "WHIRL",$1F,"ISLANDS@"
MortarString:
	db "MT.MORTAR@"
DenString:
	db "DRAGON'S",$1F,"DEN@"
PathString:
	db "ICE PATH@"
NotApplicableString:
	db "N/A@"
PalletString:
	db "PALLET TOWN@"
ViridianString:
	db "VIRIDIAN",$1F,"CITY@"
PewterString:
	db "PEWTER CITY@"
CeruleanString:
	db "CERULEAN",$1F,"CITY@"
LavenderString:
	db "LAVENDER",$1F,"TOWN@"
VermilionString:
	db "VERMILION",$1F,"CITY@"
CeladonString:
	db "CELADON",$1F,"CITY@"
SaffronString:
	db "SAFFRON",$1F,"CITY@"
FuchsiaString:
	db "FUCHSIA",$1F,"CITY@"
CinnabarString:
	db "CINNABAR",$1F,"ISLAND@"
IndigoString:
	db "INDIGO",$1F,"PLATEAU@"
RoadString:
	db "VICTORY",$1F,"ROAD@"
MoonString:
	db "MT.MOON@"
TunnelString:
	db "ROCK TUNNEL@"
LavTowerString:
	db "LAV",$1F,"RADIO TOWER@"
SilphString:
	db "SILPH CO.@"
ZoneString:
	db "SAFARI ZONE@"
SeafoamString:
	db "SEAFOAM",$1F,"ISLANDS@"
MansionString:
	db "#MON",$1F,"MANSION@"
DungeonString:
	db "CERULEAN",$1F,"CAVE@"
Route1String:
	db "ROUTE 1@"
Route2String:
	db "ROUTE 2@"
Route3String:
	db "ROUTE 3@"
Route4String:
	db "ROUTE 4@"
Route5String:
	db "ROUTE 5@"
Route6String:
	db "ROUTE 6@"
Route7String:
	db "ROUTE 7@"
Route8String:
	db "ROUTE 8@"
Route9String:
	db "ROUTE 9@"
Route10String:
	db "ROUTE 10@"
Route11String:
	db "ROUTE 11@"
Route12String:
	db "ROUTE 12@"
Route13String:
	db "ROUTE 13@"
Route14String:
	db "ROUTE 14@"
Route15String:
	db "ROUTE 15@"
Route16String:
	db "ROUTE 16@"
Route17String:
	db "ROUTE 17@"
Route18String:
	db "ROUTE 18@"
Route19String:
	db "ROUTE 19@"
Route20String:
	db "ROUTE 20@"
Route21String:
	db "ROUTE 21@"
Route22String:
	db "ROUTE 22@"
Route23String:
	db "ROUTE 23@"
Route24String:
	db "ROUTE 24@"
Route25String:
	db "ROUTE 25@"
Route26String:
	db "ROUTE 26@"
Route27String:
	db "ROUTE 27@"
Route28String:
	db "ROUTE 28@"
Route29String:
	db "ROUTE 29@"
Route30String:
	db "ROUTE 30@"
Route31String:
	db "ROUTE 31@"
Route32String:
	db "ROUTE 32@"
Route33String:
	db "ROUTE 33@"
Route34String:
	db "ROUTE 34@"
Route35String:
	db "ROUTE 35@"
Route36String:
	db "ROUTE 36@"
Route37String:
	db "ROUTE 37@"
Route38String:
	db "ROUTE 38@"
Route39String:
	db "ROUTE 39@"
Route40String:
	db "ROUTE 40@"
Route41String:
	db "ROUTE 41@"
Route42String:
	db "ROUTE 42@"
Route43String:
	db "ROUTE 43@"
Route44String:
	db "ROUTE 44@"
Route45String:
	db "ROUTE 45@"
Route46String:
	db "ROUTE 46@"
DarkString:
	db "DARK CAVE@"
IlexString:
	db "ILEX",$1F,"FOREST@"
BurnedTowerString:
	db "BURNED",$1F,"TOWER@"
AquaString:
	db "FAST SHIP@"
ViridianForestString:
	db "VIRIDIAN",$1F,"FOREST@"
DiglettsCaveString:
	db "DIGLETT'S",$1F,"CAVE@"
FallsString:
	db "TOHJO FALLS@"
UndergroundString:
	db "UNDERGROUND@"
BattleTowerString:
	db "BATTLE",$1F,"TOWER@"
SpecialMapString:
	db "SPECIAL@"

RegionCheck: ; 0x1caea1
; Checks if the player is in Kanto or Johto.
; If in Johto, returns 0 in e.
; If in Kanto, returns 1 in e.
	ld a, [MapGroup]
	ld b, a
	ld a, [MapNumber]
	ld c, a
	call GetWorldMapLocation
	cp $5f ; on S.S. Aqua
	jr z, .johto
	cp $0 ; special
	jr nz, .checkagain

; If in map $00, load map group / map id from backup locations
	ld a, [BackupMapGroup]
	ld b, a
	ld a, [BackupMapNumber]
	ld c, a
	call GetWorldMapLocation
.checkagain
	cp $2f ; Pallet Town
	jr c, .johto
	cp $58 ; Victory Road
	jr c, .kanto
.johto
	ld e, 0
	ret
.kanto
	ld e, 1
	ret

SECTION "bank73",DATA,BANK[$73]

MagikarpPokedexEntry: ; 0x1cc000
	db "FISH@" ; species name
	dw 211, 220; height, width
	
	db "This weak and", $4e, "pathetic #MON", $4e, "gets easily pushed@"
	db "along rivers when", $4e, "there are strong", $4e, "currents.@"
; 0x1cc065

GyaradosPokedexEntry: ; 0x1cc065
	db "ATROCIOUS@" ; species name
	dw 2104, 5180; height, width
	
	db "It appears when-", $4e, "ever there is", $4e, "world conflict,@"
	db "burning down any", $4e, "place it travels", $4e, "through.@"
; 0x1cc0cd

LaprasPokedexEntry: ; 0x1cc0cd
	db "TRANSPORT@" ; species name
	dw 802, 4850; height, width
	
	db "This gentle", $4e, "#MON loves to", $4e, "give people rides@"
	db "and provides a ve-", $4e, "ry comfortable way", $4e, "to get around.@"
; 0x1cc13c

DittoPokedexEntry: ; 0x1cc13c
	db "TRANSFORM@" ; species name
	dw 100, 90; height, width
	
	db "When it encount-", $4e, "ers another DITTO,", $4e, "it will move@"
	db "faster than normal", $4e, "to duplicate that", $4e, "opponent exactly.@"
; 0x1cc1b2

EeveePokedexEntry: ; 0x1cc1b2
	db "EVOLUTION@" ; species name
	dw 100, 140; height, width
	
	db "Its ability to", $4e, "evolve into many", $4e, "forms allows it to@"
	db "adapt smoothly", $4e, "and perfectly to", $4e, "any environment.@"
; 0x1cc224

VaporeonPokedexEntry: ; 0x1cc224
	db "BUBBLE JET@" ; species name
	dw 303, 640; height, width
	
	db "As it uses the", $4e, "fins on the tip", $4e, "of its tail to@"
	db "swim, it blends", $4e, "with the water", $4e, "perfectly.@"
; 0x1cc28b

JolteonPokedexEntry: ; 0x1cc28b
	db "LIGHTNING@" ; species name
	dw 207, 540; height, width
	
	db "The negatively", $4e, "charged ions", $4e, "generated in its@"
	db "fur create a", $4e, "constant sparking", $4e, "noise.@"
; 0x1cc2ec

FlareonPokedexEntry: ; 0x1cc2ec
	db "FLAME@" ; species name
	dw 211, 550; height, width
	
	db "Once it has stored", $4e, "up enough heat,", $4e, "this #MON's@"
	db "body temperature", $4e, "can reach up to", $4e, "1700 degrees.@"
; 0x1cc353

PorygonPokedexEntry: ; 0x1cc353
	db "VIRTUAL@" ; species name
	dw 207, 800; height, width
	
	db "An artificial", $4e, "#MON created", $4e, "due to extensive@"
	db "research, it can", $4e, "perform only what", $4e, "is in its program.@"
; 0x1cc3c1

OmanytePokedexEntry: ; 0x1cc3c1
	db "SPIRAL@" ; species name
	dw 104, 170; height, width
	
	db "In prehistoric", $4e, "times, it swam on", $4e, "the sea floor,@"
	db "eating plankton.", $4e, "Its fossils are", $4e, "sometimes found.@"
; 0x1cc42e

OmastarPokedexEntry: ; 0x1cc42e
	db "SPIRAL@" ; species name
	dw 303, 770; height, width
	
	db "Its heavy shell", $4e, "allowed it to", $4e, "reach only nearby@"
	db "food. This could", $4e, "be the reason it", $4e, "is extinct.@"
; 0x1cc497

KabutoPokedexEntry: ; 0x1cc497
	db "SHELLFISH@" ; species name
	dw 108, 250; height, width
	
	db "Three hundred", $4e, "million years ago,", $4e, "it hid on the sea@"
	db "floor. It also has", $4e, "eyes on its back", $4e, "that glow.@"
; 0x1cc507

KabutopsPokedexEntry: ; 0x1cc507
	db "SHELLFISH@" ; species name
	dw 403, 890; height, width
	
	db "It was able to", $4e, "swim quickly thro-", $4e, "ugh the water by@"
	db "compactly folding", $4e, "up its razor-sharp", $4e, "sickles.@"
; 0x1cc576

AerodactylPokedexEntry: ; 0x1cc576
	db "FOSSIL@" ; species name
	dw 511, 1300; height, width
	
	db "In prehistoric", $4e, "times, this", $4e, "#MON flew@"
	db "freely and", $4e, "fearlessly through", $4e, "the skies.@"
; 0x1cc5cf

SnorlaxPokedexEntry: ; 0x1cc5cf
	db "SLEEPING@" ; species name
	dw 611, 10140; height, width
	
	db "This #MON's", $4e, "stomach is so", $4e, "strong, even@"
	db "eating moldy or", $4e, "rotten food will", $4e, "not affect it.@"
; 0x1cc632

ArticunoPokedexEntry: ; 0x1cc632
	db "FREEZE@" ; species name
	dw 507, 1220; height, width
	
	db "Legendary bird", $4e, "#MON. As it", $4e, "flies through the@"
	db "sky, it cools the", $4e, "air, causing snow", $4e, "to fall.@"
; 0x1cc697

ZapdosPokedexEntry: ; 0x1cc697
	db "ELECTRIC@" ; species name
	dw 503, 1160; height, width
	
	db "Legendary bird", $4e, "#MON. They say", $4e, "lightning caused@"
	db "by the flapping of", $4e, "its wings causes", $4e, "summer storms.@"
; 0x1cc706

MoltresPokedexEntry: ; 0x1cc706
	db "FLAME@" ; species name
	dw 607, 1320; height, width
	
	db "Legendary bird", $4e, "#MON. It is", $4e, "said to migrate@"
	db "from the south", $4e, "along with the", $4e, "spring.@"
; 0x1cc761

DratiniPokedexEntry: ; 0x1cc761
	db "DRAGON@" ; species name
	dw 511, 70; height, width
	
	db "It sheds many lay-", $4e, "ers of skin as it", $4e, "grows larger. Dur-@"
	db "ing this process,", $4e, "it is protected by", $4e, "a rapid waterfall.@"
; 0x1cc7dc

DragonairPokedexEntry: ; 0x1cc7dc
	db "DRAGON@" ; species name
	dw 1301, 360; height, width
	
	db "It is called the", $4e, "divine #MON.", $4e, "When its entire@"
	db "body brightens", $4e, "slightly, the", $4e, "weather changes.@"
; 0x1cc843

DragonitePokedexEntry: ; 0x1cc843
	db "DRAGON@" ; species name
	dw 703, 4630; height, width
	
	db "It is said that", $4e, "somewhere in the", $4e, "ocean lies an@"
	db "island where these", $4e, "gather. Only they", $4e, "live there.@"
; 0x1cc8ae

MewtwoPokedexEntry: ; 0x1cc8ae
	db "GENETIC@" ; species name
	dw 607, 2690; height, width
	
	db "Said to rest qui-", $4e, "etly in an", $4e, "undiscovered cave,@"
	db "this #MON was", $4e, "created solely for", $4e, "battling.@"
; 0x1cc915

MewPokedexEntry: ; 0x1cc915
	db "NEW SPECIE@" ; species name
	dw 104, 90; height, width
	
	db "Because it can", $4e, "learn any move,", $4e, "some people began@"
	db "research to see if", $4e, "it is the ancestor", $4e, "of all #MON.@"
; 0x1cc988

ChikoritaPokedexEntry: ; 0x1cc988
	db "LEAF@" ; species name
	dw 211, 140; height, width
	
	db "It loves to bask", $4e, "in the sunlight.", $4e, "It uses the leaf@"
	db "on its head to", $4e, "seek out warm", $4e, "places.@"
; 0x1cc9e9

BayleefPokedexEntry: ; 0x1cc9e9
	db "LEAF@" ; species name
	dw 311, 350; height, width
	
	db "The scent that", $4e, "wafts from the", $4e, "leaves on its neck@"
	db "causes anyone who", $4e, "smells it to", $4e, "become energetic.@"
; 0x1cca54

MeganiumPokedexEntry: ; 0x1cca54
	db "HERB@" ; species name
	dw 511, 2220; height, width
	
	db "Anyone who stands", $4e, "beside it becomes", $4e, "refreshed, just as@"
	db "if they were", $4e, "relaxing in a", $4e, "sunny forest.@"
; 0x1ccabd

CyndaquilPokedexEntry: ; 0x1ccabd
	db "FIRE MOUSE@" ; species name
	dw 108, 170; height, width
	
	db "The fire that", $4e, "spouts from its", $4e, "back burns hottest@"
	db "when it is angry.", $4e, "The flaring flames", $4e, "intimidate foes.@"
; 0x1ccb33

QuilavaPokedexEntry: ; 0x1ccb33
	db "VOLCANO@" ; species name
	dw 211, 420; height, width
	
	db "Before battle, it", $4e, "turns its back on", $4e, "its opponent to@"
	db "demonstrate how", $4e, "ferociously its", $4e, "fire blazes.@"
; 0x1ccba0

TyphlosionPokedexEntry: ; 0x1ccba0
	db "VOLCANO@" ; species name
	dw 507, 1750; height, width
	
	db "When heat from its", $4e, "body causes the", $4e, "air around it to@"
	db "shimmer, this is a", $4e, "sign that it is", $4e, "ready to battle.@"
; 0x1ccc14

TotodilePokedexEntry: ; 0x1ccc14
	db "BIG JAW@" ; species name
	dw 200, 210; height, width
	
	db "This rough critter", $4e, "chomps at any", $4e, "moving object it@"
	db "sees. Turning your", $4e, "back on it is not", $4e, "recommended.@"
; 0x1ccc84

CroconawPokedexEntry: ; 0x1ccc84
	db "BIG JAW@" ; species name
	dw 307, 550; height, width
	
	db "The tips of its", $4e, "fangs are slanted", $4e, "backward. Once@"
	db "those fangs clamp", $4e, "down, the prey has", $4e, "no hope of escape.@"
; 0x1cccf9

FeraligatrPokedexEntry: ; 0x1cccf9
	db "BIG JAW@" ; species name
	dw 707, 1960; height, width
	
	db "Although it has a", $4e, "massive body, its", $4e, "powerful hind legs@"
	db "enable it to move", $4e, "quickly, even on", $4e, "the ground.@"
; 0x1ccd6b

SentretPokedexEntry: ; 0x1ccd6b
	db "SCOUT@" ; species name
	dw 207, 130; height, width
	
	db "When acting as a", $4e, "lookout, it warns", $4e, "others of danger@"
	db "by screeching and", $4e, "hitting the ground", $4e, "with its tail.@"
; 0x1ccddd

FurretPokedexEntry: ; 0x1ccddd
	db "LONG BODY@" ; species name
	dw 511, 720; height, width
	
	db "It lives in narrow", $4e, "burrows that fit", $4e, "its slim body. The@"
	db "deeper the nests", $4e, "go, the more maze-", $4e, "like they become.@"
; 0x1cce58

HoothootPokedexEntry: ; 0x1cce58
	db "OWL@" ; species name
	dw 204, 470; height, width
	
	db "It begins to hoot", $4e, "at the same time", $4e, "every day. Some@"
	db "trainers use them", $4e, "in place of", $4e, "clocks.@"
; 0x1cceb9

NoctowlPokedexEntry: ; 0x1cceb9
	db "OWL@" ; species name
	dw 503, 900; height, width
	
	db "Its extremely soft", $4e, "feathers make no", $4e, "sound in flight.@"
	db "It silently sneaks", $4e, "up on prey without", $4e, "being detected.@"
; 0x1ccf2c

LedybaPokedexEntry: ; 0x1ccf2c
	db "FIVE STAR@" ; species name
	dw 303, 240; height, width
	
	db "It is timid and", $4e, "clusters together", $4e, "with others. The@"
	db "fluid secreted by", $4e, "its feet indicates", $4e, "its location.@"
; 0x1ccfa0

LedianPokedexEntry: ; 0x1ccfa0
	db "FIVE STAR@" ; species name
	dw 407, 780; height, width
	
	db "In the daytime", $4e, "when it gets warm,", $4e, "it curls up inside@"
	db "a big leaf and", $4e, "drifts off into", $4e, "a deep slumber.@"
; 0x1cd012

SpinarakPokedexEntry: ; 0x1cd012
	db "STRINGSPIT@" ; species name
	dw 108, 190; height, width
	
	db "If prey becomes", $4e, "ensnared in its", $4e, "nest of spun@"
	db "string, it waits", $4e, "motionlessly until", $4e, "it becomes dark.@"
; 0x1cd083

AriadosPokedexEntry: ; 0x1cd083
	db "LONG LEG@" ; species name
	dw 307, 740; height, width
	
	db "Rather than mak-", $4e, "ing a nest in one", $4e, "specific spot, it@"
	db "wanders in search", $4e, "of food after", $4e, "darkness falls.@"
; 0x1cd0f5

CrobatPokedexEntry: ; 0x1cd0f5
	db "BAT@" ; species name
	dw 511, 1650; height, width
	
	db "As a result of its", $4e, "pursuit of faster,", $4e, "yet more silent@"
	db "flight, a new set", $4e, "of wings grew on", $4e, "its hind legs.@"
; 0x1cd165

ChinchouPokedexEntry: ; 0x1cd165
	db "ANGLER@" ; species name
	dw 108, 260; height, width
	
	db "Its antennae, whi-", $4e, "ch evolved from a", $4e, "fin, have both po-@"
	db "sitive and neg-", $4e, "ative charges flo-", $4e, "wing through them.@"
; 0x1cd1de

LanturnPokedexEntry: ; 0x1cd1de
	db "LIGHT@" ; species name
	dw 311, 500; height, width
	
	db "This #MON uses", $4e, "the bright part of", $4e, "its body, which@"
	db "changed from a", $4e, "dorsal fin, to", $4e, "lure prey.@"
; 0x1cd243

PichuPokedexEntry: ; 0x1cd243
	db "TINY MOUSE@" ; species name
	dw 100, 40; height, width
	
	db "It is unskilled at", $4e, "storing electric", $4e, "power. Any kind of@"
	db "shock causes it to", $4e, "discharge energy", $4e, "spontaneously.@"
; 0x1cd2bc

CleffaPokedexEntry: ; 0x1cd2bc
	db "STARSHAPE@" ; species name
	dw 100, 70; height, width
	
	db "If the impact site", $4e, "of a meteorite is", $4e, "found, this@"
	db "#MON is certain", $4e, "to be within the", $4e, "immediate area.@"
; 0x1cd32c

IgglybuffPokedexEntry: ; 0x1cd32c
	db "BALLOON@" ; species name
	dw 100, 20; height, width
	
	db "Instead of walking", $4e, "with its short", $4e, "legs, it moves@"
	db "around by bouncing", $4e, "on its soft,", $4e, "tender body.@"
; 0x1cd396

TogepiPokedexEntry: ; 0x1cd396
	db "SPIKE BALL@" ; species name
	dw 100, 30; height, width
	
	db "It is considered", $4e, "to be a symbol of", $4e, "good luck. Its@"
	db "shell is said to", $4e, "be filled with", $4e, "happiness.@"
; 0x1cd402

TogeticPokedexEntry: ; 0x1cd402
	db "HAPPINESS@" ; species name
	dw 200, 70; height, width
	
	db "Although it does", $4e, "not flap its wings", $4e, "very much, it can@"
	db "stay up in the air", $4e, "as it tags along", $4e, "after its trainer.@"
; 0x1cd47d

NatuPokedexEntry: ; 0x1cd47d
	db "LITTLE BIRD@" ; species name
	dw 8, 40; height, width
	
	db "It is extremely", $4e, "good at climbing", $4e, "tree trunks and@"
	db "likes to eat the", $4e, "new sprouts on", $4e, "the trees.@"
; 0x1cd4e9

XatuPokedexEntry: ; 0x1cd4e9
	db "MYSTIC@" ; species name
	dw 411, 330; height, width
	
	db "Once it begins to", $4e, "meditate at sun-", $4e, "rise, the entire@"
	db "day will pass", $4e, "before it will", $4e, "move again.@"
; 0x1cd551

MareepPokedexEntry: ; 0x1cd551
	db "WOOL@" ; species name
	dw 200, 170; height, width
	
	db "It stores lots of", $4e, "air in its soft", $4e, "fur, allowing it@"
	db "to stay cool in", $4e, "summer and warm", $4e, "in winter.@"
; 0x1cd5b8

FlaaffyPokedexEntry: ; 0x1cd5b8
	db "WOOL@" ; species name
	dw 207, 290; height, width
	
	db "Because of its", $4e, "rubbery, electric-", $4e, "ity-resistant@"
	db "skin, it can store", $4e, "lots of electric-", $4e, "ity in its fur.@"
; 0x1cd626

AmpharosPokedexEntry: ; 0x1cd626
	db "LIGHT@" ; species name
	dw 407, 1360; height, width
	
	db "When it gets dark,", $4e, "the light from its", $4e, "bright, shiny tail@"
	db "can be seen from", $4e, "far away on the", $4e, "ocean's surface.@"
; 0x1cd69a

BellossomPokedexEntry: ; 0x1cd69a
	db "FLOWER@" ; species name
	dw 104, 130; height, width
	
	db "When these dance", $4e, "together, their", $4e, "petals rub against@"
	db "each other,", $4e, "making pretty,", $4e, "relaxing sounds.@"
; 0x1cd705

MarillPokedexEntry: ; 0x1cd705
	db "AQUAMOUSE@" ; species name
	dw 104, 190; height, width
	
	db "The fur on its", $4e, "body naturally", $4e, "repels water. It@"
	db "can stay dry, even", $4e, "when it plays in", $4e, "the water.@"
; 0x1cd771

AzumarillPokedexEntry: ; 0x1cd771
	db "AQUARABBIT@" ; species name
	dw 207, 630; height, width
	
	db "The bubble-like", $4e, "pattern on its", $4e, "stomach helps it@"
	db "camouflage itself", $4e, "when it's in the", $4e, "water.@"
; 0x1cd7d9

SudowoodoPokedexEntry: ; 0x1cd7d9
	db "IMITATION@" ; species name
	dw 311, 840; height, width
	
	db "If a tree branch", $4e, "shakes when there", $4e, "is no wind, it's a@"
	db "SUDOWOODO, not a", $4e, "tree. It hides", $4e, "from the rain.@"
; 0x1cd84b

PolitoedPokedexEntry: ; 0x1cd84b
	db "FROG@" ; species name
	dw 307, 750; height, width
	
	db "When it expands", $4e, "its throat to", $4e, "croak out a tune,@"
	db "nearby POLIWAG and", $4e, "POLIWHIRL gather", $4e, "immediately.@"
; 0x1cd8b5

HoppipPokedexEntry: ; 0x1cd8b5
	db "COTTONWEED@" ; species name
	dw 104, 10; height, width
	
	db "It can be carried", $4e, "away on even the", $4e, "gentlest breeze.@"
	db "It may even float", $4e, "all the way to the", $4e, "next town.@"
; 0x1cd928

SkiploomPokedexEntry: ; 0x1cd928
	db "COTTONWEED@" ; species name
	dw 200, 20; height, width
	
	db "As soon as it", $4e, "rains, it closes", $4e, "its flower and@"
	db "hides in the shade", $4e, "of a tree to avoid", $4e, "getting wet.@"
; 0x1cd998

JumpluffPokedexEntry: ; 0x1cd998
	db "COTTONWEED@" ; species name
	dw 207, 70; height, width
	
	db "Even in the fierc-", $4e, "est wind, it can", $4e, "control its fluff@"
	db "to make its way to", $4e, "any place in the", $4e, "world it wants.@"
; 0x1cda11

AipomPokedexEntry: ; 0x1cda11
	db "LONG TAIL@" ; species name
	dw 207, 250; height, width
	
	db "It uses its tail", $4e, "to hang on to tree", $4e, "branches. It uses@"
	db "its momentum to", $4e, "swing from one", $4e, "branch to another.@"
; 0x1cda87

SunkernPokedexEntry: ; 0x1cda87
	db "SEED@" ; species name
	dw 100, 40; height, width
	
	db "It is very weak.", $4e, "Its only means of", $4e, "defense is to@"
	db "shake its leaves", $4e, "desperately at its", $4e, "attacker.@"
; 0x1cdaef

SunfloraPokedexEntry: ; 0x1cdaef
	db "SUN@" ; species name
	dw 207, 190; height, width
	
	db "As the hot season", $4e, "approaches, the", $4e, "petals on this@"
	db "#MON's face", $4e, "become more vivid", $4e, "and lively.@"
; 0x1cdb51


SECTION "bank74",DATA,BANK[$74]

YanmaPokedexEntry: ; 0x1d0000
	db "CLEAR WING@" ; species name
	dw 311, 840; height, width
	
	db "It can see in all", $4e, "directions without", $4e, "moving its big@"
	db "eyes, helping it", $4e, "spot attackers and", $4e, "food right away.@"
; 0x1d0078

WooperPokedexEntry: ; 0x1d0078
	db "WATER FISH@" ; species name
	dw 104, 190; height, width
	
	db "A mucous", $4e, "membrane covers", $4e, "its body. Touching@"
	db "it barehanded will", $4e, "cause a shooting", $4e, "pain.@"
; 0x1d00dd

QuagsirePokedexEntry: ; 0x1d00dd
	db "WATER FISH@" ; species name
	dw 407, 1650; height, width
	
	db "Its body is always", $4e, "slimy. It often", $4e, "bangs its head on@"
	db "the river bottom", $4e, "as it swims but", $4e, "seems not to care.@"
; 0x1d0155

EspeonPokedexEntry: ; 0x1d0155
	db "SUN@" ; species name
	dw 211, 580; height, width
	
	db "The tip of its", $4e, "forked tail", $4e, "quivers when it is@"
	db "predicting its", $4e, "opponent's next", $4e, "move.@"
; 0x1d01af

UmbreonPokedexEntry: ; 0x1d01af
	db "MOONLIGHT@" ; species name
	dw 303, 600; height, width
	
	db "On the night of a", $4e, "full moon, or when", $4e, "it gets excited,@"
	db "the ring patterns", $4e, "on its body glow", $4e, "yellow.@"
; 0x1d021e

MurkrowPokedexEntry: ; 0x1d021e
	db "DARKNESS@" ; species name
	dw 108, 50; height, width
	
	db "It hides any shiny", $4e, "object it finds in", $4e, "a secret location.@"
	db "MURKROW and", $4e, "MEOWTH loot one", $4e, "another's stashes.@"
; 0x1d0292

SlowkingPokedexEntry: ; 0x1d0292
	db "ROYAL@" ; species name
	dw 607, 1750; height, width
	
	db "Every time it ya-", $4e, "wns, SHELLDER", $4e, "injects more poi-@"
	db "son into it. The", $4e, "poison makes it", $4e, "more intelligent.@"
; 0x1d0301

MisdreavusPokedexEntry: ; 0x1d0301
	db "SCREECH@" ; species name
	dw 204, 20; height, width
	
	db "It loves to watch", $4e, "people it's scar-", $4e, "ed. It frightens@"
	db "them by screaming", $4e, "loudly or appear-", $4e, "ing suddenly.@"
; 0x1d0373

UnownPokedexEntry: ; 0x1d0373
	db "SYMBOL@" ; species name
	dw 108, 110; height, width
	
	db "Because different", $4e, "types of UNOWN", $4e, "exist, it is said@"
	db "that they must", $4e, "have a variety of", $4e, "abilities.@"
; 0x1d03dd

WobbuffetPokedexEntry: ; 0x1d03dd
	db "PATIENT@" ; species name
	dw 403, 630; height, width
	
	db "In order to con-", $4e, "ceal its black", $4e, "tail, it lives in@"
	db "a dark cave and", $4e, "only moves about", $4e, "at night.@"
; 0x1d0446

GirafarigPokedexEntry: ; 0x1d0446
	db "LONG NECK@" ; species name
	dw 411, 910; height, width
	
	db "When it is in", $4e, "danger, its tail", $4e, "uses some sort of@"
	db "mysterious powers", $4e, "to drive away the", $4e, "enemy.@"
; 0x1d04b0

PinecoPokedexEntry: ; 0x1d04b0
	db "BAGWORM@" ; species name
	dw 200, 160; height, width
	
	db "It spits out a", $4e, "fluid that it uses", $4e, "to glue tree bark@"
	db "to its body. The", $4e, "fluid hardens when", $4e, "it touches air.@"
; 0x1d0524

ForretressPokedexEntry: ; 0x1d0524
	db "BAGWORM@" ; species name
	dw 311, 2770; height, width
	
	db "Usually found", $4e, "hanging on to a", $4e, "fat tree trunk. It@"
	db "shoots out bits of", $4e, "its shell when it", $4e, "sees action.@"
; 0x1d0593

DunsparcePokedexEntry: ; 0x1d0593
	db "LAND SNAKE@" ; species name
	dw 411, 310; height, width
	
	db "It hides deep", $4e, "inside caves where", $4e, "no light ever@"
	db "reaches it and", $4e, "remains virtually", $4e, "motionless there.@"
; 0x1d0604

GligarPokedexEntry: ; 0x1d0604
	db "FLYSCORPIO@" ; species name
	dw 307, 1430; height, width
	
	db "It builds its nest", $4e, "on a steep cliff.", $4e, "When it is done@"
	db "gliding, it hops", $4e, "along the ground", $4e, "back to its nest.@"
; 0x1d067c

SteelixPokedexEntry: ; 0x1d067c
	db "IRON SNAKE@" ; species name
	dw 3002, 8820; height, width
	
	db "The many small", $4e, "metal particles", $4e, "that cover this@"
	db "#MON's body", $4e, "reflect bright", $4e, "light well.@"
; 0x1d06e0

SnubbullPokedexEntry: ; 0x1d06e0
	db "FAIRY@" ; species name
	dw 200, 170; height, width
	
	db "In truth, it is a", $4e, "cowardly #MON.", $4e, "It growls eagerly@"
	db "in order to hide", $4e, "its fear from its", $4e, "opponent.@"
; 0x1d074a

GranbullPokedexEntry: ; 0x1d074a
	db "FAIRY@" ; species name
	dw 407, 1070; height, width
	
	db "It can make most", $4e, "any #MON run", $4e, "away simply by@"
	db "opening its mouth", $4e, "wide to reveal its", $4e, "big fangs.@"
; 0x1d07b1

QwilfishPokedexEntry: ; 0x1d07b1
	db "BALLOON@" ; species name
	dw 108, 90; height, width
	
	db "When faced with a", $4e, "larger opponent,", $4e, "it swallows as@"
	db "much water as it", $4e, "can to match the", $4e, "opponent's size.@"
; 0x1d0821

ScizorPokedexEntry: ; 0x1d0821
	db "SCISSORS@" ; species name
	dw 511, 2600; height, width
	
	db "This #MON's", $4e, "pincers, which", $4e, "contain steel, can@"
	db "crush any hard", $4e, "object it gets a", $4e, "hold of into bits.@"
; 0x1d088e

ShucklePokedexEntry: ; 0x1d088e
	db "MOLD@" ; species name
	dw 200, 450; height, width
	
	db "The fluid secreted", $4e, "by its toes carves", $4e, "holes in rocks for@"
	db "nesting and can be", $4e, "mixed with BERRIES", $4e, "to make a drink.@"
; 0x1d0907

HeracrossPokedexEntry: ; 0x1d0907
	db "SINGLEHORN@" ; species name
	dw 411, 1190; height, width
	
	db "With its Herculean", $4e, "powers, it can", $4e, "easily throw arou-@"
	db "nd an object that", $4e, "is 100 times its", $4e, "own weight.@"
; 0x1d097a

SneaselPokedexEntry: ; 0x1d097a
	db "SHARP CLAW@" ; species name
	dw 211, 620; height, width
	
	db "This cunning", $4e, "#MON hides", $4e, "under the cover@"
	db "of darkness,", $4e, "waiting to attack", $4e, "its prey.@"
; 0x1d09da

TeddiursaPokedexEntry: ; 0x1d09da
	db "LITTLE BEAR@" ; species name
	dw 200, 190; height, width
	
	db "It always licks", $4e, "honey. Its palm", $4e, "tastes sweet@"
	db "because of all the", $4e, "honey it has", $4e, "absorbed.@"
; 0x1d0a41

UrsaringPokedexEntry: ; 0x1d0a41
	db "HIBERNANT@" ; species name
	dw 511, 2770; height, width
	
	db "Although it has a", $4e, "large body, it is", $4e, "quite skilled at@"
	db "climbing trees. It", $4e, "eats and sleeps in", $4e, "the treetops.@"
; 0x1d0ab8

SlugmaPokedexEntry: ; 0x1d0ab8
	db "LAVA@" ; species name
	dw 204, 770; height, width
	
	db "These group to-", $4e, "gether in areas", $4e, "that are hotter@"
	db "than normal. If it", $4e, "cools off, its", $4e, "skin hardens.@"
; 0x1d0b21

MagcargoPokedexEntry: ; 0x1d0b21
	db "LAVA@" ; species name
	dw 207, 1210; height, width
	
	db "Its body is as hot", $4e, "as lava and is", $4e, "always billowing.@"
	db "Flames will", $4e, "occasionally burst", $4e, "from its shell.@"
; 0x1d0b8d

SwinubPokedexEntry: ; 0x1d0b8d
	db "PIG@" ; species name
	dw 104, 140; height, width
	
	db "It uses the tip of", $4e, "its nose to dig", $4e, "for food. Its nose@"
	db "is so tough that", $4e, "even frozen ground", $4e, "poses no problem.@"
; 0x1d0c01

PiloswinePokedexEntry: ; 0x1d0c01
	db "SWINE@" ; species name
	dw 307, 1230; height, width
	
	db "Although its legs", $4e, "are short, its", $4e, "rugged hooves@"
	db "prevent it from", $4e, "slipping, even on", $4e, "icy ground.@"
; 0x1d0c68

CorsolaPokedexEntry: ; 0x1d0c68
	db "CORAL@" ; species name
	dw 200, 110; height, width
	
	db "The points on its", $4e, "head absorb", $4e, "nutrients from@"
	db "clean water. They", $4e, "cannot survive in", $4e, "polluted water.@"
; 0x1d0cd3

RemoraidPokedexEntry: ; 0x1d0cd3
	db "JET@" ; species name
	dw 200, 260; height, width
	
	db "To escape from an", $4e, "attacker, it may", $4e, "shoot water out of@"
	db "its mouth, then", $4e, "use that force to", $4e, "swim backward.@"
; 0x1d0d42

OctilleryPokedexEntry: ; 0x1d0d42
	db "JET@" ; species name
	dw 211, 630; height, width
	
	db "Its instinct is to", $4e, "bury itself in", $4e, "holes. It often@"
	db "steals the nesting", $4e, "holes of others to", $4e, "sleep in them.@"
; 0x1d0db1

DelibirdPokedexEntry: ; 0x1d0db1
	db "DELIVERY@" ; species name
	dw 211, 350; height, width
	
	db "It always carries", $4e, "its food with it,", $4e, "wherever it goes.@"
	db "If attacked, it", $4e, "throws its food at", $4e, "the opponent.@"
; 0x1d0e25

MantinePokedexEntry: ; 0x1d0e25
	db "KITE@" ; species name
	dw 611, 4850; height, width
	
	db "It swims along", $4e, "freely, eating", $4e, "things that swim@"
	db "into its mouth.", $4e, "Its whole body is", $4e, "very coarse.@"
; 0x1d0e8c

SkarmoryPokedexEntry: ; 0x1d0e8c
	db "ARMOR BIRD@" ; species name
	dw 507, 1110; height, width
	
	db "The feathers that", $4e, "it sheds are very", $4e, "sharp. It is said@"
	db "that people once", $4e, "used the feathers", $4e, "as swords.@"
; 0x1d0eff

HoundourPokedexEntry: ; 0x1d0eff
	db "DARK@" ; species name
	dw 200, 240; height, width
	
	db "Around dawn, its", $4e, "ominous howl", $4e, "echoes through the@"
	db "area to announce", $4e, "that this is its", $4e, "territory.@"
; 0x1d0f66

HoundoomPokedexEntry: ; 0x1d0f66
	db "DARK@" ; species name
	dw 407, 770; height, width
	
	db "The pungent-", $4e, "smelling flame", $4e, "that shoots from@"
	db "its mouth results", $4e, "from toxins burn-", $4e, "ing in its body.@"
; 0x1d0fd1

KingdraPokedexEntry: ; 0x1d0fd1
	db "DRAGON@" ; species name
	dw 511, 3350; height, width
	
	db "It stores energy", $4e, "by sleeping at", $4e, "underwater depths@"
	db "at which no other", $4e, "life forms can", $4e, "survive.@"
; 0x1d1038

PhanpyPokedexEntry: ; 0x1d1038
	db "LONG NOSE@" ; species name
	dw 108, 740; height, width
	
	db "During the desert-", $4e, "ed morning hours,", $4e, "it comes ashore@"
	db "where it deftly", $4e, "uses its trunk to", $4e, "take a shower.@"
; 0x1d10ac

DonphanPokedexEntry: ; 0x1d10ac
	db "ARMOR@" ; species name
	dw 307, 2650; height, width
	
	db "Because this", $4e, "#MON's skin is", $4e, "so tough, a normal@"
	db "attack won't even", $4e, "leave a scratch on", $4e, "it.@"
; 0x1d110c

Porygon2PokedexEntry: ; 0x1d110c
	db "VIRTUAL@" ; species name
	dw 200, 720; height, width
	
	db "This manmade", $4e, "#MON evolved", $4e, "from the latest@"
	db "technology. It", $4e, "may have unprog-", $4e, "rammed reactions.@"
; 0x1d1174

StantlerPokedexEntry: ; 0x1d1174
	db "BIG HORN@" ; species name
	dw 407, 1570; height, width
	
	db "The round balls", $4e, "found on the", $4e, "fallen antlers can@"
	db "be ground into a", $4e, "powder that aids", $4e, "in sleeping.@"
; 0x1d11e0

SmearglePokedexEntry: ; 0x1d11e0
	db "PAINTER@" ; species name
	dw 311, 1280; height, width
	
	db "The color of the", $4e, "mysterious fluid", $4e, "secreted from its@"
	db "tail is predeter-", $4e, "mined for each", $4e, "SMEARGLE.@"
; 0x1d124b

TyroguePokedexEntry: ; 0x1d124b
	db "SCUFFLE@" ; species name
	dw 204, 460; height, width
	
	db "To brush up on its", $4e, "fighting skills,", $4e, "it will challenge@"
	db "anyone. It has a", $4e, "very strong com-", $4e, "petitive spirit.@"
; 0x1d12c0

HitmontopPokedexEntry: ; 0x1d12c0
	db "HANDSTAND@" ; species name
	dw 407, 1060; height, width
	
	db "After doing a", $4e, "handstand to", $4e, "throw off the@"
	db "opponent's timing,", $4e, "it presents its", $4e, "fancy kick moves.@"
; 0x1d132b

SmoochumPokedexEntry: ; 0x1d132b
	db "KISS@" ; species name
	dw 104, 130; height, width
	
	db "The sensitivity of", $4e, "its lips develops", $4e, "most quickly.@"
	db "It uses them to", $4e, "try to identify", $4e, "unknown objects.@"
; 0x1d1398

ElekidPokedexEntry: ; 0x1d1398
	db "ELECTRIC@" ; species name
	dw 200, 520; height, width
	
	db "It loves violent", $4e, "thunder. The space", $4e, "between its horns@"
	db "flickers bluish-", $4e, "white when it is", $4e, "charging energy.@"
; 0x1d140e

MagbyPokedexEntry: ; 0x1d140e
	db "LIVE COAL@" ; species name
	dw 204, 470; height, width
	
	db "It naturally spits", $4e, "an 1100-degree", $4e, "flame. It is said@"
	db "when many appear,", $4e, "it heralds a", $4e, "volcanic eruption.@"
; 0x1d1482

MiltankPokedexEntry: ; 0x1d1482
	db "MILK COW@" ; species name
	dw 311, 1660; height, width
	
	db "In order to milk a", $4e, "MILTANK, one must", $4e, "have a knack for@"
	db "rhythmically pull-", $4e, "ing up and down", $4e, "on its udders.@"
; 0x1d14f7

BlisseyPokedexEntry: ; 0x1d14f7
	db "HAPPINESS@" ; species name
	dw 411, 1030; height, width
	
	db "Biting into one", $4e, "of the delicious", $4e, "eggs that BLISSEY@"
	db "provides will make", $4e, "everyone around", $4e, "smile with joy.@"
; 0x1d156b

RaikouPokedexEntry: ; 0x1d156b
	db "THUNDER@" ; species name
	dw 603, 3920; height, width
	
	db "This rough #MON", $4e, "stores energy", $4e, "inside its body,@"
	db "then sweeps across", $4e, "the land, shooting", $4e, "off electricity.@"
; 0x1d15dd

EnteiPokedexEntry: ; 0x1d15dd
	db "VOLCANO@" ; species name
	dw 607, 4370; height, width
	
	db "This brawny", $4e, "#MON courses", $4e, "around the earth,@"
	db "spouting flames", $4e, "hotter than a", $4e, "volcano's magma.@"
; 0x1d1642

SuicunePokedexEntry: ; 0x1d1642
	db "AURORA@" ; species name
	dw 607, 4120; height, width
	
	db "This divine", $4e, "#MON blows", $4e, "around the world,@"
	db "always in search", $4e, "of a pure", $4e, "reservoir.@"
; 0x1d169c

LarvitarPokedexEntry: ; 0x1d169c
	db "ROCK SKIN@" ; species name
	dw 200, 1590; height, width
	
	db "Born deep under-", $4e, "ground, this", $4e, "#MON becomes a@"
	db "pupa after eating", $4e, "enough dirt to", $4e, "make a mountain.@"
; 0x1d1709

PupitarPokedexEntry: ; 0x1d1709
	db "HARD SHELL@" ; species name
	dw 311, 3350; height, width
	
	db "It will not stay", $4e, "still, even while", $4e, "it's a pupa. It@"
	db "already has arms", $4e, "and legs under its", $4e, "solid shell.@"
; 0x1d177b

TyranitarPokedexEntry: ; 0x1d177b
	db "ARMOR@" ; species name
	dw 607, 4450; height, width
	
	db "In just one of its", $4e, "mighty hands, it", $4e, "has the power to@"
	db "make the ground", $4e, "shake and moun-", $4e, "tains crumble.@"
; 0x1d17e9

LugiaPokedexEntry: ; 0x1d17e9
	db "DIVING@" ; species name
	dw 1701, 4760; height, width
	
	db "It has an incred-", $4e, "ible ability to", $4e, "calm raging sto-@"
	db "rms. It is said", $4e, "that LUGIA appears", $4e, "when storms start.@"
; 0x1d185d

HoOhPokedexEntry: ; 0x1d185d
	db "RAINBOW@" ; species name
	dw 1206, 4390; height, width
	
	db "It will reveal", $4e, "itself before a", $4e, "pure-hearted@"
	db "trainer by shining", $4e, "its bright rain-", $4e, "bow-colored wings.@"
; 0x1d18cc

CelebiPokedexEntry: ; 0x1d18cc
	db "TIMETRAVEL@" ; species name
	dw 200, 110; height, width
	
	db "Revered as a", $4e, "guardian of the", $4e, "forest, CELEBI@"
	db "appears wherever", $4e, "beautiful forests", $4e, "exist.@"
; 0x1d1931

SECTION "bank75",DATA,BANK[$75]

SECTION "bank76",DATA,BANK[$76]

SECTION "bank77",DATA,BANK[$77]

SECTION "bank77",DATA,BANK[$77]

INCBIN "baserom.gbc", $1dc000, $1dc5a1 - $1dc000

Tileset26GFX:
Tileset32GFX:
Tileset33GFX:
Tileset34GFX:
Tileset35GFX:
Tileset36GFX: ; 1dc5a1
INCBIN "gfx/tilesets/lz/26.lz"
; 1dd1a8

INCBIN "baserom.gbc", $1dd1a8, $1de29f - $1dd1a8


DudeAutoInput_A: ; 1de29f
	db NO_INPUT, $50
	db BUTTON_A, $00
	db NO_INPUT, $ff ; end
; 1de2a5
	
DudeAutoInput_RightA: ; 1de2a5
	db NO_INPUT, $08
	db D_RIGHT,  $00
	db NO_INPUT, $08
	db BUTTON_A, $00
	db NO_INPUT, $ff ; end
; 1de2af
	
DudeAutoInput_DownA: ; 1de2af
	db NO_INPUT, $fe
	db NO_INPUT, $fe
	db NO_INPUT, $fe
	db NO_INPUT, $fe
	db D_DOWN,   $00
	db NO_INPUT, $fe
	db NO_INPUT, $fe
	db NO_INPUT, $fe
	db NO_INPUT, $fe
	db BUTTON_A, $00
	db NO_INPUT, $ff ; end
; 1de2c5


INCBIN "baserom.gbc",$1de2c5,$1de2e4 - $1de2c5

PokegearGFX: ; 1de2e4
INCBIN "gfx/misc/lz/pokegear.lz"
; 1de5c6

INCBIN "baserom.gbc",$1de5c6,$1e0000 - $1de5c6


SECTION "bank78",DATA,BANK[$78]

INCBIN "baserom.gbc",$1E0000,$4000

SECTION "bank79",DATA,BANK[$79]

SECTION "bank7A",DATA,BANK[$7A]

SECTION "bank7B",DATA,BANK[$7B]

INCBIN "baserom.gbc",$1EC000,$4000

SECTION "bank7C",DATA,BANK[$7C]

INCBIN "baserom.gbc",$1F0000,$4000

SECTION "bank7D",DATA,BANK[$7D]

INCBIN "baserom.gbc",$1F4000,$4000

SECTION "bank7E",DATA,BANK[$7E]

INCBIN "baserom.gbc",$1F8000,$4000

SECTION "bank7F",DATA,BANK[$7F]

INCBIN "baserom.gbc",$1FC000,$4000
